(function () {
    'use strict';

    class ControllerManager {
        static start(c) {
            this.root = c;
            c.start();
        }
    }

    class GameConfig {
        constructor() {
        }
        static init() {
            var reg = Laya.ClassUtils.regClass;
        }
    }
    GameConfig.width = 1280;
    GameConfig.height = 720;
    GameConfig.scaleMode = "fixedheight";
    GameConfig.screenMode = "horizontal";
    GameConfig.alignV = "top";
    GameConfig.alignH = "left";
    GameConfig.startScene = "page/Page.scene";
    GameConfig.sceneRoot = "";
    GameConfig.debug = false;
    GameConfig.stat = false;
    GameConfig.physicsDebug = false;
    GameConfig.exportSceneToJson = true;
    GameConfig.init();

    class EventDispatchers {
        constructor() {
            this.eventDispatcher = new Laya.EventDispatcher();
        }
        addEventListener(type, caller, listener) {
            this.eventDispatcher.on(type, caller, listener);
        }
        removeEventListener(type, caller, listener) {
            this.eventDispatcher.off(type, caller, listener);
        }
        onceEventListener(type, caller, listener) {
            this.eventDispatcher.once(type, caller, listener);
        }
        dispatchEvent(type, data) {
            this.eventDispatcher.event(type, data);
        }
    }

    class EventManager {
    }
    EventManager.event = new EventDispatchers();

    class MathUtil {
        static sin(x) {
            return Math.sin(this.angleToRadian(x));
        }
        static cos(x) {
            return Math.cos(this.angleToRadian(x));
        }
        static tan(x) {
            return Math.tan(this.angleToRadian(x));
        }
        static asin(x) {
            return this.radianToAngle(Math.asin(x));
        }
        static acos(x) {
            return this.radianToAngle(Math.acos(x));
        }
        static atan(x) {
            if (!x) {
                return 0;
            }
            return this.radianToAngle(Math.atan(x));
        }
        static atan2(y, x) {
            return this.radianToAngle(Math.atan2(y, x));
        }
        static angleToRadian(x) {
            return Math.PI / 180 * x;
        }
        static radianToAngle(x) {
            return x * 180 / Math.PI;
        }
        static div(x, y) {
            if (!y) {
                return 0;
            }
            if (!x) {
                return 0;
            }
            return x / y;
        }
        static int(v) {
            if (!v) {
                return 0;
            }
            return parseInt(v);
        }
        static number(v) {
            if (!v) {
                return 0;
            }
            return Number(v);
        }
        static string(v) {
            if (!v) {
                return '';
            }
            return v.toString();
        }
        static bool(v) {
            if (!v) {
                return false;
            }
            if (v == '') {
                return false;
            }
            if (v == 0) {
                return false;
            }
            if (v == '0') {
                return false;
            }
            if (v == 'true') {
                return true;
            }
            if (v == 'false') {
                return false;
            }
            return Boolean(v);
        }
        static randomInt(min, max) {
            min = Math.ceil(min);
            max = Math.floor(max);
            if (max <= min) {
                return min;
            }
            return Math.round(Math.random() * (max - min)) + min;
        }
        static randomNumber(min, max) {
            if (max <= min) {
                return min;
            }
            return (Math.random() * (max - min)) + min;
        }
        static randomHit(n) {
            if (n >= 1) {
                return true;
            }
            if (n <= 0) {
                return false;
            }
            var i = Math.random();
            if (i <= n) {
                return true;
            }
            return false;
        }
        static min(a, b) {
            if (isNaN(a)) {
                return b;
            }
            if (isNaN(b)) {
                return a;
            }
            return Math.min(a, b);
        }
        static clamp(value, min, max) {
            if (value < min) {
                return min;
            }
            if (value > max) {
                return max;
            }
            return value;
        }
        static checkRange(v, min, max) {
            if (v < min) {
                return min;
            }
            if (v > max) {
                return max;
            }
            return v;
        }
    }

    class TimeUtil {
        static getLocalTime() {
            return Laya.Browser.now();
        }
        static setTime(ms) {
            if (!ms) {
                this.startMs = 0;
                this.startLocalMs = 0;
            }
            else {
                this.startMs = ms;
                this.startLocalMs = this.getLocalTime();
            }
        }
        static getTime() {
            return this.getLocalTime() - this.startLocalMs + this.startMs;
        }
        static getTimestamp() {
            return MathUtil.int(this.getTime() / 1000);
        }
        static getZero(ms = 0) {
            if (!ms) {
                ms = this.getTime();
            }
            var d = new Date(ms);
            d.setHours(0);
            d.setMinutes(0);
            d.setSeconds(0);
            return d.getTime();
        }
        static getZeroTimestamp(ts = 0) {
            return MathUtil.int(this.getZero(ts * 1000) / 1000);
        }
        static getTomorrowZeroTimestamp() {
            return this.getZeroTimestamp() + 86400;
        }
        static getWeek() {
            var mydate = new Date(this.getTime());
            return mydate.getDay();
        }
        static getMondayZero() {
            var today = this.getZero();
            var week = this.getWeek();
            if (week == 0) {
                week = 6;
            }
            else {
                week--;
            }
            return today - week * 86400000;
            ;
        }
        static getMondayZeroTimestamp() {
            return MathUtil.int(this.getMondayZero() / 1000);
        }
    }
    TimeUtil.startMs = 0;
    TimeUtil.startLocalMs = 0;

    class IdUtil {
        static getId() {
            if (this.index == 0) {
                this.index = TimeUtil.getTime();
            }
            IdUtil.index++;
            return IdUtil.index;
        }
        static buildId() {
            var ts = TimeUtil.getLocalTime();
            if (this.buildTime < ts) {
                this.buildTime = ts;
                this.bid = 0;
            }
            else {
                this.bid++;
                if (this.bid >= 1000) {
                    this.buildTime++;
                    this.bid = 0;
                }
            }
            var id = this.buildTime * 1000 + this.bid;
            return id;
        }
    }
    IdUtil.index = 0;
    IdUtil.buildTime = 0;
    IdUtil.bid = 0;

    class CallManager {
        constructor() {
            this.list = [];
        }
        addHandler(type, caller, handler) {
            var callHandler = this.getHandler(type, caller, handler);
            if (callHandler == null) {
                this.list.push(new CallHandler(type, caller, handler));
            }
        }
        getHandler(type, caller, handler) {
            for (var element of this.list) {
                if (element.type == type && element.caller == caller && element.handler == handler) {
                    return element;
                }
            }
            return null;
        }
        clear() {
            this.list = [];
        }
    }
    class CallHandler {
        constructor(type, caller, handler) {
            this.type = type;
            this.caller = caller;
            this.handler = handler;
        }
    }

    class PoolUtil {
        static getObject(name, clas = null) {
            if (clas) {
                var obj = Laya.Pool.getItemByClass(name, clas);
                obj.poolName = name;
                obj.inPool = false;
            }
            else {
                var obj = Laya.Pool.getItem(name);
            }
            return obj;
        }
        static recover(obj) {
            if (obj && obj.hasOwnProperty("poolName")) {
                obj.inPool = true;
                Laya.Pool.recover(obj.poolName, obj);
            }
        }
        static sign(obj, name) {
            if (obj) {
                obj.poolName = name;
            }
        }
    }

    class Controller {
        constructor() {
            this.state = 0;
            this.parent = null;
            this.children = {};
            this.id = IdUtil.getId();
            this.callManager = new CallManager();
        }
        start() {
            this.state = 1;
            this.run();
        }
        stop() {
            if (this.state != 2) {
                this.state = 2;
                this.stopAllChild();
                this.removeAllEvent();
                if (this.parent) {
                    this.parent.removeChild(this.id);
                    this.parent = null;
                }
                this.data = null;
                PoolUtil.recover(this);
            }
        }
        run() {
        }
        addChild(controller) {
            controller.parent = this;
            this.children[controller.id] = controller;
        }
        removeChild(id) {
            var controller = this.children[id];
            if (controller) {
                delete this.children[id];
            }
            return controller;
        }
        startChild(controller) {
            controller.parent = this;
            this.children[controller.id] = controller;
            controller.start();
        }
        stopChild(id) {
            var controller = this.children[id];
            if (controller) {
                controller.stop();
                delete this.children[id];
            }
            return controller;
        }
        stopAllChild() {
            let list = this.children;
            for (var key in list) {
                if (list.hasOwnProperty(key)) {
                    var controller = list[key];
                    controller.stop();
                }
            }
            this.children = [];
        }
        getChild(id) {
            return this.children[id];
        }
        getChildByClass(clas) {
            for (var key in this.children) {
                if (this.children.hasOwnProperty(key)) {
                    var element = this.children[key];
                    if (element instanceof clas) {
                        return element;
                    }
                }
            }
            return null;
        }
        getChildren() {
            return this.children;
        }
        addEventListener(type, caller, listener) {
            this.callManager.addHandler(type, caller, listener);
            EventManager.event.addEventListener(type, caller, listener);
        }
        onceEventListener(type, caller, listener) {
            this.callManager.addHandler(type, caller, listener);
            EventManager.event.onceEventListener(type, caller, listener);
        }
        removeEventListener(type, caller, listener) {
            EventManager.event.removeEventListener(type, caller, listener);
        }
        dispatchEvent(type, data) {
            EventManager.event.dispatchEvent(type, data);
        }
        removeAllEvent() {
            this.callManager.list.forEach(element => {
                this.removeEventListener(element.type, element.caller, element.handler);
            });
            this.callManager.clear();
        }
        isStart() {
            return this.state == 1;
        }
        isStop() {
            return this.state == 2;
        }
        setData(data) {
            this.data = data;
        }
    }

    class StageMouseEvent {
    }
    StageMouseEvent.STAGE_MOUSE_CLICK = 'STAGE_MOUSE_CLICK';
    StageMouseEvent.STAGE_MOUSE_UP = 'STAGE_MOUSE_UP';
    StageMouseEvent.STAGE_MOUSE_DOWN = 'STAGE_MOUSE_DOWN';
    StageMouseEvent.STAGE_MOUSE_OUT = 'STAGE_MOUSE_OUT';
    StageMouseEvent.STAGE_MOUSE_OVER = 'STAGE_MOUSE_OVER';
    StageMouseEvent.STAGE_MOUSE_MOVE = 'STAGE_MOUSE_MOVE';

    class StageMouseController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            Laya.stage.on(Laya.Event.MOUSE_UP, this, this.upHander);
            Laya.stage.on(Laya.Event.MOUSE_DOWN, this, this.downHander);
            Laya.stage.on(Laya.Event.MOUSE_OVER, this, this.overHander);
            Laya.stage.on(Laya.Event.MOUSE_OUT, this, this.outHander);
            Laya.stage.on(Laya.Event.CLICK, this, this.clickHander);
        }
        stop() {
            super.stop();
            Laya.stage.off(Laya.Event.MOUSE_UP, this, this.upHander);
            Laya.stage.off(Laya.Event.MOUSE_OUT, this, this.outHander);
            Laya.stage.off(Laya.Event.CLICK, this, this.clickHander);
        }
        upHander(e) {
            this.dispatchEvent(StageMouseEvent.STAGE_MOUSE_UP);
        }
        downHander(e) {
            this.dispatchEvent(StageMouseEvent.STAGE_MOUSE_DOWN);
        }
        outHander(e) {
            this.dispatchEvent(StageMouseEvent.STAGE_MOUSE_OUT);
        }
        overHander(e) {
            this.dispatchEvent(StageMouseEvent.STAGE_MOUSE_OVER);
        }
        clickHander(e) {
            this.dispatchEvent(StageMouseEvent.STAGE_MOUSE_CLICK);
        }
    }

    class ViewType {
    }
    ViewType.AUTO = 'auto';
    ViewType.OPEN = 'open';
    ViewType.CLOSE = 'close';
    ViewType.NEW = 'new';

    class JSONUtil {
        static stringify(data) {
            if (typeof data == 'string') {
                return data;
            }
            if (data) {
                return JSON.stringify(data);
            }
            return '';
        }
        static parse(st) {
            if (st == null) {
                return null;
            }
            if (st == '') {
                return null;
            }
            if (typeof st == 'string') {
                return JSON.parse(st);
            }
            return st;
        }
    }

    class ParamUtil {
        static getInt(data, key, def = 0) {
            if (!data) {
                return def;
            }
            if (data.hasOwnProperty(key)) {
                if (!data[key]) {
                    return 0;
                }
                return parseInt(data[key]);
            }
            return def;
        }
        static getNumber(data, key, def = 0) {
            if (!data) {
                return def;
            }
            if (data.hasOwnProperty(key)) {
                if (!data[key]) {
                    return 0;
                }
                return parseFloat(data[key]);
            }
            return def;
        }
        static getString(data, key, def = '') {
            if (!data) {
                return def;
            }
            if (data.hasOwnProperty(key)) {
                if (data[key] === undefined) {
                    return def;
                }
                else if (data[key] === null) {
                    return def;
                }
                else {
                    return data[key].toString();
                }
            }
            return def;
        }
        static getBool(data, key, def = false) {
            if (!data) {
                return def;
            }
            if (data.hasOwnProperty(key)) {
                if (data[key]) {
                    return true;
                }
                else {
                    return false;
                }
            }
            return def;
        }
        static getObject(data, key, def = null) {
            if (!data) {
                return def;
            }
            if (data.hasOwnProperty(key)) {
                return data[key];
            }
            return def;
        }
        static getJson(data, key, def = null) {
            if (!data) {
                return def;
            }
            if (data.hasOwnProperty(key)) {
                return JSONUtil.parse(data[key]);
            }
            return def;
        }
        static getNum(data, key, def = "") {
            if (!data) {
                return def;
            }
            if (data.hasOwnProperty(key)) {
                return data[key] + '';
            }
            return def;
        }
        static isFunction(fun) {
            try {
                if (typeof fun === "function") {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (e) {
                return false;
            }
        }
    }

    class ViewManager {
        static show(parent, viewClass, data = null) {
            var showType = ParamUtil.getString(data, 'showType', ViewType.AUTO);
            var viewId = ParamUtil.getString(data, 'viewId', '');
            var view;
            if (showType == ViewType.NEW) {
                view = new viewClass();
                view.setData(data);
                parent.startChild(view);
                return view;
            }
            view = this.getViewController(parent, viewClass, viewId);
            if (showType == ViewType.OPEN) {
                if (!view) {
                    view = new viewClass();
                }
                if (viewId) {
                    view.id = viewId;
                }
                view.setData(data);
                parent.startChild(view);
            }
            else if (showType == ViewType.CLOSE) {
                if (view) {
                    view.setData(data);
                    view.close();
                }
            }
            else {
                if (view) {
                    if (view.isOpen) {
                        view.close();
                    }
                    else {
                        view.setData(data);
                        parent.startChild(view);
                    }
                }
                else {
                    view = new viewClass();
                    if (viewId) {
                        view.id = viewId;
                    }
                    view.setData(data);
                    parent.startChild(view);
                }
            }
            return view;
        }
        static getViewController(parent, viewClass, viewId) {
            if (viewId) {
                return parent.getChild(viewId);
            }
            return parent.getChildByClass(viewClass);
        }
        static register(type, parent, viewClass) {
            parent.addEventListener(type, parent, (data) => { ViewManager.show(parent, viewClass, data); });
        }
        static addView(c) {
            if (c.viewName) {
                this.list[c.viewName] = c;
            }
        }
        static removeView(viewName) {
            if (viewName) {
                delete this.list[viewName];
            }
        }
        static getView(viewName) {
            return this.list[viewName];
        }
    }
    ViewManager.list = {};

    class TimerController extends Controller {
        constructor() {
            super();
            this.timerCallManger = new CallManager();
        }
        stop() {
            this.stopAllTimer();
            super.stop();
        }
        exeTimer(time, caller, handler, data) {
            this.onceTimer(time, caller, () => { handler.apply(caller, data); });
        }
        onceTimer(time, caller, handler, data) {
            this.timerCallManger.addHandler('timer', caller, handler);
            if (time > 0) {
                Laya.timer.once(time, caller, handler, data);
            }
            else {
                handler.apply(caller, data);
            }
        }
        loopTimer(time, caller, handler, data) {
            this.timerCallManger.addHandler('timer', caller, handler);
            if (time > 0) {
                Laya.timer.loop(time, caller, handler, data);
            }
            else {
                handler.apply(caller, data);
            }
        }
        onceFrame(num, caller, handler, data) {
            this.timerCallManger.addHandler('timer', caller, handler);
            Laya.timer.frameOnce(num, caller, handler, data);
        }
        loopFrame(num, caller, handler, data) {
            this.timerCallManger.addHandler('timer', caller, handler);
            Laya.timer.frameLoop(num, caller, handler, data);
        }
        onceClock(time, caller, handler, data) {
            var t = time - TimeUtil.getTime();
            if (t > 0) {
                this.timerCallManger.addHandler('timer', caller, handler);
                Laya.timer.once(t, caller, handler, data);
            }
            else {
                Laya.timer.once(10, caller, handler, data);
            }
        }
        stopTimer(caller, handler) {
            Laya.timer.clear(caller, handler);
        }
        stopAllTimer() {
            var list = this.timerCallManger.list;
            for (var k in list) {
                var item = list[k];
                Laya.timer.clear(item.caller, item.handler);
            }
            this.timerCallManger.clear();
        }
    }

    class TimerUtil {
        static getTimer(c) {
            var timer = c.getChild('timer');
            if (!timer) {
                timer = new TimerController();
                timer.id = 'timer';
                c.startChild(timer);
            }
            return timer;
        }
        static callLater(caller, handler, data) {
            Laya.timer.callLater(caller, handler, data);
        }
        static exeTimer(time, caller, handler, data) {
            var timer = TimerUtil.getTimer(caller);
            timer.exeTimer(time, caller, handler, data);
        }
        static onceTimer(time, caller, handler, data) {
            var timer = TimerUtil.getTimer(caller);
            timer.onceTimer(time, caller, handler, data);
        }
        static loopTimer(time, caller, handler, data) {
            var timer = TimerUtil.getTimer(caller);
            timer.loopTimer(time, caller, handler, data);
        }
        static onceFrame(num, caller, handler, data) {
            var timer = TimerUtil.getTimer(caller);
            timer.onceFrame(num, caller, handler, data);
        }
        static loopFrame(num, caller, handler, data) {
            var timer = TimerUtil.getTimer(caller);
            timer.loopFrame(num, caller, handler, data);
        }
        static onceClock(time, caller, handler, data) {
            var timer = TimerUtil.getTimer(caller);
            timer.onceClock(time, caller, handler, data);
        }
        static stopTimer(caller, handler) {
            var timer = TimerUtil.getTimer(caller);
            timer.stopTimer(caller, handler);
        }
        static stopAllTimer(caller) {
            var timer = TimerUtil.getTimer(caller);
            timer.stopAllTimer();
        }
    }

    class MianView extends Laya.Box {
        constructor() {
            super();
            this.top = 0;
            this.left = 0;
            this.right = 0;
            this.bottom = 0;
            Laya.stage.on(Laya.Event.RESIZE, this, this.resizeHandler);
            this.resizeHandler();
        }
        static get view() {
            if (!this.main) {
                this.main = new MianView();
                Laya.stage.addChild(this.main);
            }
            return this.main;
        }
        resizeHandler() {
            if (Laya.stage.height > Laya.stage.width) {
                if (Laya.stage.height / Laya.stage.width > 1440 / 720) {
                    this.top = MianView.bangsSize;
                }
                else {
                    this.top = 0;
                }
            }
            else {
                if (Laya.stage.width / Laya.stage.height > 1440 / 720) {
                    this.left = MianView.bangsSize;
                    this.right = MianView.bangsSize;
                }
                else {
                    this.left = 0;
                    this.right = 0;
                }
            }
        }
    }
    MianView.bangsSize = 70;

    class StageUtil {
        static get bangsX() {
            if (Laya.stage.height > Laya.stage.width) {
            }
            else {
                if (Laya.stage.width / Laya.stage.height > 1440 / 720) {
                    return MianView.bangsSize;
                }
            }
            return 0;
        }
        static get bangsY() {
            if (Laya.stage.height > Laya.stage.width) {
                if (Laya.stage.height / Laya.stage.width > 1440 / 720) {
                    return MianView.bangsSize;
                }
            }
            else {
            }
            return 0;
        }
        static get stageWidth() {
            return Laya.stage.width - this.bangsX * 2;
        }
        static get stageHeight() {
            return Laya.stage.height - this.bangsY;
        }
        static get mouseX() {
            return Laya.stage.mouseX - this.bangsX;
        }
        static get mouseY() {
            return Laya.stage.mouseY - this.bangsY;
        }
        static localToGlobal(view) {
            var p = view.localToGlobal(new Laya.Point());
            p.x -= this.bangsX;
            p.y -= this.bangsY;
            return p;
        }
    }

    class DisplayUtil {
        static grayFilter(v = 1) {
            var a = v * 0.3;
            var b = v * 0.6;
            var colorMatrix = [
                a, b, 0, 0, 0,
                a, b, 0, 0, 0,
                a, b, 0, 0, 0,
                0, 0, 0, 1, 0
            ];
            var redFilter = new Laya.ColorFilter(colorMatrix);
            return redFilter;
        }
        static setGray(item, bool = true) {
            if (bool) {
                item.filters = [];
            }
            else {
                item.filters = [DisplayUtil.grayFilter(0.8)];
            }
        }
        static getChildByName(box, name) {
            if (!box) {
                return null;
            }
            if (box.destroyed) {
                return null;
            }
            var item = box.getChildByName(name);
            if (item) {
                return item;
            }
            var l = box.numChildren;
            for (var i = 0; i < l; i++) {
                var child = box.getChildAt(i);
                if (child instanceof Laya.Node) {
                    var citem = this.getChildByName(child, name);
                    if (citem) {
                        return citem;
                    }
                }
            }
            return null;
        }
        static getChildByNames(box, name) {
            if (!box) {
                return null;
            }
            if (box.destroyed) {
                return null;
            }
            if (name instanceof Array) {
                for (var nam of name) {
                    var tbox = this.getChildByName(box, nam);
                    if (tbox) {
                        box = tbox;
                    }
                    else {
                        return null;
                    }
                }
                return box;
            }
            else {
                if (box[name]) {
                    return box[name];
                }
                else {
                    return this.getChildByName(box, name);
                }
            }
        }
        static getChildByClass(box, clas) {
            if (box.destroyed) {
                return null;
            }
            var l = box.numChildren;
            for (var i = 0; i < l; i++) {
                var child = box.getChildAt(i);
                if (child instanceof clas) {
                    return child;
                }
            }
            for (var i = 0; i < l; i++) {
                var child = box.getChildAt(i);
                this.getChildByClass(box, clas);
            }
            return null;
        }
        static getComponent(box, clas) {
            if (box.destroyed) {
                return null;
            }
            var comp = box.getComponent(clas);
            if (comp) {
                return comp;
            }
            return this.getChildComponent(box, clas);
        }
        static getChildComponent(box, clas) {
            var l = box.numChildren;
            if (l == 0) {
                return null;
            }
            for (var i = 0; i < l; i++) {
                var child = box.getChildAt(i);
                var ccomp = child.getComponent(clas);
                if (ccomp) {
                    return ccomp;
                }
            }
            for (var i = 0; i < l; i++) {
                var child = box.getChildAt(i);
                var ccomp = this.getChildComponent(child, clas);
                if (ccomp) {
                    return ccomp;
                }
            }
            return null;
        }
        static disableComponent(box, clas) {
            if (box.destroyed) {
                return null;
            }
            var list = box.getComponents(clas);
            for (var k in list) {
                var item = list[k];
                item.enabled = false;
            }
        }
        static instantiate(obj, parent, x = 0, y = 0, z = 0, rx = NaN, ry = NaN, rz = NaN) {
            if (obj.destroyed) {
                return null;
            }
            var c = Laya.Sprite3D.instantiate(obj, parent, true);
            if (!Number.isNaN(x)) {
                c.transform.localPositionX = x;
            }
            if (!Number.isNaN(y)) {
                c.transform.localPositionY = y;
            }
            if (!Number.isNaN(z)) {
                c.transform.localPositionZ = z;
            }
            if (!Number.isNaN(rz)) {
                c.transform.localRotationEulerX = rx;
            }
            if (!Number.isNaN(ry)) {
                c.transform.localRotationEulerY = ry;
            }
            if (!Number.isNaN(rz)) {
                c.transform.localRotationEulerZ = rz;
            }
            return c;
        }
        static distance(x1, y1, x2 = 0, y2 = 0) {
            var x = x1 - x2;
            var y = y1 - y2;
            return Math.sqrt(x * x + y * y);
        }
        static distance3D(x1, y1, z1, x2 = 0, y2 = 0, z2 = 0) {
            var x = x1 - x2;
            var y = y1 - y2;
            var z = z1 - z2;
            return Math.sqrt(x * x + y * y + z * z);
        }
        static distanceTransform3D(t1, t2) {
            var x1 = t1.localPositionX;
            var y1 = t1.localPositionY;
            var z1 = t1.localPositionZ;
            var x2 = t2.localPositionX;
            var y2 = t2.localPositionY;
            var z2 = t2.localPositionZ;
            var x = x1 - x2;
            var y = y1 - y2;
            var z = z1 - z2;
            return Math.sqrt(x * x + y * y + z * z);
        }
        static angle(x1, y1, x0 = 0, y0 = 0) {
            var dx = x1 - x0;
            var dy = y1 - y0;
            var r = 0;
            if (dx == 0) {
                if (dy == 0) {
                    return NaN;
                }
                else if (dy > 0) {
                    r = 0;
                }
                else {
                    r = 180;
                }
            }
            else if (dx > 0) {
                if (dy > 0) {
                    r = MathUtil.atan(dx / dy);
                }
                else if (dy == 0) {
                    r = 90;
                }
                else {
                    r = 180 - MathUtil.atan(-dx / dy);
                }
            }
            else {
                if (dy > 0) {
                    r = -MathUtil.atan(-dx / dy);
                }
                else if (dy == 0) {
                    r = -90;
                }
                else {
                    r = -180 + MathUtil.atan(dx / dy);
                }
            }
            if (r > 180) {
                r -= 180;
            }
            else if (r < -180) {
                r += 180;
            }
            return 180 - r;
        }
        static angleTo180(x) {
            x = x % 360;
            if (x > 180) {
                return 360 - x;
            }
            return x;
        }
        static angleTo360(x) {
            return (x + 360) % 360;
        }
        static angleDiff(r1, r2) {
            var r = (r1 - r2) % 360;
            if (r > 180) {
                return 360 - r;
            }
            return r;
        }
        static refreshPanel(box) {
            if (box.parent) {
                if (box.parent instanceof Laya.Panel) {
                    box.parent.refresh();
                }
                this.refreshPanel(box.parent);
            }
        }
        static viewToScreenPoint(x, y, screenWidth, screenHeight) {
            var pr = 1;
            if (screenWidth > screenHeight) {
                pr = screenHeight / Laya.stage.height;
            }
            else {
                pr = screenWidth / Laya.stage.width;
            }
            y += StageUtil.bangsY;
            x += StageUtil.bangsX;
            var tx = MathUtil.int(x * pr);
            var ty = MathUtil.int(y * pr);
            return new Laya.Point(tx, ty);
        }
        static viewToScreenX(x, screenWidth, screenHeight) {
            var pr = 1;
            if (screenWidth > screenHeight) {
                pr = screenHeight / Laya.stage.height;
            }
            else {
                pr = screenWidth / Laya.stage.width;
            }
            x += StageUtil.bangsX;
            var tx = MathUtil.int(x * pr);
            return tx;
        }
        static viewToScreenY(y, screenWidth, screenHeight) {
            var pr = 1;
            if (screenWidth > screenHeight) {
                pr = screenHeight / Laya.stage.height;
            }
            else {
                pr = screenWidth / Laya.stage.width;
            }
            y += StageUtil.bangsY;
            var ty = MathUtil.int(y * pr);
            return ty;
        }
        static localToGlobal(view, point = null) {
            point = this.getPoint(point);
            if (view) {
                view.localToGlobal(point);
                point.x -= StageUtil.bangsX;
                point.y -= StageUtil.bangsY;
            }
            return point;
        }
        static globalToLocal(view, point = null) {
            point = this.getPoint(point);
            if (view) {
                view.globalToLocal(point);
                point.x -= StageUtil.bangsX;
                point.y -= StageUtil.bangsY;
            }
            return point;
        }
        static getPoint(point) {
            if (!point) {
                if (!this.point) {
                    this.point = new Laya.Point(0, 0);
                }
                point = this.point;
            }
            return point;
        }
    }

    class FileUtil {
        static getType(filePath) {
            if (!filePath) {
                return "";
            }
            var startIndex = filePath.lastIndexOf(".");
            if (startIndex != -1) {
                return filePath.substring(startIndex + 1, filePath.length).toLowerCase();
            }
            else
                return "";
        }
    }

    class HandlerUtil {
        static create(caller, fun, arg = []) {
            return new Laya.Handler(caller, fun, arg, false);
        }
        static call(handler, data = null) {
            if (handler != null) {
                if (data) {
                    if (handler.args) {
                        handler.args.push(data);
                    }
                    else {
                        handler.args = [data];
                    }
                }
                handler.run();
            }
        }
    }

    class ViewPoolUtil {
        static getObject(url, clas = null) {
            return PoolUtil.getObject(url, clas);
        }
        static recover(obj) {
            if (obj) {
                if (obj.destroyed) {
                    return;
                }
                obj.removeSelf();
                if (obj instanceof Laya.Scene3D) {
                    return;
                }
                PoolUtil.recover(obj);
            }
        }
        static recoverChild(obj) {
            if (obj) {
                if (obj.destroyed) {
                    return;
                }
                obj.removeSelf();
                if (obj instanceof Laya.Scene3D) {
                    return;
                }
                var l = obj.numChildren;
                for (var i = 0; i < l; i++) {
                    var o = obj.getChildAt(i);
                    if (o && o.destroyed == false && o.hasOwnProperty("poolName")) {
                        o.removeSelf();
                        PoolUtil.recover(o);
                    }
                }
                PoolUtil.recover(obj);
            }
        }
        static sign(obj, name) {
            PoolUtil.sign(obj, name);
        }
    }

    class LoaderUtil {
        static loads(url, c = null, fun = null, data = null) {
            if (url instanceof Array) {
                Laya.loader.load(url, HandlerUtil.create(c, fun, data));
            }
            else if (FileUtil.getType(url) == 'ls') {
                Laya.Scene3D.load(url, HandlerUtil.create(c, fun, data));
            }
            else if (FileUtil.getType(url) == 'lh') {
                this.load3D(url, null, c, fun, data);
            }
            else {
                Laya.loader.load(url, HandlerUtil.create(c, fun, data));
            }
        }
        static load3D(url, parent = null, caller = null, fun = null, arg = [], x = 0, y = 0, z = 0) {
            var obj = ViewPoolUtil.getObject(url);
            if (obj) {
                if (parent) {
                    parent.addChild(obj);
                }
                obj.transform.localPositionX = x;
                obj.transform.localPositionY = y;
                obj.transform.localPositionZ = z;
                if (caller && fun != null) {
                    Laya.timer.callLater(caller, fun, [obj]);
                }
            }
            else if (this.lib[url]) {
                var obj = this.lib[url];
                return this.loadCompHandler(url, parent, x, y, z, caller, fun, arg, obj);
            }
            else {
                Laya.loader.create(url, HandlerUtil.create(this, this.loadCompHandler, [url, parent, x, y, z, caller, fun, arg]));
                return null;
            }
        }
        static loadCompHandler(url, parent, x, y, z, caller, fun = null, arg = [], obj) {
            if (!arg) {
                arg = [];
            }
            if (!obj) {
                return null;
            }
            this.lib[url] = obj;
            var view = DisplayUtil.instantiate(obj, null, x, y, z);
            if (parent) {
                parent.addChild(view);
            }
            arg.push(view);
            if (fun != null) {
                fun.apply(caller, arg);
            }
            ViewPoolUtil.sign(view, url);
            return view;
        }
        static loadScene3D(url, parent = null, caller = null, fun = null, arg = []) {
            var obj = ViewPoolUtil.getObject(url);
            if (obj) {
                if (parent) {
                    parent.addChild(obj);
                }
                if (caller && fun != null) {
                    Laya.timer.callLater(caller, fun, [obj]);
                }
            }
            else if (this.lib[url]) {
                var obj = this.lib[url];
                return this.loadSceneCompHandler(url, parent, caller, fun, arg, obj);
            }
            else {
                Laya.Scene3D.load(url, HandlerUtil.create(this, this.loadSceneCompHandler, [url, parent, caller, fun, arg]));
                return null;
            }
        }
        static loadSceneCompHandler(url, parent, caller, fun = null, arg = [], obj) {
            if (!arg) {
                arg = [];
            }
            if (!obj) {
                return null;
            }
            this.lib[url] = obj;
            var view = obj;
            if (parent) {
                parent.addChild(view);
            }
            arg.push(view);
            if (fun != null) {
                fun.apply(caller, arg);
            }
            ViewPoolUtil.sign(view, url);
            return view;
        }
        static recover(obj) {
            ViewPoolUtil.recover(obj);
        }
        static recoverChild(obj) {
            ViewPoolUtil.recoverChild(obj);
        }
    }
    LoaderUtil.lib = {};

    class ViewUtil {
        static destroy(view, destroyChild = true) {
            if (view && !view['inPool']) {
                view.destroy(true);
            }
        }
    }

    class ViewEvent {
        static VIWE_OPEN(name) { return 'VIWE_OPEN@' + name; }
        ;
        static VIWE_OPENED(name) { return 'VIWE_OPENED@' + name; }
        ;
        static VIWE_CLOSE(name) { return 'VIWE_CLOSE@' + name; }
        ;
        static VIWE_CLOSED(name) { return 'VIWE_CLOSED@' + name; }
        ;
    }
    ViewEvent.VIEW_LAYOUT = 'VIEW_LAYOUT';

    class ViewController extends Controller {
        constructor() {
            super();
            this.view = null;
            this.lasting = false;
            this.viewName = '';
            this.isAutoShow = true;
            this.isAutoDestroy = true;
            this.parentView = MianView.view;
        }
        run() {
            super.run();
            this.open();
        }
        stop() {
            if (this.opened == true) {
                this.close();
            }
            if (this.view && this.view.destroyed == false) {
                if (this.isAutoDestroy) {
                    ViewUtil.destroy(this.view, true);
                }
                else {
                    ViewPoolUtil.recoverChild(this.view);
                }
                this.view = null;
            }
            super.stop();
        }
        open() {
            if (this.data && this.data.parentView) {
                this.parentView = this.data.parentView;
            }
            if (this.viewName) {
                ViewManager.addView(this);
                this.dispatchEvent(ViewEvent.VIWE_OPEN(this.viewName), { target: this, viewName: this.viewName });
            }
            if (this.viewURL) {
                if (this.view == null) {
                    LoaderUtil.loads(this.viewURL, this, this.openHandler);
                }
                else {
                    this.openHandler();
                }
            }
            else {
                this.openHandler();
            }
        }
        openHandler() {
            if (this.parentView) {
                if (this.view) {
                    if (this.isAutoShow) {
                        this.showView();
                    }
                }
                else if (this.viewClass) {
                    this.view = new this.viewClass();
                    if (this.isAutoShow) {
                        this.showView();
                    }
                }
                this.opened = true;
            }
            this.openComplete();
        }
        openComplete() {
            if (this.viewName) {
                this.dispatchEvent(ViewEvent.VIWE_OPENED(this.viewName), { target: this, viewName: this.viewName });
            }
        }
        showView() {
            if (this.view && this.parentView && this.view.parent != this.parentView && this.view.destroyed == false && this.parentView.destroyed == false) {
                this.parentView.addChild(this.view);
            }
        }
        reshow() {
            this.openComplete();
        }
        close() {
            if (this.viewName) {
                ViewManager.removeView(this.viewName);
                this.dispatchEvent(ViewEvent.VIWE_CLOSE(this.viewName), { target: this, viewName: this.viewName });
            }
            this.closeView();
        }
        closeView() {
            if (this.opened == true) {
                this.opened = false;
                if (this.lasting == false) {
                    this.stop();
                }
            }
            if (this.view) {
                this.view.removeSelf();
            }
            if (this.viewName) {
                ViewManager.removeView(this.viewName);
                this.dispatchEvent(ViewEvent.VIWE_CLOSED(this.viewName), { target: this, viewName: this.viewName });
            }
        }
        get isOpen() {
            return this.opened;
        }
    }

    class LogUtil {
        static trace(st) {
            if (console && console.log) {
                console.log(st);
            }
        }
        static log(st) {
            if (console && console.log) {
                console.log(st);
            }
        }
    }

    class AdEvent {
        static AD_VIDEO_COMPLETE(id) { return 'AD_VIDEO_COMPLETE@' + id; }
        ;
        static AD_NATIVE_CLICKED(viewName) { return 'AD_NATIVE_CLICKED@' + viewName; }
    }
    AdEvent.AD_VIDEO_SHOW = 'AD_VIDEO_SHOW';
    AdEvent.AD_INSERT_SHOW = 'AD_INSERT_SHOW';
    AdEvent.AD_SHARE_SHOW = 'AD_SHARE_SHOW';
    AdEvent.AD_NATIVE_LOAD = 'AD_NATIVE_LOAD';
    AdEvent.AD_NATIVE_ERROR = 'AD_NATIVE_ERROR';
    AdEvent.AD_NATIVE_CLICK = 'AD_NATIVE_CLICK';
    AdEvent.AD_SHARE_SUCCESS = 'AD_SHARE_SUCCESS';

    class ModelManager {
        static getModel(name, clas) {
            var m = this.model[name];
            if (!m) {
                m = this.model[name] = new clas();
            }
            return m;
        }
        static removeModel(name) {
            delete this.model[name];
        }
        static removeAll() {
            this.model = {};
        }
    }
    ModelManager.model = {};

    class StorageModel {
        constructor() {
            this.name = '';
        }
        static get model() {
            return ModelManager.getModel('StorageModel', StorageModel);
        }
        ;
        getName() {
            return this.name;
        }
        setData(m, data) {
            m = this.getName() + m;
            var str = JSONUtil.stringify(data);
            Laya.LocalStorage.setItem(m, str);
        }
        getData(m) {
            m = this.getName() + m;
            var str = Laya.LocalStorage.getItem(m);
            return JSONUtil.parse(str);
        }
        getValue(m, a, def = null) {
            var k = m + '_' + a;
            var obj = this.getData(k);
            if (!obj) {
                return def;
            }
            return obj;
        }
        setValue(m, a, data) {
            var k = m + '_' + a;
            this.setData(k, data);
        }
    }

    class LogModel {
        constructor() {
            this.logList = [];
        }
        static get model() {
            return ModelManager.getModel('LogModel', LogModel);
        }
        ;
        log(log) {
            if (this.logList) {
                this.logList.push(log);
            }
            if (this.logList.length > 100) {
                this.logList.shift();
            }
        }
    }

    class LogTool {
        static log(st) {
            if (console && console.log) {
                console.log(this.head + '' + st);
            }
            LogModel.model.log(st);
        }
    }
    LogTool.head = 'GameLog:';

    class AdModel {
        constructor() {
            this.isShieldCity = true;
            this.adRateLib = {};
            this.touchMistake = true;
            this.nativeCanclick = 1;
            this.videoLib = {};
            this.nativeAdList = {};
            this.nativeUseList = {};
        }
        static get model() {
            return ModelManager.getModel('AdModel', AdModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.videoLib = this.videoLib;
            StorageModel.model.setData("ad", data);
        }
        loadData() {
            var data = StorageModel.model.getData("ad");
            this.videoLib = ParamUtil.getObject(data, 'videoLib', {});
        }
        addVideoNum(viewName) {
            this.videoLib[viewName] = MathUtil.int(this.videoLib[viewName]) + 1;
        }
        getVideoNum(viewName) {
            return MathUtil.int(this.videoLib[viewName]);
        }
        setRate(key, v) {
            this.adRateLib[key] = v;
        }
        getRate(key) {
            if (!key) {
                for (var k in this.adRateLib) {
                    return this.adRateLib[k];
                }
                return 0;
            }
            return ParamUtil.getNumber(this.adRateLib, key, 0);
        }
        addNativeAd(id, ad) {
            this.nativeAdList[id] = ad;
        }
        getNativeAd(id) {
            return this.nativeAdList[id];
        }
        removeNativeAd(id) {
            delete this.nativeAdList[id];
        }
        addNativeUse(nativeId, pid) {
            this.nativeUseList[pid] = nativeId;
        }
        subNativeUse(nativeId, pid) {
            delete this.nativeUseList[pid];
        }
        hasNativeUse(nativeId) {
            LogTool.log('adModel:hasNativeUse:' + nativeId);
            for (var k in this.nativeUseList) {
                LogTool.log('adModel:hasNativeUse:' + k + '_' + this.nativeUseList[k]);
                if (nativeId == this.nativeUseList[k]) {
                    return true;
                }
            }
            return false;
        }
    }

    class AdTool {
        static videoAdShow(c, fun = null, id = '') {
            var viewName = '';
            if (c instanceof ViewController) {
                viewName = c.viewName;
            }
            if (!id) {
                id = 'videoAdShow@' + c.id;
            }
            if (fun) {
                c.onceEventListener(AdEvent.AD_VIDEO_COMPLETE(id), c, fun);
            }
            c.dispatchEvent(AdEvent.AD_VIDEO_SHOW, { id: id, viewName: viewName });
            AdModel.model.addVideoNum(viewName);
            AdModel.model.saveData();
        }
        static getVideoNum(viewName) {
            return AdModel.model.getVideoNum(viewName);
        }
        static addVideoNum(viewName) {
            AdModel.model.addVideoNum(viewName);
            AdModel.model.saveData();
        }
        static insertAdShow(c) {
            c.dispatchEvent(AdEvent.AD_INSERT_SHOW);
        }
        static nativeAdShow(c, data, showHandler = null, closeHandler = null) {
            LogUtil.log("AdTool.nativeAdShow()" + c.id);
            if (!data) {
                data = {};
            }
            data.id = 'nativeAdShow@' + c.id;
            data.viewName = c.viewName;
            if (showHandler != null) {
                data.showHandler = HandlerUtil.create(c, showHandler);
            }
            if (closeHandler != null) {
                data.closeHandler = HandlerUtil.create(c, closeHandler);
            }
            c.dispatchEvent(AdEvent.AD_NATIVE_LOAD, data);
        }
        static nativeAdClick(c) {
            c.dispatchEvent(AdEvent.AD_NATIVE_CLICK);
        }
        static shareAdShow(c) {
            c.dispatchEvent(AdEvent.AD_SHARE_SHOW);
        }
        static checkRate(name = '', checkCity = true) {
            if (checkCity) {
                if (AdModel.model.isShieldCity) {
                    return false;
                }
            }
            if (AdModel.model.touchMistake == false) {
                return false;
            }
            var rat = AdModel.model.getRate(name);
            if (rat == 0) {
                return false;
            }
            if (MathUtil.randomHit(rat)) {
                return true;
            }
            return false;
        }
        static checkBtn(name = '') {
            var rat = AdModel.model.getRate(name);
            if (rat == 0) {
                return false;
            }
            if (MathUtil.randomHit(rat)) {
                return true;
            }
            return false;
        }
        static checkVideoIco(name = '', checkCity = true) {
            var rat = AdModel.model.getRate(name);
            if (checkCity) {
                if (AdModel.model.isShieldCity) {
                    return true;
                }
            }
            if (!rat) {
                return true;
            }
            if (MathUtil.randomHit(rat)) {
                return false;
            }
            return true;
        }
    }

    class ArrayUtil {
        static remove(list, item) {
            if (!list) {
                return list;
            }
            for (var index = list.length - 1; index >= 0; index--) {
                var element = list[index];
                if (element == item) {
                    list.splice(index, 1);
                }
            }
            return list;
        }
        static removeOne(list, item) {
            for (var index = list.length - 1; index >= 0; index--) {
                var element = list[index];
                if (element == item) {
                    list.splice(index, 1);
                    return list;
                }
            }
            return list;
        }
        static subArray(list, first = 0, last = 0) {
            var nlist = [];
            last = Math.min(list.length);
            for (var i = first; i < last; i++) {
                nlist.push(list[i]);
            }
            return list;
        }
        static randomItem(list) {
            if (!list) {
                return null;
            }
            if (list.length == 0) {
                return null;
            }
            var n = Math.floor(Math.random() * list.length);
            var vo = list[n];
            return vo;
        }
        static randomArray(list, n = 1) {
            if (!list) {
                return null;
            }
            if (n <= 0) {
                return [];
            }
            if (list.length == 0) {
                return null;
            }
            if (list.length <= n) {
                return this.copy(list, []);
            }
            if (n == 1) {
                var n = Math.floor(Math.random() * list.length);
                return [list[n]];
            }
            var nlist = this.copy(list, []);
            var rlist = [];
            for (var i = 0; i < n; i++) {
                var index = Math.floor(Math.random() * nlist.length);
                var vo = nlist[index];
                rlist.push(vo);
                nlist.splice(index, 1);
            }
            return rlist;
        }
        static randomOrder(list) {
            if (!list) {
                return null;
            }
            if (list.length == 0) {
                return [];
            }
            var n = list.length;
            var nlist = this.copy(list, []);
            var rlist = [];
            for (var i = 0; i < n; i++) {
                var index = Math.floor(Math.random() * nlist.length);
                var vo = nlist[index];
                rlist.push(vo);
                nlist.splice(index, 1);
            }
            return rlist;
        }
        static objectToArray(object) {
            var list = [];
            for (var key in object) {
                if (object.hasOwnProperty(key)) {
                    var element = object[key];
                    list.push(element);
                }
            }
            return list;
        }
        static copy(from, to = null) {
            if (!to) {
                to = [];
            }
            if (from) {
                for (var key in from) {
                    if (from.hasOwnProperty(key)) {
                        to.push(from[key]);
                    }
                }
            }
            return to;
        }
        static binaryToArray(v) {
            var list = [];
            do {
                var i = v % 2;
                v = v >> 1;
                list.push(i);
            } while (v > 0);
            return list;
        }
        static sort(list, key = 'order', order = 'asc') {
            if (list && list.length > 0) {
                list.sort((a, b) => {
                    var va = a[key];
                    var vb = b[key];
                    if (order == 'asc') {
                        return va - vb;
                    }
                    else {
                        return vb - va;
                    }
                });
            }
        }
    }

    class CheckViewShowController extends Controller {
        constructor(viewEvent, data = null, openList = null, preventList = null) {
            super();
            this.openList = {};
            this.preventList = {};
            this.list = [];
            this.viewEvent = viewEvent;
            if (openList) {
                for (var k in openList) {
                    this.regOpenView(openList[k]);
                }
            }
            if (preventList) {
                for (var k in preventList) {
                    this.regPreventView(preventList[k]);
                }
            }
            this.checkView();
        }
        regOpenView(viewName, data = null) {
            if (!data) {
                data = {};
            }
            this.openList[viewName] = data;
            var view = ViewManager.getView(viewName);
            if (view) {
                this.list.push(viewName);
            }
            this.addEventListener(ViewEvent.VIWE_OPEN(viewName), this, this.openHandler);
            this.addEventListener(ViewEvent.VIWE_CLOSE(viewName), this, this.closeHandler);
            this.checkView();
        }
        regPreventView(viewName) {
            this.preventList[viewName] = true;
            this.addEventListener(ViewEvent.VIWE_OPEN(viewName), this, this.propenHandler);
            this.addEventListener(ViewEvent.VIWE_CLOSE(viewName), this, this.prcloseHandler);
        }
        openHandler(data) {
            LogTool.log("CheckViewShowController:openHandler:" + data.viewName);
            this.list.push(data.viewName);
            this.checkView();
        }
        closeHandler(data) {
            LogTool.log("CheckViewShowController:closeHandler:" + data.viewName);
            this.list = ArrayUtil.remove(this.list, data.viewName);
            this.checkView();
        }
        propenHandler(data) {
            this.checkView();
        }
        prcloseHandler(data) {
            this.checkView();
        }
        checkView() {
            TimerUtil.stopTimer(this, this.eventHanler);
            if (this.list.length <= 0) {
                LogTool.log("CheckViewShowController:close-length=0:");
                this.eventData = { showType: ViewType.CLOSE };
                TimerUtil.onceTimer(60, this, this.eventHanler);
            }
            else {
                for (var name in this.preventList) {
                    var view = ViewManager.getView(name);
                    if (view) {
                        LogTool.log("CheckViewShowController:close:" + name);
                        this.eventData = { showType: ViewType.CLOSE };
                        TimerUtil.onceTimer(60, this, this.eventHanler);
                        return;
                    }
                }
                var viewName = this.list[this.list.length - 1];
                if (this.openList[viewName]) {
                    LogTool.log("CheckViewShowController:show:" + viewName);
                    this.eventData = this.openList[viewName];
                    if (!this.eventData) {
                        this.eventData = {};
                    }
                    this.eventData.showType = ViewType.OPEN;
                    TimerUtil.onceTimer(60, this, this.eventHanler);
                }
            }
        }
        eventHanler() {
            if (this.eventData) {
                this.eventData.viewEvent = this.viewEvent;
            }
            LogTool.log("CheckViewShowController:event:" + JSONUtil.stringify(this.eventData));
            this.dispatchEvent(this.viewEvent, this.eventData);
        }
    }

    class GoodsAttrType {
    }
    GoodsAttrType.ATTR_JIN = 20010001;
    GoodsAttrType.ATTR_YIN = 20010002;
    GoodsAttrType.ATTR_TONG = 20010003;
    GoodsAttrType.ATTR_VIP = 20010101;
    GoodsAttrType.ATTR_EXP = 20010102;
    GoodsAttrType.ATTR_SCORE = 20010103;
    GoodsAttrType.ATTR_PARA = 20010109;
    GoodsAttrType.ATTR_PHY = 20010107;
    GoodsAttrType.ATTR_TAL = 20010110;
    GoodsAttrType.ATTR_PRE = 20010111;
    GoodsAttrType.ATTR_ACT = 20010112;
    GoodsAttrType.ATTR_MEDAL = 20010113;
    GoodsAttrType.ATTR_TRIPHY = 20010114;
    GoodsAttrType.ATTR_INTEGRA = 20010115;
    GoodsAttrType.ATTR_KEY = 20010301;
    GoodsAttrType.ATTR_STRENG = 60010201;

    class GoodsEvent {
        static GOODS_LV_CHANGED(cid) { return 'GOODS_LV_CHANGED@' + cid; }
        ;
    }
    GoodsEvent.GOODS_LIST_REQUEST = 'GOODS_LIST_REQUEST';
    GoodsEvent.GOODS_LIST_RESPONSE = 'GOODS_LIST_RESPONSE';
    GoodsEvent.GOODS_ADD_REQUEST = 'GOODS_ADD_REQUEST';
    GoodsEvent.GOODS_ADD_RESPONSE = 'GOODS_ADD_RESPONSE';
    GoodsEvent.GOODS_SUB_REQUEST = 'GOODS_SUB_REQUEST';
    GoodsEvent.GOODS_SUB_RESPONSE = 'GOODS_SUB_RESPONSE';
    GoodsEvent.GOODS_SET_REQUEST = 'GOODS_SET_REQUEST';
    GoodsEvent.GOODS_SET_RESPONSE = 'GOODS_SET_RESPONSE';
    GoodsEvent.GOODS_CHILD_ADD_REQUEST = 'GOODS_ADD_CHILD_REQUEST';
    GoodsEvent.GOODS_CHILD_ADD_RESPONSE = 'GOODS_ADD_CHILD_RESPONSE';
    GoodsEvent.GOODS_CHILD_REMOVE_REQUEST = 'GOODS_CHILD_REMOVE_REQUEST';
    GoodsEvent.GOODS_CHILD_REMOVE_RESPONSE = 'GOODS_CHILD_REMOVE_RESPONSE';
    GoodsEvent.GOODS_LOC_SET_REQUEST = 'GOODS_LOC_SET_REQUEST';
    GoodsEvent.GOODS_LOC_SET_RESPONSE = 'GOODS_LOC_SET_RESPONSE';
    GoodsEvent.GOODS_CHILD_LOC_SET_REQUEST = 'GOODS_CHILD_LOC_SET_REQUEST';
    GoodsEvent.GOODS_CHILD_LOC_SET_RESPONSE = 'GOODS_CHILD_LOC_SET_RESPONSE';
    GoodsEvent.GOODS_ATTR_SET_REQUEST = 'GOODS_ATTR_SET_REQUEST';
    GoodsEvent.GOODS_ATTR_SET_RESPONSE = 'GOODS_ATTR_SET_RESPONSE';
    GoodsEvent.GOODS_LV_CHANGE = 'GOODS_LV_CHANGE';
    GoodsEvent.GOODS_GET_SHOW = 'GOODS_GET_SHOW';
    GoodsEvent.GOODS_MONEY_VIEW_SHOW = 'GOODS_MONEY_VIEW_SHOW';
    GoodsEvent.GOODS_GET_VIEW_SHOW = 'GOODS_GET_VIEW_SHOW';
    GoodsEvent.GOODS_LV_UP_VIEW_SHOW = 'GOODS_LV_UP_VIEW_SHOW';
    GoodsEvent.GOODS_CARD_FLOAT_VIEW_SHOW = 'GOODS_CARD_FLOAT_VIEW_SHOW';
    GoodsEvent.GOODS_UP_SUCCESS = 'GOODS_UP_SUCCESS';
    GoodsEvent.GOODS_BUY_SUCCESS = 'GOODS_BUY_SUCCESS';
    GoodsEvent.GOODS_STRENG_SUCCESS = 'GOODS_STRENG_SUCCESS';
    GoodsEvent.GOODS_CLOSE_CLICK = 'GOODS_CLOSE_CLICK';

    class GoodsConfig {
        static getSegmentIcoUrl(cid) {
            if (cid) {
                return "res/segment/" + cid + ".png";
            }
            return null;
        }
        static getSkillIcoUrl(image, url) {
            if (image) {
                return "res/skill/" + url + "/" + image + ".png";
            }
            return null;
        }
        static getTryIcoUrl(cid) {
            if (cid) {
                return "res/try/" + cid + ".png";
            }
            return null;
        }
        static getNameIcoUrl(cid) {
            if (cid) {
                return "res/name/" + cid + ".png";
            }
            return null;
        }
        static getGunIcoUrl(cid) {
            if (cid) {
                return "res/gun/" + cid + ".png";
            }
            return null;
        }
        static getIcoUrl(image) {
            if (image) {
                return "res/ico/" + image + ".png";
            }
            return null;
        }
        static getIconUrl(image) {
            if (image) {
                return "res/icon/" + image + ".png";
            }
            return null;
        }
        static getImgUrl(image) {
            if (image) {
                return "res/image/" + image + ".png";
            }
            return null;
        }
        static getLockUrl(image, type = '') {
            if (image) {
                if (type) {
                    return "res/lock/" + image + "_" + type + ".png";
                }
                else {
                    return "res/lock/" + image + ".png";
                }
            }
            return null;
        }
        static getQualityName(quality) {
            if (quality == 1) {
                return '普通';
            }
            else if (quality == 2) {
                return '稀有';
            }
            else if (quality == 3) {
                return '卓越';
            }
            else if (quality == 4) {
                return '传说';
            }
            return '';
        }
        static getCtypeText(ctype) {
            if (ctype == 1) {
                return "步枪";
            }
            else if (ctype == 2) {
                return "冲锋枪";
            }
            else if (ctype == 3) {
                return "散弹枪";
            }
            else if (ctype == 4) {
                return "狙击枪";
            }
            else if (ctype == 5) {
                return "手枪";
            }
            else {
                return "手枪";
            }
        }
        static getGunStypeText(index) {
            if (index == 1) {
                return "9";
            }
            else if (index == 2) {
                return "5.56";
            }
            else if (index == 3) {
                return "7.62";
            }
            else {
                return "12";
            }
        }
        static getModifyCid(id) {
            if (this.modifyMap[id]) {
                return this.modifyMap[id];
            }
            return 0;
        }
        static getEquipList(index) {
            return this.equipList[index];
        }
        static getList() {
            return this.equipList;
        }
        static getGoodsAddList(index) {
            return this.goodsAddList[index];
        }
        static getGoodsByCid(cid) {
            var list = this.goodsAddList;
            var vo;
            for (var k in list) {
                if (list[k].cid == cid) {
                    vo = list[k];
                    return;
                }
            }
        }
    }
    GoodsConfig.GoodsEuipLvUpRewardType = 0;
    GoodsConfig.goodGetType = 0;
    GoodsConfig.initList = [
        { cid: 20010102, num: 1, lv: 1 },
        { cid: 20010003, num: 1000 },
        { cid: 20010001, num: 0 },
        { cid: 20010107, num: 50 },
        { cid: 20010114, num: 0 },
        { cid: 60011001, num: 1 },
        { cid: 30042001, num: 1, loc: 1, count: 0, isNew: true },
        { cid: 30042201, num: 1, loc: 1, count: 0, isNew: true },
        { cid: 30041101, num: 1, loc: 1, count: 0, isNew: true },
        { cid: 30041201, num: 1, loc: 1, count: 0, isNew: true },
        { cid: 30011001, num: 1 },
        { cid: 30011003, num: 1 },
        { cid: 30011002, num: 1 },
        { cid: 30011005, num: 1 },
        { cid: 30011004, num: 1 },
        { cid: 30011006, num: 1 },
        { cid: 30011007, num: 1 },
        { cid: 30011008, num: 1 },
        { cid: 30011009, num: 1 },
        { cid: 30011010, num: 1 },
    ];
    GoodsConfig.heroMaxIndex = 9;
    GoodsConfig.modifyMap = {};
    GoodsConfig.gunQuality1 = 1000;
    GoodsConfig.gunQuality2 = 2000;
    GoodsConfig.gunQuality3 = 3000;
    GoodsConfig.gunQuality4 = 5000;
    GoodsConfig.jinGetNum = 200;
    GoodsConfig.tongGetNum = 500;
    GoodsConfig.paintList = [51010124, 51010125, 51010126, 51010127, 51010128, 51010129, 51010130];
    GoodsConfig.equipLvMax = 50;
    GoodsConfig.equipList = {
        0: [30042001,
            30042002,
            30042003,
            30042004,
            30042101,
            30042102,
            30042103,
            30042104,
            30042105,
            30042106,
            30042107,
            30042108,
            30042109,
            30042201,
            30042202,
            30042203,
            30042204,
            30042205,
            30042206,
            30042207,
            30042208,
            30042209,
            30042210,
            30042211,
            30042212,
            30042301,
            30042302,
            30042303,
            30042304,
            30042305,
            30042401,
            30042402,
            30042403],
        1: [30041101, 30041102, 30041103, 30041104, 30041105, 30041106, 30041107, 30041108, 30041109, 30041110, 30041111],
        2: [30041201, 30041202, 30041203, 30041204, 30041205, 30041206, 30041207, 30041208, 30041209, 30041210, 30041211],
        3: [30041121, 30041122, 30041221, 30041222, 30041113, 30041213, 30041114, 30041214, 30041115, 30041215, 30041116, 30041216, 30041117, 30041217, 30041118, 30041218, 30041119, 30041219, 30041120, 30041220]
    };
    GoodsConfig.equipList2 = [
        { title: "活动解锁" },
        { cid: 30042501 },
        { cid: 30042502 },
        { cid: 30042503 },
        { cid: 30041121 },
        { cid: 30041122 },
        { cid: 30041221 },
        { cid: 30041222 },
        { cid: 30041123 },
        { cid: 30041223 },
        { title: "上等兵解锁" },
        { cid: 30041113 },
        { cid: 30041213 },
        { title: "下士解锁" },
        { cid: 30041114 },
        { cid: 30041214 },
        { title: "中士解锁" },
        { cid: 30041115 },
        { cid: 30041215 },
        { title: "上士解锁" },
        { cid: 30041116 },
        { cid: 30041216 },
        { title: "少尉解锁" },
        { cid: 30041117 },
        { cid: 30041217 },
        { title: "中尉解锁" },
        { cid: 30041118 },
        { cid: 30041218 },
        { title: "上尉解锁" },
        { cid: 30041119 },
        { cid: 30041219 },
        { title: "少校解锁" },
        { cid: 30041120 },
        { cid: 30041220 }
    ];
    GoodsConfig.goodsAddList = [
        { cid: 20010003, ico: 'ui/img_UM_gold.png', num: 2000 },
        { cid: 20010001, ico: 'ui/img_UM_Diamond.png', num: 100 },
        { cid: 20010107, ico: 'ui/img_UM_tl.png', num: 10 },
        { cid: 0, ico: 'ui/img_uk_icon_box3.png', num: 6 },
        { cid: 1, ico: 'ui/img_uk_icon_box2.png', num: 4 },
        { cid: 2, ico: 'ui/img_uk_icon_box1.png', num: 2 }
    ];

    class ObjectUtil {
        static copy(from, to = null, keys = null) {
            if (!from) {
                return to;
            }
            if (!to) {
                to = {};
            }
            if (from) {
                if (keys) {
                    for (var key of keys) {
                        if (from.hasOwnProperty(key)) {
                            to[key] = from[key];
                        }
                    }
                }
                else {
                    for (var key in from) {
                        if (from.hasOwnProperty(key)) {
                            to[key] = from[key];
                        }
                    }
                }
            }
            return to;
        }
        static copyArray(from, clas = null, keys = null) {
            var nlist = [];
            for (var k in from) {
                var v = from[k];
                var nv;
                if (clas) {
                    nv = new clas();
                }
                else {
                    nv = {};
                }
                this.copy(v, nv, keys);
                nlist.push(nv);
            }
            return nlist;
        }
        static copyMap(from, clas = null, keys = null) {
            var nlist = {};
            for (var k in from) {
                var v = from[k];
                var nv;
                if (clas) {
                    nv = new clas();
                }
                else {
                    nv = {};
                }
                this.copy(v, nv, keys);
                nlist[k] = nv;
            }
            return nlist;
        }
        static isEmpty(data) {
            if (!data) {
                return true;
            }
            if (data == "0") {
                return true;
            }
            if (data instanceof Array) {
                if (data.length == 0) {
                    return true;
                }
            }
            return false;
        }
        static instantiate(data) {
            var clas = data.class;
            var obj = new clas();
            for (var k in data) {
                if (k != 'class') {
                    obj[k] = data[k];
                }
            }
            return obj;
        }
    }

    class GoodsListConfig {
        static getVo(cid) {
            var vo = this.list[cid];
            if (vo) {
                return vo;
            }
            return null;
        }
    }
    GoodsListConfig.list = {
        30011001: { cid: 30011001, name: '丹', ico: 30011001, image: '30011001', type: 30, stype: 9, ttype: 1, lv: 1, att: 10, loc: 0, attCid: 30042001, skills: [40021013, 40021011, 40021012], lvn: 1, triphyNum: 100, isUnlock: false, unlockInfo: '奖杯累计达到100', info: '丹是国际参赛选手中最知名的一位：他的粉丝群体有20亿！过去的3届锦标赛冠军都被他收入囊中，这次的第4届，他也是虎视眈眈。', quality: 0, location: 'att', attShow: 24, isNew: true },
        30011003: { cid: 30011003, name: '杰比', ico: 30011003, image: '30011003', type: 30, stype: 9, ttype: 1, lv: 1, att: 9, loc: 0, attCid: 30042003, skills: [40021033, 40021031, 40021032], lvn: 3, triphyNum: 120, isUnlock: false, unlockInfo: '奖杯累计达到120', info: '安静而致命。他最喜欢在档案室用黄金茶杯喝茶。曾由于衣着过于闪亮而被军情六处开除。', quality: 0, location: 'Ambush', attShow: 31, isNew: true },
        30011002: { cid: 30011002, name: '麦卡奈特', ico: 30011002, image: '30011002', type: 30, stype: 9, ttype: 1, lv: 1, att: 40, loc: 0, attCid: 30042002, skills: [40021023, 40021021, 40021022], lvn: 1, triphyNum: 160, isUnlock: false, unlockInfo: '奖杯累计达到160', info: '由中世纪科技打造，他可以部署一道防弹防御护盾。全球各处的警察都已经采用这种型号对名人进行保护。', quality: 0, location: 'defense', attShow: 26, isNew: true },
        30011005: { cid: 30011005, name: '伊戈艾', ico: 30011005, image: '30011005', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042005, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 200, isUnlock: false, unlockInfo: '奖杯累计达到200', info: '伊戈艾曾经是负责训练机器猎鹰进行数字捕猎的训练师。他终于意识到，自己也有掠食者的潜质。', quality: 0, location: 'Ambush', attShow: 30, isNew: true },
        30011004: { cid: 30011004, name: '捷特', ico: 30011004, image: '30011004', type: 30, stype: 9, ttype: 1, lv: 1, att: 40, loc: 0, attCid: 30042004, skills: [40021043, 40021041, 40021042], lvn: 4, triphyNum: 300, isUnlock: false, unlockInfo: '奖杯累计达到300', info: '她是一个世界级赛车手世家中的小女儿。她决定要追求自己的事业，向世界证明自己也能成为冠军。', quality: 1, location: 'att', attShow: 33, isNew: true },
        30011006: { cid: 30011006, name: '阿爆', ico: 30011006, image: '30011006', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042006, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 400, isUnlock: false, unlockInfo: '奖杯累计达到400', info: '他在自己故乡的小岛上，连续赢得了5次火箭跳跃竞赛。他的妹妹得了重病，因此需要100亿的最终奖金，为全世界的儿童建造免费医院。', quality: 0, location: 'att', attShow: 16, isNew: true },
        30011007: { cid: 30011007, name: '波卡亨塔', ico: 30011007, image: '30011007', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042007, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 500, isUnlock: false, unlockInfo: '奖杯累计达到500', info: '永远走在战争之路上，永不停歇。她一生只为追求公正，从不妥协。她还是月球上7家赌场的老板。', quality: 0, location: 'defense', attShow: 17, isNew: true },
        30011008: { cid: 30011008, name: '费洛斯博士', ico: 30011008, image: '30011008', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042008, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 600, isUnlock: false, unlockInfo: '奖杯累计达到600', info: '有人说，冰激凌是弗洛斯博士在50年代发明的。还有人说，他以前经营过一个低温冷冻农场，后来却选择转投锦标赛。', quality: 0, location: 'defense', attShow: 19, isNew: true },
        30011009: { cid: 30011009, name: '里克·洛克', ico: 30011009, image: '30011009', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042009, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 700, isUnlock: false, unlockInfo: '奖杯累计达到700', info: '他曾是声名远播的摇滚明星，后来却发现锦标赛的粉丝比音乐圈多得多。他最流行的歌曲是：回归。', quality: 1, location: 'att', attShow: 23, isNew: true },
        30011010: { cid: 30011010, name: '伯特妈妈', ico: 30011010, image: '30011010', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042010, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 800, isUnlock: false, unlockInfo: '奖杯累计达到800', info: '建造炮塔对她来说就是小菜一碟！不过，她其实有两个不为人知的恐惧：宇宙和孤独。', quality: 2, location: 'defense', attShow: 27, isNew: true },
        30011011: { cid: 30011011, name: '史莱姆', ico: 30011011, image: '30011011', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042011, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 900, isUnlock: false, unlockInfo: '奖杯累计达到900', info: '史莱姆曾今负责非致命性人群控制科技的研发工作，可后来出了问题......现在，他已经是半人半毒素的生物了。', quality: 1, location: 'defense', attShow: 32, isNew: true },
        30011012: { cid: 30011012, name: '成吉斯', ico: 30011012, image: '30011012', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042012, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 1000, isUnlock: false, unlockInfo: '奖杯累计达到1000', info: '成吉斯是业界的传奇人物。有人说，世界飞行汽车工业的半壁江山都握在他的手中。', quality: 1, location: 'Ambush', attShow: 39, isNew: true },
        30011013: { cid: 30011013, name: '杰克·帕德雷', ico: 30011013, image: '30011013', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042013, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 1100, isUnlock: false, unlockInfo: '奖杯累计达到1100', info: '杰克是一位顶级老爸！他对自己的老婆孩子保证，要退出他的摩托帮派，加入锦标赛，好开一家“慢餐”餐馆，好好生活。', quality: 1, location: 'defense', attShow: 50, isNew: true },
        30011014: { cid: 30011014, name: '朗·绍特', ico: 30011014, image: '30011014', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042014, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 1200, isUnlock: false, unlockInfo: '奖杯累计达到1200', info: '朗·绍特是加勒比的数码海盗。他的黑客水平实在太高，甚至有人说他能穿墙壁。', quality: 2, location: 'Ambush', attShow: 13, isNew: true },
        30011015: { cid: 30011015, name: '艾米丽', ico: 30011015, image: '30011015', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042015, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 1300, isUnlock: false, unlockInfo: '奖杯累计达到1300', info: '她曾经作为精英军队士兵受过训练，但由于世界没有战争，因此决定加入锦标赛一显身手。', quality: 2, location: 'att', attShow: 39, isNew: true },
        30011016: { cid: 30011016, name: '弗里茲比', ico: 30011016, image: '30011016', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042016, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 1400, isUnlock: false, unlockInfo: '奖杯累计达到1400', info: '她本已获得了参加沙滩奥林匹克赛事的资格，却因为发现了自己对锦标赛和80年代音乐的热爱放弃了参赛。', quality: 2, location: 'att', attShow: 44, isNew: true },
        30011017: { cid: 30011017, name: '好战者', ico: 30011017, image: '30011017', type: 30, stype: 9, ttype: 1, lv: 1, att: 22, loc: 0, attCid: 30042017, skills: [40021053, 40021051, 40021052], lvn: 5, triphyNum: 1500, isUnlock: false, unlockInfo: '奖杯累计达到1500', info: '在故障之后，这一曾经的监控机器人被丢进了垃圾场，但一道隐藏代码让其进入了自我修复模式。在醒来之后，拥有意识的“好战者”选择了通往混乱的道路...并且决定拉起属于自己的一支机器人大军。', quality: 2, location: 'Ambush', attShow: 34, isNew: true },
        20010001: { cid: 20010001, name: '钻石', ico: 20010001, image: 'jin', type: 20, stype: 1, ttype: 1, ctype: 1, info: '稀有的宝石,商人们很喜欢这种宝石', },
        20010002: { cid: 20010002, name: '翡翠', ico: 20010002, image: 'yin', type: 20, stype: 1, ttype: 1, ctype: 1, info: '一种宝石,在商店中可以兑换商品', },
        20010003: { cid: 20010003, name: '金币', ico: 20010003, image: 'tong', type: 20, stype: 1, ttype: 1, ctype: 1, info: '金币', },
        20010101: { cid: 20010101, name: 'VIP', ico: 20010101, type: 20, stype: 1, ttype: 1, ctype: 1, info: 'VIP', },
        20010102: { cid: 20010102, name: '经验', ico: 20010102, type: 20, stype: 1, ttype: 1, ctype: 1, info: '经验', },
        20010103: { cid: 20010103, name: '军阶', ico: 20010103, type: 20, stype: 1, ttype: 1, ctype: 1, info: '军阶积分', },
        20010104: { cid: 20010104, name: '胜利', ico: 20010104, type: 20, stype: 1, ttype: 1, ctype: 1, info: '胜利积分', },
        20010105: { cid: 20010105, name: '失败', ico: 20010105, type: 20, stype: 1, ttype: 1, ctype: 1, info: '失败积分', },
        20010106: { cid: 20010106, name: '段位', ico: 20010106, type: 20, stype: 1, ttype: 1, ctype: 1, info: '段位', },
        20010107: { cid: 20010107, name: '体力', ico: 20010107, type: 20, stype: 1, ttype: 1, ctype: 1, info: '体力', },
        20010108: { cid: 20010108, name: '竞技', ico: 20010108, type: 20, stype: 1, ttype: 1, ctype: 1, info: '竞技点', },
        20010109: { cid: 20010109, name: '段位', ico: 20010103, type: 20, stype: 1, ttype: 1, ctype: 1, info: '段位积分', },
        20010110: { cid: 20010110, name: '天赋', ico: 20010110, type: 20, stype: 1, ttype: 1, ctype: 1, info: '天赋点数', },
        20010111: { cid: 20010111, name: '声望', ico: 20010111, type: 20, stype: 1, ttype: 1, ctype: 1, info: '角色声望', },
        20010112: { cid: 20010112, name: '活跃度', ico: 20010112, type: 20, stype: 1, ttype: 1, ctype: 1, num: 10, numMax: 100, info: '活跃度', },
        20010113: { cid: 20010113, name: '勋章', ico: 20010113, type: 20, stype: 1, ttype: 1, ctype: 1, info: '勋章', },
        20010114: { cid: 20010114, name: '奖杯', ico: 20010114, type: 20, stype: 1, ttype: 1, ctype: 1, info: '奖杯', },
        20010115: { cid: 20010115, name: '积分', ico: 20010115, type: 20, stype: 1, ttype: 1, ctype: 1, info: '积分', },
        20010201: { cid: 20010201, name: '天数', ico: 20010201, type: 20, stype: 1, ttype: 1, ctype: 1, info: '天数', },
        20010301: { cid: 20010301, name: '钥匙', ico: 20010301, type: 20, stype: 1, ttype: 1, ctype: 1, numMax: 3, info: '钥匙', },
        30042001: { cid: 30042001, name: 'M9', ico: '30042001', image: '30042001', type: 30, stype: 1, ttype: 1, ctype: 5, quality: 1, count: 1, lvn: 1, info: '' },
        30042101: { cid: 30042101, name: 'MP7', ico: '30042101', image: '30042101', type: 30, stype: 1, ttype: 2, ctype: 2, quality: 1, count: 1, lvn: 2, info: '' },
        30041101: { cid: 30041101, name: 'RORSCHACH', ico: '30041101', image: '30041101', type: 30, stype: 2, ttype: 1, ctype: 1, hp: 480, attpro: 0.05, count: 1, lvn: 1, info: '' },
        30041201: { cid: 30041201, name: 'BALLISTIC1', ico: '30041201', image: '30041201', type: 30, stype: 3, ttype: 1, ctype: 2, hp: 1200, hppro: 0.05, count: 1, lvn: 1, info: '' },
        3001: { cid: 3001, name: '青铜宝箱', ico: '3001', image: '3001', type: 20, stype: 1, ttype: 1 },
        3002: { cid: 3002, name: '黄金宝箱', ico: '3002', image: '3002', type: 20, stype: 1, ttype: 1 },
        3003: { cid: 3003, name: '钻石宝箱', ico: '3003', image: '3003', type: 20, stype: 1, ttype: 1 },
        3004: { cid: 3004, name: '传说宝箱', ico: '3004', image: '3004', type: 20, stype: 1, ttype: 1 },
        3005: { cid: 3005, name: '彩虹宝箱', ico: '3005', image: '3005', type: 20, stype: 1, ttype: 1 },
    };

    class GoodsVo {
        constructor() {
            this.id = 0;
            this.num = 0;
            this.lv = 0;
            this.lvn = 0;
            this.lib = 0;
            this.loc = 0;
            this.has = false;
            this.child = {};
            this.isNew = false;
            this.isUnlock = false;
            this.fight = 0;
            this.cid = 0;
            this.name = '';
            this.quality = 0;
            this.single = true;
            this.numMax = 0;
            this.count = 0;
            this.location = '';
            this.triphyNum = 0;
        }
        addChild(vo) {
            vo.has = true;
            this.child[vo.id] = vo;
        }
        removeChild(id) {
            delete this.child[id];
        }
        getChild(id) {
            return this.child[id];
        }
        getChildByCid(cid) {
            for (var k in this.child) {
                var vo = this.child[k];
                if (vo.cid == cid) {
                    return vo;
                }
            }
            return null;
        }
        get isHas() {
            if (this.has && this.num > 0) {
                return true;
            }
            return false;
        }
    }

    class GoodsVoBuilder {
        static getGoodsVo(cid) {
            var ncid = GoodsConfig.getModifyCid(cid);
            if (ncid) {
                cid = ncid;
            }
            var co = GoodsListConfig.list[cid];
            if (co) {
                var vo = new GoodsVo();
                ObjectUtil.copy(co, vo);
                vo.cid = cid;
                vo.id = IdUtil.getId();
                return vo;
            }
            return null;
        }
        static createGoodsVo(ele) {
            var vo;
            if (!ele) {
                return null;
            }
            else if (typeof ele == 'number') {
                vo = GoodsVoBuilder.getGoodsVo(ele);
            }
            else if (typeof ele == 'string') {
                vo = GoodsVoBuilder.getGoodsVo(MathUtil.int(ele));
            }
            else {
                vo = GoodsVoBuilder.getGoodsVo(ele.cid);
                if (vo) {
                    for (var k in ele) {
                        if (k != 'cid') {
                            vo[k] = ele[k];
                        }
                    }
                }
            }
            return vo;
        }
        static getGoodsType(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getInt(obj, 'type', 0);
        }
        static getGoodsStype(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getInt(obj, 'stype', 0);
        }
        static getGoodsLib(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getInt(obj, 'lib', 0);
        }
        static getGoodsName(cid) {
            var obj = GoodsListConfig.list[cid];
            if (obj) {
                return obj.name;
            }
            return '';
        }
        static getGoodsImage(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getString(obj, 'image', '');
        }
        static getGoodsNumMax(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getInt(obj, 'numMax', 0);
        }
        static getGoodsSingle(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getBool(obj, 'single', true);
        }
        static getGoodsLv(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getInt(obj, 'lv', 0);
        }
        static getGoodsLvn(cid) {
            var obj = GoodsListConfig.list[cid];
            return ParamUtil.getInt(obj, 'lvn', 0);
        }
    }

    class GoodsModel {
        constructor() {
            this.cidList = {};
            this.list = {};
            this.equipList = {};
            this.lvList = [];
            this.ver = 0;
        }
        static get model() {
            return ModelManager.getModel('GoodsModel', GoodsModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            var list = this.getGoodsListData(this.list);
            data.list = list;
            data.ver = this.ver;
            StorageModel.model.setData("goods", data);
        }
        getGoodsListData(list) {
            var nlist = [];
            for (var k in list) {
                var vo = list[k];
                var child = this.getGoodsListData(vo.child);
                nlist.push({ id: vo.id, cid: vo.cid, num: vo.num, lv: vo.lv, count: vo.count, loc: vo.loc, isNew: vo.isNew, child: child, isUnlock: vo.isUnlock });
            }
            return nlist;
        }
        loadData() {
            var data = StorageModel.model.getData("goods");
            this.list = {};
            this.cidList = {};
            var list = ParamUtil.getObject(data, 'list', null);
            this.ver = ParamUtil.getInt(data, 'ver', 0);
            if (!list || this.ver < 1) {
                this.ver = 1;
                list = GoodsConfig.initList;
            }
            var nlist = this.loadGoodsListData(list);
            for (var k in nlist) {
                var vo = nlist[k];
                if (vo) {
                    this.addGoods(vo);
                }
            }
        }
        loadGoodsListData(list) {
            var nlist = {};
            for (var k in list) {
                var co = list[k];
                var vo = GoodsVoBuilder.createGoodsVo(co);
                if (vo) {
                    vo.has = true;
                    vo.child = this.loadGoodsListData(co.child);
                    nlist[vo.id] = vo;
                }
            }
            return nlist;
        }
        addGoods(goods) {
            goods.has = true;
            this.list[goods.id] = goods;
            this.cidList[goods.cid] = goods;
        }
        removeGoods(id) {
            delete this.list[id];
        }
        getGoods(id) {
            return this.list[id];
        }
        getGoodsChild(id) {
            var vo = this.getGoods(id);
            return vo.child;
        }
        getGoodsByCid(cid) {
            return this.cidList[cid];
        }
        getGoodsList(cid) {
            var single = GoodsVoBuilder.getGoodsSingle(cid);
            if (single) {
                var vo = this.cidList[cid];
                if (vo) {
                    return [vo];
                }
                else {
                    return [];
                }
            }
            var list = [];
            for (var key in this.list) {
                var nvo = this.list[key];
                if (nvo.cid == cid) {
                    list.push(nvo);
                }
            }
            return list;
        }
        getFirstByType(type, stype = 0, ttype = 0, loc = -1) {
            for (var key in this.list) {
                var vo = this.list[key];
                if (type == 0 || type == vo.type) {
                    if (stype == 0 || vo.stype == stype) {
                        if (ttype == 0 || vo.ttype == ttype) {
                            if (loc == -1 || vo.loc == loc) {
                                return vo;
                            }
                        }
                    }
                }
            }
            return null;
        }
        getGoodsNum(cid) {
            var single = GoodsVoBuilder.getGoodsSingle(cid);
            if (single) {
                var vo = this.cidList[cid];
                if (vo) {
                    return vo.num;
                }
                else {
                    return 0;
                }
            }
            var n = 0;
            for (var key in this.list) {
                var nvo = this.list[key];
                if (nvo.cid == cid) {
                    n = n + nvo.num;
                }
            }
            return n;
        }
        getGoodsLv(cid) {
            var vo = this.getGoodsByCid(cid);
            if (vo) {
                return vo.lv;
            }
            else {
                return 0;
            }
        }
        getGoodsByType(type, stype = 0, ttype = 0, loc = -1) {
            var nlist = [];
            for (var key in this.list) {
                var vo = this.list[key];
                if (type == 0 || type == vo.type) {
                    if (stype == 0 || vo.stype == stype) {
                        if (ttype == 0 || vo.ttype == ttype) {
                            if (loc == -1 || vo.loc == loc) {
                                nlist.push(vo);
                            }
                        }
                    }
                }
            }
            return nlist;
        }
    }

    class MainEvent {
    }
    MainEvent.MAIN_INIT_START = 'MAIN_INIT_START';
    MainEvent.MAIN_INIT_PARAM = 'MAIN_INIT_PARAM';
    MainEvent.MAIN_INIT_COMPLETE = 'MAIN_INIT_COMPLETE';

    class PlatformEvent {
        static PLATFORM_AD_VIDEO_COMPLETED(id) { return 'PLATFORM_AD_VIDEO_COMPLETED@' + id; }
        ;
        static PLATFORM_AD_VIDEO_DISCONTINUE(id) { return 'PLATFORM_AD_VIDEO_DISCONTINUE@' + id; }
        ;
        static PLATFORM_AD_APPBOX_COMPLETED(id) { return 'PLATFORM_AD_APPBOX_COMPLETED@' + id; }
        ;
        static PLATFORM_AD_APPBOX_DISCONTINUE(id) { return 'PLATFORM_AD_APPBOX_DISCONTINUE@' + id; }
        ;
    }
    PlatformEvent.PLATFORM_EXIT = 'PLATFORM_EXIT';
    PlatformEvent.PLATFORM_API_INIT = 'PLATFORM_API_INIT';
    PlatformEvent.PLATFORM_SKD_INIT = 'PLATFORM_SKD_INIT';
    PlatformEvent.PLATFORM_AD_BANNER_SHOW = 'PLATFORM_AD_BANNER_SHOW';
    PlatformEvent.PLATFORM_AD_VIDEO_SHOW = 'PLATFORM_AD_VIDEO_SHOW';
    PlatformEvent.PLATFORM_AD_VIDEO_LOAD = 'PLATFORM_AD_VIDEO_LOAD';
    PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE = 'PLATFORM_AD_VIDEO_COMPLETE';
    PlatformEvent.PLATFORM_AD_VIDEO_FAIL = 'PLATFORM_AD_VIDEO_FAIL';
    PlatformEvent.PLATFORM_AD_CUSTOMAD_SHOW = 'PLATFORM_AD_CUSTOMAD_SHOW';
    PlatformEvent.PLATFORM_AD_GRID_SHOW = 'PLATFORM_AD_GRID_SHOW';
    PlatformEvent.PLATFORM_AD_GAMEBANNER_SHOW = 'PLATFORM_AD_GAMEBANNER_SHOW';
    PlatformEvent.PLATFORM_AD_GAMEBANNER1_SHOW = 'PLATFORM_AD_GAMEBANNER1_SHOW';
    PlatformEvent.PLATFORM_AD_RANDOM_SHOW = 'PLATFORM_AD_RANDOM_SHOW';
    PlatformEvent.PLATFORM_AD_INSERT_SHOW = 'PLATFORM_AD_INSERT_SHOW';
    PlatformEvent.PLATFORM_AD_FEED_SHOW = 'PLATFORM_AD_FEED_SHOW';
    PlatformEvent.PLATFORM_AD_CUSTOM_SHOW = 'PLATFORM_AD_CUSTOM_SHOW';
    PlatformEvent.PLATFORM_AD_APPBOX_SHOW = 'PLATFORM_AD_APPBOX_SHOW';
    PlatformEvent.PLATFORM_AD_APPBOX_LOAD = 'PLATFORM_AD_APPBOX_LOAD';
    PlatformEvent.PLATFORM_AD_APPBOX_COMPLETE = 'PLATFORM_AD_APPBOX_COMPLETE';
    PlatformEvent.PLATFORM_AD_APPBOX_FAIL = 'PLATFORM_AD_APPBOX_FAIL';
    PlatformEvent.PLATFORM_AD_BLOCK_SHOW = 'PLATFORM_AD_BLOCK_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE_VIEW_SHOW = 'PLATFORM_AD_NATIVE_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW = 'PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE_SHOW = 'PLATFORM_AD_NATIVE_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE_CLICK = 'PLATFORM_AD_NATIVE_CLICK';
    PlatformEvent.PLATFORM_AD_NATIVE_LOAD = 'PLATFORM_AD_NATIVE_LOAD';
    PlatformEvent.PLATFORM_AD_NATIVE_LOADED = 'PLATFORM_AD_NATIVE_LOADED';
    PlatformEvent.PLATFORM_AD_NATIVE_STOP = 'PLATFORM_AD_NATIVE_STOP';
    PlatformEvent.PLATFORM_AD_NATIVE_STOPED = 'PLATFORM_AD_NATIVE_STOPED';
    PlatformEvent.PLATFORM_AD_NATIVE_ERROR = 'PLATFORM_AD_NATIVE_ERROR';
    PlatformEvent.PLATFORM_SHARE_SHOW = 'PLATFORM_SHARE_SHOW';
    PlatformEvent.PLATFORM_SHARE_COMPLETE = 'PLATFORM_SHARE_COMPLETE';
    PlatformEvent.PLATFORM_SHARE_FAIL = 'PLATFORM_SHARE_FAIL';
    PlatformEvent.PLATFORM_RECORDER_BTN_VIEW_SHOW = 'PLATFORM_RECORDER_BTN_VIEW_SHOW';
    PlatformEvent.PLATFORM_RECORDER_BTN_VIEW_CLOSE = 'PLATFORM_RECORDER_BTN_VIEW_CLOSE';
    PlatformEvent.PLATFORM_RECORDER_STATE_VIEW_SHOW = 'PLATFORM_RECORDER_STATE_VIEW_SHOW';
    PlatformEvent.PLATFORM_RECORDER_START = 'PLATFORM_RECORDER_START';
    PlatformEvent.PLATFORM_RECORDER_STOP = 'PLATFORM_RECORDER_STOP';
    PlatformEvent.PLATFORM_RECORDER_END = 'PLATFORM_RECORDER_END';
    PlatformEvent.PLATFORM_SHARE_VIEW_SHOW = 'PLATFORM_SHARE_VIEW_SHOW';
    PlatformEvent.PLATFORM_SHARE_VIDEO_SHOW = 'PLATFORM_SHARE_VIDEO_SHOW';
    PlatformEvent.PLATFORM_SHARE_VIDEO_COMPLETE = 'PLATFORM_SHARE_VIDEO_COMPLETE';
    PlatformEvent.PLATFORM_SHARE_VIDEO_FAIL = 'PLATFORM_SHARE_VIDEO_FAIL';
    PlatformEvent.PLATFORM_ADDICO_VIEW_SHOW = 'PLATFORM_ADDICO_VIEW_SHOW';
    PlatformEvent.PLATFORM_ADDICO_REWARD_VIEW_SHOW = 'PLATFORM_ADDICO_REWARD_VIEW_SHOW';
    PlatformEvent.PLATFORM_ADDICO_SHOW = 'PLATFORM_ADDICO_SHOW';
    PlatformEvent.PLATFORM_ADDICO_COMPLETE = 'PLATFORM_ADDICO_COMPLETE';
    PlatformEvent.PLATFORM_ADDICO_FAIL = 'PLATFORM_ADDICO_FAIL';
    PlatformEvent.PLATFORM_LINK_GOTO = 'PLATFORM_LINK_GOTO';
    PlatformEvent.PLATFORM_IMAGE_SHOW = 'PLATFORM_IMAGE_SHOW';
    PlatformEvent.PLATFORM_INVITE = 'PLATFORM_INVITE';
    PlatformEvent.PLATFORM_GAMEBTN_SHOW = 'PLATFORM_GAMEBTN_SHOW';
    PlatformEvent.PLATFORM_VIEW_EP_SHOW = 'PLATFORM_VIEW_EP_SHOW';
    PlatformEvent.PLATFORM_VIEW_ICON_SHOW = 'PLATFORM_VIEW_ICON_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE_ICON_VIEW_SHOW = 'PLATFORM_AD_NATIVE_ICON_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE_ICON1_VIEW_SHOW = 'PLATFORM_AD_NATIVE_ICON1_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE_ICON3_VIEW_SHOW = 'PLATFORM_AD_NATIVE_ICON3_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE1_VIEW_SHOW = 'PLATFORM_AD_NATIVE1_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE2_VIEW_SHOW = 'PLATFORM_AD_NATIVE2_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE3_VIEW_SHOW = 'PLATFORM_AD_NATIVE3_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE4_VIEW_SHOW = 'PLATFORM_AD_NATIVE4_VIEW_SHOW';
    PlatformEvent.PLATFORM_AD_NATIVE5_VIEW_SHOW = 'PLATFORM_AD_NATIVE5_VIEW_SHOW';
    PlatformEvent.PLATFORM_FOLLOW_ICO_VIEW_SHOW = 'PLATFORM_FOLLOW_ICO_VIEW_SHOW';
    PlatformEvent.PLATFORM_FOLLOW_VIEW_SHOW = 'PLATFORM_FOLLOW_VIEW_SHOW';
    PlatformEvent.PLATFORM_FOLLOW_REWARD_VIEW_SHOW = 'PLATFORM_FOLLOW_REWARD_VIEW_SHOW';
    PlatformEvent.PLATFORM_FOLLOW_START = 'PLATFORM_FOLLOW_START';
    PlatformEvent.PLATFORM_FOLLOW_COMPLETE = 'PLATFORM_FOLLOW_COMPLETE';
    PlatformEvent.PLATFORM_ADD_MINI_VIEW = 'PLATFORM_ADD_MINI_VIEW';
    PlatformEvent.PLATFORM_ADDITION_VIEW_SHOW = 'PLATFORM_ADDITION_VIEW_SHOW';
    PlatformEvent.PLATFORM_CLAUSE_VIEW = 'PLATFORM_CLAUSE_VIEW';
    PlatformEvent.PLATFORM_PRIVACY_VIEW = 'PLATFORM_PRIVACY_VIEW';
    PlatformEvent.PLATFORM_PRIVACY_AGREE = 'PLATFORM_PRIVACY_AGREE';
    PlatformEvent.PLATFORM_OPPO_ICO_VIEW = 'PLATFORM_OPPO_ICO_VIEW';
    PlatformEvent.PLATFORM_VIVO_ICO_VIEW = 'PLATFORM_OPPO_ICO_VIEW';
    PlatformEvent.PLATFORM_TT_ICO_SHOW = 'PLATFORM_TT_ICO_SHOW';

    class SceneEvent {
    }
    SceneEvent.SCENE_VIEW_SHOW = 'SCENE_VIEW_SHOW';
    SceneEvent.SCENE_BATTLE_VIEW_SHOW = 'SCENE_BATTLE_VIEW_SHOW';
    SceneEvent.SCENE_EDITOR_VIEW_SHOW = 'SCENE_EDITOR_VIEW_SHOW';
    SceneEvent.SCENE_VIEW_SET = 'SCENE_VIEW_SET';
    SceneEvent.SCENE_VIEW_START = 'SCENE_VIEW_START';
    SceneEvent.SCENE_VIEW_CLOSE = 'SCENE_VIEW_CLOSE';
    SceneEvent.SCENE_VIEW_EXIT = 'SCENE_VIEW_EXIT';
    SceneEvent.SCENE_LOAD_COMPLETE = 'SCENE_LOAD_COMPLETE';
    SceneEvent.SCENE_BEGAIN_CAMERA_COMPLETE = 'SCENE_BEGAIN_CAMERA_COMPLETE';
    SceneEvent.SCENE_END_CAMERA_COMPLETE = 'SCENE_END_CAMERA_COMPLETE';
    SceneEvent.SCENE_PAUSE_REQUEST = 'SCENE_PAUSE_REQUEST';
    SceneEvent.SCENE_PAUSE_RESPONSE = 'SCENE_PAUSE_RESPONSE';
    SceneEvent.SCENE_STATE_SET = 'SCENE_STATE_SET';
    SceneEvent.SCENE_STATE_CHANGE = 'SCENE_STATE_CHANGE';
    SceneEvent.SCENE_STATE_READY = 'SCENE_STATE_READY';
    SceneEvent.SCENE_STATE_FALL = 'SCENE_STATE_FALL';
    SceneEvent.SCENE_STATE_OVER = 'SCENE_STATE_OVER';
    SceneEvent.SCENE_STATE_END = 'SCENE_STATE_END';
    SceneEvent.SCENE_STATE_PAUSE = 'SCENE_PAUSE_SET';
    SceneEvent.SCENE_CAMERA_SET = 'SCENE_CAMERA_SET';
    SceneEvent.SCENE_ELEMENT_VIEW_SHOW = 'SCENE_ELEMENT_VIEW_SHOW';
    SceneEvent.SCENE_EFFECT_VIEW_SHOW = 'SCENE_EFFECT_VIEW_SHOW';
    SceneEvent.SCENE_LINE_VIEW_SHOW = 'SCENE_LINE_VIEW_SHOW';

    class BattleConfig {
        static getMtBoxList(index) {
            return this.mysteryBoxList[index];
        }
        static getVictoryTriphy(lv) {
            return 20 + (lv - 1) * 2;
        }
        static getDefeatTriphy(lv) {
            return 9 + lv;
        }
        static getNpcLv(victoryNum) {
            if (this.battleLvType == 1) {
                var lv = Math.round((victoryNum + 1));
            }
            else {
                var lv = Math.round((victoryNum + 1) / 4 + 0.5);
            }
            return lv;
        }
    }
    BattleConfig.battleTryType = 0;
    BattleConfig.battleTaskType = 0;
    BattleConfig.battleTryTypeTwo = 0;
    BattleConfig.isAutoShowTask = false;
    BattleConfig.isShowEndCrazyChest = false;
    BattleConfig.battleLvType = 0;
    BattleConfig.battleDefProType = 0;
    BattleConfig.battleType = 0;
    BattleConfig.getGunType = 0;
    BattleConfig.endType = 0;
    BattleConfig.defeatType = 0;
    BattleConfig.victoryType = 0;
    BattleConfig.battleViewType = 0;
    BattleConfig.crazyType = 0;
    BattleConfig.phy = 5;
    BattleConfig.phyLev = 20;
    BattleConfig.pickTime = 10;
    BattleConfig.partExp = 50;
    BattleConfig.partTong = 100;
    BattleConfig.fullTong = 200;
    BattleConfig.killJin = 10;
    BattleConfig.mvpJin = 100;
    BattleConfig.winTong = 200;
    BattleConfig.winJin = 50;
    BattleConfig.isShowTaskList = true;
    BattleConfig.isShowAd = true;
    BattleConfig.defGun1Cid = 30042001;
    BattleConfig.defGun2Cid = 30042201;
    BattleConfig.defHelmetCid = 30041101;
    BattleConfig.defClothesCid = 30041201;
    BattleConfig.vip = { attPro: 0.5, invinTime: 30, num: 100 };
    BattleConfig.lotteryList = [
        [{ cid: 30042203, num: 1, lvn: 0 }, { cid: 30042403, num: 1, lvn: 10 }, { cid: 30042212, num: 1, lvn: 30 }],
        [{ cid: 30041204, num: 1, lvn: 0 }, { cid: 30041209, num: 1, lvn: 10 }, { cid: 30041211, num: 1, lvn: 30 }],
        [{ cid: 30041104, num: 1, lvn: 0 }, { cid: 30041109, num: 1, lvn: 10 }, { cid: 30041111, num: 1, lvn: 30 }],
    ];
    BattleConfig.mysteryBoxList = [
        { index: 0, goods: [{ cid: GoodsAttrType.ATTR_JIN, num: 88 }, { cid: GoodsAttrType.ATTR_TONG, num: 188 }], weight: 50 },
        { index: 1, goods: [{ cid: GoodsAttrType.ATTR_JIN, num: 138 }, { cid: GoodsAttrType.ATTR_TONG, num: 288 }], weight: 35 },
        { index: 2, goods: [{ cid: GoodsAttrType.ATTR_JIN, num: 268 }, { cid: GoodsAttrType.ATTR_TONG, num: 588 }], weight: 10 },
        { index: 3, goods: [{ cid: 30042203, num: 1 }, { cid: 30042403, num: 1 }, { cid: 30042212, num: 1 }], weight: 5 },
    ];
    BattleConfig.adTryGunCid = 30042503;
    BattleConfig.levReviveMaxNum = 1;
    BattleConfig.killRewardList = [
        { index: 1, goods: [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }], killNum: 3, taskKill: 6, isReceive: false },
        { index: 2, goods: [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }], killNum: 6, taskKill: 10, isReceive: false },
        { index: 3, goods: [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }], killNum: 10, taskKill: 16, isReceive: false },
        { index: 4, goods: [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }], killNum: 16, taskKill: 16, isReceive: false },
    ];
    BattleConfig.tryHeroList = [
        { cid: 30011006, triphyNum: 0, toTriphyNum: 400, lv: 11 },
        { cid: 30011007, triphyNum: 400, toTriphyNum: 500, lv: 12 },
        { cid: 30011008, triphyNum: 500, toTriphyNum: 600, lv: 13 },
        { cid: 30011009, triphyNum: 600, toTriphyNum: 700, lv: 14 },
        { cid: 30011010, triphyNum: 700, toTriphyNum: 800, lv: 15 },
    ];

    class BattleEvent {
    }
    BattleEvent.BATTLE_VIEW_SHOW = 'BATTLE_VIEW_SHOW';
    BattleEvent.BATTLE_READY_VIEW_SHOW = 'BATTLE_READY_VIEW_SHOW';
    BattleEvent.BATTLE_VICTORY_VIEW_SHOW = 'BATTLE_VICTORY_VIEW_SHOW';
    BattleEvent.BATTLE_DEFEAT_VIEW_SHOW = 'BATTLE_DEFEAT_VIEW_SHOW';
    BattleEvent.BATTLE_END_VIEW_SHOW = 'BATTLE_END_VIEW_SHOW';
    BattleEvent.BATTLE_LOAD_VIEW_SHOW = 'BATTLE_LOAD_VIEW_SHOW';
    BattleEvent.BATTLE_VICTORY_MVP_VIEW_SHOW = 'BATTLE_VICTORY_MVP_VIEW_SHOW';
    BattleEvent.BATTLE_DEFEAT_MVP_VIEW_SHOW = 'BATTLE_DEFEAT_MVP_VIEW_SHOW';
    BattleEvent.BATTLE_VICTORY_NOTICE_VIEW_SHOW = 'BATTLE_VICTORY_NOTICE_VIEW_SHOW';
    BattleEvent.BATTLE_DEFEAT_NOTICE_VIEW_SHOW = 'BATTLE_DEFEAT_NOTICE_VIEW_SHOW';
    BattleEvent.BATTLE_END_NOTICE_VIEW_SHOW = 'BATTLE_END_NOTICE_VIEW_SHOW';
    BattleEvent.BATTLE_RELOAD_VIEW_SHOW = 'BATTLE_RELOAD_VIEW_SHOW';
    BattleEvent.BATTLE_HP_VIEW_SHOW = 'BATTLE_HP_VIEW_SHOW';
    BattleEvent.BATTLE_AIM_AINMATION_VIEW_SHOW = 'BATTLE_AIM_AINMATION_VIEW_SHOW';
    BattleEvent.BATTLE_HP_PILL_VIEW_SHOW = 'BATTLE_HP_PILL_VIEW_SHOW';
    BattleEvent.BATTLE_ATT_TEXT_VIEW_SHOW = 'BATTLE_ATT_TEXT_VIEW_SHOW';
    BattleEvent.BATTLE_EXHAUST_TIP_VIEW_SHOW = 'BATTLE_EXHAUST_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_FULL_TIP_VIEW_SHOW = 'BATTLE_FULL_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_KILL_TIP_VIEW_SHOW = 'BATTLE_KILL_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_KILL_ANIM_VIEW_SHOW = 'BATTLE_KILL_ANIM_VIEW_SHOW';
    BattleEvent.BATTLE_REVIVE_TIP_VIEW_SHOW = 'BATTLE_REVIVE_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_ANTKILL_TIP_VIEW_SHOW = 'BATTLE_ANTKILL_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_RESURREC_VIEW_SHOW = 'BATTLE_RESURREC_VIEW_SHOW';
    BattleEvent.BATTLE_LOTTERY_VIEW_SHOW = 'BATTLE_LOTTERY_VIEW_SHOW';
    BattleEvent.BATTLE_MODES_VIEW_SHOW = 'BATTLE_MODES_VIEW_SHOW';
    BattleEvent.BATTLE_MATCH_VIEW_SHOW = 'BATTLE_MATCH_VIEW_SHOW';
    BattleEvent.BATTLE_MATCH5_VIEW_SHOW = 'BATTLE_MATCH5_VIEW_SHOW';
    BattleEvent.BATTLE_MATCH_LEV_VIEW_SHOW = 'BATTLE_MATCH_LEV_VIEW_SHOW';
    BattleEvent.BATTLE_START_TIP_VIEW_SHOW = 'BATTLE_START_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_GET_VIP_VIEW_SHOW = 'BATTLE_GET_VIP_VIEW_SHOW';
    BattleEvent.BATTLE_BOX_VIEW_SHOW = 'BATTLE_BOX_VIEW_SHOW';
    BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW = 'BATTLE_TEXT_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_GET_GUN_VIEW_SHOW = 'BATTLE_GET_GUN_VIEW_SHOW';
    BattleEvent.BATTLE_WAVE_TIP_VIEW_SHOW = 'BATTLE_WAVE_TIP_VIEW_SHOW';
    BattleEvent.BATTLE_TRY_HERO_VIEW_SHOW = 'BATTLE_TRY_HERO_VIEW_SHOW';
    BattleEvent.BATTLE_CARD_GROUP_VIEW_SHOW = 'BATTLE_CARD_GROUP_VIEW_SHOW';
    BattleEvent.BATTLE_REBORN_HERO_VIEW_SHOW = 'BATTLE_REBORN_HERO_VIEW_SHOW';
    BattleEvent.BATTLE_START_TRY_HERO_VIEW_SHOW = 'BATTLE_START_TRY_HERO_VIEW_SHOW';
    BattleEvent.BATTLE_GAME_OVER_VIEW_SHOW = 'BATTLE_GAME_OVER_VIEW_SHOW';
    BattleEvent.BATTLE_TASK_VIEW_SHOW = 'BATTLE_TASK_VIEW_SHOW';
    BattleEvent.BATTLE_START = 'BATTLE_START';
    BattleEvent.BATTLE_RESTART = 'BATTLE_RESTART';
    BattleEvent.BATTLE_STATE_START = 'BATTLE_STATE_START';
    BattleEvent.BATTLE_STATE_END = 'BATTLE_STATE_END';
    BattleEvent.BATTLE_STATE_OVER = 'BATTLE_STATE_OVER';
    BattleEvent.BATTLE_STATE_VICTORY = 'BATTLE_STATE_VICTORY';
    BattleEvent.BATTLE_STATE_DEFEAT = 'BATTLE_STATE_DEFEAT';
    BattleEvent.BATTLE_LOAD_START = 'BATTLE_LOAD_START';
    BattleEvent.BATTLE_WAVE_NEXT = 'BATTLE_WAVE_NEXT';
    BattleEvent.BATTLE_LEV_MODES_VIEW_SHOW = 'BATTLE_LEV_MODES_VIEW_SHOW';
    BattleEvent.BATTLE_LEV_SUPPLY_VIEW_SHOW = 'BATTLE_LEV_SUPPLY_VIEW_SHOW';
    BattleEvent.BATTLE_LEV_REPLACE_VIEW_SHOW = 'BATTLE_LEV_REPLACE_VIEW_SHOW';
    BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW = 'BATTLE_LEV_UNLOCK_VIEW_SHOW';
    BattleEvent.BATTLE_TIME_LAST = 'BATTLE_TIME_LAST';
    BattleEvent.BATTLE_CLOSE_CLICK = 'BATTLE_CLOSE_CLICK';
    BattleEvent.BATTLE_PLAYER_STOP = 'BATTLE_PLAYER_STOP';
    BattleEvent.BATTLE_PAUSE = 'BATTLE_PAUSE';
    BattleEvent.BATTLE_SELECT_HERO_REQUEST = 'BATTLE_SELECT_HERO_REQUEST';
    BattleEvent.BATTLE_SELECT_HERO_RESPONSE = 'BATTLE_SELECT_HERO_RESPONSE';
    BattleEvent.BATTLE_SETTLE_COMPLETE = 'BATTLE_SETTLE_COMPLETE';
    BattleEvent.BATTLE_TASK_RESPONSE = 'BATTLE_TASK_RESPONSE';
    BattleEvent.BATTLE_TASK_REQUEST = 'BATTLE_TASK_REQUEST';
    BattleEvent.BATTLE_BOX_FLOAT_VIEW_SHOW = 'BATTLE_BOX_FLOAT_VIEW_SHOW';
    BattleEvent.BATTLE_CRAZY_CHEST_VIEW_SHOW = 'BATTLE_CRAZY_CHEST_VIEW_SHOW';
    BattleEvent.BATTLE_END_CRAZY_CHEST_VIEW_SHOW = 'BATTLE_END_CRAZY_CHEST_VIEW_SHOW';

    class BattleModel {
        constructor() {
            this.isBattle = false;
            this.result = 0;
            this.victoryNum = 0;
            this.defeatNum = 0;
            this.vipBuff = 0;
            this.aridorpNum = 0;
            this.isLvUpTip = true;
            this.lev = 0;
            this.battleLev = 0;
            this.isUnlock = false;
            this.wave = 0;
            this.isSettlement = true;
            this.isPlayLev = false;
            this.foeName = '';
            this.foeIco = '';
            this.nameList = [];
            this.pickJinNum = 0;
            this.pickTongNum = 0;
            this.tryHerocid = 30011002;
            this.playerCid = 30011001;
            this.enemyTriphyNum = 0;
        }
        static get model() {
            return ModelManager.getModel('BattleModel', BattleModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.victoryNum = this.victoryNum;
            data.defeatNum = this.defeatNum;
            data.lev = this.lev;
            StorageModel.model.setData("battle", data);
        }
        loadData() {
            var data = StorageModel.model.getData("battle");
            this.victoryNum = ParamUtil.getNumber(data, 'victoryNum', 0);
            this.defeatNum = ParamUtil.getNumber(data, 'defeatNum', 0);
            this.lev = ParamUtil.getNumber(data, 'lev', 0);
        }
    }

    class BattleLocTool {
        static getGun1Loc() {
            return GoodsModel.model.getFirstByType(30, 1, 1, 1);
        }
        static getGun2Loc() {
            return GoodsModel.model.getFirstByType(30, 1, 2, 1);
        }
        static getHelmetLoc() {
            return GoodsModel.model.getFirstByType(30, 2, 1, 1);
        }
        static getClothesLoc() {
            return GoodsModel.model.getFirstByType(30, 3, 1, 1);
        }
    }

    class LeadConfig {
        static getIcoUrl(leadType) {
            return 'ui/img_uk_rank_icon' + leadType + '.png';
        }
        static getLeadData(type) {
            return this.list[type - 1];
        }
        static getList(type) {
            if (type == 1) {
                return this.list1;
            }
            else if (type == 2) {
                return this.list2;
            }
            else if (type == 3) {
                return this.list3;
            }
            else if (type == 4) {
                return this.list4;
            }
            else if (type == 5) {
                return this.list5;
            }
            else if (type == 6) {
                return this.list6;
            }
            else if (type == 7) {
                return this.list7;
            }
            else if (type == 8) {
                return this.list8;
            }
            else if (type == 9) {
                return this.list9;
            }
            else if (type == 10) {
                return this.list10;
            }
            else if (type == 11) {
                return this.list11;
            }
            else if (type == 12) {
                return this.list12;
            }
            else if (type == 13) {
                return this.list13;
            }
            else if (type == 14) {
                return this.list14;
            }
            else if (type == 15) {
                return this.list15;
            }
            else if (type == 16) {
                return this.list16;
            }
            else if (type == 17) {
                return this.list17;
            }
            else if (type == 18) {
                return this.list18;
            }
            else if (type == 19) {
                return this.list19;
            }
            else if (type == 20) {
                return this.list20;
            }
            else if (type == 21) {
                return this.list21;
            }
            else if (type == 22) {
                return this.list22;
            }
            else if (type == 23) {
                return this.list23;
            }
            else if (type == 24) {
                return this.list24;
            }
            return [];
        }
    }
    LeadConfig.leadMax = 25;
    LeadConfig.list = [
        { type: 1, name: '列兵1', hpVule: 0.05, tValue: 0.10, jValue: 0.10, reward: [{ cid: 20010001, num: 100 }, { cid: 20010003, num: 300 }] },
        { type: 2, name: '列兵2', hpVule: 0.06, tValue: 0.12, jValue: 0.12, reward: [{ cid: 20010001, num: 200 }, { cid: 20010003, num: 600 }] },
        { type: 3, name: '列兵3', hpVule: 0.08, tValue: 0.16, jValue: 0.16, reward: [{ cid: 30041113, num: 1, count: 0 }, { cid: 30041213, num: 1, count: 0 }] },
        { type: 4, name: '上等兵1', hpVule: 0.10, tValue: 0.20, jValue: 0.20, reward: [{ cid: 20010001, num: 200 }, { cid: 20010003, num: 600 }] },
        { type: 5, name: '上等兵2', hpVule: 0.11, tValue: 0.22, jValue: 0.22, reward: [{ cid: 20010001, num: 300 }, { cid: 20010003, num: 900 }] },
        { type: 6, name: '上等兵3', hpVule: 0.13, tValue: 0.26, jValue: 0.26, reward: [{ cid: 30041114, num: 1, count: 0 }, { cid: 30041214, num: 1, count: 0 }] },
        { type: 7, name: '下士1', hpVule: 0.15, tValue: 0.30, jValue: 0.30, reward: [{ cid: 20010001, num: 300 }, { cid: 20010003, num: 900 }] },
        { type: 8, name: '下士2', hpVule: 0.16, tValue: 0.32, jValue: 0.32, reward: [{ cid: 20010001, num: 400 }, { cid: 20010003, num: 1200 }] },
        { type: 9, name: '下士3', hpVule: 0.18, tValue: 0.36, jValue: 0.36, reward: [{ cid: 30041115, num: 1, count: 0 }, { cid: 30041215, num: 1, count: 0 }] },
        { type: 10, name: '中士1', hpVule: 0.20, tValue: 0.40, jValue: 0.40, reward: [{ cid: 20010001, num: 400 }, { cid: 20010003, num: 1200 }] },
        { type: 11, name: '中士2', hpVule: 0.21, tValue: 0.42, jValue: 0.42, reward: [{ cid: 20010001, num: 500 }, { cid: 20010003, num: 1500 }] },
        { type: 12, name: '中士3', hpVule: 0.23, tValue: 0.46, jValue: 0.46, reward: [{ cid: 30041116, num: 1, count: 0 }, { cid: 30041216, num: 1, count: 0 }] },
        { type: 13, name: '上士1', hpVule: 0.25, tValue: 0.50, jValue: 0.50, reward: [{ cid: 20010001, num: 500 }, { cid: 20010003, num: 1500 }] },
        { type: 14, name: '上士2', hpVule: 0.26, tValue: 0.52, jValue: 0.52, reward: [{ cid: 20010001, num: 600 }, { cid: 20010003, num: 1800 }] },
        { type: 15, name: '上士3', hpVule: 0.28, tValue: 0.56, jValue: 0.56, reward: [{ cid: 30041117, num: 1, count: 0 }, { cid: 30041217, num: 1, count: 0 }] },
        { type: 16, name: '少尉1', hpVule: 0.30, tValue: 0.60, jValue: 0.60, reward: [{ cid: 20010001, num: 600 }, { cid: 20010003, num: 1800 }] },
        { type: 17, name: '少尉2', hpVule: 0.31, tValue: 0.62, jValue: 0.62, reward: [{ cid: 20010001, num: 700 }, { cid: 20010003, num: 2100 }] },
        { type: 18, name: '少尉3', hpVule: 0.33, tValue: 0.66, jValue: 0.66, reward: [{ cid: 30041118, num: 1, count: 0 }, { cid: 30041218, num: 1, count: 0 }] },
        { type: 19, name: '中尉1', hpVule: 0.40, tValue: 0.80, jValue: 0.80, reward: [{ cid: 20010001, num: 700 }, { cid: 20010003, num: 2100 }] },
        { type: 20, name: '中尉2', hpVule: 0.41, tValue: 0.82, jValue: 0.82, reward: [{ cid: 20010001, num: 800 }, { cid: 20010003, num: 2400 }] },
        { type: 21, name: '中尉3', hpVule: 0.43, tValue: 0.86, jValue: 0.86, reward: [{ cid: 30041119, num: 1, count: 0 }, { cid: 30041219, num: 1, count: 0 }] },
        { type: 22, name: '上尉1', hpVule: 0.50, tValue: 1.00, jValue: 1.00, reward: [{ cid: 20010001, num: 800 }, { cid: 20010003, num: 2400 }] },
        { type: 23, name: '上尉2', hpVule: 0.51, tValue: 1.02, jValue: 1.02, reward: [{ cid: 20010001, num: 900 }, { cid: 20010003, num: 2700 }] },
        { type: 24, name: '上尉3', hpVule: 0.53, tValue: 1.06, jValue: 1.06, reward: [{ cid: 30041120, num: 1, count: 0 }, { cid: 30041220, num: 1, count: 0 }] },
        { type: 25, name: '少校1', hpVule: 0.60, tValue: 1.20, jValue: 1.20, reward: [] },
    ];
    LeadConfig.list1 = [
        { index: 1, info: ' 累计胜利1次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 50 }], gotoEvent: 'PAGE_BATTLE_START' },
    ];
    LeadConfig.list2 = [
        { index: 1, info: ' 累计胜利1次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 50 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计装备强化1次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
    ];
    LeadConfig.list3 = [
        { index: 1, info: ' 累计胜利1次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 50 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习1次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 100 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备强化1次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
    ];
    LeadConfig.list4 = [
        { index: 1, info: ' 累计胜利2次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习1次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备强化2次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计打开宝箱1次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 50 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list5 = [
        { index: 1, info: ' 累计胜利2次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习1次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化2次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱1次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 50 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list6 = [
        { index: 1, info: ' 累计胜利2次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习1次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化2次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱1次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 50 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list7 = [
        { index: 1, info: ' 累计胜利3次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 3, reward: [{ cid: 20010001, num: 150 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习1次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化3次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱2次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list8 = [
        { index: 1, info: ' 累计胜利3次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 3, reward: [{ cid: 20010001, num: 150 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化3次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱2次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list9 = [
        { index: 1, info: ' 累计胜利3次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 3, reward: [{ cid: 20010001, num: 150 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习1次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 1, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化3次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 300 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱2次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list10 = [
        { index: 1, info: ' 累计胜利4次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 4, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化4次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 4, reward: [{ cid: 20010003, num: 400 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱3次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 3, reward: [{ cid: 20010001, num: 150 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list11 = [
        { index: 1, info: ' 累计胜利4次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 4, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化4次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 4, reward: [{ cid: 20010003, num: 400 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱3次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 3, reward: [{ cid: 20010001, num: 150 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list12 = [
        { index: 1, info: ' 累计胜利4次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 4, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化4次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 4, reward: [{ cid: 20010003, num: 400 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱3次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 3, reward: [{ cid: 20010001, num: 150 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list13 = [
        { index: 1, info: ' 累计胜利5次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 5, reward: [{ cid: 20010001, num: 250 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化5次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 5, reward: [{ cid: 20010003, num: 500 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱4次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 4, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list14 = [
        { index: 1, info: ' 累计胜利5次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 5, reward: [{ cid: 20010001, num: 250 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化5次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 5, reward: [{ cid: 20010003, num: 500 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱4次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 4, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list15 = [
        { index: 1, info: ' 累计胜利5次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 5, reward: [{ cid: 20010001, num: 250 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化5次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 5, reward: [{ cid: 20010003, num: 500 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱4次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 4, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list16 = [
        { index: 1, info: ' 累计胜利6次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 6, reward: [{ cid: 20010001, num: 300 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化6次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 6, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱5次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 5, reward: [{ cid: 20010001, num: 250 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list17 = [
        { index: 1, info: ' 累计胜利6次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 6, reward: [{ cid: 20010001, num: 300 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化6次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 6, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱5次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 5, reward: [{ cid: 20010001, num: 250 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list18 = [
        { index: 1, info: ' 累计胜利6次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 6, reward: [{ cid: 20010001, num: 300 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习2次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 2, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买1次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 1, reward: [{ cid: 20010001, num: 100 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化6次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 6, reward: [{ cid: 20010003, num: 600 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱5次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 5, reward: [{ cid: 20010001, num: 250 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list19 = [
        { index: 1, info: ' 累计胜利7次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 7, reward: [{ cid: 20010001, num: 350 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习3次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买2次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化7次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 7, reward: [{ cid: 20010003, num: 700 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱7次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 7, reward: [{ cid: 20010001, num: 350 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list20 = [
        { index: 1, info: ' 累计胜利7次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 7, reward: [{ cid: 20010001, num: 350 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习3次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买2次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化7次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 7, reward: [{ cid: 20010003, num: 700 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱7次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 7, reward: [{ cid: 20010001, num: 350 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list21 = [
        { index: 1, info: ' 累计胜利7次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 7, reward: [{ cid: 20010001, num: 350 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习3次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买2次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化7次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 7, reward: [{ cid: 20010003, num: 700 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱7次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 7, reward: [{ cid: 20010001, num: 350 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list22 = [
        { index: 1, info: ' 累计胜利8次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 8, reward: [{ cid: 20010001, num: 400 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习3次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买2次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化8次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 8, reward: [{ cid: 20010003, num: 800 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱9次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 9, reward: [{ cid: 20010001, num: 450 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list23 = [
        { index: 1, info: ' 累计胜利8次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 8, reward: [{ cid: 20010001, num: 400 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习3次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买2次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化8次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 8, reward: [{ cid: 20010003, num: 800 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱9次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 9, reward: [{ cid: 20010001, num: 450 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];
    LeadConfig.list24 = [
        { index: 1, info: ' 累计胜利8次', type: 'event', cond: 'BATTLE_STATE_VICTORY', state: 0, value: 0, num: 8, reward: [{ cid: 20010001, num: 400 }], gotoEvent: 'PAGE_BATTLE_START' },
        { index: 2, info: ' 累计天赋学习3次', type: 'event', cond: 'TALANT_UP_RESPONSE', state: 0, value: 0, num: 3, reward: [{ cid: 20010003, num: 900 }], gotoEvent: 'TALANT_VIEW_SHOW' },
        { index: 3, info: ' 累计装备购买2次', type: 'event', cond: 'GOODS_BUY_SUCCESS', state: 0, value: 0, num: 2, reward: [{ cid: 20010001, num: 200 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 4, info: ' 累计装备强化8次', type: 'event', cond: 'GOODS_STRENG_SUCCESS', state: 0, value: 0, num: 8, reward: [{ cid: 20010003, num: 800 }], gotoEvent: 'GOODS_EQUIP_VIEW_SHOW' },
        { index: 5, info: ' 累计打开宝箱9次', type: 'event', cond: 'SHOP_ROLLBOX_SUCCESS', state: 0, value: 0, num: 9, reward: [{ cid: 20010001, num: 450 }], gotoEvent: 'SHOP_MALL_VIEW_SHOW' },
    ];

    class LeadVo {
        constructor() {
            this.id = 0;
            this.index = 0;
            this.name = '';
            this.info = '';
            this.type = '';
            this.cond = '';
            this.gotoEvent = '';
            this.reward = [];
            this.state = 0;
            this.num = 0;
            this.value = 0;
        }
    }

    class LeadVoBuilder {
        static getLeadVo(index, type) {
            var list = LeadConfig.getList(type);
            var item = list[index - 1];
            if (!item) {
                return null;
            }
            var vo = new LeadVo();
            ObjectUtil.copy(item, vo);
            return vo;
        }
    }

    class LeadModel {
        constructor() {
            this.list = {};
            this.leadType = 1;
            this.hpUp = 0;
            this.tongUp = 0;
            this.jinUp = 0;
        }
        static get model() {
            return ModelManager.getModel('LeadModel', LeadModel);
        }
        ;
        init() {
            this.loadData();
        }
        buildLeadList() {
            this.list = [];
            var type = LeadModel.model.leadType;
            var list1 = LeadConfig.getList(type);
            var nlist = [];
            for (var k of list1) {
                var vo = LeadVoBuilder.getLeadVo(k.index, type);
                if (vo) {
                    nlist[vo.index] = vo;
                }
            }
            this.list = nlist;
            this.saveData();
        }
        getLeadVo(id) {
            return this.list[id];
        }
        getLeadName() {
            var vo = LeadConfig.getLeadData(this.leadType);
            if (vo) {
                return vo.name;
            }
            return '';
        }
        saveData() {
            var data = {};
            var list = [];
            for (var k in this.list) {
                var vo = this.list[k];
                var item = { value: vo.value, state: vo.state, index: vo.index };
                list.push(item);
            }
            data.list = list;
            data.leadType = this.leadType;
            StorageModel.model.setData("Lead", data);
        }
        loadData() {
            var data = StorageModel.model.getData("Lead");
            this.leadType = ParamUtil.getNumber(data, 'leadType', 1);
            var type = LeadModel.model.leadType;
            if (data && data.list) {
                var list = data.list;
                var nlist = {};
                for (var k of list) {
                    var vo = LeadVoBuilder.getLeadVo(k.index, type);
                    if (vo) {
                        vo.value = k.value;
                        vo.state = k.state;
                        nlist[vo.index] = vo;
                    }
                }
                this.list = nlist;
            }
            else {
                this.buildLeadList();
            }
        }
    }

    class PlayerModel {
        constructor() {
            this.name = '';
            this.ico = '';
            this.isChange = false;
        }
        static get model() {
            return ModelManager.getModel('PlayerModel', PlayerModel);
        }
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.name = this.name;
            data.ico = this.ico;
            data.isChange = this.isChange;
            StorageModel.model.setData("player", data);
        }
        loadData() {
            var data = StorageModel.model.getData("player");
            this.name = ParamUtil.getString(data, 'name');
            this.ico = ParamUtil.getString(data, 'ico');
            this.isChange = ParamUtil.getBool(data, 'isChange');
            return data;
        }
    }

    class SceneUnitAttConfig {
        static getAttPro(lv) {
            var k = lv.toString();
            var v = this.attList[k];
            return v / 100;
        }
        static getAtt(base, lv) {
            var pro = this.getAttPro(lv);
            if (!pro) {
                pro = 1;
            }
            return Math.round(base * pro);
        }
    }
    SceneUnitAttConfig.attList = {
        '1': 100,
        '2': 123,
        '3': 151,
        '4': 184,
        '5': 223,
        '6': 270,
        '7': 326,
        '8': 391,
        '9': 467,
        '10': 556,
        '11': 659,
        '12': 777,
        '13': 913,
        '14': 1068,
        '15': 1245,
        '16': 1444,
        '17': 1667,
        '18': 1917,
        '19': 2196,
        '20': 2503,
        '21': 2841,
        '22': 3210,
        '23': 3611,
        '24': 4045,
        '25': 4510,
        '26': 5006,
        '27': 5532,
        '28': 6085,
        '29': 6663,
        '30': 7262,
        '31': 7880,
        '32': 8510,
        '33': 9148,
        '34': 9789,
        '35': 10425,
        '36': 11051,
        '37': 11658,
        '38': 12241,
        '39': 12792,
        '40': 13304,
        '41': 13769,
        '42': 14182,
        '43': 14537,
        '44': 14828,
        '45': 15050,
        '46': 15201,
        '47': 15277,
        '48': 15277,
        '49': 15200,
        '50': 15048,
        '51': 14823,
        '52': 14526,
        '53': 14163,
        '54': 13738,
        '55': 13257,
        '56': 12727,
        '57': 12154,
        '58': 11547,
        '59': 10911,
        '60': 10257,
        '61': 9590,
        '62': 8919,
        '63': 8250,
        '64': 7590,
        '65': 6945,
        '66': 6320,
        '67': 5719,
        '68': 5147,
        '69': 4607,
        '70': 4100,
        '71': 3629,
        '72': 3193,
        '73': 2794,
        '74': 2431,
        '75': 2103,
        '76': 1808,
        '77': 1546,
        '78': 1314,
        '79': 1110,
        '80': 933,
        '81': 779,
        '82': 646,
        '83': 533,
        '84': 437,
        '85': 356,
        '86': 289,
        '87': 232,
        '88': 186,
        '89': 148,
        '90': 117,
        '91': 92,
        '92': 72,
        '93': 55,
        '94': 43,
        '95': 33,
        '96': 25,
        '97': 19,
        '98': 14,
        '99': 10,
        '100': 8,
    };

    class SceneUnitHprConfig {
        static getHpPro(lv) {
            var k = lv.toString();
            var v = this.hpList[k];
            return v / 100;
        }
        static getHp(base, lv) {
            var pro = this.getHpPro(lv);
            if (!pro) {
                pro = 1;
            }
            return MathUtil.int(base * pro);
        }
    }
    SceneUnitHprConfig.hpList = {
        '1': 100,
        '2': 115,
        '3': 132,
        '4': 152,
        '5': 175,
        '6': 201,
        '7': 231,
        '8': 266,
        '9': 306,
        '10': 352,
        '11': 405,
        '12': 465,
        '13': 535,
        '14': 615,
        '15': 708,
        '16': 814,
        '17': 936,
        '18': 1076,
        '19': 1238,
        '20': 1423,
        '21': 1637,
        '22': 1882,
        '23': 2164,
        '24': 2489,
        '25': 2863,
        '26': 3292,
        '27': 3786,
        '28': 4354,
        '29': 5007,
        '30': 5758,
        '31': 6621,
        '32': 7614,
        '33': 8757,
        '34': 10070,
        '35': 11580,
        '36': 13318,
        '37': 15315,
        '38': 17612,
        '39': 20254,
        '40': 23292,
        '41': 26786,
        '42': 30804,
        '43': 35425,
        '44': 40739,
        '45': 46850,
        '46': 53877,
        '47': 61958,
        '48': 71252,
        '49': 81940,
        '50': 94231,
        '51': 108366,
        '52': 124621,
        '53': 143314,
        '54': 164811,
        '55': 189532,
        '56': 217962,
        '57': 250657,
        '58': 288255,
        '59': 331493,
        '60': 381217,
        '61': 438400,
        '62': 504160,
        '63': 579784,
        '64': 666751,
        '65': 766764,
        '66': 881779,
        '67': 1014046,
        '68': 1166152,
        '69': 1341075,
        '70': 1542237,
        '71': 1773572,
        '72': 2039608,
        '73': 2345549,
        '74': 2697381,
        '75': 3101989,
        '76': 3567287,
        '77': 4102380,
        '78': 4717737,
        '79': 5425397,
        '80': 6239207,
        '81': 7175088,
        '82': 8251351,
        '83': 9489054,
        '84': 10912412,
        '85': 12549274,
        '86': 14431665,
        '87': 16596414,
        '88': 19085877,
        '89': 21948758,
        '90': 25241072,
        '91': 29027233,
        '92': 33381317,
        '93': 38388515,
        '94': 44146792,
        '95': 50768811,
        '96': 58384133,
        '97': 67141753,
        '98': 77213016,
        '99': 88794968,
        '100': 102114213,
    };

    class SceneGoodsTool {
        static setGoods(unit, goods) {
            if (!goods) {
                return;
            }
            this.oldGoods = null;
            this.isPickup = false;
            this.attFull = false;
            this.changeEp = false;
            this.changeHp = false;
            this.changeInvinTime = 0;
            this.changeAttBuffPro = false;
            this.isAirdrop = false;
            if (goods.stype == 2) {
            }
            else if (goods.stype == 3) {
            }
            else if (goods.stype == 1) {
                this.addGun(unit, goods);
            }
            else if (goods.stype == 4) {
            }
            else if (goods.stype == 5) {
            }
            else if (goods.stype == 11) {
                this.setInvinBuff(unit, goods);
            }
            else if (goods.stype == 12) {
                this.setAttBuff(unit, goods);
            }
            else if (goods.stype == 13) {
                this.setMedkit(unit, goods);
            }
        }
        static addGun(unit, goods) {
            unit.attVo = goods;
            this.setGunMain(unit, goods);
        }
        static setGunMain(unit, gun) {
            unit.attVo = gun;
        }
        static getBulletNum(unit) {
            return unit.bullet;
        }
        static subBulletNum(unit, num = 1) {
            unit.bullet -= num;
        }
        static goodsUse(unit, type) {
            if (unit.hp >= unit.hpMax) {
                return 'fullHp';
            }
            unit.hp += 25;
            if (unit.hp > unit.hpMax) {
                unit.hp = unit.hpMax;
            }
            return 'changeHp';
        }
        static setInvinBuff(unit, vo) {
            this.isPickup = true;
            this.changeInvinTime = vo.invinTime;
        }
        static setInvinTime(unit, invinTime) {
            this.isPickup = true;
            this.changeInvinTime = invinTime;
        }
        static setAttBuff(unit, vo) {
            this.isPickup = true;
            this.changeAttBuffPro = true;
            unit.attBuffPro += vo.attPro;
        }
        static setMedkit(unit, vo) {
            this.isPickup = true;
            this.changeHp = true;
            unit.hp = MathUtil.int(unit.hp + unit.hp * vo.hpPro);
            if (unit.hp > unit.hpMax) {
                unit.hp = unit.hpMax;
            }
        }
        static addHpMaxPro(unit, hpPro) {
            this.isPickup = true;
            this.changeHp = true;
            unit.hpMax = MathUtil.int(unit.hpMax + unit.hpMax * hpPro);
            unit.hp = MathUtil.int(unit.hp + unit.hp * hpPro);
            if (unit.hp > unit.hpMax) {
                unit.hp = unit.hpMax;
            }
        }
        static addHp(unit, hp) {
            unit.hp += hp;
            if (unit.hp > unit.hpMax) {
                unit.hp = unit.hpMax;
            }
        }
    }
    SceneGoodsTool.isPickup = false;
    SceneGoodsTool.changeEp = false;
    SceneGoodsTool.changeHp = false;
    SceneGoodsTool.attFull = false;
    SceneGoodsTool.changeInvinTime = 0;
    SceneGoodsTool.changeAttBuffPro = false;
    SceneGoodsTool.isAirdrop = false;

    class SceneElementVo {
        constructor() {
            this.className = '';
            this.id = 0;
            this.name = '';
            this.cid = 0;
            this.ico = '';
            this.image = '';
            this.stype = 0;
            this.ttype = 0;
            this.ctype = 0;
            this.num = 1;
            this.lv = 0;
            this.dir = 0;
            this.halo = 0;
            this.haloY = 0;
            this.camp = 0;
            this.campType = 0;
            this.isRemove = false;
            this.durationTime = 0;
            this.isAutoLoad = true;
            this.ix = 0;
            this.iy = 0;
            this.iz = 0;
            this.scale = 1;
            this.actions = [];
        }
        get x() {
            if (this.transform) {
                return this.transform.localPositionX;
            }
            return this.ix;
        }
        get y() {
            if (this.transform) {
                return this.transform.localPositionY;
            }
            return this.iy;
        }
        get z() {
            if (this.transform) {
                return this.transform.localPositionZ;
            }
            return this.iz;
        }
    }

    class SceneVoClassConfig {
        static getClass(name) {
            var c = this.classList[name];
            if (c) {
                return c;
            }
            return SceneElementVo;
        }
        static regClass(name, clas) {
            this.classList[name] = clas;
        }
    }
    SceneVoClassConfig.classList = {};

    class ScenesListConfig {
    }
    ScenesListConfig.list = {
        30011001: { className: 'npc', name: '丹', ico: '30011001', image: 'role_1', stype: 9, ttype: 1, hp: 110, att: 0, actions: ['dia'], attCid: 30042001, skills: [40021013, 40021101, 40021016, 40021035], dis: 40, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true },
        30011002: { className: 'npc', name: '麦卡奈特', ico: '30011002', image: 'role_2', stype: 9, ttype: 1, hp: 240, att: 0, actions: ['mcCartney'], attCid: 30042002, skills: [40021014, 40021101, 40021016, 40021035], dis: 50, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true, cameraZ: -2.5, cameraY: 2.3 },
        30011003: { className: 'npc', name: '杰比', ico: '30011003', image: 'role_3', stype: 9, ttype: 1, hp: 110, att: 0, actions: ['gebbie'], attCid: 30042003, skills: [40021015, 40021101, 40021016, 40021035], dis: 60, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true, },
        30011004: { className: 'npc', name: '捷特', ico: '30011004', image: 'role_4', stype: 9, ttype: 1, hp: 161, att: 0, actions: ['jett'], attCid: 30042004, skills: [40021021, 40021101, 40021016, 40021035], dis: 100, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true },
        30011005: { className: 'npc', name: '伊戈艾', ico: '30011005', image: 'role_5', stype: 9, ttype: 1, hp: 110, att: 0, actions: ['igoai'], attCid: 30042005, skills: [40021022, 40021101, 40021016, 40021035], dis: 100, canRepel: true, hasShield: true, canReHp: true, },
        30011006: { className: 'npc', name: '阿爆', ico: '30011006', image: 'role_6', stype: 9, ttype: 1, hp: 198, att: 0, actions: ['abang'], attCid: 30042006, skills: [40021028, 40021101, 40021016, 40021035], dis: 100, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true, cameraZ: -2.5, cameraY: 2.3 },
        30011007: { className: 'npc', name: '波卡亨塔', ico: '30011007', image: 'role_7', stype: 9, ttype: 1, hp: 99, att: 0, actions: [], attCid: 30042007, skills: [40021029, 40021101, 40021016, 40021035], dis: 100, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true, cameraZ: -1.5, cameraY: 1.6 },
        30011008: { className: 'npc', name: '费洛斯博士', ico: '30011008', image: 'role_8', stype: 9, ttype: 1, hp: 187, att: 0, actions: ['drphilos'], attCid: 30042008, skills: [40021033, 40021101, 40021016, 40021035], dis: 25, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true, cameraZ: -2.2, cameraY: 1.5 },
        30011009: { className: 'npc', name: '里克·洛克', ico: '30011009', image: 'role_9', stype: 9, ttype: 1, hp: 185, att: 0, actions: ['ricklocke'], attCid: 30042009, skills: [40021031, 40021101, 40021016, 40021035], dis: 30, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true, cameraZ: -2.2, cameraY: 1.6 },
        30011010: { className: 'npc', name: '伯特妈妈', ico: '30011010', image: 'role_10', stype: 9, ttype: 1, hp: 267, att: 0, actions: ['burtsmother'], attCid: 30042010, skills: [40021032, 40021101, 40021016, 40021035], dis: 45, dieAnim: 'die_2', canRepel: true, hasShield: true, canReHp: true, cameraZ: -2, cameraY: 1.6 },
        30011011: { className: 'npc', name: '史莱姆', ico: '30011011', image: 'role_11', stype: 9, ttype: 1, hp: 288, att: 0, attCid: 30042011, skills: [40021013, 40021101], },
        30011012: { className: 'npc', name: '成吉斯', ico: '30011012', image: 'role_12', stype: 9, ttype: 1, hp: 288, att: 0, attCid: 30042012, skills: [40021013, 40021101], },
        30011013: { className: 'npc', name: '杰克·帕德雷', ico: '30011013', image: 'role_13', stype: 9, ttype: 1, hp: 161, att: 0, attCid: 30042013, skills: [40021013, 40021101], },
        30011014: { className: 'npc', name: '朗·绍特', ico: '30011014', image: 'role_14', stype: 9, ttype: 1, hp: 201, att: 0, attCid: 30042014, skills: [40021013, 40021101], },
        30011015: { className: 'npc', name: '艾米丽', ico: '30011015', image: 'role_15', stype: 9, ttype: 1, hp: 293, att: 0, attCid: 30042015, skills: [40021013, 40021101], },
        30011016: { className: 'npc', name: '弗里茲比', ico: '30011016', image: 'role_16', stype: 9, ttype: 1, hp: 332, att: 0, attCid: 30042016, skills: [40021013, 40021101], },
        30011017: { className: 'npc', name: '好战者', ico: '30011017', image: 'role_17', stype: 9, ttype: 1, hp: 281, att: 0, attCid: 30042017, skills: [40021013, 40021101], },
        30012017: { className: 'npc', name: 'bot', ico: '30012017', image: 'bot_10', stype: 9, ttype: 3, hp: 100, att: 0, attCid: 30042001, skills: [40021013, 40021101] },
        30012001: { className: 'npc', name: '碉堡', ico: '30012001', image: 'pillbox_1', stype: 9, ttype: 2, hp: 2000, att: 0, actions: ['hpText'], skills: [], hpPro: 0, dieAnim: 'die_1', canRepel: false, hasShield: false, canReHp: false, },
        30012002: { className: 'npc', name: '碉堡', ico: '30012002', image: 'pillbox_2', stype: 9, ttype: 2, hp: 2000, att: 0, actions: ['hpText'], skills: [], hpPro: 0, dieAnim: 'die_1', canRepel: false, hasShield: false, canReHp: false, },
        30021001: { className: 'goods', name: '钻石', ico: '30021001', image: 'gem', stype: 5, ttype: 6, attStype: 1, num: 2, pickAnim: "goods_1" },
        30021002: { className: 'goods', name: '金币', ico: '30021002', image: 'coins', stype: 5, ttype: 6, attStype: 1, num: 10, pickAnim: "goods_1" },
        30021101: { className: 'goods', name: '血包', ico: '30021101', image: 'medkit', stype: 5, ttype: 6, attStype: 1, num: 100, pickAnim: "skill_1" },
        30031001: { className: 'unit', name: '9mm', ico: 'bullet_1', image: 'bullet_1', stype: 3, ttype: 1, iy: 0.7, v: 300, durTime: 500 },
        30042001: { className: 'gun', name: '速射枪', ico: '30042001', image: '30042001', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021011, att: 0, attCd: 170, attAcc: 0.2, attNum: 1, attDis: 40, attCap: 3, attV: 1.5, attBulletMax: 30, attBulletTime: 2100, attWeight: 0, info: '中射程手枪，射速不俗。' },
        30042002: { className: 'gun', name: '轨道炮', ico: '30042002', image: '30042002', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021012, att: 0, attCd: 1040, attAcc: 0.2, attNum: 1, attDis: 60, attCap: 3, attV: 1.5, attBulletMax: 5, attBulletTime: 3450, attWeight: 0, info: '速度缓慢，力量强大的左轮枪。' },
        30042003: { className: 'gun', name: '消音手枪', ico: '30042003', image: '30042003', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021018, att: 0, attCd: 190, attAcc: 0.2, attNum: 1, attDis: 50, attCap: 3, attV: 1.5, attBulletMax: 10, attBulletTime: 1950, attWeight: 0, info: '中射程发手枪，以3发子弹爆炸模式开火。' },
        30042004: { className: 'gun', name: '等离子发射器', ico: '30042004', image: '30042004', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021019, att: 0, attCd: 370, attAcc: 0.2, attNum: 1, attDis: 100, attCap: 3, attV: 1.5, attBulletMax: 9, attBulletTime: 2100, attWeight: 0, info: '采用爆炸模式，弧线发射3发等离子球，可将敌人击退。' },
        30042005: { className: 'gun', name: '爆炸弩箭', ico: '30042005', image: '30042005', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 490, attAcc: 0.2, attNum: 1, attDis: 100, attCap: 3, attV: 1.5, attBulletMax: 12, attBulletTime: 1800, attWeight: 0, aimType: 4, info: '采用爆炸模式，弧线发射2发爆炸弩箭。' },
        30042006: { className: 'gun', name: '火箭发射器', ico: '30042006', image: '30042006', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021023, att: 0, attCd: 830, attAcc: 0.2, attNum: 1, attDis: 100, attCap: 3, attV: 1.5, attBulletMax: 6, attBulletTime: 3900, attWeight: 0, info: '以直线发射强力火箭弹。' },
        30042007: { className: 'gun', name: '能量弓', ico: '30042007', image: '30042007', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021024, att: 0, attCd: 210, attAcc: 0.2, attNum: 1, attDis: 10, attCap: 3, attV: 1.5, attBulletMax: 6, attBulletTime: 3450, attWeight: 0, info: '以稍有弯曲的抛物线发射夺命弓箭。' },
        30042008: { className: 'gun', name: '冷冻枪', ico: '30042008', image: '30042008', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021025, att: 0, attCd: 1190, attAcc: 0.2, attNum: 1, attDis: 25, attCap: 3, attV: 1.5, attBulletMax: 5, attBulletTime: 2400, attWeight: 0, info: '自动霰弹枪，可令敌人减速。' },
        30042009: { className: 'gun', name: '魔音吉他', ico: '30042009', image: '30042009', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021026, att: 0, attCd: 140, attAcc: 0.2, attNum: 1, attDis: 30, attCap: 3, attV: 1.5, attBulletMax: 40, attBulletTime: 1650, attWeight: 0, info: '中距离快速武器，可发射带有巨大杀伤效果的声波。' },
        30042010: { className: 'gun', name: '射钉枪', ico: '30042010', image: '30042010', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021027, att: 0, attCd: 760, attAcc: 0.2, attNum: 1, attDis: 45, attCap: 3, attV: 1.5, attBulletMax: 15, attBulletTime: 3150, attWeight: 0, info: '在近距离以爆破模式发射铁钉。' },
        30042011: { className: 'gun', name: '毒液枪', ico: '30042011', image: '30042011', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 210, attAcc: 0.2, attNum: 1, attDis: 100, attCap: 3, attV: 1.5, attBulletMax: 5, attBulletTime: 2400, attWeight: 0 },
        30042012: { className: 'gun', name: '火药大炮', ico: '30042012', image: '30042012', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 1040, attAcc: 0.2, attNum: 1, attDis: 60, attCap: 3, attV: 1.5, attBulletMax: 5, attBulletTime: 3150, attWeight: 0 },
        30042013: { className: 'gun', name: '霰弹枪', ico: '30042013', image: '30042013', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 1190, attAcc: 0.2, attNum: 1, attDis: 25, attCap: 3, attV: 1.5, attBulletMax: 3, attBulletTime: 3300, attWeight: 0 },
        30042014: { className: 'gun', name: '狙击步枪', ico: '30042014', image: '30042014', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 2080, attAcc: 0.2, attNum: 1, attDis: 250, attCap: 3, attV: 1.5, attBulletMax: 5, attBulletTime: 0, attWeight: 0 },
        30042015: { className: 'gun', name: '突击步枪', ico: '30042015', image: '30042015', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 170, attAcc: 0.2, attNum: 1, attDis: 60, attCap: 3, attV: 1.5, attBulletMax: 24, attBulletTime: 2400, attWeight: 0 },
        30042016: { className: 'gun', name: '飞盘发射器', ico: '30042016', image: '30042016', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 690, attAcc: 0.2, attNum: 1, attDis: 45, attCap: 3, attV: 1.5, attBulletMax: 7, attBulletTime: 2400, attWeight: 0 },
        30042017: { className: 'gun', name: '碎片分解器', ico: '30042017', image: '30042017', stype: 1, ttype: 1, ctype: 5, attType: 2, attStype: 1, skill: 40021020, att: 0, attCd: 460, attAcc: 0.2, attNum: 1, attDis: 60, attCap: 3, attV: 1.5, attBulletMax: 7, attBulletTime: 1650, attWeight: 0 },
        30041601: { className: 'goods', name: '弹药箱', ico: 'goods_601', image: 'buff_4', stype: 4, ttype: 6, attStype: 1, num: 50 },
        30041602: { className: 'goods', name: '空投降落伞', ico: 'airdrop', image: 'airdrop', stype: 5, ttype: 6, attStype: 1, num: 50 },
        30041801: { className: 'goods', name: '无敌', ico: '30041801', image: 'buff_1', stype: 11, invinTime: 6, durationTime: 15000 },
        30041802: { className: 'goods', name: '攻击', ico: '30041802', image: 'buff_2', stype: 12, attPro: 0.2, durationTime: 15000 },
        30041803: { className: 'goods', name: '绷带', ico: '30041803', image: 'buff_3', stype: 13, hpPro: 0.2, durationTime: 15000 },
        30041804: { className: 'goods', name: '子弹', ico: '30041804', image: 'buff_4', stype: 4, num: 50, durationTime: 15000 },
        30061001: { className: 'unit', name: '毒圈', ico: '', image: '', stype: 6, ttype: 9, attCd: 1000, att: 200, info: '' },
        30071001: { className: 'unit', name: '坠落伤害', ico: '', image: '', stype: 6, ttype: 9, attCd: 100, att: 99999999, info: '' },
        40021011: { className: 'skillDir', image: 'skillP_1', effectImage: 'skillP_1_2', stype: 11, skillUseType: 1, skillCd: 250, attDis: 40, skillTriggerArea: 1, skillArea: 0, att: 18, attV: 1, isOpenRepel: false, gravity: 0, attSound: '40021011', name: '速射枪' },
        40021012: { className: 'skillDir', image: 'skillP_2', effectImage: 'skillP_2_2', stype: 11, skillUseType: 1, skillCd: 1560, attDis: 50, skillTriggerArea: 1, skillArea: 3, att: 120, attV: 0.8, isOpenRepel: false, gravity: 0, attSound: '40021012', hitSound: '40021012_1', name: '轨道炮' },
        40021018: { className: 'skillDir', image: 'skillP_3', effectImage: 'skillP_3_2', stype: 11, skillUseType: 1, skillCd: 280, attDis: 60, skillTriggerArea: 1, skillArea: 0, att: 54, attV: 1, isOpenRepel: false, gravity: 0, attSound: '40021018', name: '消音手枪' },
        40021019: { className: 'skillDir', image: 'skillP_4', effectImage: 'skillP_4_2', stype: 11, skillUseType: 1, skillCd: 2500, attDis: 100, skillTriggerArea: 1, skillArea: 3, att: 81.9, attV: 0.6, isOpenRepel: false, gravity: 0, attSound: '40021019', hitSound: '40021012_1', name: '等离子发射器' },
        40021020: { className: 'skillDir', image: 'skillP_5', effectImage: 'skillP_5_2', stype: 11, skillUseType: 1, skillCd: 720, attDis: 100, skillTriggerArea: 1, skillArea: 3, att: 33, attV: 1.2, isOpenRepel: false, gravity: 0, attSound: '40021020', name: '爆炸弩箭', anim: 'att' },
        40021023: { className: 'skillDir', image: 'skillP_6', effectImage: 'skillP_2_2', stype: 11, skillUseType: 1, skillCd: 1560, attDis: 100, skillTriggerArea: 1, skillArea: 3, att: 120, attV: 1, isOpenRepel: false, gravity: 0, attSound: '40021023', hitSound: '40021012_1', name: '火箭发射器', anim: 'att' },
        40021024: { className: 'skillDir', image: 'skillP_5', effectImage: 'skillP_5_2', stype: 11, skillUseType: 1, skillCd: 720, attDis: 100, skillTriggerArea: 1, skillArea: 3, att: 90, attV: 1, isOpenRepel: false, gravity: 0, attSound: '40021024', name: '能量弓' },
        40021025: { className: 'skillDir', image: 'skillP_8', effectImage: 'skillP_8_2', stype: 11, skillUseType: 1, skillCd: 250, attDis: 25, skillTriggerArea: 1, skillArea: 0, att: 120, attV: 1, isOpenRepel: false, isSlowDown: true, skillDurationTime: 2000, gravity: 0, attSound: '40021025', name: '冷冻枪' },
        40021026: { className: 'skillDir', image: 'skillP_11', effectImage: 'skillP_11_2', stype: 11, skillUseType: 1, skillCd: 250, attDis: 30, skillTriggerArea: 1, skillArea: 0, att: 14.4, attV: 1, isOpenRepel: false, gravity: 0, attSound: '40021026', name: '电击吉他' },
        40021027: { className: 'skillDir', image: 'skillP_1', effectImage: 'skillP_1_2', stype: 11, skillUseType: 1, skillCd: 250, attDis: 45, skillTriggerArea: 1, skillArea: 0, att: 87.3, attV: 1, isOpenRepel: false, gravity: 0, attSound: '40021027', name: '射钉枪' },
        40021013: { className: 'skillRecovery', name: '恢复', ico: '40021013', image: '', effectImage: 'skill_1', stype: 11, skillUseType: 2, attCd: 15000, skillDurationTime: 5000, skillHpRc: 5.5, attSound: '40021013', info: '对自己进行持续治疗。' },
        40021014: { className: 'skillShield', name: '圣盾守护', ico: '40021014', image: '', effectImage: 'skill_2', stype: 11, skillUseType: 2, attCd: 15000, skillDurationTime: 3000, attSound: '40021014', info: '召唤圣光攻击敌人，同时生成保护自己的无敌护盾！' },
        40021015: { className: 'skillMineTrow', name: '感应地雷', ico: '40021015', image: 'skill_3', effectImage: 'skill_3_1', stype: 11, skillUseType: 2, attCd: 8000, att: 30, skillArea: 15, skillTriggerArea: 10, dis: 5, throwDis: 5, isOpenRepel: false, attSound: '40021015', hitSound: '40021015_1', info: '部署一堆地雷，敌人接近时便会爆炸！' },
        40021017: { className: 'skillAim', name: '瞄准', ico: '40021017', image: '', effectImage: '', stype: 11, skillUseType: 2, attCd: 0, attSound: '40021017', info: '瞄准' },
        40021021: { className: 'skillFly', name: '喷气背包', ico: '40021016', image: '', effectImage: '', stype: 11, skillUseType: 2, attCd: 12000, attSound: '40021021', info: '在空中进行喷射，并一路悬浮，直至落地！' },
        40021022: { className: 'skillArchery', name: '多重箭', ico: '40021022', image: 'skillP_5', effectImage: 'skillP_5_2', stype: 11, skillUseType: 2, attCd: 12000, att: 10, attSound: '40021020', info: '向前方发射三轮箭雨攻击敌人！', anim: 'att' },
        40021034: { className: 'skillRocket', name: '火箭筒', ico: '40021028', image: 'skillP_6', effectImage: 'skillP_6_2', stype: 11, skillUseType: 2, attCd: 12000, skillDurationTime: 3000, att: 40, skillArea: 2, skillTriggerArea: 1, attSound: '40021028', hitSound: '', info: '一次性发射4枚火箭弹，爆炸会点燃附近的敌人，造成持续伤害。', anim: 'att' },
        40021028: { className: 'skillArtillery', name: '炮火压制', ico: '40021028', image: 'skillP_6', effectImage: 'skillP_6_2', stype: 11, skillUseType: 2, attCd: 12000, att: 40, attSound: '40021028', info: '一次性发射4枚火箭弹，爆炸会点燃附近的敌人，造成持续伤害。', anim: 'att' },
        40021029: { className: 'skillSneak', name: '潜行', ico: '40021029', image: '', effectImage: '', stype: 11, skillUseType: 2, attCd: 16000, att: 0, skillDurationTime: 9000, attSound: '40021029', info: '进入潜行状态，只有主动攻击敌人时才会现身。' },
        40021030: { className: 'skillAvalanche', name: '雪崩', ico: '40021030', image: 'skillP_9', effectImage: 'skillP_9_2', stype: 11, skillUseType: 2, attCd: 15000, skillDurationTime: 8000, att: 20, skillArea: 2, skillTriggerArea: 1, attSound: '40021030', hitSound: '', info: '召唤一场雪崩，击中敌人后可令其减速并造成持续伤害！', anim: 'att' },
        40021033: { className: 'skillSnowflake', name: '雪崩', ico: '40021030', image: 'skillP_9', effectImage: 'skillP_9_2', stype: 11, skillUseType: 2, attCd: 15000, skillDurationTime: 8000, att: 20, skillArea: 2, skillTriggerArea: 1, attSound: '40021030', hitSound: '', info: '召唤一场雪崩，击中敌人后可令其减速并造成持续伤害！', anim: 'att' },
        40021031: { className: 'skillSound', name: '音墙', ico: '40021031', image: 'skillP_10', effectImage: 'skillP_10_2', stype: 11, skillUseType: 2, attCd: 15000, skillDurationTime: 3000, durationTime: 300, att: 0, skillArea: 30, skillTriggerArea: 0, attSound: '40021031', info: '发射声波，在远程击晕敌人！' },
        40021032: { className: 'skillRobot', name: '机器人生成', ico: '40021032', image: '', effectImage: '', stype: 11, skillUseType: 2, attCd: 20000, att: 0, attSound: '40021032', info: '生成一台巡逻机器人。最多可同时拥有2台机器人。' },
        40021101: { className: 'skillReShield', name: '复活护盾', ico: '40021014', image: '', effectImage: 'skill_2', stype: 11, skillUseType: 2, attCd: 0, skillDurationTime: 5000, info: '复活护盾' },
        40021016: { className: 'skillFirstAid', name: '急救', ico: '40021016', image: '', effectImage: 'skill_1', stype: 11, skillUseType: 2, attCd: 0, skillHpRc: 60, attSound: '40021013', info: '急救' },
        40021035: { className: 'skillLaunchMissile', name: '发射导弹', ico: '40021028', image: 'skillP_6', effectImage: 'skillP_2_2', stype: 11, skillUseType: 2, attCd: 0, att: 40, attSound: '40021028', info: '一次性发射4枚火箭弹，爆炸会点燃附近的敌人，造成持续伤害。', anim: 'att' },
    };

    class SceneTerrainConfig {
        static getTerrain(cid) {
            if (cid == 1) {
                return this.map;
            }
            else if (cid == 2) {
                return this.map2;
            }
            else {
                return this.map3;
            }
        }
        static getInitPos(cid, camp) {
            if (camp == 0) {
                return this.initPos1;
            }
            else if (camp == 1) {
                return this.initPos1_1;
            }
            else {
                return this.initPos1_2;
            }
        }
    }
    SceneTerrainConfig.map = {
        "-15_-82": 1, "-14_-82": 1, "-13_-82": 1, "-12_-82": 1, "-11_-82": 1, "-10_-82": 1, "-9_-82": 1, "-8_-82": 1, "-7_-82": 1, "-6_-82": 1, "-5_-82": 1, "-4_-82": 1,
        "-3_-82": 1, "3_-82": 1, "4_-82": 1, "5_-82": 1, "6_-82": 1, "7_-82": 1, "8_-82": 1, "9_-82": 1, "10_-82": 1, "11_-82": 1, "12_-82": 1,
        "13_-82": 1, "14_-82": 1, "15_-82": 1, "16_-82": 1, "17_-82": 1, "18_-82": 1, "19_-82": 1, "20_-82": 1, "21_-82": 1, "26_-66": 1, "26_-65": 1,
        "26_-64": 1, "26_-63": 1, "26_-62": 1, "26_-61": 1, "26_-60": 1, "26_-59": 1, "26_-58": 1, "26_-57": 1, "26_-56": 1, "26_-55": 1, "26_-54": 1,
        "26_-53": 1, "26_-52": 1, "26_-51": 1, "26_-50": 1, "26_-49": 1, "26_-48": 1, "7_-47": 1, "8_-47": 1, "9_-47": 1, "10_-47": 1, "15_-47": 1,
        "16_-47": 1, "17_-47": 1, "18_-47": 1, "19_-47": 1, "20_-47": 1, "7_-46": 1, "7_-45": 1, "7_-44": 1, "7_-43": 1, "7_-42": 1, "7_-41": 1,
        "7_-40": 1, "7_-39": 1, "7_-38": 1, "7_-37": 1, "7_-36": 1, "8_-36": 1, "9_-36": 1, "10_-36": 1, "11_-36": 1, "16_-36": 1, "17_-36": 1,
        "18_-36": 1, "19_-36": 1, "20_-36": 1, "20_-46": 1, "20_-45": 1, "20_-44": 1, "20_-43": 1, "20_-42": 1, "20_-41": 1, "20_-40": 1, "20_-39": 1,
        "20_-38": 1, "20_-37": 1, "0_-44": 1, "0_-43": 1, "0_-42": 1, "0_-41": 1, "0_-40": 1, "0_-39": 1, "0_-38": 1, "-20_-47": 1, "-17_-48": 1,
        "-16_-48": 1, "-15_-48": 1, "-10_-48": 1, "-9_-48": 1, "-8_-48": 1, "-7_-48": 1, "-7_-47": 1, "-7_-41": 1, "-7_-40": 1, "-7_-39": 1, "-7_-38": 1,
        "-7_-37": 1, "-7_-36": 1, "-11_-36": 1, "-10_-36": 1, "-9_-36": 1, "-8_-36": 1, "-20_-46": 1, "-20_-45": 1, "-20_-44": 1, "-20_-43": 1, "-20_-42": 1,
        "-20_-41": 1, "-20_-40": 1, "-20_-39": 1, "-20_-38": 1, "-20_-37": 1, "-20_-36": 1, "-19_-36": 1, "-18_-36": 1, "-17_-36": 1, "-16_-36": 1, "-7_-46": 1,
        "-7_-45": 1, "-7_-44": 1, "-7_-43": 1, "-7_-42": 1, "-20_-48": 1, "-19_-48": 1, "-18_-48": 1, "-3_-26": 1, "-3_-25": 1, "-3_-24": 1, "-3_-23": 1,
        "3_-26": 1, "3_-25": 1, "3_-24": 1, "3_-23": 1, "-9_-11": 1, "-8_-11": 1, "-7_-11": 1, "-6_-11": 1, "-5_-11": 1, "-4_-11": 1, "4_-11": 1,
        "5_-11": 1, "6_-11": 1, "7_-11": 1, "8_-11": 1, "9_-11": 1, "10_-10": 1, "10_-9": 1, "10_-8": 1, "10_-7": 1, "10_-6": 1, "10_-5": 1,
        "10_-4": 1, "10_2": 1, "10_3": 1, "10_4": 1, "10_5": 1, "10_6": 1, "10_9": 1, "10_7": 1, "10_8": 1, "10_10": 1, "10_11": 1,
        "19_-11": 1, "19_11": 1, "-19_11": 1, "-10_-11": 1, "-10_-10": 1, "-10_-9": 1, "-10_-8": 1, "-10_-7": 1, "-10_-6": 1, "-10_-5": 1, "-10_-4": 1,
        "-10_2": 1, "-10_3": 1, "-10_4": 1, "-10_5": 1, "-10_6": 1, "-10_7": 1, "-10_8": 1, "-10_9": 1, "-10_-3": 1, "-10_-2": 1, "-10_-1": 1,
        "-10_0": 1, "-10_1": 1, "10_-3": 1, "10_-2": 1, "10_-1": 1, "10_0": 1, "10_1": 1, "10_-11": 1, "-10_10": 1, "-10_11": 1, "-24_16": 1,
        "-24_17": 1, "-24_18": 1, "-24_19": 1, "-24_20": 1, "-24_21": 1, "-24_22": 1, "-24_23": 1, "-24_24": 1, "-24_25": 1, "-24_26": 1, "-23_26": 1,
        "-22_26": 1, "-21_26": 1, "-21_25": 1, "-21_24": 1, "-21_23": 1, "-21_22": 1, "-21_16": 1, "-21_17": 1, "-21_18": 1, "-21_19": 1, "-21_20": 1,
        "-21_21": 1, "-3_22": 1, "-3_23": 1, "-3_24": 1, "-3_25": 1, "-3_26": 1, "3_22": 1, "3_23": 1, "3_24": 1, "3_25": 1, "3_26": 1,
        "21_16": 1, "21_17": 1, "21_18": 1, "21_19": 1, "21_20": 1, "21_21": 1, "21_22": 1, "21_23": 1, "21_24": 1, "21_25": 1, "21_26": 1,
        "22_26": 1, "23_26": 1, "24_26": 1, "24_25": 1, "24_24": 1, "24_23": 1, "24_22": 1, "24_21": 1, "24_20": 1, "24_19": 1, "24_18": 1,
        "24_17": 1, "24_16": 1, "22_16": 1, "23_16": 1, "21_-26": 1, "21_-25": 1, "21_-24": 1, "21_-23": 1, "21_-22": 1, "21_-21": 1, "21_-20": 1,
        "21_-19": 1, "21_-18": 1, "21_-17": 1, "21_-16": 1, "22_-16": 1, "23_-16": 1, "24_-16": 1, "24_-17": 1, "24_-18": 1, "24_-19": 1, "24_-20": 1,
        "24_-21": 1, "24_-22": 1, "24_-23": 1, "24_-24": 1, "24_-25": 1, "24_-26": 1, "22_-26": 1, "23_-26": 1, "-24_-26": 1, "-24_-25": 1, "-24_-24": 1,
        "-24_-23": 1, "-24_-22": 1, "-24_-21": 1, "-24_-20": 1, "-24_-19": 1, "-24_-18": 1, "-24_-17": 1, "-24_-16": 1, "-23_-16": 1, "-22_-16": 1, "-21_-16": 1,
        "-21_-17": 1, "-21_-18": 1, "-21_-19": 1, "-21_-20": 1, "-21_-21": 1, "-21_-22": 1, "-21_-23": 1, "-21_-24": 1, "-21_-25": 1, "-21_-26": 1, "-23_-26": 1,
        "-22_-26": 1, "-20_37": 1, "-20_38": 1, "-20_39": 1, "-20_40": 1, "-20_41": 1, "-20_42": 1, "-20_43": 1, "-20_44": 1, "-20_45": 1, "-20_46": 1,
        "-20_47": 1, "-19_47": 1, "-18_47": 1, "-17_47": 1, "-16_47": 1, "-15_47": 1, "-10_47": 1, "-9_47": 1, "-8_47": 1, "-7_47": 1, "-7_46": 1,
        "-7_45": 1, "-7_44": 1, "-7_43": 1, "-7_42": 1, "-7_41": 1, "-7_40": 1, "-7_39": 1, "-7_38": 1, "-7_37": 1, "0_37": 1, "0_38": 1,
        "0_39": 1, "0_40": 1, "0_41": 1, "0_42": 1, "0_43": 1, "0_44": 1, "0_45": 1, "0_46": 1, "7_36": 1, "7_37": 1, "7_38": 1,
        "7_39": 1, "7_40": 1, "7_41": 1, "7_42": 1, "7_43": 1, "7_44": 1, "7_45": 1, "7_46": 1, "7_47": 1, "8_47": 1, "9_47": 1,
        "10_47": 1, "15_47": 1, "16_47": 1, "17_47": 1, "18_47": 1, "19_47": 1, "20_47": 1, "20_46": 1, "20_45": 1, "20_44": 1, "20_43": 1,
        "20_42": 1, "20_41": 1, "20_40": 1, "20_39": 1, "20_38": 1, "20_37": 1, "-8_58": 1, "-8_59": 1, "-8_60": 1, "-8_61": 1, "-8_62": 1,
        "-8_63": 1, "-8_64": 1, "-8_65": 1, "-8_66": 1, "-8_67": 1, "-8_68": 1, "-8_69": 1, "-8_70": 1, "-8_71": 1, "-8_72": 1, "-8_73": 1,
        "-8_74": 1, "-7_74": 1, "-6_74": 1, "-5_74": 1, "-4_74": 1, "-3_74": 1, "-2_74": 1, "-1_74": 1, "0_74": 1, "1_74": 1, "3_74": 1,
        "4_74": 1, "5_74": 1, "6_74": 1, "7_74": 1, "8_74": 1, "2_74": 1, "8_73": 1, "8_72": 1, "8_71": 1, "8_70": 1, "8_69": 1,
        "8_68": 1, "8_67": 1, "8_66": 1, "8_65": 1, "8_64": 1, "8_63": 1, "8_62": 1, "8_61": 1, "-7_58": 1, "-6_58": 1, "-5_58": 1,
        "-4_58": 1, "-3_58": 1, "-2_58": 1, "-1_58": 1, "0_58": 1, "1_58": 1, "2_58": 1, "3_58": 1, "4_58": 1, "5_58": 1, "6_58": 1,
        "7_58": 1, "8_58": 1, "8_59": 1, "8_60": 1, "8_36": 1, "9_36": 1, "10_36": 1, "11_36": 1, "-20_36": 1, "-19_36": 1, "-18_36": 1,
        "-17_36": 1, "-16_36": 1, "-11_36": 1, "-10_36": 1, "-9_36": 1, "-8_36": 1, "-7_36": 1, "16_36": 1, "17_36": 1, "18_36": 1, "19_36": 1,
        "20_36": 1, "-23_-25": 1, "-23_-24": 1, "-23_-23": 1, "-23_-22": 1, "-23_-21": 1, "-23_-20": 1, "-23_-19": 1, "-23_-17": 1, "-23_-18": 1, "-22_-25": 1,
        "-22_-24": 1, "-22_-23": 1, "-22_-22": 1, "-22_-21": 1, "-22_-20": 1, "-22_-19": 1, "-22_-18": 1, "-22_-17": 1, "22_-25": 1, "22_-24": 1, "22_-23": 1,
        "22_-22": 1, "22_-21": 1, "22_-20": 1, "22_-19": 1, "22_-18": 1, "22_-17": 1, "23_-25": 1, "23_-24": 1, "23_-23": 1, "23_-22": 1, "23_-21": 1,
        "23_-20": 1, "23_-19": 1, "23_-18": 1, "23_-17": 1, "-7_-74": 1, "-7_-73": 1, "-7_-72": 1, "-7_-66": 1, "-7_-65": 1, "-7_-64": 1, "-7_-63": 1,
        "-7_-62": 1, "-7_-61": 1, "-7_-60": 1, "-7_-59": 1, "-6_-59": 1, "-5_-59": 1, "-4_-59": 1, "-3_-59": 1, "-2_-59": 1, "-1_-59": 1, "0_-59": 1,
        "1_-59": 1, "2_-59": 1, "3_-59": 1, "4_-59": 1, "5_-59": 1, "6_-59": 1, "7_-59": 1, "7_-72": 1, "7_-71": 1, "7_-70": 1, "7_-69": 1,
        "7_-68": 1, "7_-67": 1, "7_-66": 1, "7_-65": 1, "7_-64": 1, "7_-63": 1, "7_-62": 1, "7_-61": 1, "7_-60": 1, "-6_-74": 1, "-5_-74": 1,
        "-4_-74": 1, "-3_-74": 1, "-2_-74": 1, "-1_-74": 1, "-1_-73": 1, "0_-73": 1, "1_-73": 1, "2_-73": 1, "3_-73": 1, "4_-74": 1, "5_-74": 1,
        "6_-74": 1, "7_-74": 1, "0_-74": 1, "1_-74": 1, "2_-74": 1, "3_-74": 1, "-7_-71": 1, "-7_-70": 1, "-7_-69": 1, "-7_-68": 1, "-7_-67": 1,
        "4_-73": 1, "5_-73": 1, "6_-73": 1, "7_-73": 1, "-6_-73": 1, "-5_-73": 1, "-4_-73": 1, "-3_-73": 1, "-2_-73": 1, "-6_-72": 1, "-6_-71": 1,
        "-6_-70": 1, "-5_-70": 1, "-5_-69": 1, "-5_-68": 1, "-5_-67": 1, "-5_-66": 1, "-5_-65": 1, "-5_-64": 1, "-5_-63": 1, "-6_-69": 1, "-6_-68": 1,
        "-6_-67": 1, "-6_-66": 1, "-5_-62": 1, "-5_-61": 1, "-5_-60": 1, "-6_-60": 1, "-6_-61": 1, "-6_-62": 1, "-6_-63": 1, "-6_-64": 1, "-6_-65": 1,
        "-5_-72": 1, "-5_-71": 1, "-4_-72": 1, "-4_-71": 1, "-4_-70": 1, "-4_-69": 1, "-4_-68": 1, "-4_-67": 1, "-4_-66": 1, "-4_-65": 1, "-4_-64": 1,
        "-4_-63": 1, "-4_-62": 1, "-4_-61": 1, "-4_-60": 1, "-3_-72": 1, "-3_-71": 1, "-3_-70": 1, "-3_-69": 1, "-3_-68": 1, "-3_-67": 1, "-3_-66": 1,
        "-3_-65": 1, "-3_-64": 1, "-3_-63": 1, "-3_-62": 1, "-3_-61": 1, "-3_-60": 1, "-2_-72": 1, "-2_-71": 1, "-2_-70": 1, "-2_-69": 1, "-2_-68": 1,
        "-2_-67": 1, "-2_-66": 1, "-2_-65": 1, "-2_-64": 1, "-2_-63": 1, "-2_-62": 1, "-2_-61": 1, "-2_-60": 1, "-1_-72": 1, "-1_-71": 1, "-1_-70": 1,
        "-1_-69": 1, "-1_-68": 1, "-1_-67": 1, "-1_-66": 1, "-1_-65": 1, "-1_-64": 1, "-1_-63": 1, "-1_-62": 1, "-1_-61": 1, "-1_-60": 1, "0_-72": 1,
        "0_-71": 1, "0_-70": 1, "0_-69": 1, "0_-68": 1, "0_-67": 1, "0_-66": 1, "0_-65": 1, "0_-64": 1, "0_-63": 1, "0_-62": 1, "0_-61": 1,
        "0_-60": 1, "1_-72": 1, "1_-71": 1, "1_-70": 1, "1_-69": 1, "1_-68": 1, "1_-67": 1, "1_-66": 1, "1_-65": 1, "1_-64": 1, "1_-63": 1,
        "1_-62": 1, "1_-61": 1, "1_-60": 1, "2_-72": 1, "2_-71": 1, "2_-70": 1, "2_-69": 1, "2_-68": 1, "2_-67": 1, "2_-66": 1, "2_-65": 1,
        "2_-64": 1, "2_-63": 1, "2_-62": 1, "2_-61": 1, "2_-60": 1, "4_-72": 1, "3_-72": 1, "3_-71": 1, "3_-70": 1, "3_-69": 1, "3_-68": 1,
        "3_-67": 1, "3_-66": 1, "3_-65": 1, "3_-64": 1, "3_-63": 1, "3_-62": 1, "3_-61": 1, "3_-60": 1, "5_-72": 1, "5_-71": 1, "5_-70": 1,
        "5_-69": 1, "5_-68": 1, "5_-67": 1, "5_-66": 1, "5_-65": 1, "5_-64": 1, "4_-63": 1, "4_-62": 1, "4_-61": 1, "4_-60": 1, "4_-71": 1,
        "4_-64": 1, "4_-65": 1, "4_-66": 1, "4_-67": 1, "4_-68": 1, "4_-69": 1, "4_-70": 1, "6_-72": 1, "6_-65": 1, "6_-64": 1, "6_-63": 1,
        "6_-62": 1, "6_-61": 1, "6_-60": 1, "5_-60": 1, "5_-61": 1, "5_-62": 1, "5_-63": 1, "6_-69": 1, "6_-70": 1, "6_-71": 1, "6_-68": 1,
        "6_-67": 1, "6_-66": 1, "-9_11": 1, "-8_11": 1, "-7_11": 1, "-6_11": 1, "-5_11": 1, "-4_11": 1, "6_11": 1, "7_11": 1, "8_11": 1,
        "9_11": 1, "5_11": 1, "-4_-10": 1, "-4_-9": 1, "-4_-8": 1, "-4_-7": 1, "-4_-6": 1, "-4_-5": 1, "-4_-4": 1, "-4_-3": 1, "-4_-2": 1,
        "-4_-1": 1, "-4_0": 1, "-4_1": 1, "-4_2": 1, "-4_3": 1, "-4_4": 1, "-4_5": 1, "-4_6": 1, "-4_7": 1, "-4_8": 1, "-4_9": 1,
        "-4_10": 1, "4_-10": 1, "4_-9": 1, "4_-8": 1, "4_-7": 1, "4_-6": 1, "4_-5": 1, "4_-4": 1, "4_-3": 1, "4_-2": 1, "4_-1": 1,
        "4_0": 1, "4_1": 1, "4_2": 1, "4_3": 1, "4_4": 1, "4_5": 1, "4_6": 1, "4_7": 1, "4_8": 1, "4_9": 1, "4_10": 1,
        "4_11": 1, "-9_-10": 1, "-8_-10": 1, "-7_-10": 1, "-6_-10": 1, "-5_-10": 1, "-5_-9": 1, "-5_-8": 1, "-5_-7": 1, "-5_-6": 1, "-5_-5": 1,
        "-5_-4": 1, "-5_-3": 1, "-5_-2": 1, "-6_-9": 1, "-6_-8": 1, "-6_-7": 1, "-6_-6": 1, "-6_-5": 1, "-6_-4": 1, "-6_-3": 1, "-6_-2": 1,
        "-6_-1": 1, "-6_0": 1, "-6_1": 1, "-8_-9": 1, "-8_-8": 1, "-8_-7": 1, "-8_-6": 1, "-8_-5": 1, "-8_-4": 1, "-8_-3": 1, "-8_-2": 1,
        "-8_-1": 1, "-8_0": 1, "-8_1": 1, "-7_-9": 1, "-7_-8": 1, "-7_-7": 1, "-7_-6": 1, "-7_-5": 1, "-7_-4": 1, "-7_-3": 1, "-7_-2": 1,
        "-7_-1": 1, "-7_0": 1, "-7_1": 1, "-9_-9": 1, "-9_-8": 1, "-9_-7": 1, "-9_-6": 1, "-9_-5": 1, "-9_-4": 1, "-9_-2": 1, "-9_-1": 1,
        "-9_0": 1, "-9_1": 1, "-9_2": 1, "-9_-3": 1, "-9_3": 1, "-9_4": 1, "-9_5": 1, "-9_6": 1, "-9_7": 1, "-9_8": 1, "-9_9": 1,
        "-9_10": 1, "-8_2": 1, "-8_3": 1, "-8_4": 1, "-8_5": 1, "-8_6": 1, "-8_7": 1, "-8_8": 1, "-8_9": 1, "-8_10": 1, "-6_2": 1,
        "-7_2": 1, "-7_3": 1, "-7_4": 1, "-7_5": 1, "-7_6": 1, "-7_7": 1, "-7_8": 1, "-7_9": 1, "-7_10": 1, "-5_-1": 1, "-5_0": 1,
        "-5_1": 1, "-5_3": 1, "-5_4": 1, "-5_5": 1, "-5_6": 1, "-5_7": 1, "-5_8": 1, "-5_9": 1, "-5_10": 1, "-5_2": 1, "-6_3": 1,
        "-6_4": 1, "-6_5": 1, "-6_6": 1, "-6_7": 1, "-6_8": 1, "-6_9": 1, "-6_10": 1, "5_-10": 1, "6_-10": 1, "7_-10": 1, "8_-10": 1,
        "9_-10": 1, "9_-9": 1, "8_-9": 1, "7_-9": 1, "6_-9": 1, "5_-9": 1, "5_-8": 1, "6_-8": 1, "7_-8": 1, "8_-8": 1, "9_-8": 1,
        "9_-7": 1, "8_-7": 1, "7_-7": 1, "6_-7": 1, "5_-7": 1, "5_-6": 1, "6_-6": 1, "7_-6": 1, "8_-6": 1, "9_-6": 1, "9_-5": 1,
        "9_-4": 1, "9_-3": 1, "9_-2": 1, "9_-1": 1, "8_-1": 1, "7_-1": 1, "6_-1": 1, "6_-2": 1, "5_-2": 1, "5_-3": 1, "5_-4": 1,
        "5_-5": 1, "6_-5": 1, "7_-5": 1, "8_-5": 1, "8_-4": 1, "8_-3": 1, "7_-2": 1, "7_-3": 1, "6_-4": 1, "6_-3": 1, "6_0": 1,
        "8_-2": 1, "7_-4": 1, "8_0": 1, "7_0": 1, "5_0": 1, "5_-1": 1, "9_0": 1, "9_1": 1, "8_1": 1, "7_1": 1, "6_1": 1,
        "5_1": 1, "5_2": 1, "6_2": 1, "7_2": 1, "8_2": 1, "9_2": 1, "9_3": 1, "8_3": 1, "7_3": 1, "6_3": 1, "5_3": 1,
        "5_4": 1, "6_4": 1, "7_4": 1, "8_4": 1, "9_4": 1, "5_5": 1, "6_5": 1, "7_5": 1, "8_5": 1, "8_6": 1, "8_7": 1,
        "9_7": 1, "9_8": 1, "9_9": 1, "9_10": 1, "9_5": 1, "9_6": 1, "7_6": 1, "7_7": 1, "7_8": 1, "7_9": 1, "7_10": 1,
        "8_10": 1, "8_9": 1, "8_8": 1, "6_6": 1, "6_7": 1, "6_8": 1, "6_9": 1, "6_10": 1, "5_10": 1, "5_9": 1, "5_8": 1,
        "5_7": 1, "5_6": 1, "-23_16": 1, "-22_16": 1, "-23_17": 1, "-23_18": 1, "-23_19": 1, "-23_20": 1, "-23_21": 1, "-23_22": 1, "-23_23": 1,
        "-23_24": 1, "-23_25": 1, "-22_17": 1, "-22_18": 1, "-22_19": 1, "-22_20": 1, "-22_21": 1, "-22_22": 1, "-22_23": 1, "-22_24": 1, "-22_25": 1,
        "22_17": 1, "22_18": 1, "22_19": 1, "22_20": 1, "22_21": 1, "22_22": 1, "22_23": 1, "22_24": 1, "22_25": 1, "23_17": 1, "23_18": 1,
        "23_19": 1, "23_20": 1, "23_21": 1, "23_22": 1, "23_23": 1, "23_24": 1, "23_25": 1, "20_-11": 1, "21_-11": 1, "22_-11": 1, "23_-11": 1,
        "24_-11": 1, "25_-11": 1, "26_-11": 1, "26_-12": 1, "26_-13": 1, "26_-14": 1, "26_-15": 1, "26_-16": 1, "26_-17": 1, "26_-18": 1, "26_-19": 1,
        "26_-20": 1, "26_-21": 1, "26_-22": 1, "26_-37": 1, "26_-36": 1, "26_-35": 1, "26_-34": 1, "26_-33": 1, "26_-32": 1, "26_-31": 1, "26_-30": 1,
        "26_-29": 1, "26_-28": 1, "26_-27": 1, "26_-26": 1, "26_-25": 1, "26_-24": 1, "26_-23": 1, "26_-47": 1, "26_-46": 1, "26_-45": 1, "26_-44": 1,
        "26_-43": 1, "26_-42": 1, "26_-41": 1, "26_-40": 1, "26_-39": 1, "26_-38": 1, "26_-80": 1, "26_-79": 1, "26_-78": 1, "26_-77": 1, "26_-76": 1,
        "26_-75": 1, "26_-74": 1, "26_-73": 1, "26_-72": 1, "26_-71": 1, "26_-70": 1, "26_-69": 1, "26_-68": 1, "26_-67": 1, "22_-82": 1, "23_-82": 1,
        "24_-82": 1, "25_-82": 1, "26_-82": 1, "26_-81": 1, "-2_-82": 1, "-1_-82": 1, "0_-82": 1, "1_-82": 1, "2_-82": 1, "-26_-82": 1, "-25_-82": 1,
        "-23_-82": 1, "-22_-82": 1, "-21_-82": 1, "-20_-82": 1, "-19_-82": 1, "-18_-82": 1, "-17_-82": 1, "-16_-82": 1, "-24_-82": 1, "-26_-81": 1, "-26_-80": 1,
        "-26_-79": 1, "-26_-78": 1, "-26_-77": 1, "-26_-76": 1, "-26_-75": 1, "-26_-74": 1, "-26_-73": 1, "-26_-72": 1, "-26_-71": 1, "-26_-70": 1, "-26_-69": 1,
        "-26_-68": 1, "-26_-67": 1, "-26_-66": 1, "-26_-65": 1, "-26_-64": 1, "-26_-63": 1, "-26_-62": 1, "-26_-61": 1, "-26_-60": 1, "-26_-59": 1, "-26_-58": 1,
        "-26_-57": 1, "-26_-56": 1, "-26_-55": 1, "-26_-54": 1, "-26_-53": 1, "-26_-52": 1, "-26_-51": 1, "-26_-50": 1, "-26_-49": 1, "-26_-48": 1, "-26_-47": 1,
        "-26_-46": 1, "-26_-45": 1, "-26_-44": 1, "-26_-43": 1, "-26_-42": 1, "-26_-41": 1, "-26_-40": 1, "-26_-39": 1, "-26_-38": 1, "-26_-37": 1, "-26_-36": 1,
        "-26_-35": 1, "-26_-34": 1, "-26_-33": 1, "-26_-32": 1, "-26_-31": 1, "-26_-30": 1, "-26_-29": 1, "-26_-28": 1, "-26_-27": 1, "-26_-26": 1, "-26_-25": 1,
        "-26_-24": 1, "-26_-23": 1, "-26_-22": 1, "-26_-21": 1, "-26_-20": 1, "-26_-19": 1, "-26_-18": 1, "-26_-17": 1, "-26_-16": 1, "-26_-15": 1, "-26_-14": 1,
        "-26_-13": 1, "-26_-12": 1, "-26_-11": 1, "-25_-11": 1, "-24_-11": 1, "-23_-11": 1, "-22_-11": 1, "-21_-11": 1, "-20_-11": 1, "-26_11": 1, "-25_11": 1,
        "-24_11": 1, "-23_11": 1, "-22_11": 1, "-21_11": 1, "-20_11": 1, "-26_12": 1, "-26_13": 1, "-26_14": 1, "-26_15": 1, "-26_16": 1, "-26_17": 1,
        "-26_18": 1, "-26_19": 1, "-26_20": 1, "-26_21": 1, "-26_22": 1, "-26_23": 1, "-26_24": 1, "-26_25": 1, "-26_26": 1, "-26_27": 1, "-26_28": 1,
        "-26_29": 1, "-26_30": 1, "-26_31": 1, "-26_32": 1, "-26_33": 1, "-26_34": 1, "-26_35": 1, "-26_36": 1, "-26_37": 1, "-26_38": 1, "-26_39": 1,
        "-26_40": 1, "-26_41": 1, "-26_42": 1, "-26_43": 1, "-26_44": 1, "-26_45": 1, "-26_46": 1, "-26_47": 1, "-26_48": 1, "-26_49": 1, "-26_50": 1,
        "-26_51": 1, "-26_52": 1, "-26_53": 1, "-26_54": 1, "-26_55": 1, "-26_56": 1, "-26_57": 1, "-26_58": 1, "-26_59": 1, "-26_60": 1, "-26_61": 1,
        "-26_62": 1, "-26_63": 1, "-26_64": 1, "-26_65": 1, "-26_66": 1, "-26_67": 1, "-26_68": 1, "-26_69": 1, "-26_70": 1, "-26_71": 1, "-26_72": 1,
        "-26_73": 1, "-26_74": 1, "-26_75": 1, "-26_76": 1, "-26_77": 1, "-26_78": 1, "-26_79": 1, "-26_80": 1, "-26_81": 1, "-26_82": 1, "-25_82": 1,
        "-24_82": 1, "-23_82": 1, "-22_82": 1, "-21_82": 1, "-20_82": 1, "-19_82": 1, "-18_82": 1, "-17_82": 1, "-16_82": 1, "-15_82": 1, "-14_82": 1,
        "-13_82": 1, "-12_82": 1, "-11_82": 1, "-10_82": 1, "-9_82": 1, "-8_82": 1, "-7_82": 1, "-6_82": 1, "-5_82": 1, "-4_82": 1, "-3_82": 1,
        "-2_82": 1, "-1_82": 1, "0_82": 1, "1_82": 1, "2_82": 1, "3_82": 1, "4_82": 1, "5_82": 1, "6_82": 1, "7_82": 1, "8_82": 1,
        "9_82": 1, "10_82": 1, "11_82": 1, "12_82": 1, "13_82": 1, "14_82": 1, "15_82": 1, "16_82": 1, "17_82": 1, "18_82": 1, "19_82": 1,
        "20_82": 1, "21_82": 1, "22_82": 1, "23_82": 1, "24_82": 1, "25_82": 1, "26_82": 1, "26_69": 1, "26_70": 1, "26_71": 1, "26_72": 1,
        "26_73": 1, "26_74": 1, "26_75": 1, "26_76": 1, "26_77": 1, "26_78": 1, "26_79": 1, "26_80": 1, "26_81": 1, "26_54": 1, "26_55": 1,
        "26_56": 1, "26_57": 1, "26_58": 1, "26_61": 1, "26_62": 1, "26_63": 1, "26_64": 1, "26_65": 1, "26_66": 1, "26_67": 1, "26_68": 1,
        "26_59": 1, "26_60": 1, "26_42": 1, "26_43": 1, "26_44": 1, "26_45": 1, "26_46": 1, "26_47": 1, "26_48": 1, "26_49": 1, "26_50": 1,
        "26_51": 1, "26_52": 1, "26_53": 1, "26_26": 1, "26_27": 1, "26_28": 1, "26_29": 1, "26_30": 1, "26_31": 1, "26_32": 1, "26_33": 1,
        "26_34": 1, "26_35": 1, "26_36": 1, "26_37": 1, "26_38": 1, "26_39": 1, "26_40": 1, "26_41": 1, "26_11": 1, "26_12": 1, "26_13": 1,
        "26_14": 1, "26_15": 1, "26_16": 1, "26_17": 1, "26_18": 1, "26_19": 1, "26_20": 1, "26_21": 1, "26_22": 1, "26_23": 1, "26_24": 1,
        "26_25": 1, "-19_-11": 1, "-18_-11": 1, "-17_-11": 1, "-16_-11": 1, "-15_-11": 1, "-14_-11": 1, "-14_-10": 1, "-14_-9": 1, "-14_-5": 1, "-14_-4": 1,
        "-14_-3": 1, "-14_-2": 1, "-14_-1": 1, "-14_0": 1, "-14_-8": 1, "-14_-7": 1, "-14_-6": 1, "-14_1": 1, "-14_2": 1, "-14_3": 1, "-14_4": 1,
        "-14_5": 1, "-14_6": 1, "-14_7": 1, "-14_8": 1, "-14_9": 1, "-14_10": 1, "-14_11": 1, "-18_11": 1, "-17_11": 1, "-16_11": 1, "-15_11": 1,
        "15_-11": 1, "15_-10": 1, "15_-9": 1, "15_-6": 1, "15_-5": 1, "15_-4": 1, "15_-3": 1, "15_-2": 1, "15_-1": 1, "15_0": 1, "15_-8": 1,
        "15_-7": 1, "16_-11": 1, "17_-11": 1, "18_-11": 1, "20_11": 1, "21_11": 1, "22_11": 1, "23_11": 1, "24_11": 1, "25_11": 1, "15_1": 1,
        "15_2": 1, "15_3": 1, "15_4": 1, "15_5": 1, "15_6": 1, "15_7": 1, "15_8": 1, "15_9": 1, "15_10": 1, "15_11": 1, "16_11": 1,
        "17_11": 1, "18_11": 1, "16_-10": 1, "16_-9": 1, "16_-8": 1, "16_-7": 1, "16_-6": 1, "16_-5": 1, "16_-4": 1, "16_-3": 1, "16_-2": 1,
        "16_-1": 1, "16_0": 1, "16_1": 1, "16_2": 1, "16_3": 1, "17_-10": 1, "17_-7": 1, "17_-6": 1, "17_-5": 1, "17_-4": 1, "17_-3": 1,
        "17_-2": 1, "17_-1": 1, "17_0": 1, "17_1": 1, "17_2": 1, "17_3": 1, "17_-8": 1, "17_-9": 1, "18_-10": 1, "18_-9": 1, "18_-8": 1,
        "18_-7": 1, "18_-6": 1, "18_-5": 1, "18_-4": 1, "18_-3": 1, "18_-2": 1, "18_-1": 1, "18_0": 1, "18_1": 1, "18_2": 1, "18_3": 1,
        "19_-10": 1, "19_-9": 1, "19_-8": 1, "19_-7": 1, "19_-6": 1, "19_-5": 1, "19_-4": 1, "20_-4": 1, "20_-3": 1, "20_-2": 1, "20_-1": 1,
        "20_0": 1, "20_1": 1, "20_2": 1, "20_3": 1, "19_3": 1, "19_2": 1, "19_1": 1, "19_0": 1, "19_-1": 1, "19_-2": 1, "19_-3": 1,
        "20_-7": 1, "20_-8": 1, "20_-9": 1, "20_-10": 1, "20_-6": 1, "20_-5": 1, "21_-10": 1, "21_-9": 1, "21_-8": 1, "21_-7": 1, "21_-6": 1,
        "21_-5": 1, "21_-4": 1, "21_-3": 1, "21_-2": 1, "21_-1": 1, "21_0": 1, "21_1": 1, "21_2": 1, "22_-10": 1, "22_-9": 1, "22_-8": 1,
        "22_-7": 1, "22_-6": 1, "22_-5": 1, "22_-4": 1, "22_-3": 1, "22_-2": 1, "22_-1": 1, "22_0": 1, "22_1": 1, "22_2": 1, "23_-10": 1,
        "23_-9": 1, "23_-8": 1, "23_-7": 1, "23_-6": 1, "23_-5": 1, "23_-4": 1, "23_-3": 1, "23_-2": 1, "23_-1": 1, "23_0": 1, "23_1": 1,
        "23_2": 1, "24_-10": 1, "24_-9": 1, "24_-8": 1, "24_-7": 1, "24_-6": 1, "24_-5": 1, "24_-4": 1, "24_-3": 1, "24_-2": 1, "24_-1": 1,
        "24_0": 1, "24_1": 1, "24_2": 1, "25_-10": 1, "25_-9": 1, "25_-8": 1, "25_-7": 1, "25_-6": 1, "25_-5": 1, "25_-4": 1, "25_-3": 1,
        "25_-2": 1, "25_-1": 1, "25_0": 1, "25_1": 1, "25_2": 1, "26_-10": 1, "26_-9": 1, "26_-8": 1, "26_-7": 1, "26_-6": 1, "26_-5": 1,
        "26_-4": 1, "26_-3": 1, "26_-2": 1, "26_-1": 1, "26_0": 1, "26_1": 1, "26_2": 1, "26_3": 1, "26_4": 1, "26_5": 1, "26_6": 1,
        "26_7": 1, "26_8": 1, "26_9": 1, "26_10": 1, "21_3": 1, "22_3": 1, "23_3": 1, "24_3": 1, "25_3": 1, "25_4": 1, "24_4": 1,
        "23_4": 1, "22_4": 1, "21_4": 1, "20_4": 1, "16_4": 1, "17_4": 1, "18_4": 1, "19_4": 1, "16_5": 1, "17_5": 1, "18_5": 1,
        "19_5": 1, "20_5": 1, "21_5": 1, "22_5": 1, "23_5": 1, "24_5": 1, "25_5": 1, "16_6": 1, "17_6": 1, "18_6": 1, "19_6": 1,
        "20_6": 1, "21_6": 1, "22_6": 1, "23_6": 1, "24_6": 1, "25_6": 1, "16_7": 1, "17_7": 1, "18_7": 1, "19_7": 1, "20_7": 1,
        "21_7": 1, "22_7": 1, "23_7": 1, "24_7": 1, "25_7": 1, "16_8": 1, "17_8": 1, "18_8": 1, "19_8": 1, "20_8": 1, "21_8": 1,
        "22_8": 1, "23_8": 1, "24_8": 1, "25_8": 1, "16_9": 1, "17_9": 1, "18_9": 1, "19_9": 1, "20_9": 1, "21_9": 1, "22_9": 1,
        "23_9": 1, "24_9": 1, "25_9": 1, "16_10": 1, "17_10": 1, "18_10": 1, "19_10": 1, "20_10": 1, "21_10": 1, "22_10": 1, "23_10": 1,
        "24_10": 1, "25_10": 1, "-26_-10": 1, "-25_-10": 1, "-24_-10": 1, "-23_-10": 1, "-22_-10": 1, "-21_-10": 1, "-20_-10": 1, "-19_-10": 1, "-18_-10": 1,
        "-17_-10": 1, "-16_-10": 1, "-15_-10": 1, "-26_-9": 1, "-25_-9": 1, "-24_-9": 1, "-23_-9": 1, "-22_-9": 1, "-21_-9": 1, "-20_-9": 1, "-19_-9": 1,
        "-18_-9": 1, "-17_-9": 1, "-16_-9": 1, "-15_-9": 1, "-15_-8": 1, "-16_-8": 1, "-17_-8": 1, "-18_-8": 1, "-19_-8": 1, "-20_-8": 1, "-21_-8": 1,
        "-22_-8": 1, "-23_-8": 1, "-24_-8": 1, "-25_-8": 1, "-26_-8": 1, "-26_-7": 1, "-25_-7": 1, "-24_-7": 1, "-23_-7": 1, "-22_-7": 1, "-21_-7": 1,
        "-20_-7": 1, "-19_-7": 1, "-18_-7": 1, "-17_-7": 1, "-16_-7": 1, "-15_-7": 1, "-15_-6": 1, "-16_-6": 1, "-17_-6": 1, "-18_-6": 1, "-19_-6": 1,
        "-20_-6": 1, "-21_-6": 1, "-22_-6": 1, "-23_-6": 1, "-24_-6": 1, "-25_-6": 1, "-26_-6": 1, "-26_-5": 1, "-25_-5": 1, "-24_-5": 1, "-23_-5": 1,
        "-22_-5": 1, "-21_-5": 1, "-20_-5": 1, "-19_-5": 1, "-18_-5": 1, "-17_-5": 1, "-16_-5": 1, "-15_-5": 1, "-26_-4": 1, "-26_-3": 1, "-26_-2": 1,
        "-26_-1": 1, "-26_0": 1, "-26_1": 1, "-26_2": 1, "-26_3": 1, "-26_4": 1, "-26_5": 1, "-26_6": 1, "-26_7": 1, "-26_8": 1, "-26_9": 1,
        "-26_10": 1, "-25_-4": 1, "-25_-3": 1, "-25_-2": 1, "-25_-1": 1, "-25_0": 1, "-25_1": 1, "-25_2": 1, "-25_3": 1, "-25_4": 1, "-25_5": 1,
        "-25_6": 1, "-25_7": 1, "-25_8": 1, "-25_9": 1, "-25_10": 1, "-24_10": 1, "-23_10": 1, "-21_10": 1, "-20_10": 1, "-19_10": 1, "-18_10": 1,
        "-17_10": 1, "-16_10": 1, "-15_10": 1, "-15_9": 1, "-15_8": 1, "-15_7": 1, "-15_6": 1, "-15_5": 1, "-15_4": 1, "-15_3": 1, "-15_2": 1,
        "-15_1": 1, "-15_0": 1, "-15_-1": 1, "-15_-2": 1, "-15_-3": 1, "-15_-4": 1, "-16_-4": 1, "-17_-4": 1, "-18_-4": 1, "-19_-4": 1, "-20_-4": 1,
        "-21_-4": 1, "-22_-4": 1, "-23_-4": 1, "-24_-4": 1, "-24_-3": 1, "-24_-2": 1, "-24_-1": 1, "-24_0": 1, "-24_1": 1, "-24_2": 1, "-24_3": 1,
        "-24_4": 1, "-24_5": 1, "-24_6": 1, "-24_7": 1, "-24_8": 1, "-24_9": 1, "-23_9": 1, "-22_9": 1, "-21_9": 1, "-20_9": 1, "-19_9": 1,
        "-18_9": 1, "-17_9": 1, "-16_9": 1, "-16_8": 1, "-16_7": 1, "-16_6": 1, "-16_5": 1, "-16_4": 1, "-16_3": 1, "-16_2": 1, "-17_2": 1,
        "-17_1": 1, "-17_0": 1, "-17_-1": 1, "-17_-2": 1, "-17_-3": 1, "-16_-3": 1, "-16_-2": 1, "-16_-1": 1, "-16_0": 1, "-16_1": 1, "-17_3": 1,
        "-17_4": 1, "-17_5": 1, "-17_6": 1, "-17_7": 1, "-17_8": 1, "-18_8": 1, "-19_8": 1, "-20_8": 1, "-21_8": 1, "-22_8": 1, "-23_8": 1,
        "-23_7": 1, "-23_-3": 1, "-23_-2": 1, "-23_-1": 1, "-23_0": 1, "-23_1": 1, "-23_2": 1, "-23_3": 1, "-23_4": 1, "-23_5": 1, "-23_6": 1,
        "-22_7": 1, "-21_7": 1, "-20_7": 1, "-19_7": 1, "-18_7": 1, "-18_6": 1, "-18_5": 1, "-18_4": 1, "-18_3": 1, "-18_2": 1, "-18_1": 1,
        "-18_0": 1, "-18_-1": 1, "-18_-2": 1, "-18_-3": 1, "-19_-3": 1, "-19_-2": 1, "-19_-1": 1, "-19_0": 1, "-19_1": 1, "-19_2": 1, "-19_3": 1,
        "-19_4": 1, "-19_5": 1, "-19_6": 1, "-20_-3": 1, "-20_-2": 1, "-20_-1": 1, "-20_0": 1, "-20_1": 1, "-20_2": 1, "-20_3": 1, "-20_4": 1,
        "-20_5": 1, "-20_6": 1, "-21_-3": 1, "-21_-2": 1, "-21_-1": 1, "-21_0": 1, "-21_1": 1, "-21_2": 1, "-21_3": 1, "-21_4": 1, "-21_5": 1,
        "-21_6": 1, "-22_-3": 1, "-22_-2": 1, "-22_-1": 1, "-22_0": 1, "-22_1": 1, "-22_2": 1, "-22_3": 1, "-22_4": 1, "-22_5": 1, "-22_6": 1,
        "-22_10": 1, "-6_18": 1, "-6_19": 1, "-6_20": 1, "-6_21": 1, "-6_22": 1, "-5_18": 1, "-4_18": 1, "-3_18": 1, "-5_22": 1, "-4_22": 1,
        "-5_19": 1, "-5_20": 1, "-5_21": 1, "-4_21": 1, "-4_20": 1, "-4_19": 1, "-3_19": 1, "-3_20": 1, "-3_21": 1, "3_18": 1, "3_19": 1,
        "3_20": 1, "3_21": 1, "4_18": 1, "5_18": 1, "6_18": 1, "6_19": 1, "6_20": 1, "6_21": 1, "6_22": 1, "5_22": 1, "4_22": 1,
        "4_19": 1, "4_20": 1, "4_21": 1, "5_21": 1, "5_20": 1, "5_19": 1, "-6_-22": 1, "-6_-21": 1, "-6_-20": 1, "-6_-19": 1, "-5_-19": 1,
        "-4_-19": 1, "-5_-22": 1, "-4_-22": 1, "-3_-22": 1, "-3_-21": 1, "-3_-20": 1, "-3_-19": 1, "3_-22": 1, "3_-21": 1, "3_-20": 1, "3_-19": 1,
        "3_-18": 1, "4_-19": 1, "5_-19": 1, "6_-19": 1, "4_-22": 1, "5_-22": 1, "6_-22": 1, "6_-21": 1, "6_-20": 1, "4_-20": 1, "4_-21": 1,
        "5_-21": 1, "5_-20": 1, "-5_-21": 1, "-5_-20": 1, "-4_-21": 1, "-4_-20": 1, "-3_-18": 1, "-4_-18": 1, "4_-18": 1, "-6_-18": 1, "-5_-18": 1,
        "5_-18": 1, "6_-18": 1, "-3_-11": 1, "-3_-10": 1, "-3_-9": 1, "-3_-8": 1, "-3_-7": 1, "-3_-6": 1, "-3_-5": 1, "-3_-4": 1, "-3_-3": 1,
        "-3_-2": 1, "3_-11": 1, "3_-10": 1, "3_-9": 1, "3_-8": 1, "3_-7": 1, "3_-6": 1, "3_-5": 1, "3_-4": 1, "3_-3": 1, "3_-2": 1,
        "-3_-1": 1, "-3_0": 1, "-3_1": 1, "-3_2": 1, "-3_3": 1, "-3_4": 1, "-3_5": 1, "-3_6": 1, "-3_7": 1, "-3_8": 1, "-3_9": 1,
        "-3_10": 1, "-3_11": 1, "3_-1": 1, "3_0": 1, "3_1": 1, "3_2": 1, "3_3": 1, "3_4": 1, "3_5": 1, "3_6": 1, "3_7": 1,
        "3_8": 1, "3_9": 1, "3_10": 1, "3_11": 1, "-7_59": 1, "-7_60": 1, "-7_61": 1, "-7_62": 1, "-7_63": 1, "-7_73": 1, "-7_72": 1,
        "-7_71": 1, "-7_70": 1, "-7_69": 1, "-7_68": 1, "-7_67": 1, "-7_66": 1, "-7_65": 1, "-7_64": 1, "-6_59": 1, "-6_60": 1, "-6_61": 1,
        "-6_62": 1, "-6_63": 1, "-6_64": 1, "-6_65": 1, "-6_66": 1, "-6_73": 1, "-6_72": 1, "-6_71": 1, "-6_70": 1, "-6_69": 1, "-6_68": 1,
        "-6_67": 1, "-5_64": 1, "-5_63": 1, "-5_62": 1, "-5_61": 1, "-5_59": 1, "-5_60": 1, "-5_65": 1, "-5_66": 1, "-5_67": 1, "-5_68": 1,
        "-5_69": 1, "-5_70": 1, "-5_71": 1, "-5_72": 1, "-5_73": 1, "-4_59": 1, "-4_60": 1, "-4_61": 1, "-4_62": 1, "-4_63": 1, "-4_64": 1,
        "-4_65": 1, "-4_66": 1, "-4_67": 1, "-4_68": 1, "-4_69": 1, "-4_70": 1, "-4_71": 1, "-4_72": 1, "-4_73": 1, "-3_72": 1, "-3_71": 1,
        "-3_70": 1, "-3_69": 1, "-3_68": 1, "-3_67": 1, "-3_66": 1, "-3_65": 1, "-3_64": 1, "-3_63": 1, "-3_62": 1, "-3_61": 1, "-3_60": 1,
        "-3_59": 1, "-2_59": 1, "-2_60": 1, "-2_61": 1, "-2_62": 1, "-2_63": 1, "-2_64": 1, "-2_65": 1, "-2_66": 1, "-2_67": 1, "-2_68": 1,
        "-2_69": 1, "-2_70": 1, "-2_71": 1, "-2_72": 1, "-2_73": 1, "-3_73": 1, "-1_59": 1, "-1_60": 1, "-1_61": 1, "-1_62": 1, "-1_63": 1,
        "-1_64": 1, "-1_65": 1, "-1_66": 1, "-1_67": 1, "-1_68": 1, "-1_69": 1, "-1_70": 1, "-1_71": 1, "-1_72": 1, "-1_73": 1, "0_73": 1,
        "1_73": 1, "2_73": 1, "3_73": 1, "4_73": 1, "5_73": 1, "6_73": 1, "7_73": 1, "7_72": 1, "7_71": 1, "7_70": 1, "7_69": 1,
        "7_68": 1, "7_67": 1, "7_66": 1, "7_65": 1, "7_64": 1, "7_63": 1, "7_62": 1, "7_61": 1, "7_60": 1, "7_59": 1, "6_59": 1,
        "5_59": 1, "4_59": 1, "3_59": 1, "2_59": 1, "1_59": 1, "0_59": 1, "0_60": 1, "0_61": 1, "0_62": 1, "0_63": 1, "0_64": 1,
        "0_65": 1, "0_66": 1, "0_67": 1, "0_68": 1, "0_69": 1, "0_70": 1, "0_71": 1, "0_72": 1, "1_72": 1, "2_72": 1, "3_72": 1,
        "4_72": 1, "5_72": 1, "6_72": 1, "6_71": 1, "6_70": 1, "6_69": 1, "6_68": 1, "6_67": 1, "6_66": 1, "6_65": 1, "6_64": 1,
        "6_63": 1, "6_62": 1, "6_61": 1, "6_60": 1, "5_60": 1, "4_60": 1, "3_60": 1, "2_60": 1, "1_60": 1, "1_61": 1, "1_62": 1,
        "1_63": 1, "1_64": 1, "1_65": 1, "1_66": 1, "1_69": 1, "1_68": 1, "1_67": 1, "2_61": 1, "2_62": 1, "2_63": 1, "2_64": 1,
        "2_65": 1, "2_66": 1, "2_67": 1, "2_68": 1, "2_69": 1, "2_70": 1, "2_71": 1, "1_70": 1, "1_71": 1, "3_61": 1, "3_62": 1,
        "3_63": 1, "3_64": 1, "3_65": 1, "3_66": 1, "3_67": 1, "3_68": 1, "3_69": 1, "3_70": 1, "3_71": 1, "4_61": 1, "4_62": 1,
        "4_63": 1, "4_64": 1, "4_65": 1, "4_66": 1, "4_67": 1, "4_68": 1, "4_69": 1, "4_70": 1, "4_71": 1, "5_61": 1, "5_62": 1,
        "5_63": 1, "5_64": 1, "5_65": 1, "5_66": 1, "5_67": 1, "5_68": 1, "5_69": 1, "5_70": 1, "5_71": 1, "-15_-51": 1, "-15_-50": 1,
        "-15_-49": 1, "-10_-51": 1, "-10_-50": 1, "-10_-49": 1, "10_-50": 1, "10_-49": 1, "10_-51": 1, "10_-48": 1, "15_-51": 1, "15_-50": 1, "15_-49": 1,
        "15_-48": 1, "11_-35": 1, "11_-34": 1, "11_-33": 1, "11_-32": 1, "16_-35": 1, "16_-34": 1, "16_-33": 1, "16_-32": 1, "-16_-35": 1, "-16_-34": 1,
        "-16_-33": 1, "-16_-32": 1, "-11_-35": 1, "-11_-34": 1, "-11_-33": 1, "-11_-32": 1, "10_-12": 1, "10_-13": 1, "-18_-13": 1, "-18_-12": 1, "-17_-13": 1,
        "-16_-13": 1, "-16_-12": 1, "-17_-12": 1, "9_-13": 1, "9_-12": 1, "-10_13": 1, "-10_12": 1, "-9_12": 1, "-9_13": 1, "16_12": 1, "16_13": 1,
        "17_13": 1, "18_13": 1, "18_12": 1, "17_12": 1, "-16_32": 1, "-16_33": 1, "-16_34": 1, "-16_35": 1, "-11_32": 1, "-11_33": 1, "-11_34": 1,
        "-11_35": 1, "-15_48": 1, "-15_49": 1, "-15_50": 1, "-15_51": 1, "-10_48": 1, "-10_49": 1, "-10_50": 1, "-10_51": 1, "10_48": 1, "10_49": 1,
        "10_50": 1, "10_51": 1, "15_48": 1, "15_49": 1, "15_50": 1, "15_51": 1, "11_32": 1, "11_33": 1, "11_34": 1, "11_35": 1, "16_32": 1,
        "16_33": 1, "16_34": 1, "16_35": 1, "-2_-11": 1, "-1_-11": 1, "0_-11": 1, "1_-11": 1, "2_-11": 1, "-1_-10": 1, "-2_-10": 1, "-2_-9": 1,
        "-2_-8": 1, "-2_-7": 1, "-2_-6": 1, "-1_-8": 1, "-1_-9": 1, "0_-9": 1, "0_-10": 1, "1_-10": 1, "2_-10": 1, "1_-9": 1, "2_-9": 1,
        "1_-8": 1, "0_-8": 1, "2_-8": 1, "-1_-7": 1, "0_-7": 1, "2_-7": 1, "1_-7": 1, "0_-6": 1, "1_-6": 1, "2_-6": 1, "-1_-6": 1,
        "1_-5": 1, "-1_-5": 1, "-2_-5": 1, "0_-5": 1, "-2_-4": 1, "2_-5": 1, "2_-4": 1, "0_-4": 1, "-1_-4": 1, "1_-4": 1, "2_-3": 1,
        "1_-3": 1, "-1_-3": 1, "-2_-3": 1, "0_-3": 1, "-2_-2": 1, "0_-2": 1, "2_-2": 1, "0_-1": 1, "-1_-1": 1, "-2_-1": 1, "1_-1": 1,
        "2_-1": 1, "1_-2": 1, "-1_-2": 1, "-2_0": 1, "-1_0": 1, "0_0": 1, "1_0": 1, "2_0": 1, "2_1": 1, "2_2": 1, "2_3": 1,
        "2_4": 1, "2_5": 1, "2_6": 1, "2_7": 1, "2_8": 1, "2_9": 1, "2_10": 1, "2_11": 1, "1_11": 1, "0_11": 1, "-1_11": 1,
        "-2_11": 1, "-2_10": 1, "-2_9": 1, "-2_8": 1, "-2_7": 1, "-2_6": 1, "-2_5": 1, "-2_4": 1, "-2_3": 1, "-2_2": 1, "-2_1": 1,
        "-1_1": 1, "-1_2": 1, "-1_3": 1, "-1_4": 1, "-1_5": 1, "-1_6": 1, "-1_7": 1, "-1_8": 1, "-1_10": 1, "-1_9": 1, "0_10": 1,
        "1_10": 1, "1_9": 1, "1_8": 1, "1_7": 1, "0_7": 1, "0_6": 1, "0_5": 1, "0_4": 1, "0_3": 1, "0_2": 1, "0_1": 1,
        "1_1": 1, "1_2": 1, "1_3": 1, "1_4": 1, "1_5": 1, "1_6": 1, "0_8": 1, "0_9": 1, "-2_-26": 1, "-1_-26": 1, "0_-26": 1,
        "1_-26": 1, "2_-26": 1, "2_-25": 1, "1_-25": 1, "0_-25": 1, "-1_-25": 1, "-2_-25": 1, "-2_-24": 1, "-1_-24": 1, "0_-24": 1, "1_-24": 1,
        "2_-24": 1, "2_-23": 1, "1_-23": 1, "0_-23": 1, "-1_-23": 1, "-2_-23": 1, "-2_-22": 1, "-2_-21": 1, "-2_-20": 1, "-2_-19": 1, "-2_-18": 1,
        "-1_-18": 1, "0_-18": 1, "1_-18": 1, "2_-18": 1, "2_-19": 1, "2_-20": 1, "2_-21": 1, "2_-22": 1, "1_-22": 1, "0_-22": 1, "-1_-22": 1,
        "-1_-21": 1, "-1_-20": 1, "-1_-19": 1, "0_-19": 1, "0_-20": 1, "0_-21": 1, "1_-21": 1, "1_-20": 1, "1_-19": 1, "-2_18": 1, "-1_18": 1,
        "0_18": 1, "1_18": 1, "2_18": 1, "-2_19": 1, "-1_19": 1, "0_19": 1, "1_19": 1, "2_19": 1, "2_20": 1, "1_20": 1, "0_20": 1,
        "-1_20": 1, "-2_20": 1, "-2_21": 1, "-1_21": 1, "0_21": 1, "1_21": 1, "2_21": 1, "2_22": 1, "2_23": 1, "2_24": 1, "2_25": 1,
        "2_26": 1, "1_26": 1, "0_26": 1, "-1_26": 1, "-2_26": 1, "-2_25": 1, "-2_24": 1, "-2_23": 1, "-2_22": 1, "-1_22": 1, "-1_23": 1,
        "-1_24": 1, "-1_25": 1, "0_25": 1, "0_24": 1, "0_23": 1, "0_22": 1, "1_22": 1, "1_23": 1, "1_24": 1, "1_25": 1,
    };
    SceneTerrainConfig.map2 = {};
    SceneTerrainConfig.map3 = {};
    SceneTerrainConfig.initPos1 = [
        { "x": -6, "z": -54 }, { "x": -5, "z": -54 }, { "x": -4, "z": -54 }, { "x": -3, "z": -54 }, { "x": -2, "z": -54 }, { "x": -1, "z": -54 }, { "x": 0, "z": -54 },
        { "x": 1, "z": -54 }, { "x": 2, "z": -54 }, { "x": 3, "z": -54 }, { "x": 4, "z": -54 }, { "x": 5, "z": -54 }, { "x": 6, "z": -54 }, { "x": 11, "z": -54 },
        { "x": 12, "z": -54 }, { "x": 13, "z": -54 }, { "x": 14, "z": -54 }, { "x": -14, "z": -54 }, { "x": -13, "z": -54 }, { "x": -12, "z": -54 }, { "x": -11, "z": -54 },
        { "x": -1, "z": 55 }, { "x": 0, "z": 55 }, { "x": 1, "z": 55 }, { "x": 2, "z": 55 }, { "x": 3, "z": 55 }, { "x": 4, "z": 55 }, { "x": 5, "z": 55 },
        { "x": 6, "z": 55 }, { "x": -5, "z": 55 }, { "x": -4, "z": 55 }, { "x": -3, "z": 55 }, { "x": -2, "z": 55 }, { "x": -6, "z": 55 }, { "x": -14, "z": 55 },
        { "x": -13, "z": 55 }, { "x": -12, "z": 55 }, { "x": -11, "z": 55 }, { "x": 11, "z": 55 }, { "x": 12, "z": 55 }, { "x": 13, "z": 55 }, { "x": 14, "z": 55 }
    ];
    SceneTerrainConfig.initPos1_1 = [
        { "x": -6, "z": -54 }, { "x": -5, "z": -54 }, { "x": -4, "z": -54 }, { "x": -3, "z": -54 }, { "x": -2, "z": -54 }, { "x": -1, "z": -54 }, { "x": 0, "z": -54 },
        { "x": 1, "z": -54 }, { "x": 2, "z": -54 }, { "x": 3, "z": -54 }, { "x": 4, "z": -54 }, { "x": 5, "z": -54 }, { "x": 6, "z": -54 }, { "x": 11, "z": -54 },
        { "x": 12, "z": -54 }, { "x": 13, "z": -54 }, { "x": 14, "z": -54 }, { "x": -14, "z": -54 }, { "x": -13, "z": -54 }, { "x": -12, "z": -54 }, { "x": -11, "z": -54 }
    ];
    SceneTerrainConfig.initPos1_2 = [
        { "x": -1, "z": 55 }, { "x": 0, "z": 55 }, { "x": 1, "z": 55 }, { "x": 2, "z": 55 }, { "x": 3, "z": 55 }, { "x": 4, "z": 55 }, { "x": 5, "z": 55 },
        { "x": 6, "z": 55 }, { "x": -5, "z": 55 }, { "x": -4, "z": 55 }, { "x": -3, "z": 55 }, { "x": -2, "z": 55 }, { "x": -6, "z": 55 }, { "x": -14, "z": 55 },
        { "x": -13, "z": 55 }, { "x": -12, "z": 55 }, { "x": -11, "z": 55 }, { "x": 11, "z": 55 }, { "x": 12, "z": 55 }, { "x": 13, "z": 55 }, { "x": 14, "z": 55 }
    ];
    SceneTerrainConfig.size = [-25, 25, -80, 80];

    class RoVo {
        constructor() {
            this.lib = {};
        }
        add(name) {
            this.lib[name] = true;
        }
        remove(name) {
            delete this.lib[name];
        }
        getValue() {
            for (var k in this.lib) {
                return true;
            }
            return false;
        }
    }

    class SceneVo {
        constructor() {
            this.cid = 2;
            this.battleType = 0;
            this.victoryNum = 1;
            this.state = 0;
            this.startTs = 0;
            this.totalTime = 0;
            this.leftTime = 0;
            this.isExit = false;
            this.circleTs = 0;
            this.circleOpen = true;
            this.circle = 1;
            this.circleSize = 100;
            this.npcCamp = 0;
            this.teamNum = 0;
            this.playerDieNum = 0;
            this.playerKillNum = 0;
            this.teamKillNum = 0;
            this.foeKillNum = 0;
            this.killMap = {};
            this.teamHp = 0;
            this.foeHp = 0;
            this.teamAllMaxHp = 0;
            this.foeAllmaxHp = 0;
            this.vipBuff = 0;
            this.airdropNum = 0;
            this.difficulty = 0;
            this.teamIntegralTotal = 0;
            this.foeIntegralTotal = 0;
            this.locList1 = [];
            this.locList2 = [];
            this.unitList = {};
            this.goodsList = {};
            this.teamList = [];
            this.loadComp = false;
            this.isPause = false;
            this.lv = 1;
            this.pauseVo = new RoVo();
        }
        addUnit(vo) {
            this.unitList[vo.id] = vo;
        }
        removeUnit(id) {
            delete this.unitList[id];
        }
        getUnit(id) {
            return this.unitList[id];
        }
        hasFoeUnit() {
            for (var k in this.unitList) {
                var vo = this.unitList[k];
                if (vo.isDie == false && vo.camp != 1) {
                    return true;
                }
            }
            return false;
        }
        addGoods(vo) {
            this.goodsList[vo.id] = vo;
        }
        removeGoods(id) {
            delete this.goodsList[id];
        }
        getGoodsNum() {
            var n = 0;
            for (var k in this.goodsList) {
                n++;
            }
            return n;
        }
    }

    class SceneVoBuilder {
        static getSceneVo(cid) {
            var vo = new SceneVo();
            vo.cid = cid;
            vo.terrain = SceneTerrainConfig.getTerrain(cid);
            return vo;
        }
        static getElementVo(cid, className = null) {
            var item = ScenesListConfig.list[cid];
            if (!item) {
                return null;
            }
            if (!className) {
                className = item.className;
            }
            var clas = SceneVoClassConfig.getClass(className);
            var vo = new clas();
            ObjectUtil.copy(item, vo);
            vo.id = IdUtil.getId();
            vo.cid = cid;
            vo.className = className;
            vo.attBulletNum = vo.attBulletMax;
            vo.attBulletNumBase = vo.attBulletMax;
            vo.attBulletMaxBase = vo.attBulletMax;
            vo.createTs = TimeUtil.getTimestamp();
            vo.hpBase = vo.hpMax = vo.hp;
            vo.attBase = vo.att;
            return vo;
        }
        static getName(cid) {
            var item = ScenesListConfig.list[cid];
            if (!item) {
                return '';
            }
            return item.name;
        }
        static getImage(cid) {
            var item = ScenesListConfig.list[cid];
            if (!item) {
                return '';
            }
            return item.image;
        }
        static getStype(cid) {
            var item = ScenesListConfig.list[cid];
            if (!item) {
                return '';
            }
            return item.stype;
        }
        static getTtype(cid) {
            var item = ScenesListConfig.list[cid];
            if (!item) {
                return '';
            }
            return item.ttype;
        }
    }

    class SceneSkillTool {
        static buildSkillList(vo) {
            var list = {};
            for (var k in vo.skills) {
                var cid = vo.skills[k];
                var skillVo = SceneVoBuilder.getElementVo(cid);
                list[cid] = skillVo;
            }
            vo.skillList = list;
        }
        static checkSkill(vo) {
            if (!vo) {
                return 'null';
            }
            var ts = TimeUtil.getLocalTime();
            if (vo.skillCdTs && ts - vo.skillCdTs < vo.attCd) {
                return 'cd';
            }
            return 'ok';
        }
        static lastCdTime(vo) {
            var ts = TimeUtil.getLocalTime();
            if (!vo.skillCdTs) {
                return 0;
            }
            var lastTime = vo.skillCdTs + vo.attCd - ts;
            if (lastTime <= 0) {
                return 0;
            }
            return lastTime;
        }
        static getAtt(skillVo, vo) {
            var v = MathUtil.int(vo.att) + MathUtil.int(skillVo.att);
            if (vo.attVo) {
                v += vo.attVo.att;
            }
            v = v * (1 + vo.attPro + vo.attBuffPro);
            v = MathUtil.int(v);
            v = SceneUnitAttConfig.getAtt(v, vo.lv);
            return v;
        }
    }

    class SceneConfig {
        static getSceneUrl(image) {
            return 'scene/LayaScene_scene_' + image + '/Conventional/scene_' + image + '.ls';
        }
        static getElementUrl(image) {
            if (image) {
                return 'scene/LayaScene_element/Conventional/' + image + '.lh';
            }
            return null;
        }
        static getUnitUrl(image) {
            if (image) {
                return 'scene/LayaScene_unit/Conventional/' + image + '.lh';
            }
            return null;
        }
        static getSkillUrl(image) {
            if (image) {
                return 'scene/LayaScene_effect/Conventional/' + image + '.lh';
            }
            return null;
        }
        static getEffectUrl(image) {
            if (image) {
                return 'scene/LayaScene_effect/Conventional/' + image + '.lh';
            }
            return null;
        }
        static getIcoUrl(image) {
            if (image) {
                return "res/image/" + image + ".png";
            }
            return null;
        }
        static getNameColor(camp, isPlayer) {
            if (camp == 1) {
                if (isPlayer) {
                    return '#388fff';
                }
                else {
                    return '#388fff';
                }
            }
            else {
                return '#ff0000';
            }
        }
        static getSeckill(ctype) {
            return this.seckill[ctype];
        }
        static getBulletCid(attStype) {
            return 30031001;
        }
        static getMonStrengList(streng = 0) {
            if (streng < 3) {
                return [1, 1, 1, 1, 1, 1, 1, 1, 1];
            }
            else if (streng < 6) {
                return [1, 1, 1, 1, 1, 2, 2, 2, 2];
            }
            else if (streng < 10) {
                return [1, 1, 1, 2, 2, 2, 2, 2, 2];
            }
            else if (streng < 15) {
                return [2, 2, 2, 2, 2, 2, 2, 2, 2];
            }
            else if (streng < 20) {
                return [2, 2, 2, 2, 2, 2, 2, 3, 3];
            }
            else if (streng < 30) {
                return [2, 2, 2, 2, 2, 3, 3, 3, 3];
            }
            else if (streng < 40) {
                return [2, 2, 3, 3, 3, 3, 3, 3, 3];
            }
            else {
                return [3, 3, 3, 3, 3, 3, 3, 3, 3];
            }
        }
        static getAirdrop(num) {
            return this.aridropList[num - 1];
        }
        static getAirdropPos(cid) {
            return this.airdropPos[cid];
        }
    }
    SceneConfig.playKillSound = true;
    SceneConfig.seckill = {
        1: 0.3,
        2: 0.15,
        3: 0.4,
        4: 0.4,
        5: 0.2
    };
    SceneConfig.playerCid = 30011001;
    SceneConfig.roleCid = 30011001;
    SceneConfig.gunCid = 30042101;
    SceneConfig.npcList = [30011001, 30011002, 30011003, 30011004, 30011005, 30011006, 30011007, 30011008, 30011009, 30011010];
    SceneConfig.bulletList = [30041601];
    SceneConfig.buffList = [30041801, 30041802, 30041803, 30041804];
    SceneConfig.buffLevList = [30041803];
    SceneConfig.vip = { attPro: 0.5, invinTime: 30, num: 100 };
    SceneConfig.aridropList = [
        { goods: [{ cid: 30042204, num: 1, name: "G36C" }, { cid: 30042104, num: 1, name: "MAC-11" }], durationTime: 15000 },
        { goods: [{ cid: 30042207, num: 1, name: "F2000" }, { cid: 30042402, num: 1, name: "SPAS-12" }], durationTime: 15000 },
        { goods: [{ cid: 30042209, num: 1, name: "SCAR-H" }, { cid: 30042302, num: 1, name: "KILLSHOT" }], durationTime: 15000 },
        { goods: [{ cid: 30042403, num: 1, name: "DP-12" }, { cid: 30042004, num: 1, name: "DEAGLE" }], durationTime: 15000 },
        { goods: [{ cid: 30042212, num: 1, name: "XM-8" }, { cid: 30042305, num: 1, name: "CHARLEY GOLD" }], durationTime: 15000 },
    ];
    SceneConfig.airdropPos = {
        1: { x: 9, y: 6, z: 0 },
        2: { x: 0, y: 6, z: 8 },
        3: { x: 9, y: 6, z: 0 }
    };
    SceneConfig.airdropParachute = 30041602;
    SceneConfig.pillboxList_1 = [
        { cid: 30012001, x: 0, y: 1, z: -80, haloY: 0, stre: 2 },
        { cid: 30012001, x: 17.5, y: 1, z: -37.3, haloY: 0, stre: 1 },
        { cid: 30012001, x: -17.5, y: 1, z: -37.3, haloY: 0, stre: 1 },
    ];
    SceneConfig.pillboxList_2 = [
        { cid: 30012002, x: 0, y: 1, z: 80, haloY: 0, stre: 2 },
        { cid: 30012002, x: 17.5, y: 1, z: 37.3, haloY: 0, stre: 1 },
        { cid: 30012002, x: -17.5, y: 1, z: 37.3, haloY: 0, stre: 1 },
    ];
    SceneConfig.reShieldCid = 40021101;
    SceneConfig.reviveTime = 10;
    SceneConfig.playeRreviveTime = 5;
    SceneConfig.endScenePos = [{ x: 0, z: 0 }, { x: 1, z: 0 }, { x: -1, z: 0 }, { x: 2, z: 0 }, { x: -2, z: 0 }];
    SceneConfig.dazzleList = ['dazzle_1', 'dazzle_2', 'dazzle_3'];

    class SceneModel {
        constructor() {
            this.vo = new SceneVo();
        }
        static get model() {
            return ModelManager.getModel('SceneModel', SceneModel);
        }
        ;
        init() {
        }
    }

    class RandomUtil {
        static randomInt(min, max) {
            return MathUtil.randomInt(min, max);
        }
        static randomNumber(min, max) {
            return MathUtil.randomNumber(min, max);
        }
        static randomHit(n) {
            return MathUtil.randomHit(n);
        }
        static randomItem(list) {
            return ArrayUtil.randomItem(list);
        }
        static randomArray(list, n = 1) {
            return ArrayUtil.randomArray(list, n);
        }
        static randomOrder(list) {
            return ArrayUtil.randomOrder(list);
        }
        static randomWeight(list, num) {
            var tweight = 0;
            var nlist = [];
            var glist = [];
            for (var k in list) {
                var co = list[k];
                if (!co.weight) {
                    glist.push(co);
                }
                else {
                    tweight += co.weight;
                    co.cweight = tweight;
                    nlist.push(co);
                }
            }
            for (var i = 0; i < num; i++) {
                var n = MathUtil.randomInt(0, tweight);
                var vo = this.randomWeightItem(nlist, n);
                if (vo) {
                    glist.push(vo);
                }
            }
            return glist;
        }
        static randomWeightItem(list, cw) {
            for (var vo of list) {
                if (cw <= vo.cweight) {
                    return vo;
                }
            }
            return null;
        }
        static randomProb(list, min = 1, max = 999999) {
            if (!list) {
                return [];
            }
            if (list.length <= 1) {
                return [];
            }
            if (min == 0) {
                return [];
            }
            var nlist = [];
            var tprob = 0;
            for (var k in list) {
                var co = list[k];
                var prob = ParamUtil.getNumber(co, 'prob', 1);
                tprob += prob;
                if (prob >= 1) {
                    nlist.push(co);
                }
                else if (this.randomHit(prob)) {
                    nlist.push(co);
                }
                if (nlist.length >= max) {
                    return nlist;
                }
            }
            if (tprob == 0) {
                return [];
            }
            if (nlist.length < min) {
                var l = list.length;
                var i = 0;
                while (true) {
                    var index = i % l;
                    var co = list[index];
                    var prob = ParamUtil.getNumber(co, 'prob', 1);
                    if (prob >= 1) {
                        nlist.push(co);
                    }
                    else if (this.randomHit(prob)) {
                        nlist.push(co);
                    }
                    if (nlist.length >= min) {
                        return nlist;
                    }
                    if (nlist.length >= max) {
                        return nlist;
                    }
                }
            }
            return nlist;
        }
    }

    class SceneTerrainTool {
        static getTerrain(x, z) {
            var map = SceneModel.model.vo.terrain;
            x = Math.round(x);
            z = Math.round(z);
            var k = x + "_" + z;
            if (map[k]) {
                return map[k];
            }
            return 0;
        }
        static check(x, z) {
            var map = SceneModel.model.vo.terrain;
            x = Math.round(x);
            z = Math.round(z);
            var k = x + "_" + z;
            if (map[k]) {
                return false;
            }
            return true;
        }
        static redomPosCamp(camp = 0) {
            var cid = SceneModel.model.vo.cid;
            var initPos = SceneTerrainConfig.getInitPos(cid, camp);
            var item = ArrayUtil.randomItem(initPos);
            return { x: item.x, y: 0, z: item.z };
        }
        static randomPos(sx, sz) {
            var size = SceneTerrainConfig.size;
            var map = SceneModel.model.vo.terrain;
            sx = Math.round(sx);
            sz = Math.round(sz);
            var l = size[0];
            var r = size[1];
            var t = size[2];
            var b = size[3];
            var xw = 5;
            var zw = 10;
            for (var i = 0; i < 10; i++) {
                var x = RandomUtil.randomInt(-xw, xw) + sx;
                var z = RandomUtil.randomInt(-zw, zw) + sz;
                if (x < l) {
                    x = l;
                }
                if (x > r) {
                    x = r;
                }
                if (z < t) {
                    z = t;
                }
                if (z > b) {
                    z = b;
                }
                var k = x + '_' + z;
                if (!map[k]) {
                    return { x: x, y: 0, z: z };
                }
            }
            return null;
        }
    }

    class SceneTool {
        static createPlayer(cid = 0) {
            if (cid == 0) {
                cid = SceneConfig.playerCid;
            }
            return SceneVoBuilder.getElementVo(cid, 'player');
        }
        static createNpc(cid = 0) {
            if (cid == 0) {
                cid = SceneConfig.roleCid;
            }
            return SceneVoBuilder.getElementVo(cid, 'npc');
        }
        static randomPos() {
            return SceneTerrainTool.redomPosCamp(0);
        }
        static randomPosCamp(camp = 1) {
            return SceneTerrainTool.redomPosCamp(camp);
        }
        static randomBullet() {
            var cid = ArrayUtil.randomItem(SceneConfig.bulletList);
            var mon = SceneVoBuilder.getElementVo(cid);
            var pos = SceneTool.randomPos();
            mon.ix = pos.x + MathUtil.randomNumber(-2, 2);
            mon.iy = pos.y;
            mon.iz = pos.z + MathUtil.randomNumber(-2, 2);
            mon.halo = 3;
            return mon;
        }
        static getPlayerRank() {
            var playerKillNum = SceneModel.model.vo.playerKillNum;
            var killMap = SceneModel.model.vo.killMap;
            var rank = 1;
            for (var k in killMap) {
                var v = killMap[k];
                if (v > playerKillNum) {
                    rank++;
                }
            }
            return rank;
        }
    }

    class SegmentModel {
        constructor() {
            this.list = {};
            this.finishNum = 0;
            this.tipsIco = true;
            this.maxTriphyNum = 0;
            this.maxSegment = 1;
        }
        static get model() {
            return ModelManager.getModel('SegmentModel', SegmentModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.list = this.list;
            data.maxTriphyNum = this.maxTriphyNum;
            data.maxSegment = this.maxSegment;
            data.tipsIco = this.tipsIco;
            StorageModel.model.setData("segment", data);
        }
        loadData() {
            var data = StorageModel.model.getData("segment");
            if (data) {
                this.list = ParamUtil.getObject(data, 'list', {});
                this.maxTriphyNum = ParamUtil.getNumber(data, 'maxTriphyNum');
                this.maxSegment = ParamUtil.getNumber(data, 'maxSegment');
                this.tipsIco = ParamUtil.getBool(data, 'tipsIco', true);
            }
        }
        setState(lv, state) {
            this.list[lv] = state;
        }
        getState(lv) {
            if (this.list[lv]) {
                return this.list[lv];
            }
            return 0;
        }
    }

    class BattleTryTool {
        static getTryHero(maxTriphyNum) {
            for (var k in BattleConfig.tryHeroList) {
                var tryHero = BattleConfig.tryHeroList[k];
                if (maxTriphyNum >= tryHero.triphyNum && maxTriphyNum < tryHero.toTriphyNum) {
                    return tryHero;
                }
            }
            return null;
        }
    }

    class BattleTool {
        static getBattleData(cid, playerCid, isTry = false, battleType = 1, difficulty = 0, locList1 = [], locList2 = []) {
            var playerVo = SceneTool.createPlayer(playerCid);
            var vo = GoodsModel.model.getGoodsByCid(playerCid);
            playerVo.isPlayer = true;
            playerVo.camp = 1;
            playerVo.halo = 1;
            playerVo.name = PlayerModel.model.name;
            if (isTry == true) {
                playerVo.lv = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).lv;
            }
            else {
                playerVo.lv = vo.lv;
            }
            LogTool.log('-----------------------------------:' + JSONUtil.stringify(playerVo.lv));
            SceneSkillTool.buildSkillList(playerVo);
            if (battleType == 1) {
                var teamNum = 4;
                var monCamp = 3;
                var totalTime = 180;
            }
            else if (battleType == 2) {
                var teamNum = 0;
                var monCamp = 0;
                var totalTime = 180;
            }
            else {
                var teamNum = 0;
                var monCamp = 3;
                var totalTime = 0;
            }
            var gun = SceneVoBuilder.getElementVo(playerVo.attCid);
            SceneGoodsTool.setGoods(playerVo, gun);
            if (gun) {
                playerVo.attCd = gun.attCd;
            }
            playerVo.hpPro += LeadModel.model.hpUp;
            var hp = MathUtil.int(playerVo.hp * (1 + playerVo.hpPro));
            playerVo.hp = playerVo.hpMax = hp;
            playerVo.attBase = playerVo.att = SceneUnitAttConfig.getAtt(playerVo.att, playerVo.lv);
            playerVo.hpBase = playerVo.hpMax = playerVo.hp = SceneUnitHprConfig.getHp(playerVo.hp, playerVo.lv);
            var victoryNum = BattleModel.model.victoryNum;
            var vipBuff = BattleModel.model.vipBuff;
            if (BattleConfig.battleDefProType == 1) {
                if (victoryNum <= 9 && victoryNum >= 0) {
                    playerVo.defPro = 0.1 + (3 - victoryNum) * 0.05;
                }
                else {
                    playerVo.defPro = 0;
                }
            }
            else {
                if (victoryNum <= 9 && victoryNum >= 0) {
                    playerVo.defPro = 0.1 + (9 - victoryNum) * 0.05;
                }
                else {
                    playerVo.defPro = 0.15;
                }
            }
            return { cid: cid, battleType: battleType, totalTime: totalTime, difficulty: difficulty, playerVo: playerVo, teamNum: teamNum, victoryNum: victoryNum, monCamp: monCamp, vipBuff: vipBuff, showType: ViewType.OPEN, lv: playerVo.lv, locList1: locList1, locList2: locList2 };
        }
    }

    class Display3DUtil {
        static setDisplayColor(item, r, g, b, a = 1) {
            if (item instanceof Laya.RenderableSprite3D) {
                this.setMeshColor(item, r, g, b, a);
            }
            if (item.numChildren >= 1) {
                for (var i = 0; i < item.numChildren; i++) {
                    var child = item.getChildAt(i);
                    if (child) {
                        this.setDisplayColor(child, r, g, b, a);
                    }
                }
            }
        }
        static setMeshColor(item, r, g, b, a = 1) {
            if (item instanceof Laya.MeshSprite3D) {
                if (item.meshRenderer) {
                    var list = item.meshRenderer.materials;
                    for (var k in list) {
                        var mater = list[k];
                        this.setMaterialColor(mater, r, g, b, a);
                    }
                }
            }
            else if (item instanceof Laya.SkinnedMeshSprite3D) {
                if (item.skinnedMeshRenderer) {
                    var list = item.skinnedMeshRenderer.materials;
                    for (var k in list) {
                        var mater = list[k];
                        this.setMaterialColor(mater, r, g, b, a);
                    }
                }
            }
        }
        static setMaterialColor(mater, r, g, b, a = 1) {
            if (mater instanceof Laya.PBRSpecularMaterial) {
                mater.renderMode = 2;
                mater.albedoColor.x = r;
                mater.albedoColor.y = g;
                mater.albedoColor.z = b;
                mater.albedoColor.w = a;
            }
            else if (mater instanceof Laya.PBRMaterial) {
                mater.renderMode = 2;
                mater.albedoColor.x = r;
                mater.albedoColor.y = g;
                mater.albedoColor.z = b;
                mater.albedoColor.w = a;
            }
            else if (mater instanceof Laya.BlinnPhongMaterial) {
                mater.renderMode = 2;
                mater.albedoTexture = null;
                mater.albedoColorR = r;
                mater.albedoColorG = g;
                mater.albedoColorB = b;
                mater.albedoColorA = a;
            }
            else if (mater instanceof Laya.UnlitMaterial) {
                mater.renderMode = 2;
                mater.albedoTexture = null;
                mater.albedoColorR = r;
                mater.albedoColorG = g;
                mater.albedoColorB = b;
                mater.albedoColorA = a;
            }
        }
        static setDisplayAlpha(item, a = 1) {
            if (item instanceof Laya.RenderableSprite3D) {
                this.setMeshAlpha(item, a);
            }
            if (item.numChildren >= 1) {
                for (var i = 0; i < item.numChildren; i++) {
                    var child = item.getChildAt(i);
                    if (child) {
                        this.setDisplayAlpha(child, a);
                    }
                }
            }
        }
        static setMeshAlpha(item, a = 1) {
            if (item instanceof Laya.MeshSprite3D) {
                if (item.meshRenderer) {
                    var list = item.meshRenderer.materials;
                    for (var k in list) {
                        var mater = list[k];
                        this.setMaterialAlpha(mater, a);
                    }
                }
            }
            else if (item instanceof Laya.SkinnedMeshSprite3D) {
                if (item.skinnedMeshRenderer) {
                    var list = item.skinnedMeshRenderer.materials;
                    for (var k in list) {
                        var mater = list[k];
                        this.setMaterialAlpha(mater, a);
                    }
                }
            }
        }
        static setMaterialAlpha(mater, a = 1) {
            if (mater instanceof Laya.PBRSpecularMaterial) {
                mater.renderMode = 2;
                mater.albedoColor.w = a;
            }
            else if (mater instanceof Laya.PBRMaterial) {
                mater.albedoColor.w = a;
            }
            else if (mater instanceof Laya.BlinnPhongMaterial) {
                mater.renderMode = 2;
                mater.albedoColorA = a;
            }
            else if (mater instanceof Laya.UnlitMaterial) {
                mater.renderMode = 2;
                mater.albedoColorA = a;
            }
        }
        static showShadow(sprite, shadowMode = 2, shadowCascadesMode = 0) {
            if (sprite instanceof Laya.DirectionLight) {
                sprite.shadowMode = shadowMode;
                sprite.shadowCascadesMode = shadowCascadesMode;
            }
            else if (sprite instanceof Laya.MeshSprite3D) {
                sprite.meshRenderer.castShadow = true;
                sprite.meshRenderer.receiveShadow = true;
            }
            else {
                for (var i = 0; i < sprite.numChildren; i++) {
                    var item = sprite.getChildAt(i);
                    this.showShadow(item);
                }
            }
        }
        static setCollisionGroup(sprite, collisionGroup) {
            if (!sprite) {
                return;
            }
            if (sprite.destroyed) {
                return;
            }
            var c2 = sprite.getComponent(Laya.PhysicsCollider);
            if (c2) {
                c2.collisionGroup = collisionGroup;
            }
            var l = sprite.numChildren;
            for (var i = 0; i < l; i++) {
                var child = sprite.getChildAt(i);
                this.setCollisionGroup(child, collisionGroup);
            }
        }
        static getRay(fx, fy, fz, tx, ty, tz, ray = null) {
            if (!ray) {
                ray = new Laya.Ray(new Laya.Vector3(), new Laya.Vector3());
            }
            ray.origin.x = fx;
            ray.origin.y = fy;
            ray.origin.z = fz;
            ray.direction.x = tx - fx;
            ray.direction.y = ty - fy;
            ray.direction.z = tz - fz;
            Laya.Vector3.normalize(ray.direction, ray.direction);
            return ray;
        }
        static getDirRay(dir, angle) {
            var x = MathUtil.sin(dir);
            var z = MathUtil.cos(dir);
            var disxz = DisplayUtil.distance(x, z);
            var y = MathUtil.tan(angle) * disxz;
            return this.getRay(0, 0, 0, x, y, z);
        }
        static direction3D(fx, fy, fz, tx, ty, tz, direction = null) {
            if (!direction) {
                direction = new Laya.Vector3();
            }
            direction.x = tx - fx;
            direction.y = ty - fy;
            direction.z = tz - fz;
            Laya.Vector3.normalize(direction, direction);
            return direction;
        }
        static toDirection3D(dir, angle, direction = null) {
            var x = MathUtil.sin(dir);
            var z = MathUtil.cos(dir);
            var disxz = DisplayUtil.distance(x, z);
            var y = MathUtil.tan(angle) * disxz;
            return this.direction3D(0, 0, 0, x, y, z, direction);
        }
        static distance3D(x1, y1, z1, x2 = 0, y2 = 0, z2 = 0) {
            var x = x1 - x2;
            var y = y1 - y2;
            var z = z1 - z2;
            return Math.sqrt(x * x + y * y + z * z);
        }
        static worldToViewportPoint(camera, x, y, z) {
            if (this.monV3 == null) {
                this.monV3 = new Laya.Vector3();
                this.monV4 = new Laya.Vector4();
            }
            this.monV3.x = x;
            this.monV3.y = y;
            this.monV3.z = z;
            camera.worldToViewportPoint(this.monV3, this.monV4);
            this.monV4.y -= StageUtil.bangsY;
            this.monV4.x -= StageUtil.bangsX;
            return this.monV4;
        }
        static angle(x1, y1, x0 = 0, y0 = 0) {
            var dx = x1 - x0;
            var dy = y1 - y0;
            var r = 0;
            if (dx == 0) {
                if (dy == 0) {
                    return NaN;
                }
                else if (dy > 0) {
                    r = 0;
                }
                else {
                    r = 180;
                }
            }
            else if (dx > 0) {
                if (dy > 0) {
                    r = MathUtil.atan(dx / dy);
                }
                else if (dy == 0) {
                    r = 90;
                }
                else {
                    r = 180 - MathUtil.atan(-dx / dy);
                }
            }
            else {
                if (dy > 0) {
                    r = -MathUtil.atan(-dx / dy);
                }
                else if (dy == 0) {
                    r = -90;
                }
                else {
                    r = -180 + MathUtil.atan(dx / dy);
                }
            }
            if (r > 180) {
                r -= 180;
            }
            else if (r < -180) {
                r += 180;
            }
            return r;
        }
        static playParticle(effect) {
            if (!effect) {
                return;
            }
            if (effect instanceof Laya.ShuriKenParticle3D) {
                effect.particleSystem.play();
            }
            else if (effect instanceof Laya.TrailSprite3D) {
                var time = effect.trailFilter.time;
                if (time > 0) {
                    effect.trailFilter.time = 0;
                    Laya.timer.frameOnce(1, this, reTimeHandler, [effect, time]);
                    function reTimeHandler(effect, time) {
                        effect.trailFilter.time = time;
                    }
                }
            }
            for (var i = 0; i < effect.numChildren; i++) {
                var o = effect.getChildAt(i);
                this.playParticle(o);
            }
        }
        static stopParticle(effect) {
            if (!effect) {
                return;
            }
            if (effect instanceof Laya.ShuriKenParticle3D) {
                effect.particleSystem.stop();
            }
            for (var i = 0; i < effect.numChildren; i++) {
                var o = effect.getChildAt(i);
                this.stopParticle(o);
            }
        }
        static copyScene3D(scene, isReplace = false) {
            var sceneNew = new Laya.Scene3D();
            sceneNew.currentCreationLayer = scene.currentCreationLayer;
            sceneNew.enableLight = scene.enableLight;
            sceneNew.enableFog = scene.enableFog;
            sceneNew.fogColor = scene.fogColor;
            sceneNew.fogStart = scene.fogStart;
            sceneNew.fogRange = scene.fogRange;
            sceneNew.ambientMode = scene.ambientMode;
            sceneNew.ambientColor = scene.ambientColor;
            sceneNew.ambientSphericalHarmonics = scene.ambientSphericalHarmonics;
            sceneNew.ambientSphericalHarmonicsIntensity = scene.ambientSphericalHarmonicsIntensity;
            sceneNew.reflection = scene.reflection;
            sceneNew.reflectionDecodingFormat = scene.reflectionDecodingFormat;
            sceneNew.reflectionIntensity = scene.reflectionIntensity;
            sceneNew.lightmaps = scene.lightmaps;
            var l = scene.numChildren;
            for (var i = 0; i < l; i++) {
                var item = scene.getChildAt(i);
                if (item) {
                    Laya.Sprite3D.instantiate(item, sceneNew, true);
                }
            }
            if (isReplace && scene.parent) {
                var parent = scene.parent;
                scene.removeSelf();
                parent.addChild(sceneNew);
            }
            return sceneNew;
        }
    }

    var View = Laya.Views;
    var Scene = Laya.Scene;
    var REG = Laya.ClassUtils.regClass;
    var ui;
    (function (ui) {
        var battle;
        (function (battle) {
            class BattleUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleUI.uiView);
                }
            }
            BattleUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "BattleColl", "props": { "y": 0, "width": 1280, "visible": true, "var": "ui_coll", "name": "ui_coll", "height": 720, "centerX": 0, "runtime": "ui.battle.BattleCollUI" }, "compId": 632 }, { "type": "Image", "props": { "var": "img_hurt", "top": 0, "skin": "ui/img_uk_ui2_obj22.png", "rotation": 0, "right": -100, "name": "img_hurt", "mouseThrough": true, "mouseEnabled": false, "left": -100, "bottom": 0, "alpha": 0.9 }, "compId": 520 }, { "type": "BattleDir", "props": { "width": 1280, "var": "ui_dir", "top": 0, "right": 0, "name": "ui_dir", "mouseEnabled": true, "left": 0, "height": 720, "bottom": 0, "runtime": "ui.battle.BattleDirUI" }, "compId": 279 }, { "type": "BattleMove", "props": { "y": 0, "x": 0, "width": 500, "var": "ui_move", "name": "ui_move", "height": 720, "runtime": "ui.battle.BattleMoveUI" }, "compId": 280 }, { "type": "BattleTop", "props": { "y": 0, "var": "ui_top", "name": "ui_top", "centerX": 0, "runtime": "ui.battle.BattleTopUI" }, "compId": 631 }, { "type": "BattleAtt", "props": { "y": 432, "width": 168, "var": "ui_att", "right": 193, "name": "ui_att", "height": 175, "runtime": "ui.battle.BattleAttUI" }, "compId": 658 }, { "type": "BattleTryBtn", "props": { "width": 200, "visible": true, "var": "ui_try", "right": -17, "name": "ui_try", "height": 200, "bottom": -8, "runtime": "ui.battle.BattleTryBtnUI" }, "compId": 682 }, { "type": "BattleRight", "props": { "y": 0, "width": 500, "var": "ui_right", "right": 0, "name": "ui_right", "mouseThrough": true, "height": 720, "runtime": "ui.battle.BattleRightUI" }, "compId": 633 }, { "type": "BattleButtom", "props": { "y": 614, "width": 300, "var": "ui_bottom", "scaleY": 0.8, "scaleX": 0.8, "name": "ui_bottom", "height": 100, "centerX": 42, "runtime": "ui.battle.BattleButtomUI" }, "compId": 634 }, { "type": "BattleMaps", "props": { "y": 5, "x": 5, "width": 200, "var": "ui_map", "scaleY": 0.8, "scaleX": 0.8, "name": "ui_map", "height": 380, "runtime": "ui.battle.BattleMapsUI" }, "compId": 639 }, { "type": "BattleKillInfo", "props": { "width": 275, "var": "ui_info", "top": 30, "right": 25, "name": "ui_info", "height": 91, "runtime": "ui.battle.BattleKillInfoUI" }, "compId": 642 }, { "type": "BattleRecord", "props": { "y": 7, "x": 151, "width": 225, "var": "ui_record", "scaleY": 0.8, "scaleX": 0.75, "name": "ui_record", "height": 146, "runtime": "ui.battle.BattleRecordUI" }, "compId": 659 }, { "type": "Box", "props": { "y": 74, "x": 446, "visible": false, "centerX": 0 }, "compId": 657, "child": [{ "type": "Box", "props": { "y": 2, "x": 7 }, "compId": 645, "child": [{ "type": "Image", "props": { "width": 22, "var": "img_0", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_0", "height": 44 }, "compId": 647 }, { "type": "Image", "props": { "x": 23, "width": 22, "var": "img_1", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_1", "height": 44 }, "compId": 648 }, { "type": "Image", "props": { "x": 46, "width": 22, "var": "img_2", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_2", "height": 44 }, "compId": 649 }, { "type": "Image", "props": { "x": 68, "width": 22, "var": "img_3", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_3", "height": 44 }, "compId": 650 }, { "type": "Image", "props": { "x": 91, "width": 22, "var": "img_4", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_4", "height": 44 }, "compId": 651 }] }, { "type": "Box", "props": { "y": 2, "x": 245 }, "compId": 646, "child": [{ "type": "Image", "props": { "width": 22, "var": "img_5", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_5", "height": 44 }, "compId": 652 }, { "type": "Image", "props": { "x": 23, "width": 22, "var": "img_6", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_6", "height": 44 }, "compId": 653 }, { "type": "Image", "props": { "x": 46, "width": 22, "var": "img_7", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_7", "height": 44 }, "compId": 654 }, { "type": "Image", "props": { "x": 68, "width": 22, "var": "img_8", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_8", "height": 44 }, "compId": 655 }, { "type": "Image", "props": { "x": 91, "width": 22, "var": "img_9", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_9", "height": 44 }, "compId": 656 }] }] }, { "type": "Label", "props": { "wordWrap": false, "width": 285, "visible": true, "var": "txt_skip", "valign": "middle", "text": "点击屏幕跳过>>", "strokeColor": "#000000", "stroke": 3, "right": 34, "name": "txt_skip", "height": 34, "fontSize": 40, "font": "SimHei", "color": "#e9ead6", "bottom": 100, "bold": true, "align": "left" }, "compId": 664 }, { "type": "List", "props": { "width": 323, "visible": true, "var": "list_task", "selectEnable": true, "name": "list_task", "left": 227, "height": 73, "bottom": 23 }, "compId": 673, "child": [{ "type": "BattleTaskBoxItem", "props": { "renderType": "render", "runtime": "ui.battle.BattleTaskBoxItemUI" }, "compId": 683 }] }], "loadList": ["ui/img_uk_ui2_obj22.png", "ui/img_UM_icon_teamplayer_bg.png"], "loadList3D": [] };
            battle.BattleUI = BattleUI;
            REG("ui.battle.BattleUI", BattleUI);
            class Battle1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Battle1UI.uiView);
                }
            }
            Battle1UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "BattleColl", "props": { "y": 0, "width": 1280, "visible": true, "var": "ui_coll", "name": "ui_coll", "height": 720, "centerX": 0, "runtime": "ui.battle.BattleCollUI" }, "compId": 632 }, { "type": "Image", "props": { "var": "img_hurt", "top": 0, "skin": "ui/img_uk_ui2_obj22.png", "rotation": 0, "right": -100, "name": "img_hurt", "mouseThrough": true, "mouseEnabled": false, "left": -100, "bottom": 0, "alpha": 0.9 }, "compId": 520 }, { "type": "BattleDir", "props": { "width": 1280, "var": "ui_dir", "top": 0, "right": 0, "name": "ui_dir", "mouseEnabled": true, "left": 0, "height": 720, "bottom": 0, "runtime": "ui.battle.BattleDirUI" }, "compId": 279 }, { "type": "BattleMove", "props": { "y": 0, "x": 0, "width": 500, "var": "ui_move", "name": "ui_move", "height": 720, "runtime": "ui.battle.BattleMoveUI" }, "compId": 280 }, { "type": "BattleAtt", "props": { "y": 397, "width": 168, "var": "ui_att", "right": 193, "name": "ui_att", "height": 175, "runtime": "ui.battle.BattleAttUI" }, "compId": 658 }, { "type": "BattleTryBtn", "props": { "width": 200, "var": "ui_try", "right": -17, "name": "ui_try", "height": 200, "bottom": -8, "runtime": "ui.battle.BattleTryBtnUI" }, "compId": 682 }, { "type": "BattleRight1", "props": { "y": 0, "var": "ui_right", "right": 0, "name": "ui_right", "runtime": "ui.battle.BattleRight1UI" }, "compId": 684 }, { "type": "BattleButtom", "props": { "width": 300, "var": "ui_bottom", "top": 133, "scaleY": 0.8, "scaleX": 0.8, "name": "ui_bottom", "height": 100, "centerX": 151, "runtime": "ui.battle.BattleButtomUI" }, "compId": 634 }, { "type": "BattleMaps", "props": { "y": 5, "x": 5, "width": 200, "var": "ui_map", "scaleY": 0.8, "scaleX": 0.8, "name": "ui_map", "height": 380, "runtime": "ui.battle.BattleMapsUI" }, "compId": 639 }, { "type": "BattleKillInfo", "props": { "width": 275, "var": "ui_info", "top": 30, "right": 25, "name": "ui_info", "height": 91, "runtime": "ui.battle.BattleKillInfoUI" }, "compId": 642 }, { "type": "BattleRecord", "props": { "y": 7, "x": 151, "width": 225, "var": "ui_record", "scaleY": 0.8, "scaleX": 0.75, "name": "ui_record", "height": 146, "runtime": "ui.battle.BattleRecordUI" }, "compId": 659 }, { "type": "Box", "props": { "y": 74, "x": 446, "visible": false, "centerX": 0 }, "compId": 657, "child": [{ "type": "Box", "props": { "y": 2, "x": 7 }, "compId": 645, "child": [{ "type": "Image", "props": { "width": 22, "var": "img_0", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_0", "height": 44 }, "compId": 647 }, { "type": "Image", "props": { "x": 23, "width": 22, "var": "img_1", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_1", "height": 44 }, "compId": 648 }, { "type": "Image", "props": { "x": 46, "width": 22, "var": "img_2", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_2", "height": 44 }, "compId": 649 }, { "type": "Image", "props": { "x": 68, "width": 22, "var": "img_3", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_3", "height": 44 }, "compId": 650 }, { "type": "Image", "props": { "x": 91, "width": 22, "var": "img_4", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_4", "height": 44 }, "compId": 651 }] }, { "type": "Box", "props": { "y": 2, "x": 245 }, "compId": 646, "child": [{ "type": "Image", "props": { "width": 22, "var": "img_5", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_5", "height": 44 }, "compId": 652 }, { "type": "Image", "props": { "x": 23, "width": 22, "var": "img_6", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_6", "height": 44 }, "compId": 653 }, { "type": "Image", "props": { "x": 46, "width": 22, "var": "img_7", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_7", "height": 44 }, "compId": 654 }, { "type": "Image", "props": { "x": 68, "width": 22, "var": "img_8", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_8", "height": 44 }, "compId": 655 }, { "type": "Image", "props": { "x": 91, "width": 22, "var": "img_9", "skin": "ui/img_UM_icon_teamplayer_bg.png", "name": "img_9", "height": 44 }, "compId": 656 }] }] }, { "type": "Label", "props": { "wordWrap": false, "width": 285, "visible": true, "var": "txt_skip", "valign": "middle", "text": "点击屏幕跳过>>", "strokeColor": "#000000", "stroke": 3, "right": 34, "name": "txt_skip", "height": 34, "fontSize": 40, "font": "SimHei", "color": "#e9ead6", "bottom": 100, "bold": true, "align": "left" }, "compId": 664 }, { "type": "List", "props": { "x": 334, "width": 323, "var": "list_task", "top": 146, "selectEnable": true, "name": "list_task", "height": 73 }, "compId": 673, "child": [{ "type": "BattleTaskBoxItem", "props": { "renderType": "render", "runtime": "ui.battle.BattleTaskBoxItemUI" }, "compId": 683 }] }, { "type": "BattleTop", "props": { "y": 0, "var": "ui_top", "name": "ui_top", "centerX": 0, "runtime": "ui.battle.BattleTopUI" }, "compId": 631 }], "loadList": ["ui/img_uk_ui2_obj22.png", "ui/img_UM_icon_teamplayer_bg.png"], "loadList3D": [] };
            battle.Battle1UI = Battle1UI;
            REG("ui.battle.Battle1UI", Battle1UI);
            class BattleAimAnimationUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleAimAnimationUI.uiView);
                }
            }
            BattleAimAnimationUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "BattleAimItem", "props": { "y": 260, "x": 540, "runtime": "ui.battle.BattleAimItemUI" }, "compId": 1173 }], "animations": [{ "nodes": [{ "target": 1172, "keyframes": { "y": [{ "value": -46, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "y", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "y", "index": 5 }], "x": [{ "value": 1370, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "x", "index": 0 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "x", "index": 5 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": [], "loadList3D": [] };
            battle.BattleAimAnimationUI = BattleAimAnimationUI;
            REG("ui.battle.BattleAimAnimationUI", BattleAimAnimationUI);
            class BattleAimItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleAimItemUI.uiView);
                }
            }
            BattleAimItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 147, "x": 100, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1168 }, { "type": "Image", "props": { "y": 94, "x": 133, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "rotation": 60, "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1169 }, { "type": "Image", "props": { "y": 94, "x": 70, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "rotation": -60, "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1170 }], "animations": [{ "nodes": [{ "target": 1168, "keyframes": { "y": [{ "value": 1064, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "y", "index": 0 }, { "value": 147, "tweenMethod": "linearNone", "tween": true, "target": 1168, "label": null, "key": "y", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "width", "index": 17 }], "rotation": [{ "value": 90, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "rotation", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 17 }] } }, { "target": 1169, "keyframes": { "y": [{ "value": -452, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "y", "index": 0 }, { "value": 94, "tweenMethod": "linearNone", "tween": true, "target": 1169, "label": null, "key": "y", "index": 17 }], "x": [{ "value": 999, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "x", "index": 0 }, { "value": 133, "tweenMethod": "linearNone", "tween": true, "target": 1169, "label": null, "key": "x", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "width", "index": 17 }], "rotation": [{ "value": -30, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "rotation", "index": 0 }, { "value": 60, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "alpha", "index": 17 }] } }, { "target": 1170, "keyframes": { "y": [{ "value": -460, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "y", "index": 0 }, { "value": 94, "tweenMethod": "linearNone", "tween": true, "target": 1170, "label": null, "key": "y", "index": 17 }], "x": [{ "value": -880, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "x", "index": 0 }, { "value": 70, "tweenMethod": "linearNone", "tween": true, "target": 1170, "label": null, "key": "x", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "width", "index": 17 }], "rotation": [{ "value": 30, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 0 }, { "value": -60, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "alpha", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_ui_mubiao.png"], "loadList3D": [] };
            battle.BattleAimItemUI = BattleAimItemUI;
            REG("ui.battle.BattleAimItemUI", BattleAimItemUI);
            class BattleAntikillTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleAntikillTipUI.uiView);
                }
            }
            BattleAntikillTipUI.uiView = { "type": "View", "props": { "y": 150, "x": 0, "width": 320, "mouseThrough": true, "mouseEnabled": false, "height": 320, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -70, "x": 110, "width": 100, "skin": "ui/img_kill.png", "height": 100 }, "compId": 364 }, { "type": "Label", "props": { "y": 41, "x": 45, "wordWrap": true, "width": 229, "text": "复仇成功", "strokeColor": "#000000", "stroke": 6, "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 365 }], "loadList": ["ui/img_kill.png"], "loadList3D": [] };
            battle.BattleAntikillTipUI = BattleAntikillTipUI;
            REG("ui.battle.BattleAntikillTipUI", BattleAntikillTipUI);
            class BattleAttUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleAttUI.uiView);
                }
            }
            BattleAttUI.uiView = { "type": "View", "props": { "width": 174, "height": 166 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 85, "x": 87.5, "width": 240, "var": "btn_dir_bg", "skin": "ui/img_UM_lunpan.png", "pivotY": 120, "pivotX": 120, "name": "btn_dir_bg", "height": 240, "alpha": 1 }, "compId": 38 }, { "type": "Image", "props": { "y": 86, "x": 89, "width": 140, "var": "btn_dir", "skin": "ui/img_UM_lunpan_btn3.png", "pivotY": 70, "pivotX": 70, "name": "btn_dir", "height": 140 }, "compId": 39 }], "loadList": ["ui/img_UM_lunpan.png", "ui/img_UM_lunpan_btn3.png"], "loadList3D": [] };
            battle.BattleAttUI = BattleAttUI;
            REG("ui.battle.BattleAttUI", BattleAttUI);
            class BattleAttTextUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleAttTextUI.uiView);
                }
            }
            BattleAttTextUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 50 }, "compId": 2, "child": [{ "type": "Label", "props": { "y": -9, "x": -84, "wordWrap": true, "width": 168, "var": "txt_att", "text": "100", "strokeColor": "#212121", "stroke": 4, "name": "txt_att", "fontSize": 50, "font": "SimHei", "color": "#ff0400", "bold": true, "align": "center" }, "compId": 431 }], "animations": [{ "nodes": [{ "target": 431, "keyframes": { "y": [{ "value": -9, "tweenMethod": "backOut", "tween": true, "target": 431, "key": "y", "index": 0 }, { "value": -160, "tweenMethod": "linearNone", "tween": true, "target": 431, "key": "y", "index": 5 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": [], "loadList3D": [] };
            battle.BattleAttTextUI = BattleAttTextUI;
            REG("ui.battle.BattleAttTextUI", BattleAttTextUI);
            class BattleBoxFloatUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleBoxFloatUI.uiView);
                }
            }
            BattleBoxFloatUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 105, "mouseThrough": false, "mouseEnabled": true, "height": 82 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -9, "x": 2, "width": 100, "var": "img_box", "skin": "ui/img_UM_battle_taskbox.png", "name": "img_box", "height": 100, "gray": false }, "compId": 404 }], "loadList": ["ui/img_UM_battle_taskbox.png"], "loadList3D": [] };
            battle.BattleBoxFloatUI = BattleBoxFloatUI;
            REG("ui.battle.BattleBoxFloatUI", BattleBoxFloatUI);
            class BattleBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleBtnUI.uiView);
                }
            }
            BattleBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": false, "height": 150 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 32, "x": 17 }, "compId": 719, "child": [{ "type": "Box", "props": { "y": -24, "x": 6 }, "compId": 720, "child": [{ "type": "Image", "props": { "y": 23, "x": 0, "width": 257, "skin": "ui/img_uk_ui2_btn1.png", "height": 87 }, "compId": 721 }, { "type": "Label", "props": { "y": 37, "x": 32, "wordWrap": true, "width": 192, "valign": "middle", "text": "狂点开宝箱", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 722 }] }] }, { "type": "Image", "props": { "y": 38, "x": 274, "width": 50, "skin": "ui/img_uk_ui2_zy2.png", "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 725 }, { "type": "Image", "props": { "y": 112, "x": 32, "width": 50, "skin": "ui/img_uk_ui2_zy3.png", "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 726 }, { "type": "Image", "props": { "y": 38, "x": 32, "width": 50, "skin": "ui/img_uk_ui2_zy2.png", "scaleX": -1, "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 731 }, { "type": "Image", "props": { "y": 112, "x": 274, "width": 50, "skin": "ui/img_uk_ui2_zy3.png", "scaleX": -1, "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 732 }], "animations": [{ "nodes": [{ "target": 726, "keyframes": { "y": [{ "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "y", "index": 0 }, { "value": 122, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "y", "index": 10 }, { "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 726, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "x", "index": 0 }, { "value": 22, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "x", "index": 10 }, { "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 726, "label": null, "key": "x", "index": 20 }] } }, { "target": 725, "keyframes": { "y": [{ "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "y", "index": 0 }, { "value": 28, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "y", "index": 10 }, { "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 725, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 275, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "x", "index": 0 }, { "value": 285, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "x", "index": 10 }, { "value": 275, "tweenMethod": "linearNone", "tween": true, "target": 725, "label": null, "key": "x", "index": 20 }] } }, { "target": 731, "keyframes": { "y": [{ "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "y", "index": 0 }, { "value": 28, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "y", "index": 10 }, { "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 731, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "x", "index": 0 }, { "value": 22, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "x", "index": 10 }, { "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 731, "label": null, "key": "x", "index": 20 }] } }, { "target": 732, "keyframes": { "y": [{ "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "y", "index": 0 }, { "value": 122, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "y", "index": 10 }, { "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 732, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 274, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "x", "index": 0 }, { "value": 284, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "x", "index": 10 }, { "value": 274, "tweenMethod": "linearNone", "tween": true, "target": 732, "label": null, "key": "x", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_zy2.png", "ui/img_uk_ui2_zy3.png"], "loadList3D": [] };
            battle.BattleBtnUI = BattleBtnUI;
            REG("ui.battle.BattleBtnUI", BattleBtnUI);
            class BattleBtnDaodanUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleBtnDaodanUI.uiView);
                }
            }
            BattleBtnDaodanUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 51, "width": 120, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,22,22,22", "pivotY": 49, "pivotX": 60, "height": 120, "blendMode": "lighter" }, "compId": 1657 }, { "type": "Image", "props": { "y": 50, "x": 50, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "pivotY": 50, "pivotX": 50, "height": 100 }, "compId": 1652 }, { "type": "Image", "props": { "y": 77, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text78.png", "height": 30 }, "compId": 1653 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 104, "skin": "ui/img_UM_icon_daodan.png", "height": 82 }, "compId": 1655 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 38, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1656 }], "animations": [{ "nodes": [{ "target": 1657, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 20 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 30 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 40 }] } }, { "target": 1652, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 7 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 11 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleY", "index": 19 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 7 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 11 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleX", "index": 19 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text78.png", "ui/img_UM_icon_daodan.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleBtnDaodanUI = BattleBtnDaodanUI;
            REG("ui.battle.BattleBtnDaodanUI", BattleBtnDaodanUI);
            class BattleBtnHuixueUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleBtnHuixueUI.uiView);
                }
            }
            BattleBtnHuixueUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 51, "width": 120, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,22,22,22", "pivotY": 49, "pivotX": 60, "height": 120, "blendMode": "lighter" }, "compId": 1657 }, { "type": "Image", "props": { "y": 50, "x": 50, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "pivotY": 50, "pivotX": 50, "height": 100 }, "compId": 1652 }, { "type": "Image", "props": { "y": 77, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text79.png", "height": 30 }, "compId": 1653 }, { "type": "Image", "props": { "y": 6, "x": 14, "width": 73, "skin": "ui/img_UM_icon_jiaxue.png", "height": 71 }, "compId": 1659 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 38, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1656 }], "animations": [{ "nodes": [{ "target": 1657, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 20 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 30 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 40 }] } }, { "target": 1652, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 7 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 11 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleY", "index": 19 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 7 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 11 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleX", "index": 19 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text79.png", "ui/img_UM_icon_jiaxue.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleBtnHuixueUI = BattleBtnHuixueUI;
            REG("ui.battle.BattleBtnHuixueUI", BattleBtnHuixueUI);
            class BattleBtnTryUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleBtnTryUI.uiView);
                }
            }
            BattleBtnTryUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 250, "mouseThrough": false, "height": 80 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 125, "width": 243, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 36, "pivotX": 122, "height": 72 }, "compId": 1144 }, { "type": "Image", "props": { "y": 21, "x": 101, "width": 103, "var": "img_try", "skin": "ui/img_UM_Card_text3.png", "name": "img_try", "height": 30 }, "compId": 1145 }, { "type": "Image", "props": { "y": 20.5, "x": 44, "width": 41, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 33 }, "compId": 1146 }], "animations": [{ "nodes": [{ "target": 1144, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleY", "index": 0 }, { "value": 1.04, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleY", "index": 15 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleX", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleX", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_Card_text3.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleBtnTryUI = BattleBtnTryUI;
            REG("ui.battle.BattleBtnTryUI", BattleBtnTryUI);
            class BattleButtomUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleButtomUI.uiView);
                }
            }
            BattleButtomUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 74, "x": 100, "skin": "ui/img_UM_ui_hpbarbg.png" }, "compId": 1147 }, { "type": "Image", "props": { "y": -4, "x": -4, "width": 108, "skin": "ui/img_UM_herohead_bg.png", "height": 108 }, "compId": 1152 }, { "type": "Image", "props": { "y": 78, "x": 105, "var": "img_hp", "skin": "ui/img_UM_hp_1.png", "name": "img_hp" }, "compId": 1148 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 104, "var": "img_ico", "skin": "ui/img_UM_playerhead2.png", "name": "img_ico", "height": 102 }, "compId": 1146 }, { "type": "Image", "props": { "y": 56, "x": 67, "width": 45, "skin": "ui/img_UM_Payload_HP_blue.png", "height": 45 }, "compId": 1143 }, { "type": "Label", "props": { "y": 61, "x": 75, "wordWrap": true, "width": 30, "var": "txt_lv", "valign": "middle", "text": "9", "strokeColor": "#006a9c", "stroke": 4, "name": "txt_lv", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1144 }, { "type": "Box", "props": { "y": 34, "x": 146 }, "compId": 1151, "child": [{ "type": "Label", "props": { "y": 1, "x": 44, "wordWrap": false, "width": 65, "var": "txt_num", "valign": "bottom", "text": "/30", "strokeColor": "#006a9c", "stroke": 4, "name": "txt_num", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1149 }, { "type": "Label", "props": { "y": 1, "x": -23, "wordWrap": false, "width": 63, "var": "txt_num1", "valign": "bottom", "text": "30", "strokeColor": "#006a9c", "stroke": 4, "name": "txt_num1", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1150 }] }], "animations": [{ "nodes": [{ "target": 1139, "keyframes": { "width": [{ "value": 3, "tweenMethod": "linearNone", "tween": true, "target": 1139, "key": "width", "index": 0 }, { "value": 193, "tweenMethod": "linearNone", "tween": true, "target": 1139, "key": "width", "index": 100 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_hpbarbg.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_hp_1.png", "ui/img_UM_playerhead2.png", "ui/img_UM_Payload_HP_blue.png"], "loadList3D": [] };
            battle.BattleButtomUI = BattleButtomUI;
            REG("ui.battle.BattleButtomUI", BattleButtomUI);
            class BattleCardAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleCardAnimUI.uiView);
                }
            }
            BattleCardAnimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 37, "x": 50, "width": 79, "skin": "ui/img_UM_jt.png", "rotation": 180, "pivotY": 39, "pivotX": 40, "height": 78 }, "compId": 1138 }], "animations": [{ "nodes": [{ "target": 1138, "keyframes": { "y": [{ "value": 34, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 0 }, { "value": 44, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 5 }, { "value": 61.5, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 10 }, { "value": 72, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 15 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 10 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_jt.png"], "loadList3D": [] };
            battle.BattleCardAnimUI = BattleCardAnimUI;
            REG("ui.battle.BattleCardAnimUI", BattleCardAnimUI);
            class BattleCardGrondUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleCardGrondUI.uiView);
                }
            }
            BattleCardGrondUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg2.png", "right": -100, "left": -100, "bottom": 0 }, "compId": 1127 }, { "type": "Box", "props": { "y": 593, "x": 978, "var": "box_start", "name": "box_start" }, "compId": 1163, "child": [{ "type": "Image", "props": { "y": -5, "x": 0, "width": 269, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 114 }, "compId": 1213 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 216, "skin": "ui/img_UM_text_ksyx.png", "height": 51 }, "compId": 1214 }] }, { "type": "Box", "props": { "y": 28, "x": 38, "var": "box_close", "name": "box_close" }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Box", "props": { "y": 49, "x": 954 }, "compId": 1215, "child": [{ "type": "Image", "props": { "x": 11, "skin": "ui/img_UM_gameMode_hero.png" }, "compId": 1216 }, { "type": "Image", "props": { "y": 2, "x": 0, "width": 304, "skin": "ui/img_UM_tu.png", "height": 304 }, "compId": 1217 }, { "type": "Image", "props": { "y": 17, "x": 41, "skin": "ui/img_UM_hero_text1.png" }, "compId": 1220 }, { "type": "BattleBtnTry", "props": { "y": 332, "x": 25, "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1253 }, { "type": "BattleSkillicon", "props": { "y": 220, "x": 194, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.battle.BattleSkilliconUI" }, "compId": 1254 }, { "type": "BattleSkillicon", "props": { "y": 220, "x": 34, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.battle.BattleSkilliconUI" }, "compId": 1255 }] }, { "type": "Image", "props": { "y": -1, "x": 169, "width": 751, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 721, "alpha": 0.6 }, "compId": 1222 }, { "type": "Image", "props": { "y": 326, "x": 180, "width": 723, "skin": "ui/img_UM_cardbg.png", "sizeGrid": "4,5,3,5", "height": 386 }, "compId": 1223 }, { "type": "Image", "props": { "y": -6, "x": 180, "width": 728, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 70 }, "compId": 1224 }, { "type": "Image", "props": { "y": 60, "x": 180, "width": 1818, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "50,50,70,50", "scaleY": 0.4, "scaleX": 0.4, "height": 698 }, "compId": 1225 }, { "type": "List", "props": { "y": 394, "x": 203, "width": 701, "var": "ui_list1", "vScrollBarSkin": "comp/vscroll.png", "spaceY": 10, "spaceX": 15, "repeatY": 2, "repeatX": 5, "renderType": "render", "name": "ui_list1", "height": 314 }, "compId": 1226, "child": [{ "type": "GoodsItem6", "props": { "y": 0, "x": 0, "width": 122, "renderType": "render", "height": 204, "runtime": "ui.goods.GoodsItem6UI" }, "compId": 1250 }] }, { "type": "Image", "props": { "y": 71, "x": 193, "skin": "ui/img_UM_card_bg.png" }, "compId": 1228 }, { "type": "Image", "props": { "y": 80, "x": 203, "width": 111, "skin": "ui/img_UM_Card_text2.png", "height": 32 }, "compId": 1229 }, { "type": "Image", "props": { "y": 11, "x": 466, "skin": "ui/img_UM_Card_text1.png" }, "compId": 1230 }, { "type": "Image", "props": { "y": 343, "x": 190, "skin": "ui/img_UM_card_bg.png", "alpha": 0.2 }, "compId": 1232 }, { "type": "Box", "props": { "y": 134, "x": 207, "width": 681, "height": 175 }, "compId": 1248, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "width": 200, "var": "ui_palyer", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_palyer", "height": 300, "runtime": "ui.goods.GoodsItemUI" }, "compId": 1247 }, { "type": "List", "props": { "x": 136, "width": 549, "var": "ui_list", "spaceX": -60, "name": "ui_list", "height": 175 }, "compId": 1227, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "width": 200, "scaleY": 0.6, "scaleX": 0.6, "renderType": "render", "height": 300, "runtime": "ui.goods.GoodsItemUI" }, "compId": 1243 }] }, { "type": "BattleCardAnim", "props": { "y": 130, "x": 9, "runtime": "ui.battle.BattleCardAnimUI" }, "compId": 1252 }] }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_text_ksyx.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_gameMode_hero.png", "ui/img_UM_tu.png", "ui/img_UM_hero_text1.png", "ui/img_UM_black.png", "ui/img_UM_cardbg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_btn_BlueButton_2.png", "comp/vscroll.png", "ui/img_UM_card_bg.png", "ui/img_UM_Card_text2.png", "ui/img_UM_Card_text1.png"], "loadList3D": [] };
            battle.BattleCardGrondUI = BattleCardGrondUI;
            REG("ui.battle.BattleCardGrondUI", BattleCardGrondUI);
            class BattleCollUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleCollUI.uiView);
                }
            }
            BattleCollUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720 }, "compId": 2, "child": [{ "type": "BattleColl4", "props": { "y": 360, "x": 640, "width": 1280, "visible": true, "var": "img_coll_4", "pivotY": 360, "pivotX": 640, "name": "img_coll_4", "height": 720, "runtime": "ui.battle.BattleColl4UI" }, "compId": 3 }, { "type": "BattleColl5", "props": { "y": 310, "x": 590, "width": 100, "var": "img_coll_1", "name": "img_coll_1", "height": 100, "runtime": "ui.battle.BattleColl5UI" }, "compId": 8 }, { "type": "BattleColl8", "props": { "y": 310, "x": 590, "width": 100, "var": "img_coll_3", "name": "img_coll_3", "height": 100, "runtime": "ui.battle.BattleColl8UI" }, "compId": 7 }, { "type": "BattleColl6", "props": { "y": 310, "x": 590, "width": 100, "var": "img_coll_2", "name": "img_coll_2", "height": 100, "runtime": "ui.battle.BattleColl6UI" }, "compId": 9 }, { "type": "BattleColl7", "props": { "y": 310, "x": 590, "width": 100, "visible": false, "var": "img_coll_5", "name": "img_coll_5", "height": 100, "runtime": "ui.battle.BattleColl7UI" }, "compId": 10 }, { "type": "BattleAimItem", "props": { "y": 346, "x": 640, "width": 200, "var": "img_coll_6", "pivotY": 100, "pivotX": 100, "name": "img_coll_6", "height": 200, "runtime": "ui.battle.BattleAimItemUI" }, "compId": 12 }], "loadList": [], "loadList3D": [] };
            battle.BattleCollUI = BattleCollUI;
            REG("ui.battle.BattleCollUI", BattleCollUI);
            class BattleColl3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleColl3UI.uiView);
                }
            }
            BattleColl3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 59, "mouseThrough": true, "height": 59 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_uk_ui_u2_zunxing2.png" }, "compId": 967 }, { "type": "Image", "props": { "y": 27, "x": 35, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": 45, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 968 }, { "type": "Image", "props": { "y": 34, "x": 35, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": 135, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 969 }, { "type": "Image", "props": { "y": 34, "x": 26.5, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": 225, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 970 }, { "type": "Image", "props": { "y": 28, "x": 27, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": 315, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 971 }], "animations": [{ "nodes": [{ "target": 971, "keyframes": { "y": [{ "value": 27, "tweenMethod": "linearNone", "tween": true, "target": 971, "key": "y", "index": 0 }], "x": [{ "value": 26, "tweenMethod": "linearNone", "tween": true, "target": 971, "key": "x", "index": 0 }], "scaleY": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 971, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 971, "key": "scaleY", "index": 1 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 971, "label": null, "key": "scaleY", "index": 3 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 971, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 971, "key": "alpha", "index": 1 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 971, "label": null, "key": "alpha", "index": 3 }] } }, { "target": 968, "keyframes": { "scaleY": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 968, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 968, "key": "scaleY", "index": 1 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 968, "label": null, "key": "scaleY", "index": 3 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 968, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 968, "key": "alpha", "index": 1 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 968, "label": null, "key": "alpha", "index": 3 }] } }, { "target": 969, "keyframes": { "x": [{ "value": 34, "tweenMethod": "linearNone", "tween": true, "target": 969, "key": "x", "index": 0 }], "scaleY": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 969, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 969, "key": "scaleY", "index": 1 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 969, "label": null, "key": "scaleY", "index": 3 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 969, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 969, "key": "alpha", "index": 1 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 969, "label": null, "key": "alpha", "index": 3 }] } }, { "target": 970, "keyframes": { "scaleY": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 970, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 970, "key": "scaleY", "index": 1 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 970, "label": null, "key": "scaleY", "index": 3 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 970, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 970, "key": "alpha", "index": 1 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 970, "label": null, "key": "alpha", "index": 3 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_ui_u2_zunxing2.png", "ui/img_uk_ui_u2_zunxinghuo.png"], "loadList3D": [] };
            battle.BattleColl3UI = BattleColl3UI;
            REG("ui.battle.BattleColl3UI", BattleColl3UI);
            class BattleColl4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleColl4UI.uiView);
                }
            }
            BattleColl4UI.uiView = { "type": "View", "props": { "width": 1280, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 280, "width": 720, "skin": "ui/img_uk_ui_Scope.png", "sizeGrid": "1,1,1,1", "height": 720 }, "compId": 4 }, { "type": "Image", "props": { "y": 0, "x": -421, "width": 720, "skin": "comp/img_black.png", "sizeGrid": "1,1,1,1", "height": 720 }, "compId": 5 }, { "type": "Image", "props": { "y": 0, "x": 980, "width": 720, "skin": "comp/img_black.png", "sizeGrid": "1,1,1,1", "height": 720 }, "compId": 6 }], "loadList": ["ui/img_uk_ui_Scope.png", "comp/img_black.png"], "loadList3D": [] };
            battle.BattleColl4UI = BattleColl4UI;
            REG("ui.battle.BattleColl4UI", BattleColl4UI);
            class BattleColl5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleColl5UI.uiView);
                }
            }
            BattleColl5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_uk_ui_u2_zunxing1.png", "height": 100 }, "compId": 1078 }, { "type": "Image", "props": { "y": 43, "x": 43, "skin": "ui/img_UM_Collimation_3.png" }, "compId": 1079 }], "loadList": ["ui/img_uk_ui_u2_zunxing1.png", "ui/img_UM_Collimation_3.png"], "loadList3D": [] };
            battle.BattleColl5UI = BattleColl5UI;
            REG("ui.battle.BattleColl5UI", BattleColl5UI);
            class BattleColl6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleColl6UI.uiView);
                }
            }
            BattleColl6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 20, "x": 20, "skin": "ui/img_uk_ui_u2_zunxing2.png" }, "compId": 1079 }], "loadList": ["ui/img_uk_ui_u2_zunxing2.png"], "loadList3D": [] };
            battle.BattleColl6UI = BattleColl6UI;
            REG("ui.battle.BattleColl6UI", BattleColl6UI);
            class BattleColl7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleColl7UI.uiView);
                }
            }
            BattleColl7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_UM_Collimation_2.png" }, "compId": 1079 }, { "type": "Image", "props": { "y": 32, "x": 32, "skin": "ui/img_UM_Collimation_4.png" }, "compId": 1081 }, { "type": "Label", "props": { "y": 81, "x": 14, "wordWrap": false, "width": 72, "var": "txt_time", "valign": "middle", "text": "弹道受阻", "strokeColor": "#212121", "stroke": 4, "name": "txt_time", "height": 18, "fontSize": 15, "font": "SimHei", "color": "#e7e4da", "bold": false, "align": "center" }, "compId": 1082 }], "loadList": ["ui/img_UM_Collimation_2.png", "ui/img_UM_Collimation_4.png"], "loadList3D": [] };
            battle.BattleColl7UI = BattleColl7UI;
            REG("ui.battle.BattleColl7UI", BattleColl7UI);
            class BattleColl8UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleColl8UI.uiView);
                }
            }
            BattleColl8UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 20, "x": 20, "skin": "ui/img_uk_ui_u2_zunxing2.png" }, "compId": 1079 }, { "type": "Image", "props": { "y": 37, "x": 37, "width": 36, "skin": "ui/img_UM_Collimation_5.png", "scaleY": 0.7, "scaleX": 0.7, "height": 36 }, "compId": 1082 }, { "type": "Image", "props": { "y": 25, "x": 75, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": 45, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 1083 }, { "type": "Image", "props": { "y": 75, "x": 75, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": 135, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 1084 }, { "type": "Image", "props": { "y": 25, "x": 22, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": -45, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 1085 }, { "type": "Image", "props": { "y": 75, "x": 22, "width": 10, "skin": "ui/img_uk_ui_u2_zunxinghuo.png", "rotation": -135, "pivotY": 50, "pivotX": 5, "height": 50 }, "compId": 1086 }], "animations": [{ "nodes": [{ "target": 1082, "keyframes": { "y": [{ "value": 42, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "y", "index": 0 }, { "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "y", "index": 2 }, { "value": 42, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "y", "index": 4 }], "x": [{ "value": 42, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "x", "index": 0 }, { "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "x", "index": 2 }, { "value": 42, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "x", "index": 4 }], "scaleY": [{ "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleY", "index": 2 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "label": null, "key": "scaleY", "index": 4 }], "scaleX": [{ "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleX", "index": 2 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "label": null, "key": "scaleX", "index": 4 }] } }, { "target": 1079, "keyframes": { "skin": [{ "value": "ui/img_uk_ui_u2_zunxing2.png", "tweenMethod": "linearNone", "tween": false, "target": 1079, "key": "skin", "index": 0 }, { "value": "ui/img_uk_ui_u2_zunxing2.png", "tweenMethod": "linearNone", "tween": false, "target": 1079, "key": "skin", "index": 4 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui_u2_zunxing2.png", "ui/img_UM_Collimation_5.png", "ui/img_uk_ui_u2_zunxinghuo.png"], "loadList3D": [] };
            battle.BattleColl8UI = BattleColl8UI;
            REG("ui.battle.BattleColl8UI", BattleColl8UI);
            class BattleCrazyChestUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleCrazyChestUI.uiView);
                }
            }
            BattleCrazyChestUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": -100, "skin": "ui/img_UM_cardbg3.png", "right": -100, "left": -100, "height": 720 }, "compId": 1040 }, { "type": "Box", "props": { "y": -19, "width": 498, "height": 716, "centerX": 0 }, "compId": 1039, "child": [{ "type": "Image", "props": { "y": 256.78, "x": 266, "width": 471, "skin": "ui/img_ui_ui_effect.png", "scaleY": 0.91, "scaleX": 0.91, "rotation": 0, "pivotY": 258, "pivotX": 257, "height": 421 }, "compId": 1025 }, { "type": "Image", "props": { "y": 105.78, "x": 127, "width": 239, "visible": true, "skin": "ui/img_UM_box_box4.png", "height": 230 }, "compId": 1026 }, { "type": "Button", "props": { "y": 581.78, "x": 95, "width": 303, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_green.png", "name": "btn_ok", "height": 126 }, "compId": 1027, "child": [{ "type": "Label", "props": { "y": 56, "x": 152, "wordWrap": false, "width": 256, "text": "狂点开宝箱", "strokeColor": "#000089", "stroke": 7, "scaleY": 0.86, "scaleX": 0.86, "pivotY": 23, "pivotX": 128, "name": "txt_phy", "height": 46, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1032 }] }, { "type": "Box", "props": { "y": 406.78, "x": 2, "var": "img_bar", "name": "img_bar" }, "compId": 1038, "child": [{ "type": "Image", "props": { "width": 490, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "7,15,6,13", "height": 50 }, "compId": 1029 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 496, "var": "bar_num", "skin": "ui/img_UM_bar_green.png", "sizeGrid": "0,18,0,20", "name": "bar_num", "height": 52 }, "compId": 1030 }, { "type": "Label", "props": { "y": -5, "x": 187, "wordWrap": true, "width": 115, "var": "txt_num", "text": "100%", "strokeColor": "#3b3b3b", "stroke": 7, "name": "txt_num", "height": 46, "fontSize": 47, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1031 }] }, { "type": "Button", "props": { "y": 369.28, "x": 95, "width": 303, "visible": false, "var": "btn_get", "stateNum": 1, "skin": "ui/img_UM_btn_green.png", "name": "btn_get", "height": 126 }, "compId": 1034, "child": [{ "type": "Label", "props": { "y": 56, "x": 152, "wordWrap": false, "width": 256, "text": "获得奖励", "strokeColor": "#000089", "stroke": 7, "scaleY": 0.86, "scaleX": 0.86, "pivotY": 23, "pivotX": 128, "name": "txt_phy", "height": 46, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1035 }] }] }], "loadList": ["ui/img_UM_cardbg3.png", "ui/img_ui_ui_effect.png", "ui/img_UM_box_box4.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_bar_green.png"], "loadList3D": [] };
            battle.BattleCrazyChestUI = BattleCrazyChestUI;
            REG("ui.battle.BattleCrazyChestUI", BattleCrazyChestUI);
            class BattleCrazyChest1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleCrazyChest1UI.uiView);
                }
            }
            BattleCrazyChest1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": -100, "skin": "ui/img_UM_cardbg3.png", "right": -100, "left": -100, "height": 720 }, "compId": 1040 }, { "type": "Box", "props": { "y": -19, "width": 498, "height": 716, "centerX": 0 }, "compId": 1039, "child": [{ "type": "Image", "props": { "y": 256.78, "x": 266, "width": 471, "skin": "ui/img_ui_ui_effect.png", "scaleY": 0.91, "scaleX": 0.91, "rotation": 0, "pivotY": 258, "pivotX": 257, "height": 421 }, "compId": 1025 }, { "type": "Image", "props": { "y": 105.78, "x": 127, "width": 239, "visible": true, "skin": "ui/img_UM_box_box4.png", "height": 230 }, "compId": 1026 }, { "type": "Button", "props": { "y": 581.78, "x": 95, "width": 303, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_green.png", "name": "btn_ok", "height": 126 }, "compId": 1027, "child": [{ "type": "Label", "props": { "y": 56, "x": 152, "wordWrap": false, "width": 256, "text": "狂点开宝箱", "strokeColor": "#000089", "stroke": 7, "scaleY": 0.86, "scaleX": 0.86, "pivotY": 23, "pivotX": 128, "name": "txt_phy", "height": 46, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1032 }] }, { "type": "Box", "props": { "y": 406.78, "x": 2, "var": "img_bar", "name": "img_bar" }, "compId": 1038, "child": [{ "type": "Image", "props": { "width": 490, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "7,15,6,13", "height": 50 }, "compId": 1029 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 496, "var": "bar_num", "skin": "ui/img_UM_bar_green.png", "sizeGrid": "0,18,0,20", "name": "bar_num", "height": 52 }, "compId": 1030 }, { "type": "Label", "props": { "y": -5, "x": 187, "wordWrap": true, "width": 115, "var": "txt_num", "text": "100%", "strokeColor": "#3b3b3b", "stroke": 7, "name": "txt_num", "height": 46, "fontSize": 47, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1031 }] }, { "type": "Button", "props": { "y": 369.28, "x": 95, "width": 303, "visible": false, "var": "btn_get", "stateNum": 1, "skin": "ui/img_UM_btn_green.png", "name": "btn_get", "height": 126 }, "compId": 1034, "child": [{ "type": "Label", "props": { "y": 56, "x": 152, "wordWrap": false, "width": 256, "text": "获得奖励", "strokeColor": "#000089", "stroke": 7, "scaleY": 0.86, "scaleX": 0.86, "pivotY": 23, "pivotX": 128, "name": "txt_phy", "height": 46, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1035 }] }] }], "loadList": ["ui/img_UM_cardbg3.png", "ui/img_ui_ui_effect.png", "ui/img_UM_box_box4.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_bar_green.png"], "loadList3D": [] };
            battle.BattleCrazyChest1UI = BattleCrazyChest1UI;
            REG("ui.battle.BattleCrazyChest1UI", BattleCrazyChest1UI);
            class BattleDefeatUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatUI.uiView);
                }
            }
            BattleDefeatUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "BattleDefeatAnim", "props": { "var": "ui_anim", "name": "ui_anim", "centerX": 0, "runtime": "ui.battle.BattleDefeatAnimUI" }, "compId": 778 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleDefeatUI = BattleDefeatUI;
            REG("ui.battle.BattleDefeatUI", BattleDefeatUI);
            class BattleDefeat1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeat1UI.uiView);
                }
            }
            BattleDefeat1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }, { "type": "BattleDefeatAnim1", "props": { "y": 321, "var": "ui_anim", "name": "ui_anim", "centerX": 0, "runtime": "ui.battle.BattleDefeatAnim1UI" }, "compId": 789 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleDefeat1UI = BattleDefeat1UI;
            REG("ui.battle.BattleDefeat1UI", BattleDefeat1UI);
            class BattleDefeat2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeat2UI.uiView);
                }
            }
            BattleDefeat2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }, { "type": "BattleDefeatAnim2", "props": { "y": 448, "x": 350, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleDefeatAnim2UI" }, "compId": 790 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleDefeat2UI = BattleDefeat2UI;
            REG("ui.battle.BattleDefeat2UI", BattleDefeat2UI);
            class BattleDefeat3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeat3UI.uiView);
                }
            }
            BattleDefeat3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }, { "type": "BattleDefeatAnim3", "props": { "y": 298, "x": 424, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleDefeatAnim3UI" }, "compId": 791 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleDefeat3UI = BattleDefeat3UI;
            REG("ui.battle.BattleDefeat3UI", BattleDefeat3UI);
            class BattleDefeat4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeat4UI.uiView);
                }
            }
            BattleDefeat4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }, { "type": "BattleDefeatAnim4", "props": { "y": 474, "var": "ui_anim", "name": "ui_anim", "centerX": 0, "runtime": "ui.battle.BattleDefeatAnim4UI" }, "compId": 792 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleDefeat4UI = BattleDefeat4UI;
            REG("ui.battle.BattleDefeat4UI", BattleDefeat4UI);
            class BattleDefeat5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeat5UI.uiView);
                }
            }
            BattleDefeat5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }, { "type": "BattleDefeatAnim5", "props": { "y": 301, "x": 245, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleDefeatAnim5UI" }, "compId": 793 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleDefeat5UI = BattleDefeat5UI;
            REG("ui.battle.BattleDefeat5UI", BattleDefeat5UI);
            class BattleDefeat6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeat6UI.uiView);
                }
            }
            BattleDefeat6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }, { "type": "BattleDefeatAnim6", "props": { "y": 632, "var": "ui_anim", "name": "ui_anim", "centerX": 0, "runtime": "ui.battle.BattleDefeatAnim6UI" }, "compId": 794 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleDefeat6UI = BattleDefeat6UI;
            REG("ui.battle.BattleDefeat6UI", BattleDefeat6UI);
            class BattleDefeat7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeat7UI.uiView);
                }
            }
            BattleDefeat7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 760 }, { "type": "Box", "props": { "y": 0, "right": 0 }, "compId": 779, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 780 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 781 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 57, "right": 0 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 785 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 786 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 788 }] }, { "type": "BattleDefeatAnim4", "props": { "y": 474, "var": "ui_anim", "name": "ui_anim", "centerX": 0, "runtime": "ui.battle.BattleDefeatAnim4UI" }, "compId": 792 }, { "type": "Box", "props": { "y": 234, "centerX": 0 }, "compId": 795, "child": [{ "type": "CheckBox", "props": { "width": 50, "var": "check_ad", "toggle": false, "stateNum": 2, "skin": "ui/btn_UM_gouxuan.png", "selected": true, "scaleY": 1, "scaleX": 1, "name": "check_ad", "height": 51 }, "compId": 793 }, { "type": "Label", "props": { "y": 18, "x": 58, "width": 141, "underline": false, "text": "看视频获得奖励", "stroke": 0, "name": "txt_ad", "height": 32, "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 794 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png", "ui/btn_UM_gouxuan.png"], "loadList3D": [] };
            battle.BattleDefeat7UI = BattleDefeat7UI;
            REG("ui.battle.BattleDefeat7UI", BattleDefeat7UI);
            class BattleDefeatAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatAnimUI.uiView);
                }
            }
            BattleDefeatAnimUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1297 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1298 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -0.5, "x": 301, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": -0.5, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }, { "target": 1296, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 51 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 56 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleDefeatAnimUI = BattleDefeatAnimUI;
            REG("ui.battle.BattleDefeatAnimUI", BattleDefeatAnimUI);
            class BattleDefeatAnim1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatAnim1UI.uiView);
                }
            }
            BattleDefeatAnim1UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1300 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -12, "x": 420, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": 255, "x": -462, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }, { "type": "Label", "props": { "y": 652.5, "x": 166, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleDefeatAnim1UI = BattleDefeatAnim1UI;
            REG("ui.battle.BattleDefeatAnim1UI", BattleDefeatAnim1UI);
            class BattleDefeatAnim2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatAnim2UI.uiView);
                }
            }
            BattleDefeatAnim2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -12, "x": 460, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": 97, "x": 460, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }, { "type": "Label", "props": { "y": 603, "x": -328, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleDefeatAnim2UI = BattleDefeatAnim2UI;
            REG("ui.battle.BattleDefeatAnim2UI", BattleDefeatAnim2UI);
            class BattleDefeatAnim3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatAnim3UI.uiView);
                }
            }
            BattleDefeatAnim3UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1300 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Image", "props": { "y": 1062, "x": -479, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }, { "type": "Box", "props": { "y": 522, "right": 20 }, "compId": 1301, "child": [{ "type": "Image", "props": { "x": -0.5, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 122, "x": 53.5, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }] }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleDefeatAnim3UI = BattleDefeatAnim3UI;
            REG("ui.battle.BattleDefeatAnim3UI", BattleDefeatAnim3UI);
            class BattleDefeatAnim4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatAnim4UI.uiView);
                }
            }
            BattleDefeatAnim4UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "var": "box_1", "pivotY": 103, "pivotX": 245, "name": "box_1", "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "var": "box_2", "pivotY": 101, "pivotX": 243, "name": "box_2", "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1300 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "var": "img_light", "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "name": "img_light", "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 521.5, "var": "box_3", "name": "box_3", "centerX": 0 }, "compId": 1301, "child": [{ "type": "Image", "props": { "x": -0.5, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "var": "img_get3", "skin": "ui/img_UM_ui_text11.png", "name": "img_get3" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 106, "x": 53.5, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }, { "type": "Image", "props": { "y": 98, "x": 0, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleDefeatAnim4UI = BattleDefeatAnim4UI;
            REG("ui.battle.BattleDefeatAnim4UI", BattleDefeatAnim4UI);
            class BattleDefeatAnim5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatAnim5UI.uiView);
                }
            }
            BattleDefeatAnim5UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "visible": true, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1300 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Image", "props": { "y": 1062, "x": -479, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }, { "type": "Image", "props": { "y": 583, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "right": 30, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 621, "x": 110, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleDefeatAnim5UI = BattleDefeatAnim5UI;
            REG("ui.battle.BattleDefeatAnim5UI", BattleDefeatAnim5UI);
            class BattleDefeatAnim6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatAnim6UI.uiView);
                }
            }
            BattleDefeatAnim6UI.uiView = { "type": "View", "props": { "width": 1280, "visible": true, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1300 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Image", "props": { "y": 1062, "x": -479, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }, { "type": "Image", "props": { "y": 594, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 0.8, "scaleX": 0.8, "right": 0, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 621, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "left": 50, "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleDefeatAnim6UI = BattleDefeatAnim6UI;
            REG("ui.battle.BattleDefeatAnim6UI", BattleDefeatAnim6UI);
            class BattleDefeatMvpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatMvpUI.uiView);
                }
            }
            BattleDefeatMvpUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 140, "x": 633, "width": 500, "skin": "ui/img_UM_end_defeatbg.png", "pivotY": 52, "pivotX": 250, "height": 130 }, "compId": 1242 }, { "type": "Image", "props": { "y": 121, "x": 640, "width": 256, "skin": "ui/img_UM_text_fail.png", "pivotY": 60, "pivotX": 128, "height": 119 }, "compId": 1239 }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "scaleY": 1, "scaleX": 1, "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter", "alpha": 0 }, "compId": 1285 }, { "type": "Image", "props": { "y": 512, "x": 293, "width": 693, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 124, "alpha": 0.4 }, "compId": 1297 }, { "type": "Box", "props": { "y": 518, "x": 300 }, "compId": 1307, "child": [{ "type": "Image", "props": { "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1298 }, { "type": "Label", "props": { "y": 34, "x": 39, "wordWrap": true, "width": 202, "text": "最大Frag连击", "strokeColor": "#000000", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1299 }, { "type": "Label", "props": { "y": 14, "x": 253, "wordWrap": false, "width": 66, "var": "txt_kill", "text": "8", "strokeColor": "#000000", "name": "txt_kill", "height": 69, "fontSize": 70, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1300 }] }, { "type": "Box", "props": { "y": 473, "x": 640 }, "compId": 1308, "child": [{ "type": "Image", "props": { "y": 45, "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1301 }, { "type": "Label", "props": { "y": 77, "x": 31, "wordWrap": true, "width": 202, "text": "MVP", "strokeColor": "#000000", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#141414", "bold": true, "align": "center" }, "compId": 1302 }, { "type": "BattleHeroCardItem", "props": { "y": 0, "x": 205, "var": "ui_npc", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_npc", "runtime": "ui.battle.BattleHeroCardItemUI" }, "compId": 1309 }] }], "animations": [{ "nodes": [{ "target": 1242, "keyframes": { "y": [{ "value": 233, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 0 }, { "value": 140, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 20 }], "scaleX": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 20 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 30 }] } }, { "target": 1239, "keyframes": { "y": [{ "value": 214, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 0 }, { "value": 121, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_ui_obj9.png"], "loadList3D": [] };
            battle.BattleDefeatMvpUI = BattleDefeatMvpUI;
            REG("ui.battle.BattleDefeatMvpUI", BattleDefeatMvpUI);
            class BattleDefeatNoticeUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDefeatNoticeUI.uiView);
                }
            }
            BattleDefeatNoticeUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseEnabled": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 52, "x": 503, "width": 273, "skin": "ui/img_uk_ui2_obj18.png", "height": 273 }, "compId": 705 }, { "type": "Image", "props": { "y": 87, "x": 540, "skin": "ui/img_uk_icon_bg.png" }, "compId": 707 }, { "type": "Image", "props": { "y": 142, "x": 534, "skin": "ui/img_uk_text_defeat.png" }, "compId": 704 }, { "type": "Box", "props": { "y": 496, "x": 274 }, "compId": 715, "child": [{ "type": "Image", "props": { "y": 5, "x": 0, "width": 277, "skin": "ui/img_uk_img_db.png", "height": 83 }, "compId": 712 }, { "type": "Label", "props": { "y": 7, "x": 295, "wordWrap": true, "width": 142, "valign": "middle", "text": "VS", "strokeColor": "#212121", "height": 80, "fontSize": 80, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 711 }, { "type": "Image", "props": { "y": 6, "x": 454, "width": 277, "skin": "ui/img_uk_img_db2.png", "height": 83 }, "compId": 716 }, { "type": "Label", "props": { "y": 30, "x": 29, "wordWrap": true, "width": 109, "valign": "middle", "text": "己方部队", "strokeColor": "#212121", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 717 }, { "type": "Label", "props": { "y": 22, "x": 170, "wordWrap": true, "width": 80, "var": "txt_kill_1", "valign": "middle", "text": "23", "strokeColor": "#001671", "stroke": 4, "name": "txt_kill_1", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 718 }, { "type": "Label", "props": { "y": 30, "x": 593, "wordWrap": true, "width": 109, "valign": "middle", "text": "敌方部队", "strokeColor": "#212121", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ff826a", "bold": false, "align": "left" }, "compId": 719 }, { "type": "Label", "props": { "y": 22, "x": 505, "wordWrap": true, "width": 80, "var": "txt_kill_2", "valign": "middle", "text": "23", "strokeColor": "#690100", "stroke": 4, "name": "txt_kill_2", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#ff826a", "bold": false, "align": "left" }, "compId": 720 }] }], "loadList": ["ui/img_uk_ui2_obj18.png", "ui/img_uk_icon_bg.png", "ui/img_uk_text_defeat.png", "ui/img_uk_img_db.png", "ui/img_uk_img_db2.png"], "loadList3D": [] };
            battle.BattleDefeatNoticeUI = BattleDefeatNoticeUI;
            REG("ui.battle.BattleDefeatNoticeUI", BattleDefeatNoticeUI);
            class BattleDirUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleDirUI.uiView);
                }
            }
            BattleDirUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "loadList": [], "loadList3D": [] };
            battle.BattleDirUI = BattleDirUI;
            REG("ui.battle.BattleDirUI", BattleDirUI);
            class BattleEditorUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleEditorUI.uiView);
                }
            }
            BattleEditorUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "loadList": [], "loadList3D": [] };
            battle.BattleEditorUI = BattleEditorUI;
            REG("ui.battle.BattleEditorUI", BattleEditorUI);
            class BattleEndUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleEndUI.uiView);
                }
            }
            BattleEndUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 8, "x": 315 }, "compId": 694, "child": [{ "type": "Image", "props": { "skin": "ui/img_uk_ui2_obj18.png" }, "compId": 656 }, { "type": "Box", "props": { "y": 611, "x": 54, "var": "btn_close", "name": "btn_close" }, "compId": 657, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 268, "skin": "ui/img_uk_ui2_btn1.png", "height": 92 }, "compId": 662 }, { "type": "Label", "props": { "y": 17, "x": 64, "wordWrap": true, "width": 139, "valign": "middle", "text": "领取奖励", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 663 }] }, { "type": "Box", "props": { "y": 608, "x": 333, "var": "img_ok", "name": "img_ok" }, "compId": 658, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 268, "skin": "ui/img_uk_ui2_btn2.png", "height": 92 }, "compId": 664 }, { "type": "Label", "props": { "y": 17, "x": 85, "wordWrap": true, "width": 139, "valign": "middle", "text": "三倍领取", "strokeColor": "#126c1a", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 665 }, { "type": "Image", "props": { "y": 31, "x": 45, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 695 }] }, { "type": "Image", "props": { "y": 135, "x": 36, "width": 579, "skin": "ui/img_uk_ui2_obj13.png", "sizeGrid": "39,68,43,90", "height": 466 }, "compId": 660 }, { "type": "Box", "props": { "y": 172, "x": 110 }, "compId": 661, "child": [{ "type": "Label", "props": { "wordWrap": true, "width": 109, "valign": "middle", "text": "参赛奖励", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 667 }, { "type": "Label", "props": { "y": 47, "wordWrap": true, "width": 109, "valign": "middle", "text": "打满全场", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 668 }, { "type": "Label", "props": { "y": 94, "wordWrap": true, "width": 109, "valign": "middle", "text": "击杀", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 669 }, { "type": "Label", "props": { "y": 143, "wordWrap": true, "width": 109, "valign": "middle", "text": "MVP", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 670 }, { "type": "Label", "props": { "y": 357, "wordWrap": true, "width": 109, "valign": "middle", "text": "合计", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 672 }, { "type": "Label", "props": { "x": 153, "wordWrap": true, "width": 57, "var": "txt_exp", "valign": "middle", "text": "50", "strokeColor": "#212121", "stroke": 4, "name": "txt_exp", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 673 }, { "type": "Label", "props": { "x": 343, "wordWrap": true, "width": 57, "var": "txt_tong", "valign": "middle", "text": "100", "strokeColor": "#212121", "stroke": 4, "name": "txt_tong", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 674 }, { "type": "Image", "props": { "y": 2, "x": 214, "width": 30, "skin": "ui/img_uk_icon_exp.png", "height": 30 }, "compId": 675 }, { "type": "Image", "props": { "y": 2, "x": 401, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 676 }, { "type": "Label", "props": { "y": 47, "x": 153, "wordWrap": true, "width": 57, "var": "txt_tongFull", "valign": "middle", "text": "100", "strokeColor": "#212121", "stroke": 4, "name": "txt_tongFull", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 677 }, { "type": "Image", "props": { "y": 49, "x": 214, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 678 }, { "type": "Image", "props": { "y": 99, "x": 214, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 679 }, { "type": "Label", "props": { "y": 96, "x": 153, "wordWrap": true, "width": 57, "var": "txt_jinKill", "valign": "middle", "text": "10", "strokeColor": "#212121", "stroke": 4, "name": "txt_jinKill", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 680 }, { "type": "Image", "props": { "y": 148, "x": 214, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 681 }, { "type": "Label", "props": { "y": 146, "x": 153, "wordWrap": true, "width": 57, "var": "txt_jinMvp", "valign": "middle", "text": "50", "strokeColor": "#212121", "stroke": 4, "name": "txt_jinMvp", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 682 }, { "type": "Label", "props": { "y": 357, "x": 118, "wordWrap": true, "width": 57, "var": "txt_expAll", "valign": "middle", "text": "50", "strokeColor": "#212121", "stroke": 4, "name": "txt_expAll", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 687 }, { "type": "Image", "props": { "y": 359, "x": 184, "width": 30, "skin": "ui/img_uk_icon_exp.png", "height": 30 }, "compId": 688 }, { "type": "Label", "props": { "y": 357, "x": 232, "wordWrap": true, "width": 57, "var": "txt_tongAll", "valign": "middle", "text": "500", "strokeColor": "#212121", "stroke": 4, "name": "txt_tongAll", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 689 }, { "type": "Image", "props": { "y": 359, "x": 295, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 690 }, { "type": "Image", "props": { "y": 359, "x": 401, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 691 }, { "type": "Label", "props": { "y": 357, "x": 339, "wordWrap": true, "width": 57, "var": "txt_jinAll", "valign": "middle", "text": "110", "strokeColor": "#212121", "stroke": 4, "name": "txt_jinAll", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 692 }] }, { "type": "Label", "props": { "y": 22, "x": 194, "wordWrap": true, "width": 262, "valign": "middle", "text": "战斗结束", "strokeColor": "#212121", "stroke": 8, "height": 100, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 693 }] }], "loadList": ["ui/img_uk_ui2_obj18.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_icon_exp.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_Icon_zs.png"], "loadList3D": [] };
            battle.BattleEndUI = BattleEndUI;
            REG("ui.battle.BattleEndUI", BattleEndUI);
            class BattleEndCrazyChestUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleEndCrazyChestUI.uiView);
                }
            }
            BattleEndCrazyChestUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": -100, "skin": "ui/img_UM_cardbg3.png", "right": -100, "left": -100, "height": 720 }, "compId": 1040 }, { "type": "Box", "props": { "y": -19, "width": 498, "height": 716, "centerX": 0 }, "compId": 1039, "child": [{ "type": "Image", "props": { "y": 256.78, "x": 266, "width": 471, "skin": "ui/img_ui_ui_effect.png", "scaleY": 0.91, "scaleX": 0.91, "rotation": 0, "pivotY": 258, "pivotX": 257, "height": 421 }, "compId": 1025 }, { "type": "Image", "props": { "y": 105.78, "x": 127, "width": 239, "visible": true, "skin": "ui/img_UM_box_box4.png", "height": 230 }, "compId": 1026 }, { "type": "Box", "props": { "y": 406.78, "x": 2, "var": "img_bar", "name": "img_bar" }, "compId": 1038, "child": [{ "type": "Image", "props": { "width": 490, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "7,15,6,13", "height": 50 }, "compId": 1029 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 496, "var": "bar_num", "skin": "ui/img_UM_bar_green.png", "sizeGrid": "0,18,0,20", "name": "bar_num", "height": 52 }, "compId": 1030 }, { "type": "Label", "props": { "y": -5, "x": 187, "wordWrap": true, "width": 115, "var": "txt_num", "text": "100%", "strokeColor": "#3b3b3b", "stroke": 7, "name": "txt_num", "height": 46, "fontSize": 47, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1031 }] }, { "type": "Button", "props": { "y": 358, "x": 95, "width": 303, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_green.png", "name": "btn_ok", "height": 126 }, "compId": 1027, "child": [{ "type": "Label", "props": { "y": 56, "x": 152, "wordWrap": false, "width": 256, "text": "狂点开宝箱", "strokeColor": "#000089", "stroke": 7, "scaleY": 0.86, "scaleX": 0.86, "pivotY": 23, "pivotX": 128, "name": "txt_phy", "height": 46, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1032 }] }, { "type": "Button", "props": { "y": 601, "x": 82, "width": 303, "visible": false, "var": "btn_get", "stateNum": 1, "skin": "ui/img_UM_btn_green.png", "name": "btn_get", "height": 126 }, "compId": 1034, "child": [{ "type": "Label", "props": { "y": 56, "x": 152, "wordWrap": false, "width": 256, "text": "获得奖励", "strokeColor": "#000089", "stroke": 7, "scaleY": 0.86, "scaleX": 0.86, "pivotY": 23, "pivotX": 128, "name": "txt_phy", "height": 46, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1035 }] }] }], "loadList": ["ui/img_UM_cardbg3.png", "ui/img_ui_ui_effect.png", "ui/img_UM_box_box4.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_bar_green.png", "ui/img_UM_btn_green.png"], "loadList3D": [] };
            battle.BattleEndCrazyChestUI = BattleEndCrazyChestUI;
            REG("ui.battle.BattleEndCrazyChestUI", BattleEndCrazyChestUI);
            class BattleEndNoticeUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleEndNoticeUI.uiView);
                }
            }
            BattleEndNoticeUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseEnabled": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 52, "x": 503, "width": 273, "skin": "ui/img_uk_ui2_obj19.png", "height": 273 }, "compId": 705 }, { "type": "Image", "props": { "y": 87, "x": 540, "skin": "ui/img_uk_icon_bg.png" }, "compId": 707 }, { "type": "Box", "props": { "y": 477, "x": 326 }, "compId": 715, "child": [{ "type": "Image", "props": { "y": 5, "x": 0, "width": 277, "skin": "ui/img_uk_img_db.png", "height": 83 }, "compId": 712 }, { "type": "Label", "props": { "y": 30, "x": 51, "wordWrap": true, "width": 80, "valign": "middle", "text": "击杀", "strokeColor": "#212121", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 717 }, { "type": "Label", "props": { "y": 22, "x": 174, "wordWrap": true, "width": 61, "var": "txt_kill_1", "valign": "middle", "text": "23", "strokeColor": "#001671", "stroke": 4, "name": "txt_kill_1", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 718 }, { "type": "Image", "props": { "y": 5, "x": 351, "width": 277, "skin": "ui/img_uk_img_db.png", "height": 83 }, "compId": 722 }, { "type": "Label", "props": { "y": 30, "x": 402, "wordWrap": true, "width": 77, "valign": "middle", "text": "排名", "strokeColor": "#212121", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 723 }, { "type": "Label", "props": { "y": 22, "x": 526, "wordWrap": true, "width": 61, "var": "txt_kill_2", "valign": "middle", "text": "23", "strokeColor": "#003f69", "stroke": 4, "name": "txt_kill_2", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 724 }] }, { "type": "Label", "props": { "y": 139, "x": 509, "wordWrap": true, "width": 262, "valign": "middle", "text": "结束", "strokeColor": "#212121", "stroke": 8, "height": 100, "fontSize": 65, "font": "SimHei", "color": "#fff084", "bold": true, "align": "center" }, "compId": 721 }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_bg.png", "ui/img_uk_img_db.png"], "loadList3D": [] };
            battle.BattleEndNoticeUI = BattleEndNoticeUI;
            REG("ui.battle.BattleEndNoticeUI", BattleEndNoticeUI);
            class BattleExhaustTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleExhaustTipUI.uiView);
                }
            }
            BattleExhaustTipUI.uiView = { "type": "View", "props": { "y": 150, "x": 0, "width": 320, "mouseThrough": true, "mouseEnabled": false, "height": 80, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 180, "var": "img_1", "skin": "ui/img_uj_ui_text_zdyhj.png", "pivotY": 30, "pivotX": 155, "name": "img_1" }, "compId": 362 }], "animations": [{ "nodes": [{ "target": 362, "keyframes": { "scaleY": [{ "value": 0.5, "tweenMethod": "backOut", "tween": true, "target": 362, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "label": null, "key": "scaleY", "index": 25 }, { "value": 1.2, "tweenMethod": "backOut", "tween": true, "target": 362, "label": null, "key": "scaleY", "index": 30 }], "scaleX": [{ "value": 0.5, "tweenMethod": "backOut", "tween": true, "target": 362, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "label": null, "key": "scaleX", "index": 25 }, { "value": 1.2, "tweenMethod": "backOut", "tween": true, "target": 362, "label": null, "key": "scaleX", "index": 30 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "alpha", "index": 25 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "alpha", "index": 30 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_uj_ui_text_zdyhj.png"], "loadList3D": [] };
            battle.BattleExhaustTipUI = BattleExhaustTipUI;
            REG("ui.battle.BattleExhaustTipUI", BattleExhaustTipUI);
            class BattleFullTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleFullTipUI.uiView);
                }
            }
            BattleFullTipUI.uiView = { "type": "View", "props": { "y": 150, "x": 0, "width": 320, "mouseThrough": true, "mouseEnabled": false, "height": 80, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 160, "width": 310, "var": "img_1", "skin": "ui/img_uj_ui_text_zdbbm.png", "pivotY": 30, "pivotX": 155, "name": "img_1", "height": 60, "alpha": 1 }, "compId": 362 }], "animations": [{ "nodes": [{ "target": 362, "keyframes": { "scaleY": [{ "value": 0.5, "tweenMethod": "backOut", "tween": true, "target": 362, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "label": null, "key": "scaleY", "index": 25 }, { "value": 1.2, "tweenMethod": "backOut", "tween": true, "target": 362, "label": null, "key": "scaleY", "index": 30 }], "scaleX": [{ "value": 0.5, "tweenMethod": "backOut", "tween": true, "target": 362, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "label": null, "key": "scaleX", "index": 25 }, { "value": 1.2, "tweenMethod": "backOut", "tween": true, "target": 362, "label": null, "key": "scaleX", "index": 30 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "alpha", "index": 25 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 362, "key": "alpha", "index": 40 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_uj_ui_text_zdbbm.png"], "loadList3D": [] };
            battle.BattleFullTipUI = BattleFullTipUI;
            REG("ui.battle.BattleFullTipUI", BattleFullTipUI);
            class BattleGameOverUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleGameOverUI.uiView);
                }
            }
            BattleGameOverUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "centerY": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Label", "props": { "wordWrap": false, "width": 545, "var": "txt_over", "valign": "middle", "text": "游戏结束！", "strokeColor": "#0b0808", "stroke": 6, "name": "txt_over", "height": 74, "fontSize": 70, "font": "SimHei", "color": "#be7922", "centerY": 0, "centerX": 0, "bold": false, "align": "center" }, "compId": 1297 }], "loadList": [], "loadList3D": [] };
            battle.BattleGameOverUI = BattleGameOverUI;
            REG("ui.battle.BattleGameOverUI", BattleGameOverUI);
            class BattleGetGunUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleGetGunUI.uiView);
                }
            }
            BattleGetGunUI.uiView = { "type": "View", "props": { "y": -22, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 22, "x": 291, "width": 774, "scaleY": 0.9, "scaleX": 0.9, "height": 675 }, "compId": 1077, "child": [{ "type": "Image", "props": { "width": 774, "skin": "ui/img_uk_ui2_obj19.png", "height": 650 }, "compId": 1078 }, { "type": "Image", "props": { "y": 125, "x": 47, "width": 685, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 550, "alpha": 1 }, "compId": 1079 }, { "type": "Image", "props": { "y": 152, "x": 147, "width": 486, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "43,81,40,78", "height": 254, "alpha": 0.7 }, "compId": 1080 }, { "type": "Image", "props": { "y": 409, "x": 158, "width": 464, "skin": "ui/img_uk_ui2_obj13.png", "height": 169 }, "compId": 1081 }, { "type": "Image", "props": { "y": 284, "x": 182, "width": 416, "skin": "ui/img_uk_ui2_obj3.png", "height": 125 }, "compId": 1082 }, { "type": "Label", "props": { "y": 174, "x": 254, "wordWrap": false, "width": 271, "var": "txt_name", "valign": "middle", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1083 }, { "type": "Image", "props": { "y": 219, "x": 200, "var": "img_1", "skin": "ui/img_uk_icon_gunimg.png", "name": "img_1" }, "compId": 1084 }, { "type": "Box", "props": { "y": 578, "x": 163 }, "compId": 1085, "child": [{ "type": "Box", "props": { "y": 2, "var": "btn_ok", "name": "btn_ok" }, "compId": 1086, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 1087 }, { "type": "Label", "props": { "y": 11, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "关闭", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1088 }] }, { "type": "Box", "props": { "x": 233, "var": "btn_use", "name": "btn_use" }, "compId": 1089, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1090 }, { "type": "Label", "props": { "y": 10, "x": 60, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即使用", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1091 }, { "type": "Image", "props": { "y": 14, "x": 19, "width": 50, "skin": "ui/img_uk_ui2_guanggao2.png", "height": 50 }, "compId": 1092 }] }, { "type": "Box", "props": { "y": 0, "x": 233, "var": "btn_use1", "name": "btn_use1" }, "compId": 1093, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1094 }, { "type": "Label", "props": { "y": 10, "x": 40, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即使用", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1095 }] }] }, { "type": "Image", "props": { "y": 45, "x": 67, "skin": "ui/img_uk_text_gxhd.png" }, "compId": 1096 }, { "type": "Label", "props": { "y": 439, "x": 231, "wordWrap": true, "width": 128, "var": "txt_ctype", "text": "类型：步枪", "strokeColor": "#e26740", "stroke": 0, "name": "txt_ctype", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1097 }, { "type": "Label", "props": { "y": 439, "x": 429, "wordWrap": true, "width": 128, "var": "txt_quality", "text": "品质：良", "strokeColor": "#e26740", "stroke": 0, "name": "txt_quality", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1098 }, { "type": "Label", "props": { "y": 465, "x": 231, "wordWrap": true, "width": 128, "var": "txt_attStype", "text": "口径：7.62mm", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attStype", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1099 }, { "type": "Label", "props": { "y": 465, "x": 429, "wordWrap": true, "width": 128, "var": "txt_attBulletMax", "text": "弹容：25", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletMax", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1100 }, { "type": "Label", "props": { "y": 500, "x": 231, "wordWrap": true, "width": 128, "var": "txt_att", "text": "伤害：50", "strokeColor": "#e26740", "stroke": 0, "name": "txt_att", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1101 }, { "type": "Label", "props": { "y": 500, "x": 429, "wordWrap": true, "width": 128, "var": "txt_attCd", "text": "射速：20", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attCd", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1102 }, { "type": "Label", "props": { "y": 529, "x": 231, "wordWrap": true, "width": 128, "var": "txt_attAcc", "text": "精度：90", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attAcc", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1103 }, { "type": "Label", "props": { "y": 529, "x": 429, "wordWrap": true, "width": 128, "var": "txt_attBulletTime", "text": "换弹：10", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletTime", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1104 }] }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_ui2_obj3.png", "ui/img_uk_icon_gunimg.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao2.png", "ui/img_uk_text_gxhd.png"], "loadList3D": [] };
            battle.BattleGetGunUI = BattleGetGunUI;
            REG("ui.battle.BattleGetGunUI", BattleGetGunUI);
            class BattleGetVipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleGetVipUI.uiView);
                }
            }
            BattleGetVipUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": 250, "width": 774, "skin": "ui/img_uk_ui2_obj19.png", "height": 650 }, "compId": 1027 }, { "type": "Image", "props": { "y": 110, "x": 297, "width": 685, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 550, "alpha": 1 }, "compId": 876 }, { "type": "Box", "props": { "y": 544, "x": 413 }, "compId": 1032, "child": [{ "type": "Box", "props": { "y": 2, "var": "btn_close", "name": "btn_close" }, "compId": 937, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 918 }, { "type": "Label", "props": { "y": 11, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "残忍拒绝", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 919 }] }, { "type": "Box", "props": { "x": 233, "var": "btn_ok", "name": "btn_ok" }, "compId": 1023, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1024 }, { "type": "Label", "props": { "y": 11, "x": 59, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即领取", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1025 }, { "type": "Image", "props": { "y": 25, "x": 26, "width": 40, "skin": "ui/img_uk_ui2_guanggao3.png", "height": 30 }, "compId": 1119 }] }] }, { "type": "Label", "props": { "y": 664, "x": 405, "wordWrap": true, "width": 470, "valign": "middle", "text": "观看1个广告可领取奖励", "strokeColor": "#4f1904", "stroke": 2, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 1069 }, { "type": "Image", "props": { "y": 156, "x": 366, "width": 547, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "43,81,40,78", "height": 345, "alpha": 0.7 }, "compId": 1101 }, { "type": "Image", "props": { "y": 34, "x": 305, "width": 670, "skin": "ui/img_uk_text_vip.png", "height": 71 }, "compId": 1087 }, { "type": "Label", "props": { "y": 391, "x": 605, "wordWrap": true, "width": 66, "valign": "middle", "text": "x5", "strokeColor": "#4f1904", "stroke": 2, "height": 59, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1094 }, { "type": "Label", "props": { "y": 391, "x": 449, "wordWrap": true, "width": 66, "valign": "middle", "text": "x5", "strokeColor": "#4f1904", "stroke": 2, "height": 59, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1097 }, { "type": "Label", "props": { "y": 391, "x": 761, "wordWrap": true, "width": 66, "valign": "middle", "text": "x5", "strokeColor": "#4f1904", "stroke": 2, "height": 59, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1098 }, { "type": "Image", "props": { "y": 268, "x": 426, "skin": "ui/img_uk_ui2_obj4.png" }, "compId": 1109, "child": [{ "type": "Image", "props": { "y": -3, "x": -5, "width": 120, "skin": "ui/img_uk_icon_vip_skill1.png", "height": 120 }, "compId": 1112 }] }, { "type": "Image", "props": { "y": 268, "x": 583, "skin": "ui/img_uk_ui2_obj4.png" }, "compId": 1110, "child": [{ "type": "Image", "props": { "y": -3, "x": -5, "width": 120, "skin": "ui/img_uk_icon_vip_skill2.png", "height": 120 }, "compId": 1113 }] }, { "type": "Image", "props": { "y": 268, "x": 739, "skin": "ui/img_uk_ui2_obj4.png" }, "compId": 1111, "child": [{ "type": "Image", "props": { "y": -3, "x": -5, "width": 120, "skin": "ui/img_uk_icon_vip_skill3.png", "height": 120 }, "compId": 1114 }] }, { "type": "Label", "props": { "y": 197, "x": 407, "wordWrap": true, "width": 148, "valign": "middle", "text": "伤害增强", "strokeColor": "#4f1904", "stroke": 2, "height": 59, "fontSize": 30, "font": "SimHei", "color": "#ffdc51", "bold": false, "align": "center" }, "compId": 1116 }, { "type": "Label", "props": { "y": 197, "x": 564, "wordWrap": true, "width": 148, "valign": "middle", "text": "弹药补给", "strokeColor": "#4f1904", "stroke": 2, "height": 59, "fontSize": 30, "font": "SimHei", "color": "#ffdc51", "bold": false, "align": "center" }, "compId": 1117 }, { "type": "Label", "props": { "y": 197, "x": 720, "wordWrap": true, "width": 148, "valign": "middle", "text": "无敌状态", "strokeColor": "#4f1904", "stroke": 2, "height": 59, "fontSize": 30, "font": "SimHei", "color": "#ffdc51", "bold": false, "align": "center" }, "compId": 1118 }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_text_vip.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_icon_vip_skill1.png", "ui/img_uk_icon_vip_skill2.png", "ui/img_uk_icon_vip_skill3.png"], "loadList3D": [] };
            battle.BattleGetVipUI = BattleGetVipUI;
            REG("ui.battle.BattleGetVipUI", BattleGetVipUI);
            class BattleGoldGunBattleUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleGoldGunBattleUI.uiView);
                }
            }
            BattleGoldGunBattleUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 250, "mouseThrough": false, "mouseEnabled": true, "height": 160 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 7, "x": 13, "width": 223, "skin": "ui/img_uk_ui2_goldgun.png", "height": 145, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": 10, "x": 16, "width": 218, "skin": "ui/img_uk_ui2_goldguneffect.png", "height": 139, "blendMode": "lighter" }, "compId": 1015 }, { "type": "Image", "props": { "y": 19, "x": 16, "width": 106, "skin": "ui/img_uk_ui_new_ui33.png", "height": 24 }, "compId": 1016 }, { "type": "Image", "props": { "y": 20, "x": 16, "width": 90, "skin": "ui/img_uk_text_goldgun1.png", "height": 23 }, "compId": 1013 }, { "type": "Box", "props": { "y": 107, "x": 139, "width": 95, "height": 42 }, "compId": 1022, "child": [{ "type": "Image", "props": { "y": 3, "x": 6, "width": 82, "skin": "ui/img_uk_ui2_btn2.png", "height": 35 }, "compId": 1021 }, { "type": "Label", "props": { "y": 5, "x": 38, "wordWrap": true, "width": 40, "valign": "middle", "text": "免费", "strokeColor": "#563d16", "stroke": 4, "height": 33, "fontSize": 12, "font": "SimHei", "color": "#ffff64", "bold": false, "align": "center" }, "compId": 1023 }, { "type": "GoodsAd", "props": { "y": 3, "x": 13, "scaleY": 0.7, "scaleX": 0.7, "runtime": "ui.goods.GoodsAdUI" }, "compId": 1024 }] }, { "type": "Image", "props": { "y": 27, "x": 54, "width": 141, "skin": "ui/img_uk_Icon_goldgun2.png", "height": 106 }, "compId": 1025 }], "animations": [{ "nodes": [{ "target": 1015, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_goldgun.png", "ui/img_uk_ui2_goldguneffect.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_text_goldgun1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_Icon_goldgun2.png"], "loadList3D": [] };
            battle.BattleGoldGunBattleUI = BattleGoldGunBattleUI;
            REG("ui.battle.BattleGoldGunBattleUI", BattleGoldGunBattleUI);
            class BattleHeroCardUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHeroCardUI.uiView);
                }
            }
            BattleHeroCardUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 122, "scaleY": 0.6, "scaleX": 0.6, "mouseThrough": true, "height": 173 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "skin": "ui/img_UM_herohead_card.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "skin": "ui/img_ui_num_7.png" }, "compId": 1151 }, { "type": "Image", "props": { "y": 6, "x": 7, "skin": "ui/img_UM_ui_text9.png" }, "compId": 1152 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_ui_text9.png"], "loadList3D": [] };
            battle.BattleHeroCardUI = BattleHeroCardUI;
            REG("ui.battle.BattleHeroCardUI", BattleHeroCardUI);
            class BattleHeroCard2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHeroCard2UI.uiView);
                }
            }
            BattleHeroCard2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 122, "scaleY": 0.6, "scaleX": 0.6, "mouseThrough": true, "height": 170 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "skin": "ui/img_UM_herohead_card.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "skin": "ui/img_ui_num_7.png" }, "compId": 1151 }, { "type": "Image", "props": { "y": 6, "x": 7, "skin": "ui/img_UM_ui_text9.png" }, "compId": 1152 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_ui_text9.png"], "loadList3D": [] };
            battle.BattleHeroCard2UI = BattleHeroCard2UI;
            REG("ui.battle.BattleHeroCard2UI", BattleHeroCard2UI);
            class BattleHeroCard3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHeroCard3UI.uiView);
                }
            }
            BattleHeroCard3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 73, "scaleY": 0.35, "scaleX": 0.35, "mouseThrough": true, "height": 101 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "skin": "ui/img_UM_herohead_card.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "skin": "ui/img_ui_num_7.png" }, "compId": 1151 }, { "type": "Image", "props": { "y": 6, "x": 7, "skin": "ui/img_UM_ui_text9.png" }, "compId": 1152 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_ui_text9.png"], "loadList3D": [] };
            battle.BattleHeroCard3UI = BattleHeroCard3UI;
            REG("ui.battle.BattleHeroCard3UI", BattleHeroCard3UI);
            class BattleHeroCard4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHeroCard4UI.uiView);
                }
            }
            BattleHeroCard4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 183, "scaleY": 0.9, "scaleX": 0.9, "mouseThrough": false, "height": 316 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "skin": "ui/img_ui_num_7.png" }, "compId": 1151 }, { "type": "Image", "props": { "y": 280, "x": 4, "width": 193, "var": "img_battle", "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_battle", "mouseEnabled": true, "height": 72 }, "compId": 1153, "child": [{ "type": "Image", "props": { "y": 16, "x": 59, "skin": "ui/img_UM_ui_text7.png" }, "compId": 1154 }] }, { "type": "Label", "props": { "y": 4, "x": 10, "wordWrap": false, "width": 143, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 35, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1156 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text7.png"], "loadList3D": [] };
            battle.BattleHeroCard4UI = BattleHeroCard4UI;
            REG("ui.battle.BattleHeroCard4UI", BattleHeroCard4UI);
            class BattleHeroCardItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHeroCardItemUI.uiView);
                }
            }
            BattleHeroCardItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 0, "x": 162, "wordWrap": false, "width": 27, "visible": true, "var": "txt_lv", "text": "7", "strokeColor": "#272727", "stroke": 4, "name": "txt_lv", "height": 50, "fontSize": 60, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1155 }, { "type": "Label", "props": { "y": 246, "x": 11, "wordWrap": true, "width": 178, "var": "txt_airdrop", "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_airdrop", "height": 25, "fontSize": 25, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png"], "loadList3D": [] };
            battle.BattleHeroCardItemUI = BattleHeroCardItemUI;
            REG("ui.battle.BattleHeroCardItemUI", BattleHeroCardItemUI);
            class BattleHeroSkillIcoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHeroSkillIcoUI.uiView);
                }
            }
            BattleHeroSkillIcoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_btn_Skill3.png" }, "compId": 1174 }, { "type": "Image", "props": { "y": 25, "x": 25, "var": "img_bg", "skin": "ui/img_UM_btn_Skill.png", "name": "img_bg" }, "compId": 1172 }, { "type": "Image", "props": { "y": 40, "x": 40, "var": "img_bg2", "skin": "ui/img_UM_ui_skill icon1_1.png", "name": "img_bg2" }, "compId": 1173 }, { "type": "Image", "props": { "y": 0, "x": 0, "var": "img_skillCd", "skin": "ui/img_UM_btn_Skill3_1.png", "name": "img_skillCd" }, "compId": 1175 }], "animations": [{ "nodes": [{ "target": 1172, "keyframes": { "var": [{ "value": "img_bg", "tweenMethod": "linearNone", "tween": false, "target": 1172, "key": "var", "index": 0 }], "name": [{ "value": "img_bg", "tweenMethod": "linearNone", "tween": false, "target": 1172, "key": "name", "index": 0 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Skill3.png", "ui/img_UM_btn_Skill.png", "ui/img_UM_ui_skill icon1_1.png", "ui/img_UM_btn_Skill3_1.png"], "loadList3D": [] };
            battle.BattleHeroSkillIcoUI = BattleHeroSkillIcoUI;
            REG("ui.battle.BattleHeroSkillIcoUI", BattleHeroSkillIcoUI);
            class BattleHeroSkillIco2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHeroSkillIco2UI.uiView);
                }
            }
            BattleHeroSkillIco2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_btn_Skill.png" }, "compId": 1172 }, { "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_UM_ui_skill icon1_1.png" }, "compId": 1173 }], "loadList": ["ui/img_UM_btn_Skill.png", "ui/img_UM_ui_skill icon1_1.png"], "loadList3D": [] };
            battle.BattleHeroSkillIco2UI = BattleHeroSkillIco2UI;
            REG("ui.battle.BattleHeroSkillIco2UI", BattleHeroSkillIco2UI);
            class BattleHpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHpUI.uiView);
                }
            }
            BattleHpUI.uiView = { "type": "View", "props": { "width": 50, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -13, "x": -86, "skin": "ui/img_UM_ui_hpbarbg.png" }, "compId": 31 }, { "type": "Image", "props": { "y": -9, "x": -81, "var": "img_hp", "skin": "ui/img_UM_hp_2.png", "name": "img_hp" }, "compId": 32 }, { "type": "Image", "props": { "y": -29, "x": -112, "width": 45, "var": "img_lv", "skin": "ui/img_UM_Payload_HP_red.png", "name": "img_lv", "height": 45 }, "compId": 33 }, { "type": "Label", "props": { "y": -24, "x": -113, "wordWrap": true, "width": 47, "var": "txt_lv", "valign": "middle", "text": "9", "strokeColor": "#000000", "stroke": 4, "name": "txt_lv", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 37 }], "loadList": ["ui/img_UM_ui_hpbarbg.png", "ui/img_UM_hp_2.png", "ui/img_UM_Payload_HP_red.png"], "loadList3D": [] };
            battle.BattleHpUI = BattleHpUI;
            REG("ui.battle.BattleHpUI", BattleHpUI);
            class BattleHp2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHp2UI.uiView);
                }
            }
            BattleHp2UI.uiView = { "type": "View", "props": { "width": 50, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -11, "x": -80.5, "skin": "ui/img_UM_ui_hpbarbg.png" }, "compId": 31 }, { "type": "Image", "props": { "y": -11, "x": -79, "var": "img_hp", "skin": "ui/img_UM_hp_2.png", "name": "img_hp" }, "compId": 32 }, { "type": "Image", "props": { "y": -29, "x": -112, "width": 45, "var": "img_lv", "skin": "ui/img_UM_Payload_HP_red.png", "name": "img_lv", "height": 45 }, "compId": 33 }, { "type": "Label", "props": { "y": -24, "x": -113, "wordWrap": true, "width": 47, "var": "txt_lv", "valign": "middle", "text": "9", "strokeColor": "#000000", "stroke": 4, "name": "txt_lv", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 37 }], "loadList": ["ui/img_UM_ui_hpbarbg.png", "ui/img_UM_hp_2.png", "ui/img_UM_Payload_HP_red.png"], "loadList3D": [] };
            battle.BattleHp2UI = BattleHp2UI;
            REG("ui.battle.BattleHp2UI", BattleHp2UI);
            class BattleHpPillUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHpPillUI.uiView);
                }
            }
            BattleHpPillUI.uiView = { "type": "View", "props": { "width": 50, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -40, "width": 80, "var": "img_hp", "skin": "ui/img_UM_hp_p_1.png", "name": "img_hp", "height": 80 }, "compId": 40 }, { "type": "Image", "props": { "y": -20, "x": -20, "width": 40, "skin": "ui/img_UM_ui_battle_wg0.png", "height": 40 }, "compId": 44 }], "loadList": ["ui/img_UM_hp_p_1.png", "ui/img_UM_ui_battle_wg0.png"], "loadList3D": [] };
            battle.BattleHpPillUI = BattleHpPillUI;
            REG("ui.battle.BattleHpPillUI", BattleHpPillUI);
            class BattleHuXiAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleHuXiAnimUI.uiView);
                }
            }
            BattleHuXiAnimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 106, "x": 100, "width": 141, "skin": "ui/img_UM_herokill_bg_zi.png", "sizeGrid": "22,29,30,34", "pivotY": 103, "pivotX": 71, "height": 192, "blendMode": "lighter" }, "compId": 1249 }], "animations": [{ "nodes": [{ "target": 1249, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1249, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1249, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1249, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png"], "loadList3D": [] };
            battle.BattleHuXiAnimUI = BattleHuXiAnimUI;
            REG("ui.battle.BattleHuXiAnimUI", BattleHuXiAnimUI);
            class BattleInfoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleInfoUI.uiView);
                }
            }
            BattleInfoUI.uiView = { "type": "View", "props": { "width": 275, "height": 91 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 276, "skin": "ui/img_uj_ui_bg2.png", "height": 91, "alpha": 0.2 }, "compId": 4 }, { "type": "List", "props": { "y": 5, "x": 0, "width": 274, "var": "list_1", "vScrollBarSkin": "comp/vscroll.png", "name": "list_1", "height": 83 }, "compId": 9, "child": [{ "type": "BattleInfoItem", "props": { "y": -3, "x": 0, "width": 275, "renderType": "render", "height": 88, "runtime": "ui.battle.BattleInfoItemUI" }, "compId": 10 }] }, { "type": "Label", "props": { "y": 28, "x": 0, "wordWrap": false, "width": 274, "var": "txt_tip", "valign": "middle", "text": "因坠落而死", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_tip", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 11 }], "loadList": ["ui/img_uj_ui_bg2.png", "comp/vscroll.png"], "loadList3D": [] };
            battle.BattleInfoUI = BattleInfoUI;
            REG("ui.battle.BattleInfoUI", BattleInfoUI);
            class BattleInfoItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleInfoItemUI.uiView);
                }
            }
            BattleInfoItemUI.uiView = { "type": "View", "props": { "width": 275, "height": 88 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -2, "x": -1, "width": 118, "skin": "ui/img_UM_herokill_bg_red.png", "height": 64 }, "compId": 6 }, { "type": "Image", "props": { "y": -4, "x": 153, "skin": "ui/img_UM_herokill_bg_blue.png" }, "compId": 7 }, { "type": "Image", "props": { "y": 3, "x": 162, "var": "img_head1", "skin": "ui/img_UM_herohead_mini.png", "name": "img_head1" }, "compId": 8 }, { "type": "Image", "props": { "y": 5, "x": 8, "var": "img_head2", "skin": "ui/img_UM_herohead_mini.png", "name": "img_head2" }, "compId": 9 }, { "type": "Image", "props": { "y": 2, "x": 106, "width": 51, "skin": "ui/img_UM_herokillicon.png", "height": 51 }, "compId": 10 }, { "type": "Label", "props": { "y": 53, "x": 160, "wordWrap": false, "width": 108, "var": "txt_name1", "valign": "middle", "text": "英雄名称", "strokeColor": "#093d4e", "stroke": 4, "overflow": "hidden", "name": "txt_name1", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 11 }, { "type": "Label", "props": { "y": 55, "x": 4, "wordWrap": false, "width": 108, "var": "txt_name2", "valign": "middle", "text": "英雄名称", "strokeColor": "#4e091c", "stroke": 4, "overflow": "hidden", "name": "txt_name2", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 12 }], "loadList": ["ui/img_UM_herokill_bg_red.png", "ui/img_UM_herokill_bg_blue.png", "ui/img_UM_herohead_mini.png", "ui/img_UM_herokillicon.png"], "loadList3D": [] };
            battle.BattleInfoItemUI = BattleInfoItemUI;
            REG("ui.battle.BattleInfoItemUI", BattleInfoItemUI);
            class BattleInfoItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleInfoItem1UI.uiView);
                }
            }
            BattleInfoItem1UI.uiView = { "type": "View", "props": { "width": 275, "height": 88 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -2, "x": -2, "skin": "ui/img_UM_herokill_bg_red.png" }, "compId": 14 }, { "type": "Image", "props": { "y": 5, "x": 8, "width": 100, "var": "img_head2", "skin": "ui/img_UM_herohead_mini.png", "name": "img_head2", "height": 50 }, "compId": 15 }, { "type": "Label", "props": { "y": 55, "x": 4, "wordWrap": false, "width": 108, "var": "txt_name2", "valign": "middle", "text": "英雄名称", "strokeColor": "#4e091c", "stroke": 4, "overflow": "hidden", "name": "txt_name2", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 16 }, { "type": "Label", "props": { "y": 28, "x": 111, "wordWrap": false, "width": 149, "var": "txt_tip", "valign": "middle", "text": "因坠落而死", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_tip", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 17 }], "loadList": ["ui/img_UM_herokill_bg_red.png", "ui/img_UM_herohead_mini.png"], "loadList3D": [] };
            battle.BattleInfoItem1UI = BattleInfoItem1UI;
            REG("ui.battle.BattleInfoItem1UI", BattleInfoItem1UI);
            class BattleKillAnimItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleKillAnimItemUI.uiView);
                }
            }
            BattleKillAnimItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 314, "x": 100, "width": 116, "skin": "ui/img_UM_killConfirmed.png", "pivotY": 57, "pivotX": 58, "height": 113 }, "compId": 1142 }], "animations": [{ "nodes": [{ "target": 1142, "keyframes": { "y": [{ "value": 314, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "y", "index": 0 }, { "value": 314, "tweenMethod": "linearNone", "tween": true, "target": 1142, "label": null, "key": "y", "index": 9 }, { "value": 80, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "y", "index": 20 }], "scaleX": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 0 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 2 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 5 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 9 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "label": null, "key": "scaleX", "index": 15 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 2 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 9 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "label": null, "key": "alpha", "index": 11 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_killConfirmed.png"], "loadList3D": [] };
            battle.BattleKillAnimItemUI = BattleKillAnimItemUI;
            REG("ui.battle.BattleKillAnimItemUI", BattleKillAnimItemUI);
            class BattleKillInfoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleKillInfoUI.uiView);
                }
            }
            BattleKillInfoUI.uiView = { "type": "View", "props": { "width": 275, "height": 91 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 276, "skin": "ui/img_uj_ui_bg2.png", "height": 91, "alpha": 0.2 }, "compId": 4 }, { "type": "BattleInfoItem", "props": { "y": 2, "x": 0, "width": 275, "var": "ui_kill", "renderType": "render", "name": "ui_kill", "height": 88, "runtime": "ui.battle.BattleInfoItemUI" }, "compId": 10 }, { "type": "BattleInfoItem1", "props": { "y": 1, "x": 0, "var": "ui_fall", "name": "ui_fall", "runtime": "ui.battle.BattleInfoItem1UI" }, "compId": 12 }], "loadList": ["ui/img_uj_ui_bg2.png"], "loadList3D": [] };
            battle.BattleKillInfoUI = BattleKillInfoUI;
            REG("ui.battle.BattleKillInfoUI", BattleKillInfoUI);
            class BattleKillItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleKillItemUI.uiView);
                }
            }
            BattleKillItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "mouseEnabled": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 50, "x": 75, "width": 138, "var": "img_ico", "skin": "ui/img_uj_kill_1.png", "pivotY": 47, "pivotX": 69, "name": "img_ico", "height": 93 }, "compId": 435 }], "animations": [{ "nodes": [{ "target": 435, "keyframes": { "skewY": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "skewY", "index": 0 }], "skewX": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "skewX", "index": 0 }], "scaleY": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleY", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleY", "index": 2 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleY", "index": 3 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleY", "index": 5 }], "scaleX": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleX", "index": 2 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleX", "index": 3 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleX", "index": 5 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "alpha", "index": 28 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uj_kill_1.png"], "loadList3D": [] };
            battle.BattleKillItemUI = BattleKillItemUI;
            REG("ui.battle.BattleKillItemUI", BattleKillItemUI);
            class BattleKillSceItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleKillSceItemUI.uiView);
                }
            }
            BattleKillSceItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "mouseEnabled": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 50, "x": 75, "width": 138, "var": "img_ico", "skin": "ui/img_uk_Icon_miaosha.png", "pivotY": 47, "pivotX": 69, "name": "img_ico", "height": 93 }, "compId": 435 }], "animations": [{ "nodes": [{ "target": 435, "keyframes": { "skewY": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "skewY", "index": 0 }], "skewX": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "skewX", "index": 0 }], "scaleY": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleY", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleY", "index": 2 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleY", "index": 3 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleY", "index": 5 }], "scaleX": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "scaleX", "index": 2 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleX", "index": 3 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 435, "label": null, "key": "scaleX", "index": 5 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 435, "key": "alpha", "index": 28 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_Icon_miaosha.png"], "loadList3D": [] };
            battle.BattleKillSceItemUI = BattleKillSceItemUI;
            REG("ui.battle.BattleKillSceItemUI", BattleKillSceItemUI);
            class BattleKillTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleKillTipUI.uiView);
                }
            }
            BattleKillTipUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "BattleKillItem", "props": { "y": 180, "x": 565, "var": "ui_kill", "name": "ui_kill", "runtime": "ui.battle.BattleKillItemUI" }, "compId": 479 }, { "type": "Label", "props": { "y": 158, "x": 569, "wordWrap": true, "width": 142, "var": "txt_kill", "valign": "middle", "text": "击杀x4", "strokeColor": "#212121", "stroke": 4, "name": "txt_kill", "fontSize": 25, "font": "SimHei", "color": "#ff0400", "bold": false, "align": "center" }, "compId": 480 }, { "type": "BattleKillSceItem", "props": { "y": 180, "x": 565, "var": "ui_sceKill", "name": "ui_sceKill", "runtime": "ui.battle.BattleKillSceItemUI" }, "compId": 483 }], "loadList": [], "loadList3D": [] };
            battle.BattleKillTipUI = BattleKillTipUI;
            REG("ui.battle.BattleKillTipUI", BattleKillTipUI);
            class BattleKlllAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleKlllAnimUI.uiView);
                }
            }
            BattleKlllAnimUI.uiView = { "type": "View", "props": { "width": 100, "height": 100 }, "compId": 2, "child": [{ "type": "BattleKillAnimItem", "props": { "y": -444, "x": -100, "runtime": "ui.battle.BattleKillAnimItemUI" }, "compId": 3 }, { "type": "Image", "props": { "y": 79, "x": -60.5, "width": 121, "skin": "ui/img_UM_ui_defen_red.png", "sizeGrid": "23,23,23,23", "height": 61, "alpha": 0.5 }, "compId": 4 }, { "type": "Image", "props": { "y": 52, "x": 2, "width": 56, "skin": "ui/img_UM_CrownMVP.png", "pivotY": 28, "pivotX": 28, "height": 56 }, "compId": 5 }, { "type": "Label", "props": { "y": 74, "x": -60, "wordWrap": true, "width": 120, "var": "txt_soc", "valign": "middle", "text": "+25", "strokeColor": "#000000", "stroke": 0, "name": "txt_soc", "height": 60, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 6 }], "loadList": ["ui/img_UM_ui_defen_red.png", "ui/img_UM_CrownMVP.png"], "loadList3D": [] };
            battle.BattleKlllAnimUI = BattleKlllAnimUI;
            REG("ui.battle.BattleKlllAnimUI", BattleKlllAnimUI);
            class BattleLevModesUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleLevModesUI.uiView);
                }
            }
            BattleLevModesUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": -1, "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 576 }, { "type": "Image", "props": { "y": 58, "x": 380, "width": 522, "skin": "ui/img_uk_ui_new_ui33.png", "height": 42 }, "compId": 588 }, { "type": "Image", "props": { "y": 40, "x": 406, "var": "img_title", "skin": "ui/img_uk_text_sbtjcg.png", "name": "img_title" }, "compId": 589 }, { "type": "Box", "props": { "y": 503, "x": 530, "var": "btn_ok", "name": "btn_ok" }, "compId": 590, "child": [{ "type": "Image", "props": { "y": 23, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 591 }, { "type": "LotteryObj3", "props": { "y": 1, "x": -90, "scaleY": 0.6, "scaleX": 2, "runtime": "ui.lottery.LotteryObj3UI" }, "compId": 596 }, { "type": "Label", "props": { "y": 34, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "前往战场", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 592 }] }, { "type": "Box", "props": { "y": 24, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 578, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 593 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 594 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 595 }] }, { "type": "List", "props": { "y": 169, "x": 161, "width": 1064, "var": "list_lev", "scaleY": 0.9, "scaleX": 0.9, "name": "list_lev", "height": 360, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 597, "child": [{ "type": "BattleLevModesItem", "props": { "y": 0, "x": 0, "renderType": "render", "runtime": "ui.battle.BattleLevModesItemUI" }, "compId": 602 }] }, { "type": "Box", "props": { "y": 332, "x": 1106, "var": "medal_shop", "name": "medal_shop" }, "compId": 604, "child": [{ "type": "BattleMedalShop", "props": { "runtime": "ui.battle.BattleMedalShopUI" }, "compId": 608 }] }, { "type": "Box", "props": { "y": 164, "x": 1105, "var": "benefits", "name": "benefits" }, "compId": 606, "child": [{ "type": "PageBenefits", "props": { "runtime": "ui.page.PageBenefitsUI" }, "compId": 609 }, { "type": "PageIco", "props": { "y": 0, "x": 142, "var": "img_tt4", "name": "img_tt4", "runtime": "ui.page.PageIcoUI" }, "compId": 610 }] }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_text_sbtjcg.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png", "comp/hscroll.png"], "loadList3D": [] };
            battle.BattleLevModesUI = BattleLevModesUI;
            REG("ui.battle.BattleLevModesUI", BattleLevModesUI);
            class BattleLevModesItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleLevModesItemUI.uiView);
                }
            }
            BattleLevModesItemUI.uiView = { "type": "View", "props": { "width": 530, "height": 350 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 2, "var": "img_bg", "skin": "ui/img_uk_scenebg1.png", "name": "img_bg" }, "compId": 4 }, { "type": "Image", "props": { "y": 19, "x": 451, "skin": "ui/img_uk_icon_tl.png" }, "compId": 5 }, { "type": "Label", "props": { "y": 30, "x": 382, "wordWrap": true, "width": 65, "valign": "middle", "text": "20", "strokeColor": "#0f6200", "stroke": 5, "height": 41, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 6 }, { "type": "Clip", "props": { "y": 162, "x": 178, "width": 835, "var": "selectBox", "skin": "ui/clip_uk_ui2_uieffect_1.png", "pivotY": 259, "pivotX": 335, "name": "selectBox", "height": 524, "clipY": 2 }, "compId": 8 }, { "type": "Image", "props": { "y": 5, "x": 2, "var": "img_dis", "skin": "ui/img_uk_scenebg0.png", "name": "img_dis" }, "compId": 9 }], "loadList": ["ui/img_uk_scenebg1.png", "ui/img_uk_icon_tl.png", "ui/clip_uk_ui2_uieffect_1.png", "ui/img_uk_scenebg0.png"], "loadList3D": [] };
            battle.BattleLevModesItemUI = BattleLevModesItemUI;
            REG("ui.battle.BattleLevModesItemUI", BattleLevModesItemUI);
            class BattleLevReplaceUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleLevReplaceUI.uiView);
                }
            }
            BattleLevReplaceUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 140, "x": 333, "width": 614, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "67,69,81,59", "height": 506 }, "compId": 1019, "child": [{ "type": "Image", "props": { "y": -30, "x": 723, "width": 454, "skin": "ui/img_uk_ui2_obj19.png", "rotation": 90, "height": 826, "alpha": 0.6 }, "compId": 1024 }, { "type": "Image", "props": { "y": 39, "x": 49, "width": 516, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "20,17,16,17", "height": 314, "alpha": 0.8 }, "compId": 1073 }, { "type": "Image", "props": { "y": 234, "x": 274.5, "width": 83, "skin": "ui/img_uk_ui2_jiantou3.png", "rotation": -90, "height": 66 }, "compId": 1088 }, { "type": "Label", "props": { "y": 270, "x": -4, "wordWrap": true, "width": 348, "var": "txt_info_1", "valign": "middle", "text": "无敌状态30秒", "strokeColor": "#000000", "stroke": 0, "name": "txt_info_1", "height": 46, "fontSize": 22, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1148 }, { "type": "Image", "props": { "y": 138, "x": 114, "skin": "ui/img_uk_ui2_obj4.png" }, "compId": 1149 }, { "type": "Label", "props": { "y": 66, "x": -4, "wordWrap": true, "width": 348, "var": "txt_name_1", "valign": "middle", "text": "无敌状态（大）", "strokeColor": "#000000", "stroke": 0, "name": "txt_name_1", "height": 46, "fontSize": 28, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1150 }, { "type": "Label", "props": { "y": 270, "x": 264, "wordWrap": true, "width": 348, "var": "txt_info_2", "valign": "middle", "text": "无敌状态30秒", "strokeColor": "#000000", "stroke": 0, "name": "txt_info_2", "height": 46, "fontSize": 22, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1152 }, { "type": "Image", "props": { "y": 138, "x": 382, "skin": "ui/img_uk_ui2_obj4.png" }, "compId": 1153 }, { "type": "Label", "props": { "y": 66, "x": 264, "wordWrap": true, "width": 348, "var": "txt_name_2", "valign": "middle", "text": "无敌状态（大）", "strokeColor": "#000000", "stroke": 0, "name": "txt_name_2", "height": 46, "fontSize": 28, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1154 }, { "type": "Image", "props": { "y": 143, "x": 115, "width": 109, "var": "img_ico_1", "skin": "ui/img_uk_icon_vip_skill3.png", "name": "img_ico_1", "height": 107 }, "compId": 1157 }, { "type": "Image", "props": { "y": 143, "x": 384, "width": 109, "var": "img_ico_2", "skin": "ui/img_uk_icon_vip_skill3.png", "name": "img_ico_2", "height": 107 }, "compId": 1158 }] }, { "type": "Box", "props": { "y": 496, "x": 590, "var": "btn_ad", "name": "btn_ad" }, "compId": 1077, "child": [{ "type": "Image", "props": { "y": 29, "x": 73, "width": 243, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1078 }, { "type": "LotteryObj4", "props": { "y": 24, "x": -11, "scaleY": 0.5, "scaleX": 2, "runtime": "ui.lottery.LotteryObj4UI" }, "compId": 1079 }, { "type": "Label", "props": { "y": 40, "x": 148, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即领取", "strokeColor": "#0d7f36", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1080 }, { "type": "Image", "props": { "y": 54, "x": 113, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1081 }] }, { "type": "Box", "props": { "y": 501, "x": 379, "width": 258, "var": "btn_ok", "name": "btn_ok", "height": 114 }, "compId": 1082, "child": [{ "type": "Image", "props": { "y": 26.5, "x": 8.5, "width": 240, "skin": "ui/img_uk_ui2_btn1.png", "height": 80 }, "compId": 1083 }, { "type": "LotteryObj3", "props": { "y": 14, "x": -66, "scaleY": 0.5, "scaleX": 2, "runtime": "ui.lottery.LotteryObj3UI" }, "compId": 1084 }, { "type": "Label", "props": { "y": 37.5, "x": 59, "wordWrap": true, "width": 139, "valign": "middle", "text": "残忍拒绝", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1085 }] }, { "type": "Image", "props": { "y": 39, "x": 311, "skin": "ui/img_uk_text_kt2.png" }, "compId": 1087 }, { "type": "Label", "props": { "y": 640, "x": 472, "wordWrap": true, "width": 348, "valign": "middle", "text": "观看1个广告可领取奖励", "strokeColor": "#000000", "stroke": 0, "height": 46, "fontSize": 22, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1100 }], "loadList": ["ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_jiantou3.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_icon_vip_skill3.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_text_kt2.png"], "loadList3D": [] };
            battle.BattleLevReplaceUI = BattleLevReplaceUI;
            REG("ui.battle.BattleLevReplaceUI", BattleLevReplaceUI);
            class BattleLevSupplyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleLevSupplyUI.uiView);
                }
            }
            BattleLevSupplyUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 140, "x": 473 }, "compId": 1044, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 334, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "67,69,81,59", "height": 553 }, "compId": 1019, "child": [{ "type": "Image", "props": { "y": -43, "x": 395, "width": 454, "skin": "ui/img_uk_ui2_obj19.png", "rotation": 90, "height": 454, "alpha": 0.6 }, "compId": 1024 }, { "type": "Image", "props": { "y": 39, "x": 49, "width": 236, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "20,17,16,17", "height": 314, "alpha": 0.8 }, "compId": 1073 }, { "type": "Label", "props": { "y": 270, "x": -7, "wordWrap": true, "width": 348, "var": "txt_info", "valign": "middle", "text": "无敌状态30秒", "strokeColor": "#000000", "stroke": 0, "name": "txt_info", "height": 46, "fontSize": 22, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1101 }, { "type": "Image", "props": { "y": 138, "x": 112, "skin": "ui/img_uk_ui2_obj4.png" }, "compId": 1102 }, { "type": "Label", "props": { "y": 66, "x": -7, "wordWrap": true, "width": 348, "var": "txt_name", "valign": "middle", "text": "无敌状态（大）", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 46, "fontSize": 28, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1103 }, { "type": "Image", "props": { "y": 142, "x": 112, "width": 109, "var": "img_ico", "skin": "ui/img_uk_icon_vip_skill3.png", "name": "img_ico", "height": 108 }, "compId": 1105 }, { "type": "Image", "props": { "y": 106, "x": 106, "var": "img_gun", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_gun" }, "compId": 1108 }] }, { "type": "Image", "props": { "y": -40, "x": 275, "var": "img_close", "skin": "ui/img_uk_btn_X.png", "name": "img_close" }, "compId": 1109 }] }, { "type": "Image", "props": { "y": 45, "x": 405, "skin": "ui/img_uk_text_kt.png" }, "compId": 1072 }, { "type": "Box", "props": { "y": 563, "x": 445, "var": "btn_ad", "name": "btn_ad" }, "compId": 1077, "child": [{ "type": "Image", "props": { "y": 29, "x": 73, "width": 243, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1078 }, { "type": "LotteryObj4", "props": { "y": 24, "x": -11, "scaleY": 0.5, "scaleX": 2, "runtime": "ui.lottery.LotteryObj4UI" }, "compId": 1079 }, { "type": "Label", "props": { "y": 40, "x": 148, "wordWrap": true, "width": 139, "valign": "middle", "text": "换一批", "strokeColor": "#0d7f36", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1080 }, { "type": "Image", "props": { "y": 54, "x": 113, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1081 }] }, { "type": "Box", "props": { "y": 478, "x": 512, "width": 256, "var": "btn_ok", "name": "btn_ok", "height": 114 }, "compId": 1082, "child": [{ "type": "Image", "props": { "y": 26.5, "x": 8.5, "width": 240, "skin": "ui/img_uk_ui2_btn1.png", "height": 80 }, "compId": 1083 }, { "type": "LotteryObj3", "props": { "y": 14, "x": -66, "scaleY": 0.5, "scaleX": 2, "runtime": "ui.lottery.LotteryObj3UI" }, "compId": 1084 }, { "type": "Label", "props": { "y": 37.5, "x": 59, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即领取", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1085 }] }], "loadList": ["ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_icon_vip_skill3.png", "ui/img_uk_icon_gunicon.png", "ui/img_uk_btn_X.png", "ui/img_uk_text_kt.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_ui2_btn1.png"], "loadList3D": [] };
            battle.BattleLevSupplyUI = BattleLevSupplyUI;
            REG("ui.battle.BattleLevSupplyUI", BattleLevSupplyUI);
            class BattleLevUnlockUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleLevUnlockUI.uiView);
                }
            }
            BattleLevUnlockUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "centerX": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -72, "skin": "ui/img_uk_ui2_uibg2.jpg", "right": -100, "left": -100 }, "compId": 721 }, { "type": "Box", "props": { "y": 8, "width": 643, "left": 50, "height": 703 }, "compId": 672, "child": [{ "type": "Image", "props": { "skin": "ui/img_uk_ui2_obj19.png" }, "compId": 635 }, { "type": "Box", "props": { "y": 609.5, "x": 44, "var": "btn_close", "name": "btn_close" }, "compId": 636, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 268, "skin": "ui/img_uk_ui2_btn1.png", "height": 92 }, "compId": 641 }, { "type": "Label", "props": { "y": 17, "x": 63, "wordWrap": true, "width": 139, "valign": "middle", "text": "确定", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 33, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 642 }] }, { "type": "Box", "props": { "y": 608, "x": 333, "width": 266, "var": "btn_triple", "name": "btn_triple", "mouseEnabled": true, "height": 95 }, "compId": 637, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 268, "skin": "ui/img_uk_ui2_btn2.png", "height": 92 }, "compId": 643 }, { "type": "LotteryObj4", "props": { "y": -5, "x": -33, "scaleY": 0.5, "scaleX": 1.7, "runtime": "ui.lottery.LotteryObj4UI" }, "compId": 701 }, { "type": "Label", "props": { "y": 17, "x": 64.5, "wordWrap": true, "width": 139, "valign": "middle", "text": "前往挑战", "strokeColor": "#126c1a", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 644 }] }, { "type": "Image", "props": { "y": 24, "x": 223, "skin": "ui/img_uk_text_victory.png" }, "compId": 638 }, { "type": "Image", "props": { "y": 135, "x": 36, "width": 579, "skin": "ui/img_uk_ui2_obj13.png", "sizeGrid": "39,68,43,90", "height": 466 }, "compId": 639 }] }, { "type": "Box", "props": { "y": 533, "x": 173 }, "compId": 715, "child": [{ "type": "Label", "props": { "y": 4, "x": -31, "wordWrap": true, "width": 134, "valign": "middle", "text": "通关奖励：", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 708 }, { "type": "Label", "props": { "y": 4, "x": 116, "wordWrap": true, "width": 57, "var": "txt_expAll", "valign": "middle", "text": "50", "strokeColor": "#212121", "stroke": 4, "name": "txt_expAll", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 709 }, { "type": "Image", "props": { "y": 0, "x": 182, "width": 40, "skin": "ui/img_uk_icon_xz.png", "height": 40 }, "compId": 710 }, { "type": "Label", "props": { "y": 4, "x": 232, "wordWrap": true, "width": 57, "var": "txt_tongAll", "valign": "middle", "text": "500", "strokeColor": "#212121", "stroke": 4, "name": "txt_tongAll", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 711 }, { "type": "Image", "props": { "y": 6, "x": 295, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 712 }, { "type": "Image", "props": { "y": 6, "x": 401, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 713 }, { "type": "Label", "props": { "y": 4, "x": 339, "wordWrap": true, "width": 57, "var": "txt_jinAll", "valign": "middle", "text": "110", "strokeColor": "#212121", "stroke": 4, "name": "txt_jinAll", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 714 }] }, { "type": "Image", "props": { "y": 189.5, "x": 106, "width": 531, "skin": "ui/img_uk_ui2_uieffect.png", "height": 329 }, "compId": 718 }, { "type": "Image", "props": { "y": 160, "x": 43, "width": 650, "skin": "ui/img_uk_ui2_obj19.png", "height": 373 }, "compId": 720 }, { "type": "Image", "props": { "y": 256, "x": 209, "width": 325, "var": "img_difficult", "skin": "ui/img_uk_scenebg5_2.png", "name": "img_difficult", "height": 200 }, "compId": 719 }, { "type": "Image", "props": { "y": 170, "x": 195, "width": 40, "skin": "ui/img_uk_ui_new_ui39.png", "height": 40 }, "compId": 717 }, { "type": "Label", "props": { "y": 172, "x": 242, "wordWrap": true, "width": 362, "valign": "middle", "underline": false, "text": "恭喜解锁了更高难度的关卡", "strokeColor": "#212121", "stroke": 4, "italic": false, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 716 }], "loadList": ["ui/img_uk_ui2_uibg2.jpg", "ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_text_victory.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_icon_xz.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_ui2_uieffect.png", "ui/img_uk_scenebg5_2.png", "ui/img_uk_ui_new_ui39.png"], "loadList3D": [] };
            battle.BattleLevUnlockUI = BattleLevUnlockUI;
            REG("ui.battle.BattleLevUnlockUI", BattleLevUnlockUI);
            class BattleLoadUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleLoadUI.uiView);
                }
            }
            BattleLoadUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -8, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "height": 756 }, "compId": 501 }, { "type": "Box", "props": { "var": "box_no", "top": 40, "name": "box_no", "left": 20 }, "compId": 503, "child": [{ "type": "Image", "props": { "width": 169, "skin": "ui/img_UM_btn_red.png", "height": 89 }, "compId": 506 }, { "type": "Image", "props": { "y": 20, "x": 47, "skin": "ui/img_UM_ui_text1.png" }, "compId": 507 }] }, { "type": "Box", "props": { "y": 23, "width": 872, "height": 646, "centerX": 0 }, "compId": 508, "child": [{ "type": "Label", "props": { "y": 46, "x": 269, "wordWrap": true, "width": 338, "var": "txt_time", "text": "0", "strokeColor": "#390f3e", "name": "txt_time", "height": 57, "fontSize": 60, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 502 }, { "type": "Image", "props": { "y": 392, "x": 438, "width": 876, "skin": "ui/img_UM_SponsorWall2.png", "pivotY": 262, "pivotX": 438, "height": 505 }, "compId": 504 }, { "type": "Image", "props": { "x": 316, "skin": "ui/img_UM_ui_text13.png" }, "compId": 505 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_btn_red.png", "ui/img_UM_ui_text1.png", "ui/img_UM_SponsorWall2.png", "ui/img_UM_ui_text13.png"], "loadList3D": [] };
            battle.BattleLoadUI = BattleLoadUI;
            REG("ui.battle.BattleLoadUI", BattleLoadUI);
            class BattleMapUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapUI.uiView);
                }
            }
            BattleMapUI.uiView = { "type": "View", "props": { "width": 200, "height": 200 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 100, "x": 100, "var": "box_map", "name": "box_map" }, "compId": 3, "child": [{ "type": "Image", "props": { "y": -75, "x": -75, "width": 150, "skin": "ui/img_uk_ui_map.png", "height": 150 }, "compId": 4 }, { "type": "Label", "props": { "y": 69, "x": -1, "wordWrap": true, "text": "W", "strokeColor": "#000000", "stroke": 0, "rotation": 180, "fontSize": 20, "font": "Helvetica", "color": "#ffffff", "bold": true, "anchorY": 0.5, "anchorX": 0.5, "align": "center" }, "compId": 5 }, { "type": "Label", "props": { "y": -71, "x": -1, "wordWrap": true, "text": "E", "strokeColor": "#000000", "stroke": 0, "fontSize": 20, "font": "Helvetica", "color": "#ffffff", "bold": true, "anchorY": 0.5, "anchorX": 0.5, "align": "center" }, "compId": 6 }, { "type": "Label", "props": { "y": 1, "x": 70, "wordWrap": true, "text": "S", "strokeColor": "#000000", "stroke": 0, "rotation": -90, "fontSize": 20, "font": "Helvetica", "color": "#ffffff", "bold": true, "anchorY": 0.5, "anchorX": 0.5, "align": "center" }, "compId": 7 }, { "type": "Label", "props": { "y": 0, "x": -72, "wordWrap": true, "text": "N", "strokeColor": "#000000", "stroke": 0, "rotation": 90, "fontSize": 20, "font": "Helvetica", "color": "#ffffff", "bold": true, "anchorY": 0.5, "anchorX": 0.5, "align": "center" }, "compId": 8 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 0, "var": "box_role", "name": "box_role", "height": 0 }, "compId": 13 }] }], "loadList": ["ui/img_uk_ui_map.png"], "loadList3D": [] };
            battle.BattleMapUI = BattleMapUI;
            REG("ui.battle.BattleMapUI", BattleMapUI);
            class BattleMapItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapItemUI.uiView);
                }
            }
            BattleMapItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 350 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 10, "x": 12, "skin": "ui/img_UM_map_bg.png", "alpha": 0.4 }, "compId": 1147 }, { "type": "Image", "props": { "y": 154, "x": 20, "skin": "ui/img_UM_map_obj1.png" }, "compId": 1148 }, { "type": "Box", "props": { "y": 275, "x": 75, "alpha": 0.6 }, "compId": 1151, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_blue.png" }, "compId": 1149 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_blue_hp.png" }, "compId": 1150 }] }, { "type": "Box", "props": { "y": 225, "x": 25, "alpha": 0.6 }, "compId": 1152, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_blue.png" }, "compId": 1153 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_blue_hp.png" }, "compId": 1154 }] }, { "type": "Box", "props": { "y": 225, "x": 125, "alpha": 0.6 }, "compId": 1155, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_blue.png" }, "compId": 1156 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_blue_hp.png" }, "compId": 1157 }] }, { "type": "Box", "props": { "y": 77, "x": 25, "alpha": 0.6 }, "compId": 1158, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_red.png" }, "compId": 1159 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_red_hp.png" }, "compId": 1160 }] }, { "type": "Box", "props": { "y": 77, "x": 125, "alpha": 0.6 }, "compId": 1161, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_red.png" }, "compId": 1162 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_red_hp.png" }, "compId": 1163 }] }, { "type": "Box", "props": { "y": 27, "x": 75, "alpha": 0.6 }, "compId": 1164, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_red.png" }, "compId": 1165 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_red_hp.png" }, "compId": 1166 }] }, { "type": "Image", "props": { "y": 241.5, "x": 91.5, "skin": "ui/img_UM_map_player_blue.png" }, "compId": 1167 }, { "type": "Image", "props": { "y": 118.5, "x": 91.5, "skin": "ui/img_UM_map_player_red.png" }, "compId": 1169 }], "loadList": ["ui/img_UM_map_bg.png", "ui/img_UM_map_obj1.png", "ui/img_UM_map_tower_blue.png", "ui/img_UM_map_tower_blue_hp.png", "ui/img_UM_map_tower_red.png", "ui/img_UM_map_tower_red_hp.png", "ui/img_UM_map_player_blue.png", "ui/img_UM_map_player_red.png"], "loadList3D": [] };
            battle.BattleMapItemUI = BattleMapItemUI;
            REG("ui.battle.BattleMapItemUI", BattleMapItemUI);
            class BattleMapItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapItem1UI.uiView);
                }
            }
            BattleMapItem1UI.uiView = { "type": "View", "props": { "width": 17, "height": 17 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -8.5, "x": -8.5, "width": 17, "skin": "ui/img_UM_map_player_blue.png", "height": 17 }, "compId": 18 }], "loadList": ["ui/img_UM_map_player_blue.png"], "loadList3D": [] };
            battle.BattleMapItem1UI = BattleMapItem1UI;
            REG("ui.battle.BattleMapItem1UI", BattleMapItem1UI);
            class BattleMapItem2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapItem2UI.uiView);
                }
            }
            BattleMapItem2UI.uiView = { "type": "View", "props": { "width": 17, "height": 17 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -8.5, "x": -8.5, "width": 17, "skin": "ui/img_UM_map_player_red.png", "height": 17 }, "compId": 18 }], "loadList": ["ui/img_UM_map_player_red.png"], "loadList3D": [] };
            battle.BattleMapItem2UI = BattleMapItem2UI;
            REG("ui.battle.BattleMapItem2UI", BattleMapItem2UI);
            class BattleMapItem3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapItem3UI.uiView);
                }
            }
            BattleMapItem3UI.uiView = { "type": "View", "props": { "width": 17, "height": 17 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -8.5, "x": -8.5, "width": 17, "skin": "ui/img_UM_ui_lunpan.png", "height": 17 }, "compId": 18 }], "loadList": ["ui/img_UM_ui_lunpan.png"], "loadList3D": [] };
            battle.BattleMapItem3UI = BattleMapItem3UI;
            REG("ui.battle.BattleMapItem3UI", BattleMapItem3UI);
            class BattleMapPillItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapPillItem1UI.uiView);
                }
            }
            BattleMapPillItem1UI.uiView = { "type": "View", "props": { "width": 17, "height": 17 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -25, "x": -26, "var": "img_hp", "skin": "ui/img_UM_map_tower_blue_hp.png", "name": "img_hp" }, "compId": 20 }, { "type": "Image", "props": { "y": -13, "x": -14, "skin": "ui/img_UM_map_tower_blue.png" }, "compId": 19 }], "loadList": ["ui/img_UM_map_tower_blue_hp.png", "ui/img_UM_map_tower_blue.png"], "loadList3D": [] };
            battle.BattleMapPillItem1UI = BattleMapPillItem1UI;
            REG("ui.battle.BattleMapPillItem1UI", BattleMapPillItem1UI);
            class BattleMapPillItem2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapPillItem2UI.uiView);
                }
            }
            BattleMapPillItem2UI.uiView = { "type": "View", "props": { "width": 17, "height": 17 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -25, "x": -26, "var": "img_hp", "skin": "ui/img_UM_map_tower_red_hp.png", "name": "img_hp" }, "compId": 19 }, { "type": "Image", "props": { "y": -13, "x": -14, "skin": "ui/img_UM_map_tower_red.png" }, "compId": 20 }], "loadList": ["ui/img_UM_map_tower_red_hp.png", "ui/img_UM_map_tower_red.png"], "loadList3D": [] };
            battle.BattleMapPillItem2UI = BattleMapPillItem2UI;
            REG("ui.battle.BattleMapPillItem2UI", BattleMapPillItem2UI);
            class BattleMapsUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMapsUI.uiView);
                }
            }
            BattleMapsUI.uiView = { "type": "View", "props": { "width": 200, "height": 380 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 2, "x": 9, "width": 179, "var": "box_map", "name": "box_map", "height": 375 }, "compId": 3, "child": [{ "type": "Image", "props": { "y": -1, "x": 1, "width": 176, "skin": "ui/img_UM_map_bg.png", "height": 377, "alpha": 0.4 }, "compId": 16 }, { "type": "Image", "props": { "y": 168, "x": 16, "width": 145, "skin": "ui/img_UM_map_obj1.png", "height": 41 }, "compId": 17 }] }, { "type": "Box", "props": { "y": 190, "x": 98, "var": "box_role", "name": "box_role" }, "compId": 18 }], "loadList": ["ui/img_UM_map_bg.png", "ui/img_UM_map_obj1.png"], "loadList3D": [] };
            battle.BattleMapsUI = BattleMapsUI;
            REG("ui.battle.BattleMapsUI", BattleMapsUI);
            class BattleMatchUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMatchUI.uiView);
                }
            }
            BattleMatchUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": -100, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "height": 720 }, "compId": 1249 }, { "type": "BattleMatchAnim1", "props": { "y": 0, "width": 1280, "var": "ui_ani", "name": "ui_ani", "height": 720, "centerX": 0, "runtime": "ui.battle.BattleMatchAnim1UI" }, "compId": 1266 }], "loadList": ["ui/img_UM_ui_bg.jpg"], "loadList3D": [] };
            battle.BattleMatchUI = BattleMatchUI;
            REG("ui.battle.BattleMatchUI", BattleMatchUI);
            class BattleMatchAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMatchAnimUI.uiView);
                }
            }
            BattleMatchAnimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 800, "mouseThrough": true, "height": 300 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 150, "x": 400, "width": 609, "skin": "ui/img_uk_ui_vseffect.png", "scaleY": 1, "scaleX": 1, "pivotY": 102, "pivotX": 305, "height": 203, "blendMode": "lighter", "alpha": 0.7714285714285715 }, "compId": 626 }], "animations": [{ "nodes": [{ "target": 626, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "scaleY", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "scaleY", "index": 14 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "scaleX", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "scaleX", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "scaleX", "index": 14 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "key": "alpha", "index": 0 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 626, "key": "alpha", "index": 1 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "alpha", "index": 3 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "alpha", "index": 4 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "alpha", "index": 11 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "alpha", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 626, "label": null, "key": "alpha", "index": 14 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui_vseffect.png"], "loadList3D": [] };
            battle.BattleMatchAnimUI = BattleMatchAnimUI;
            REG("ui.battle.BattleMatchAnimUI", BattleMatchAnimUI);
            class BattleMatchAnim1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMatchAnim1UI.uiView);
                }
            }
            BattleMatchAnim1UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 365, "skin": "ui/img_UM_black.png", "scaleY": 0.2, "right": -150, "pivotY": 179, "pivotX": 740, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Box", "props": { "y": 360, "x": -300, "width": 559, "pivotY": 116, "pivotX": 280, "height": 231, "alpha": 0 }, "compId": 1225, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1207 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1218 }, { "type": "List", "props": { "y": 102, "x": 29, "width": 407, "var": "ui_list1", "spaceX": -120, "repeatY": 1, "repeatX": 5, "name": "ui_list1", "height": 105 }, "compId": 1210, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "width": 200, "scaleY": 0.35, "scaleX": 0.35, "renderType": "render", "height": 280, "runtime": "ui.goods.GoodsItemUI" }, "compId": 1268 }] }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1216 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": false, "width": 77, "var": "txt_num", "text": "100", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1219 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1220 }, { "type": "Label", "props": { "y": 33, "x": 92, "wordWrap": false, "width": 202, "var": "txt_name", "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1221 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1222 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "var": "txt_lv1", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_lv1", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1223 }, { "type": "Image", "props": { "y": 21, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1244 }, { "type": "Image", "props": { "y": 23, "x": 29, "width": 50, "var": "img_head", "skin": "ui/img_UM_playerhead.png", "name": "img_head", "height": 50 }, "compId": 1242 }] }, { "type": "Box", "props": { "y": 351, "x": 1580, "width": 559, "pivotY": 107, "pivotX": 280, "height": 231, "alpha": 0 }, "compId": 1226, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_red.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1227 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1228 }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1231 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": false, "width": 79, "var": "txt_num2", "text": "100", "strokeColor": "#000000", "stroke": 4, "name": "txt_num2", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1232 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1233 }, { "type": "Label", "props": { "y": 32, "x": 91, "wordWrap": false, "width": 199, "var": "txt_foeName", "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_foeName", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1234 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1235 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "var": "txt_lv2", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_lv2", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1236 }, { "type": "List", "props": { "y": 92, "x": 27, "width": 408, "var": "ui_list2", "spaceX": -120, "repeatY": 1, "repeatX": 5, "renderType": "render", "name": "ui_list2", "height": 92 }, "compId": 1240, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "scaleY": 0.35, "scaleX": 0.35, "renderType": "render", "runtime": "ui.goods.GoodsItemUI" }, "compId": 1267 }] }, { "type": "Image", "props": { "y": 20, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1245 }, { "type": "Image", "props": { "y": 22, "x": 29, "width": 50, "var": "img_head2", "skin": "ui/img_UM_playerhead.png", "name": "img_head2", "height": 50 }, "compId": 1243 }] }, { "type": "Image", "props": { "y": 360, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48, "alpha": 1 }, "compId": 1224 }, { "type": "Image", "props": { "y": 162, "x": 640, "width": 238, "skin": "ui/img_UM_Logo.png", "scaleX": 1, "pivotY": 93, "pivotX": 119, "height": 186, "alpha": 0 }, "compId": 1246 }, { "type": "Box", "props": { "y": 10, "x": 10, "width": 811, "visible": true, "centerX": 0 }, "compId": 1250, "child": [{ "type": "Box", "props": { "y": 539, "x": 296, "width": 219, "visible": false, "var": "btn_ok", "name": "btn_ok", "height": 121 }, "compId": 1251, "child": [{ "type": "Image", "props": { "y": 14, "x": 6, "width": 206, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "19,19,29,19", "height": 92 }, "compId": 1252 }, { "type": "Label", "props": { "y": 27, "x": 40, "wordWrap": true, "width": 139, "valign": "middle", "text": "进入战场", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1253 }] }] }], "animations": [{ "nodes": [{ "target": 1225, "keyframes": { "x": [{ "value": -300, "tweenMethod": "circOut", "tween": true, "target": 1225, "key": "x", "index": 0 }, { "value": 300, "tweenMethod": "linearNone", "tween": true, "target": 1225, "key": "x", "index": 7 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1225, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1225, "key": "alpha", "index": 7 }] } }, { "target": 1226, "keyframes": { "x": [{ "value": 1580, "tweenMethod": "circOut", "tween": true, "target": 1226, "key": "x", "index": 0 }, { "value": 978, "tweenMethod": "linearNone", "tween": true, "target": 1226, "key": "x", "index": 7 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1226, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1226, "key": "alpha", "index": 7 }] } }, { "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "cubicOut", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 4 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }], "alpha": [{ "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "alpha", "index": 0 }] } }, { "target": 1246, "keyframes": { "y": [{ "value": 162, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "y", "index": 0 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 7 }] } }, { "target": 1224, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 0 }] } }], "name": "ani_in", "id": 1, "frameRate": 24, "action": 0 }, { "nodes": [{ "target": 1225, "keyframes": { "x": [{ "value": 300, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "x", "index": 0 }, { "value": 300, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "x", "index": 5 }, { "value": -300, "tweenMethod": "circOut", "tween": true, "target": 1225, "label": null, "key": "x", "index": 10 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "alpha", "index": 10 }] } }, { "target": 1226, "keyframes": { "x": [{ "value": 978, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "x", "index": 0 }, { "value": 978, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "x", "index": 5 }, { "value": 1580, "tweenMethod": "circOut", "tween": true, "target": 1226, "label": null, "key": "x", "index": 10 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "alpha", "index": 10 }] } }, { "target": 1205, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "scaleY", "index": 5 }], "alpha": [{ "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "alpha", "index": 0 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "alpha", "index": 10 }] } }, { "target": 1246, "keyframes": { "y": [{ "value": 162, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "y", "index": 0 }, { "value": 162, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "y", "index": 5 }, { "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "y", "index": 10 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 10 }] } }, { "target": 1224, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1224, "label": null, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 10 }] } }], "name": "ani_out", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_xpicon.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_team_red.png", "ui/img_UM_vs.png", "ui/img_UM_Logo.png", "ui/img_UM_btn_BlueButton_2.png"], "loadList3D": [] };
            battle.BattleMatchAnim1UI = BattleMatchAnim1UI;
            REG("ui.battle.BattleMatchAnim1UI", BattleMatchAnim1UI);
            class BattleMatchItemUI extends Scene {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMatchItemUI.uiView);
                }
            }
            BattleMatchItemUI.uiView = { "type": "Scene", "props": { "width": 130, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 5, "width": 120, "skin": "ui/img_uk_player_headbg1.png", "sizeGrid": "16,16,16,16", "height": 120 }, "compId": 5 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 100, "var": "img_ico", "skin": "ui/img_uk_ui_morenhead.png", "name": "img_ico", "height": 100 }, "compId": 6 }, { "type": "Label", "props": { "y": 92, "x": 1, "wordWrap": true, "width": 128, "var": "txt_name", "strokeColor": "#3b3b3b", "stroke": 2, "name": "txt_name", "height": 29, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "alpha": 1, "align": "center" }, "compId": 4 }], "loadList": ["ui/img_uk_player_headbg1.png", "ui/img_uk_ui_morenhead.png"], "loadList3D": [] };
            battle.BattleMatchItemUI = BattleMatchItemUI;
            REG("ui.battle.BattleMatchItemUI", BattleMatchItemUI);
            class BattleMatchLevUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMatchLevUI.uiView);
                }
            }
            BattleMatchLevUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100, "height": 720 }, "compId": 641 }, { "type": "Box", "props": { "y": 0, "width": 811, "height": 715, "centerX": 0 }, "compId": 655, "child": [{ "type": "Image", "props": { "x": 38, "width": 723, "skin": "ui/img_uk_bg_Time.png", "sizeGrid": "0,191,0,177", "height": 96 }, "compId": 592 }, { "type": "Box", "props": { "y": 449, "x": 296, "width": 219, "var": "btn_ok", "name": "btn_ok", "height": 121 }, "compId": 656, "child": [{ "type": "Image", "props": { "y": 23, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 657 }, { "type": "LotteryObj3", "props": { "y": 1, "x": -90, "scaleY": 0.6, "scaleX": 2, "runtime": "ui.lottery.LotteryObj3UI" }, "compId": 658 }, { "type": "Label", "props": { "y": 34, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "进入战场", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 659 }] }, { "type": "Label", "props": { "y": 334, "x": 60, "wordWrap": true, "width": 690, "var": "txt_con", "valign": "middle", "text": "场景加载中...", "strokeColor": "#191919", "stroke": 4, "name": "txt_con", "height": 50, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 661 }] }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_bg_Time.png", "ui/img_uk_ui2_btn1.png"], "loadList3D": [] };
            battle.BattleMatchLevUI = BattleMatchLevUI;
            REG("ui.battle.BattleMatchLevUI", BattleMatchLevUI);
            class BattleMedalShopUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMedalShopUI.uiView);
                }
            }
            BattleMedalShopUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 180 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 15, "width": 149, "skin": "ui/img_uk_ui2_goldgun1.png", "height": 105, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": -11, "x": 3, "width": 173, "skin": "ui/img_uk_ui2_obj19.png", "height": 127, "blendMode": "lighter" }, "compId": 1015 }, { "type": "Image", "props": { "y": 9, "x": 15, "width": 97, "skin": "ui/img_uk_ui_new_ui33.png", "height": 24 }, "compId": 1016 }, { "type": "Image", "props": { "y": 9, "x": 19, "width": 89, "skin": "ui/img_uk_text_xzshop.png", "height": 22 }, "compId": 1029 }, { "type": "Image", "props": { "y": 3, "x": 26, "width": 135, "skin": "ui/img_uk_Icon_gunnew.png", "height": 106 }, "compId": 1030 }, { "type": "Box", "props": { "y": 90, "x": -14, "width": 305, "height": 110 }, "compId": 1031, "child": [{ "type": "Image", "props": { "y": 25, "x": 34, "width": 133, "skin": "ui/img_uk_ui2_btn1.png", "height": 38 }, "compId": 1032 }, { "type": "Label", "props": { "y": 15, "x": 31, "wordWrap": true, "width": 136, "valign": "middle", "text": "立即前往", "strokeColor": "#275f9c", "stroke": 4, "height": 56, "fontSize": 17, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1034 }] }], "animations": [{ "nodes": [{ "target": 1015, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_goldgun1.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_text_xzshop.png", "ui/img_uk_Icon_gunnew.png", "ui/img_uk_ui2_btn1.png"], "loadList3D": [] };
            battle.BattleMedalShopUI = BattleMedalShopUI;
            REG("ui.battle.BattleMedalShopUI", BattleMedalShopUI);
            class BattleModesUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleModesUI.uiView);
                }
            }
            BattleModesUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 576 }, { "type": "Box", "props": { "y": 40, "width": 1085, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 628, "centerX": 0 }, "compId": 577, "child": [{ "type": "Box", "props": { "y": 129, "x": 0, "var": "btn_1", "name": "btn_1" }, "compId": 580, "child": [{ "type": "Image", "props": { "x": 0, "skin": "ui/img_uk_scenebg1.png" }, "compId": 581 }, { "type": "Image", "props": { "y": 14, "x": 449, "skin": "ui/img_uk_icon_tl.png" }, "compId": 582 }, { "type": "Label", "props": { "y": 25, "x": 380, "wordWrap": true, "width": 65, "valign": "middle", "text": "5", "strokeColor": "#0f6200", "stroke": 5, "height": 41, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 583 }] }, { "type": "Box", "props": { "y": 129, "x": 560, "var": "btn_2", "name": "btn_2" }, "compId": 584, "child": [{ "type": "Image", "props": { "skin": "ui/img_uk_scenebg3.png" }, "compId": 585 }, { "type": "Image", "props": { "y": 8, "x": 455, "skin": "ui/img_uk_icon_tl.png" }, "compId": 586 }, { "type": "Label", "props": { "y": 20, "x": 385, "wordWrap": true, "width": 65, "valign": "middle", "text": "5", "strokeColor": "#0f6200", "stroke": 5, "height": 41, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 587 }] }, { "type": "Image", "props": { "y": 19, "x": 282, "width": 522, "skin": "ui/img_uk_ui_new_ui33.png", "height": 42 }, "compId": 588 }, { "type": "Image", "props": { "y": 1, "x": 308, "var": "img_title", "skin": "ui/img_uk_text_td.png", "name": "img_title" }, "compId": 589 }, { "type": "Box", "props": { "y": 464, "x": 432, "var": "btn_ok", "name": "btn_ok" }, "compId": 590, "child": [{ "type": "Image", "props": { "y": 23, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 591 }, { "type": "LotteryObj3", "props": { "y": 1, "x": -90, "scaleY": 0.6, "scaleX": 2, "runtime": "ui.lottery.LotteryObj3UI" }, "compId": 596 }, { "type": "Label", "props": { "y": 34, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "前往战场", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 592 }] }, { "type": "Image", "props": { "y": 121, "x": -3, "width": 656, "var": "img_select", "skin": "ui/img_uk_ui2_uieffect.png", "sizeGrid": "127,91,119,94", "pivotY": 92, "pivotX": 64, "name": "img_select", "height": 516 }, "compId": 579 }] }, { "type": "Box", "props": { "y": 25, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 578, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 593 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 594 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 595 }] }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_scenebg1.png", "ui/img_uk_icon_tl.png", "ui/img_uk_scenebg3.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_text_td.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_uieffect.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            battle.BattleModesUI = BattleModesUI;
            REG("ui.battle.BattleModesUI", BattleModesUI);
            class BattleMoveUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMoveUI.uiView);
                }
            }
            BattleMoveUI.uiView = { "type": "View", "props": { "width": 500, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 539, "x": 150, "width": 210, "var": "btn_dir_bg", "skin": "ui/img_UM_lunpan.png", "pivotY": 105, "pivotX": 105, "name": "btn_dir_bg", "height": 210 }, "compId": 12 }, { "type": "Image", "props": { "y": 539, "x": 151, "width": 85, "var": "btn_dir", "skin": "ui/img_UM_lunpan_btn.png", "pivotY": 43, "pivotX": 43, "name": "btn_dir", "height": 85 }, "compId": 13 }, { "type": "Image", "props": { "y": 371, "x": 93, "width": 100, "var": "btn_att", "skin": "ui/img_UM_lunpan_btn3.png", "rotation": -270, "pivotY": 50, "pivotX": 50, "name": "btn_att", "height": 100 }, "compId": 17 }], "loadList": ["ui/img_UM_lunpan.png", "ui/img_UM_lunpan_btn.png", "ui/img_UM_lunpan_btn3.png"], "loadList3D": [] };
            battle.BattleMoveUI = BattleMoveUI;
            REG("ui.battle.BattleMoveUI", BattleMoveUI);
            class BattleMysteryBoxUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleMysteryBoxUI.uiView);
                }
            }
            BattleMysteryBoxUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "centerX": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 249.5, "x": 115, "width": 265, "skin": "ui/img_uk_ui2_obj13.png", "height": 145 }, "compId": 1008 }, { "type": "Image", "props": { "y": 205, "x": 158, "width": 174, "var": "btn_close", "skin": "ui/img_uk_text_bldj.png", "name": "btn_close", "height": 44 }, "compId": 1009 }, { "type": "Image", "props": { "y": 245, "x": 170, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico" }, "compId": 1010 }, { "type": "Label", "props": { "y": 254, "x": 118, "wordWrap": true, "width": 111, "var": "txt_name", "valign": "middle", "text": "AK-47", "strokeColor": "#275f9c", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1018 }, { "type": "Box", "props": { "y": 407, "x": 840, "width": 300, "var": "btn_ok", "name": "btn_ok", "height": 138 }, "compId": 1016, "child": [{ "type": "BattleBtn", "props": { "y": 0, "runtime": "ui.battle.BattleBtnUI" }, "compId": 1011 }] }, { "type": "Image", "props": { "y": 297, "x": 579, "width": 349, "skin": "ui/img_uk_ui2_obj19.png", "pivotY": 114, "pivotX": 114, "height": 349 }, "compId": 997 }, { "type": "Image", "props": { "y": 195, "x": 475, "width": 330, "skin": "ui/img_uk_icon_box4.png", "height": 330 }, "compId": 1002 }, { "type": "Image", "props": { "y": 322, "x": 640, "width": 330, "skin": "ui/img_uk_icon_boxopen4.png", "pivotY": 165, "pivotX": 165, "height": 330 }, "compId": 1001 }, { "type": "Image", "props": { "y": 212, "x": 639, "width": 524, "skin": "ui/img_uk_ui_jlsbox_openEffect.png", "scaleX": -1, "pivotY": 145, "pivotX": 262, "height": 290, "blendMode": "lighter" }, "compId": 1003 }, { "type": "Image", "props": { "y": 52, "x": 390, "width": 500, "skin": "ui/img_uk_ui_obj.png", "height": 56 }, "compId": 1014 }, { "type": "Image", "props": { "y": 31, "x": 483, "skin": "ui/img_uk_text_smbx.png" }, "compId": 1013 }, { "type": "Image", "props": { "y": 525, "x": 440, "width": 400, "skin": "ui/img_uk_ui2_obj6.png", "sizeGrid": "5,5,5,5", "height": 20 }, "compId": 1005 }, { "type": "Image", "props": { "y": 530, "x": 445, "width": 390, "var": "bar_num", "skin": "ui/img_uk_ui2_obj7.png", "sizeGrid": "2,2,2,2", "name": "bar_num", "height": 10 }, "compId": 1006 }, { "type": "Label", "props": { "y": 521, "x": 553, "wordWrap": true, "width": 173, "var": "txt_num", "text": "0%", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1007 }], "animations": [{ "nodes": [{ "target": 1003, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleY", "index": 18 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleX", "index": 18 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 12 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 18 }] } }, { "target": 1001, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleY", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleY", "index": 14 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleY", "index": 16 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleX", "index": 14 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleX", "index": 16 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "alpha", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "alpha", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "label": null, "key": "alpha", "index": 16 }] } }, { "target": 1002, "keyframes": { "y": [{ "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "y", "index": 0 }, { "value": 190, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "y", "index": 1 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 2 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 3 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 4 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 5 }, { "value": 190, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 6 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 7 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 8 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 9 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 10 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 12 }], "x": [{ "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "x", "index": 0 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 2 }, { "value": 470, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 3 }, { "value": 480, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 4 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 5 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 7 }, { "value": 470, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 8 }, { "value": 480, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 9 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 10 }, { "value": 480, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 12 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "alpha", "index": 11 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "alpha", "index": 12 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_ui2_obj13.png", "ui/img_uk_text_bldj.png", "ui/img_uk_icon_gunicon.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_box4.png", "ui/img_uk_icon_boxopen4.png", "ui/img_uk_ui_jlsbox_openEffect.png", "ui/img_uk_ui_obj.png", "ui/img_uk_text_smbx.png", "ui/img_uk_ui2_obj6.png", "ui/img_uk_ui2_obj7.png"], "loadList3D": [] };
            battle.BattleMysteryBoxUI = BattleMysteryBoxUI;
            REG("ui.battle.BattleMysteryBoxUI", BattleMysteryBoxUI);
            class BattleNpcStateUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleNpcStateUI.uiView);
                }
            }
            BattleNpcStateUI.uiView = { "type": "View", "props": { "width": 40, "height": 47 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -4, "x": -3, "width": 46, "var": "img_bg", "skin": "ui/img_UM_herokill_bg_blue.png", "name": "img_bg", "height": 56 }, "compId": 24 }, { "type": "Image", "props": { "y": 1, "x": 1, "width": 38, "var": "img_npc", "skin": "ui/img_UM_ui_herohead.png", "name": "img_npc", "height": 45 }, "compId": 19 }, { "type": "Image", "props": { "y": -1, "x": -1, "width": 42, "var": "img_bg2", "skin": "ui/img_UM_black.png", "name": "img_bg2", "height": 48, "alpha": 0.8 }, "compId": 25 }, { "type": "Label", "props": { "y": 14, "x": 10, "wordWrap": true, "width": 20, "visible": true, "var": "txt_time", "valign": "middle", "text": "0s", "strokeColor": "#000000", "stroke": 3, "name": "txt_time", "height": 20, "fontSize": 15, "font": "Helvetica", "color": "#d3e80d", "bold": true, "align": "center" }, "compId": 21 }], "loadList": ["ui/img_UM_herokill_bg_blue.png", "ui/img_UM_ui_herohead.png", "ui/img_UM_black.png"], "loadList3D": [] };
            battle.BattleNpcStateUI = BattleNpcStateUI;
            REG("ui.battle.BattleNpcStateUI", BattleNpcStateUI);
            class BattleReadyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleReadyUI.uiView);
                }
            }
            BattleReadyUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 529 }, { "type": "Box", "props": { "y": 0, "x": 0, "var": "box_scene", "name": "box_scene" }, "compId": 609 }, { "type": "Box", "props": { "y": 25, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 531, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 597 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 598 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 599 }] }, { "type": "Box", "props": { "y": 26, "right": 30 }, "compId": 610, "child": [{ "type": "Image", "props": { "width": 520, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 678, "alpha": 1 }, "compId": 532 }, { "type": "Image", "props": { "y": 331, "x": 12, "width": 500, "skin": "ui/img_uk_ui2_btn3.png", "sizeGrid": "17,53,14,55", "height": 41, "alpha": 0.7 }, "compId": 533 }, { "type": "Label", "props": { "y": 338, "x": 57, "wordWrap": true, "width": 236, "text": "当前装备", "strokeColor": "#363636", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 534 }, { "type": "Box", "props": { "y": 550, "x": 150, "var": "btn_ok", "name": "btn_ok" }, "compId": 535, "child": [{ "type": "Image", "props": { "y": 23, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 536 }, { "type": "LotteryObj3", "props": { "y": -1, "x": -93, "scaleY": 0.6, "scaleX": 2, "runtime": "ui.lottery.LotteryObj3UI" }, "compId": 626 }, { "type": "Label", "props": { "y": 34, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "开始战斗", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 537 }] }, { "type": "Image", "props": { "y": 12, "x": 12, "width": 500, "skin": "ui/img_uk_ui2_btn3.png", "sizeGrid": "17,53,14,55", "height": 41, "alpha": 0.7 }, "compId": 538 }, { "type": "Label", "props": { "y": 16, "x": 62, "wordWrap": true, "width": 262, "valign": "middle", "text": "推荐组合", "strokeColor": "#252534", "stroke": 4, "height": 31, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 539 }, { "type": "GoodsItem2", "props": { "y": 363, "x": 15, "var": "item_goods1", "name": "item_goods1", "runtime": "ui.goods.GoodsItem2UI" }, "compId": 516 }, { "type": "GoodsItem2", "props": { "y": 365, "x": 177, "var": "item_goods2", "name": "item_goods2", "runtime": "ui.goods.GoodsItem2UI" }, "compId": 517 }, { "type": "GoodsItem2", "props": { "y": 365, "x": 339, "var": "item_goods3", "name": "item_goods3", "runtime": "ui.goods.GoodsItem2UI" }, "compId": 518 }, { "type": "Box", "props": { "y": 234, "x": 24, "var": "btn_trial", "name": "btn_trial" }, "compId": 627, "child": [{ "type": "Image", "props": { "width": 145, "skin": "ui/img_uk_ui2_btn2.png", "height": 52 }, "compId": 623 }, { "type": "Label", "props": { "y": 13, "x": 68, "wordWrap": true, "width": 50, "text": "试用", "strokeColor": "#154e0e", "stroke": 4, "height": 27, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 617 }, { "type": "Image", "props": { "y": 10, "x": 22, "width": 40, "skin": "ui/img_uk_ui2_guanggao3.png", "height": 30 }, "compId": 639 }] }, { "type": "Box", "props": { "y": 234, "x": 185, "var": "btn_trial2" }, "compId": 628, "child": [{ "type": "Image", "props": { "width": 145, "skin": "ui/img_uk_ui2_btn2.png", "height": 52 }, "compId": 624 }, { "type": "Label", "props": { "y": 13, "x": 68, "wordWrap": true, "width": 50, "text": "试用", "strokeColor": "#154e0e", "stroke": 4, "height": 27, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 619 }, { "type": "Image", "props": { "y": 10, "x": 22, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 640 }] }, { "type": "Box", "props": { "y": 234, "x": 350, "var": "btn_trial3", "name": "btn_trial3" }, "compId": 629, "child": [{ "type": "Image", "props": { "width": 145, "skin": "ui/img_uk_ui2_btn2.png", "height": 52 }, "compId": 625 }, { "type": "Label", "props": { "y": 13, "x": 68, "wordWrap": true, "width": 50, "text": "试用", "strokeColor": "#154e0e", "stroke": 4, "height": 27, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 621 }, { "type": "Image", "props": { "y": 10, "x": 22, "width": 40, "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 641 }] }, { "type": "Box", "props": { "y": 61, "x": 17, "var": "img_bg", "name": "img_bg" }, "compId": 630, "child": [{ "type": "GoodsItem3", "props": { "var": "item_ad1", "name": "item_ad1", "runtime": "ui.goods.GoodsItem3UI" }, "compId": 614 }, { "type": "GoodsItem3", "props": { "x": 163, "var": "item_ad2", "name": "item_ad2", "runtime": "ui.goods.GoodsItem3UI" }, "compId": 615 }, { "type": "GoodsItem3", "props": { "x": 326, "var": "item_ad3", "name": "item_ad3", "runtime": "ui.goods.GoodsItem3UI" }, "compId": 616 }] }] }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_btn3.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleReadyUI = BattleReadyUI;
            REG("ui.battle.BattleReadyUI", BattleReadyUI);
            class BattleRebornHeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleRebornHeroUI.uiView);
                }
            }
            BattleRebornHeroUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "skin": "ui/img_UM_ui_bg6.jpg", "right": -100, "left": -100, "height": 720, "alpha": 1 }, "compId": 1178 }, { "type": "BattleMapItem", "props": { "top": 10, "scaleY": 0.7, "scaleX": 0.7, "left": 10, "runtime": "ui.battle.BattleMapItemUI" }, "compId": 1268 }, { "type": "Box", "props": { "y": 13, "centerX": 0 }, "compId": 1267, "child": [{ "type": "Image", "props": { "y": 137, "width": 983, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "50,50,70,50", "scaleY": 1, "scaleX": 1, "height": 429 }, "compId": 1151 }, { "type": "Image", "props": { "y": 159, "x": 19, "width": 946, "skin": "ui/img_UM_card_bg.png", "height": 50 }, "compId": 1153 }, { "type": "Image", "props": { "y": 164, "x": 34, "skin": "ui/img_UM_ui_text8.png" }, "compId": 1166 }, { "type": "Box", "props": { "x": 230 }, "compId": 1249, "child": [{ "type": "Image", "props": { "y": 6, "x": 209, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 1238 }, { "type": "Image", "props": { "x": 239, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 1239 }, { "type": "Label", "props": { "y": 36, "x": 208, "wordWrap": true, "width": 108, "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 1240 }, { "type": "Box", "props": { "y": 17 }, "compId": 1241, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1243 }, { "type": "Image", "props": { "y": 3, "x": 5, "width": 326, "skin": "ui/img_UM_progressbar_blue2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1244 }, { "type": "Label", "props": { "y": 4, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1245 }] }, { "type": "Box", "props": { "y": 19, "x": 317 }, "compId": 1242, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1246 }, { "type": "Image", "props": { "y": 3, "x": 3, "width": 331, "skin": "ui/img_UM_progressbar_red2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1247 }, { "type": "Label", "props": { "y": 5, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1248 }] }] }, { "type": "List", "props": { "y": 217, "x": 16, "width": 933, "var": "list_card", "spaceX": 10, "name": "list_card", "height": 316 }, "compId": 1254, "child": [{ "type": "BattleHeroCard4", "props": { "renderType": "render", "runtime": "ui.battle.BattleHeroCard4UI" }, "compId": 1265 }] }] }], "loadList": ["ui/img_UM_ui_bg6.jpg", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_card_bg.png", "ui/img_UM_ui_text8.png", "ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_progressbar_blue2_1.png", "ui/img_UM_progressbar_blue2.png", "ui/img_UM_progressbar_red2.png"], "loadList3D": [] };
            battle.BattleRebornHeroUI = BattleRebornHeroUI;
            REG("ui.battle.BattleRebornHeroUI", BattleRebornHeroUI);
            class BattleRecordUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleRecordUI.uiView);
                }
            }
            BattleRecordUI.uiView = { "type": "View", "props": { "width": 225, "height": 146 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": 3, "width": 219, "skin": "ui/img_UM_map_bg.png", "sizeGrid": "28,38,28,38", "height": 143, "alpha": 0.4 }, "compId": 16 }, { "type": "Label", "props": { "y": 19, "x": 19, "wordWrap": false, "width": 117, "visible": true, "valign": "middle", "text": "【我的战绩】", "strokeColor": "#000000", "stroke": 3, "height": 27, "fontSize": 20, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "left" }, "compId": 21 }, { "type": "Box", "props": { "y": 56, "x": 19 }, "compId": 25, "child": [{ "type": "Label", "props": { "y": 4, "wordWrap": false, "width": 87, "visible": true, "valign": "middle", "text": "当前击杀", "strokeColor": "#000000", "stroke": 3, "height": 27, "fontSize": 20, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "left" }, "compId": 22 }, { "type": "Label", "props": { "y": 0, "x": 86, "wordWrap": false, "width": 29, "visible": true, "var": "txt_kill_1", "valign": "middle", "text": "1", "strokeColor": "#000000", "stroke": 3, "name": "txt_kill_1", "height": 35, "fontSize": 25, "font": "SimHei", "color": "#ff634e", "bold": true, "align": "center" }, "compId": 23 }, { "type": "Label", "props": { "y": 4, "x": 117, "wordWrap": false, "width": 87, "visible": true, "valign": "middle", "text": "人", "strokeColor": "#000000", "stroke": 3, "height": 27, "fontSize": 20, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "left" }, "compId": 24 }] }, { "type": "Box", "props": { "y": 96, "x": 19, "var": "box_next", "name": "box_next" }, "compId": 29, "child": [{ "type": "Label", "props": { "y": 4, "wordWrap": false, "width": 117, "visible": true, "var": "txt_info", "valign": "middle", "text": "下个目标:击杀", "strokeColor": "#000000", "stroke": 3, "name": "txt_info", "height": 27, "fontSize": 20, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "left" }, "compId": 26 }, { "type": "Label", "props": { "y": 0, "x": 132, "wordWrap": false, "width": 30, "visible": true, "var": "txt_kill_2", "valign": "middle", "text": "15", "strokeColor": "#000000", "stroke": 3, "name": "txt_kill_2", "height": 35, "fontSize": 25, "font": "SimHei", "color": "#ff634e", "bold": true, "align": "center" }, "compId": 27 }, { "type": "Label", "props": { "y": 4, "x": 166, "wordWrap": false, "width": 87, "visible": true, "var": "txt_info1", "valign": "middle", "text": "人", "strokeColor": "#000000", "stroke": 3, "name": "txt_info1", "height": 27, "fontSize": 20, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "left" }, "compId": 28 }] }], "loadList": ["ui/img_UM_map_bg.png"], "loadList3D": [] };
            battle.BattleRecordUI = BattleRecordUI;
            REG("ui.battle.BattleRecordUI", BattleRecordUI);
            class BattleReloadUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleReloadUI.uiView);
                }
            }
            BattleReloadUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 60, "mouseThrough": true, "height": 60, "centerY": 0, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 30, "width": 60, "var": "img_time", "skin": "ui/img_uj_icon_cd.png", "pivotY": 30, "pivotX": 30, "name": "img_time", "height": 60 }, "compId": 357 }, { "type": "Label", "props": { "y": 19, "x": -2, "wordWrap": true, "width": 63, "var": "txt_time", "valign": "middle", "text": "6.0s", "strokeColor": "#212121", "stroke": 4, "name": "txt_time", "height": 22, "fontSize": 16, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 358 }], "loadList": ["ui/img_uj_icon_cd.png"], "loadList3D": [] };
            battle.BattleReloadUI = BattleReloadUI;
            REG("ui.battle.BattleReloadUI", BattleReloadUI);
            class BattleResurrecUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleResurrecUI.uiView);
                }
            }
            BattleResurrecUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 233, "x": 433, "width": 1713, "skin": "ui/img_uk_ui_new_ui38.png", "sizeGrid": "9,8,10,9", "pivotY": 111, "pivotX": 650, "height": 161, "alpha": 0.6 }, "compId": 455 }, { "type": "Box", "props": { "y": 152, "visible": false, "height": 35, "centerX": 0 }, "compId": 456, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 95, "valign": "middle", "text": "你已被", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 458 }, { "type": "Label", "props": { "y": 0, "x": 302, "wordWrap": true, "width": 70, "valign": "middle", "text": "击败", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 460 }] }, { "type": "Box", "props": { "y": 325, "width": 296, "height": 182, "centerX": 3 }, "compId": 457, "child": [{ "type": "Label", "props": { "y": 109, "x": 2, "wordWrap": true, "width": 49, "var": "txt_time", "valign": "middle", "text": "5", "strokeColor": "#212121", "stroke": 4, "name": "txt_time", "height": 48, "fontSize": 50, "font": "SimHei", "color": "#e7e4da", "bold": false, "align": "center" }, "compId": 462 }, { "type": "Image", "props": { "y": 50, "x": 26, "width": 204, "skin": "ui/img_UM_ui_text4.png", "height": 44 }, "compId": 483 }, { "type": "Image", "props": { "y": 105, "x": 42, "skin": "ui/img_UM_ui_text5.png" }, "compId": 484 }] }, { "type": "Box", "props": { "y": 392, "x": 506, "visible": false, "var": "btn_ok", "name": "btn_ok" }, "compId": 464, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 268, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "17,20,32,20", "height": 92 }, "compId": 465 }, { "type": "Label", "props": { "y": 13, "x": 64, "wordWrap": true, "width": 139, "valign": "middle", "text": "复活", "strokeColor": "#9c4727", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 466 }] }, { "type": "Box", "props": { "y": 393, "x": 506, "width": 271, "visible": false, "var": "btn_ad", "name": "btn_ad", "height": 85 }, "compId": 467, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 268, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "19,19,29,19", "height": 92 }, "compId": 468 }, { "type": "Label", "props": { "y": 10, "x": 64, "wordWrap": true, "width": 139, "valign": "middle", "text": "复活", "strokeColor": "#9c3027", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 469 }, { "type": "Image", "props": { "y": -5, "x": 7, "var": "img_video", "skin": "ui/img_uk_ui2_guanggao2.png", "name": "img_video" }, "compId": 470 }] }, { "type": "Box", "props": { "y": 497, "x": 506, "visible": false, "var": "btn_no", "name": "btn_no" }, "compId": 471, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 268, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "19,19,29,19", "height": 92 }, "compId": 472 }, { "type": "Label", "props": { "y": 10, "x": 64, "wordWrap": true, "width": 139, "valign": "middle", "text": "残忍拒绝", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 473 }] }, { "type": "Box", "props": { "y": 158, "x": 501, "var": "box_show", "name": "box_show" }, "compId": 481, "child": [{ "type": "Image", "props": { "x": 160, "skin": "ui/img_UM_herokill_bg_blue.png" }, "compId": 474 }, { "type": "Image", "props": { "skin": "ui/img_UM_herokill_bg_red.png" }, "compId": 475 }, { "type": "Image", "props": { "y": 7, "x": 9, "var": "img_head2", "skin": "ui/img_UM_herohead_mini.png", "name": "img_head2" }, "compId": 476 }, { "type": "Image", "props": { "y": 7, "x": 169, "var": "img_head", "skin": "ui/img_UM_herohead_mini.png", "name": "img_head" }, "compId": 477 }, { "type": "Image", "props": { "y": 6, "x": 113, "width": 51, "skin": "ui/img_UM_herokillicon.png", "height": 51 }, "compId": 478 }, { "type": "Label", "props": { "y": 59, "x": 165, "wordWrap": true, "width": 108, "var": "txt_name", "valign": "middle", "text": "英雄名称", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 479 }, { "type": "Label", "props": { "y": 59, "x": 5, "wordWrap": true, "width": 108, "var": "txt_name2", "valign": "middle", "text": "英雄名称", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_name2", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 480 }] }, { "type": "Label", "props": { "y": 186, "x": 503, "wordWrap": false, "width": 274, "var": "txt_tip", "valign": "middle", "text": "因坠落而死", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_tip", "height": 47, "fontSize": 50, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 482 }], "loadList": ["ui/img_uk_ui_new_ui38.png", "ui/img_UM_ui_text4.png", "ui/img_UM_ui_text5.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_uk_ui2_guanggao2.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_herokill_bg_blue.png", "ui/img_UM_herokill_bg_red.png", "ui/img_UM_herohead_mini.png", "ui/img_UM_herokillicon.png"], "loadList3D": [] };
            battle.BattleResurrecUI = BattleResurrecUI;
            REG("ui.battle.BattleResurrecUI", BattleResurrecUI);
            class BattleReviveTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleReviveTipUI.uiView);
                }
            }
            BattleReviveTipUI.uiView = { "type": "View", "props": { "y": 250, "width": 750, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 700, "centerX": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 274, "x": 375, "width": 80, "skin": "ui/img_uj_icon_num1.png", "scaleY": 0.6, "scaleX": 0.6, "pivotY": 50, "pivotX": 40, "height": 100, "alpha": 0 }, "compId": 432 }, { "type": "Image", "props": { "y": 275, "x": 375, "width": 80, "skin": "ui/img_uj_icon_num2.png", "scaleY": 0.6, "scaleX": 0.6, "pivotY": 50, "pivotX": 40, "height": 100, "alpha": 0 }, "compId": 433 }, { "type": "Image", "props": { "y": 274, "x": 375, "width": 80, "skin": "ui/img_uj_icon_num3.png", "scaleY": 0.6, "scaleX": 0.6, "pivotY": 50, "pivotX": 40, "height": 100, "alpha": 0 }, "compId": 434 }], "animations": [{ "nodes": [{ "target": 434, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleY", "index": 0 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleY", "index": 9 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleY", "index": 25 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleY", "index": 29 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleX", "index": 0 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleX", "index": 9 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleX", "index": 25 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "scaleX", "index": 29 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "alpha", "index": 9 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "alpha", "index": 25 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 434, "key": "alpha", "index": 29 }] } }, { "target": 433, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleY", "index": 0 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleY", "index": 33 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleY", "index": 50 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleY", "index": 54 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleX", "index": 0 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleX", "index": 33 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleX", "index": 50 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "scaleX", "index": 54 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "alpha", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "alpha", "index": 33 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "alpha", "index": 50 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 433, "key": "alpha", "index": 54 }] } }, { "target": 432, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleY", "index": 0 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleY", "index": 54 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleY", "index": 58 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleY", "index": 116 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleY", "index": 120 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleX", "index": 0 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleX", "index": 54 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleX", "index": 58 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleX", "index": 116 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "scaleX", "index": 120 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "alpha", "index": 54 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "alpha", "index": 58 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "alpha", "index": 116 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 432, "key": "alpha", "index": 120 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_uj_icon_num1.png", "ui/img_uj_icon_num2.png", "ui/img_uj_icon_num3.png"], "loadList3D": [] };
            battle.BattleReviveTipUI = BattleReviveTipUI;
            REG("ui.battle.BattleReviveTipUI", BattleReviveTipUI);
            class BattleRightUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleRightUI.uiView);
                }
            }
            BattleRightUI.uiView = { "type": "View", "props": { "width": 500, "mouseThrough": true, "mouseEnabled": true, "height": 720 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 133, "x": 612, "var": "btn_jump", "name": "btn_jump" }, "compId": 7, "child": [{ "type": "Button", "props": { "width": 90, "stateNum": 1, "skin": "ui/img_UM_o1.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 8 }, { "type": "Image", "props": { "y": 20, "x": 17.5, "width": 37, "skin": "ui/img_uk_Icon_jump.png", "height": 35 }, "compId": 9 }] }, { "type": "Box", "props": { "y": 324, "x": 612, "width": 72, "var": "btn_vis", "rotation": 0, "name": "btn_vis", "height": 72 }, "compId": 10, "child": [{ "type": "Button", "props": { "y": 0, "x": 0, "width": 90, "stateNum": 1, "skin": "ui/img_UM_o1.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 11 }, { "type": "Image", "props": { "y": 13, "x": 16, "skin": "ui/img_uk_ui_u2_exchang.png", "scaleY": 0.6, "scaleX": 0.6 }, "compId": 12 }] }, { "type": "Box", "props": { "y": 233, "x": 612, "var": "btn_aim", "name": "btn_aim" }, "compId": 16, "child": [{ "type": "Button", "props": { "width": 90, "stateNum": 1, "skin": "ui/img_UM_o1.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 17 }, { "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_uk_ui_crossair2.png", "scaleY": 0.7, "scaleX": 0.7 }, "compId": 18 }] }, { "type": "Image", "props": { "y": 150, "x": 246, "width": 74, "var": "btn_close", "skin": "ui/img_uk_ui_Pause.png", "right": 11, "name": "btn_close", "height": 64 }, "compId": 19 }, { "type": "Box", "props": { "y": 390, "x": 352, "width": 145, "var": "box_skill", "name": "box_skill", "height": 146 }, "compId": 20, "child": [{ "type": "BattleHeroSkillIco", "props": { "y": 0, "x": -2, "width": 150, "var": "ui_skill", "name": "ui_skill", "mouseEnabled": true, "height": 150, "runtime": "ui.battle.BattleHeroSkillIcoUI" }, "compId": 41 }] }, { "type": "Box", "props": { "y": 259, "x": 366, "width": 125, "var": "btn_reload", "name": "btn_reload", "height": 125 }, "compId": 28, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 125, "skin": "ui/img_UM_skillbg.png", "scaleY": 1, "scaleX": 1, "height": 125, "alpha": 0.3 }, "compId": 29 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 120, "var": "img_cd", "skin": "ui/img_UM_skillcdWhite.png", "name": "img_cd", "height": 120 }, "compId": 30 }, { "type": "Label", "props": { "y": 34, "x": 32, "wordWrap": true, "width": 61, "var": "txt_num", "text": "7", "strokeColor": "#212121", "name": "txt_num", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 31 }, { "type": "Image", "props": { "y": 71, "x": 47, "width": 30, "skin": "ui/img_UM_AmmoIcon_white.png", "height": 14 }, "compId": 32 }] }, { "type": "Box", "props": { "y": 548, "x": -2, "var": "box_switch", "name": "box_switch" }, "compId": 43, "child": [{ "type": "Image", "props": { "width": 86, "skin": "ui/img_UM_lunpan_btn4.png", "height": 86 }, "compId": 44 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 55, "skin": "ui/img_UM_text_qiehuan.png", "height": 54 }, "compId": 45 }] }, { "type": "GuideArrow", "props": { "y": 467, "x": 425.5, "width": 50, "var": "ui_hand", "rotation": 181, "name": "ui_hand", "height": 50, "runtime": "ui.guide.GuideArrowUI" }, "compId": 46 }, { "type": "BattleBtnDaodan", "props": { "y": 114, "x": 150, "visible": true, "var": "ui_bullet", "name": "ui_bullet", "runtime": "ui.battle.BattleBtnDaodanUI" }, "compId": 50 }, { "type": "BattleBtnHuixue", "props": { "y": 114, "x": 293, "visible": true, "var": "ui_recovery", "name": "ui_recovery", "runtime": "ui.battle.BattleBtnHuixueUI" }, "compId": 51 }], "loadList": ["ui/img_UM_o1.png", "ui/img_uk_Icon_jump.png", "ui/img_uk_ui_u2_exchang.png", "ui/img_uk_ui_crossair2.png", "ui/img_uk_ui_Pause.png", "ui/img_UM_skillbg.png", "ui/img_UM_skillcdWhite.png", "ui/img_UM_AmmoIcon_white.png", "ui/img_UM_lunpan_btn4.png", "ui/img_UM_text_qiehuan.png"], "loadList3D": [] };
            battle.BattleRightUI = BattleRightUI;
            REG("ui.battle.BattleRightUI", BattleRightUI);
            class BattleRight1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleRight1UI.uiView);
                }
            }
            BattleRight1UI.uiView = { "type": "View", "props": { "width": 500, "mouseThrough": true, "mouseEnabled": true, "height": 720 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 133, "x": 612, "var": "btn_jump", "name": "btn_jump" }, "compId": 7, "child": [{ "type": "Button", "props": { "width": 90, "stateNum": 1, "skin": "ui/img_UM_o1.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 8 }, { "type": "Image", "props": { "y": 20, "x": 17.5, "width": 37, "skin": "ui/img_uk_Icon_jump.png", "height": 35 }, "compId": 9 }] }, { "type": "Box", "props": { "y": 324, "x": 612, "width": 72, "var": "btn_vis", "rotation": 0, "name": "btn_vis", "height": 72 }, "compId": 10, "child": [{ "type": "Button", "props": { "y": 0, "x": 0, "width": 90, "stateNum": 1, "skin": "ui/img_UM_o1.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 11 }, { "type": "Image", "props": { "y": 13, "x": 16, "skin": "ui/img_uk_ui_u2_exchang.png", "scaleY": 0.6, "scaleX": 0.6 }, "compId": 12 }] }, { "type": "Box", "props": { "y": 233, "x": 612, "var": "btn_aim", "name": "btn_aim" }, "compId": 16, "child": [{ "type": "Button", "props": { "width": 90, "stateNum": 1, "skin": "ui/img_UM_o1.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 17 }, { "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_uk_ui_crossair2.png", "scaleY": 0.7, "scaleX": 0.7 }, "compId": 18 }] }, { "type": "Image", "props": { "y": 150, "x": 246, "width": 74, "var": "btn_close", "skin": "ui/img_uk_ui_Pause.png", "right": 11, "name": "btn_close", "height": 64 }, "compId": 19 }, { "type": "Box", "props": { "y": 390, "x": 352, "width": 145, "var": "box_skill", "name": "box_skill", "height": 146 }, "compId": 20, "child": [{ "type": "BattleHeroSkillIco", "props": { "y": 0, "x": -2, "width": 150, "var": "ui_skill", "name": "ui_skill", "mouseEnabled": true, "height": 150, "runtime": "ui.battle.BattleHeroSkillIcoUI" }, "compId": 41 }] }, { "type": "Box", "props": { "y": 259, "x": 366, "width": 125, "var": "btn_reload", "name": "btn_reload", "height": 125 }, "compId": 28, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 125, "skin": "ui/img_UM_skillbg.png", "scaleY": 1, "scaleX": 1, "height": 125, "alpha": 0.3 }, "compId": 29 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 120, "var": "img_cd", "skin": "ui/img_UM_skillcdWhite.png", "name": "img_cd", "height": 120 }, "compId": 30 }, { "type": "Label", "props": { "y": 34, "x": 32, "wordWrap": true, "width": 61, "var": "txt_num", "text": "7", "strokeColor": "#212121", "name": "txt_num", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 31 }, { "type": "Image", "props": { "y": 71, "x": 47, "width": 30, "skin": "ui/img_UM_AmmoIcon_white.png", "height": 14 }, "compId": 32 }] }, { "type": "Box", "props": { "y": 409, "x": 8, "var": "box_switch", "name": "box_switch" }, "compId": 43, "child": [{ "type": "Image", "props": { "width": 86, "skin": "ui/img_UM_lunpan_btn4.png", "height": 86 }, "compId": 44 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 55, "skin": "ui/img_UM_text_qiehuan.png", "height": 54 }, "compId": 45 }] }, { "type": "GuideArrow", "props": { "y": 467, "x": 425.5, "width": 50, "var": "ui_hand", "rotation": 181, "name": "ui_hand", "height": 50, "runtime": "ui.guide.GuideArrowUI" }, "compId": 46 }, { "type": "BattleBtnDaodan", "props": { "y": 114, "x": 150, "visible": true, "var": "ui_bullet", "name": "ui_bullet", "runtime": "ui.battle.BattleBtnDaodanUI" }, "compId": 50 }, { "type": "BattleBtnHuixue", "props": { "y": 114, "x": 293, "visible": true, "var": "ui_recovery", "name": "ui_recovery", "runtime": "ui.battle.BattleBtnHuixueUI" }, "compId": 51 }], "loadList": ["ui/img_UM_o1.png", "ui/img_uk_Icon_jump.png", "ui/img_uk_ui_u2_exchang.png", "ui/img_uk_ui_crossair2.png", "ui/img_uk_ui_Pause.png", "ui/img_UM_skillbg.png", "ui/img_UM_skillcdWhite.png", "ui/img_UM_AmmoIcon_white.png", "ui/img_UM_lunpan_btn4.png", "ui/img_UM_text_qiehuan.png"], "loadList3D": [] };
            battle.BattleRight1UI = BattleRight1UI;
            REG("ui.battle.BattleRight1UI", BattleRight1UI);
            class BattleSkilliconUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleSkilliconUI.uiView);
                }
            }
            BattleSkilliconUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -1, "x": 3, "skin": "ui/img_UM_btn_purple.png" }, "compId": 1171 }, { "type": "Image", "props": { "y": 32, "x": 28, "width": 93, "skin": "ui/img_UM_hero_skill_icon1.png", "height": 89 }, "compId": 1170 }, { "type": "Label", "props": { "y": 136, "x": 21, "width": 108, "text": "技能名称", "strokeColor": "#404040", "stroke": 2, "height": 22, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 1172 }], "loadList": ["ui/img_UM_btn_purple.png", "ui/img_UM_hero_skill_icon1.png"], "loadList3D": [] };
            battle.BattleSkilliconUI = BattleSkilliconUI;
            REG("ui.battle.BattleSkilliconUI", BattleSkilliconUI);
            class BattleStartTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleStartTipUI.uiView);
                }
            }
            BattleStartTipUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "mouseEnabled": false, "height": 720 }, "compId": 2, "child": [{ "type": "BattleTishi7", "props": { "y": 193, "x": 0, "var": "ui_1", "name": "ui_1", "runtime": "ui.battle.BattleTishi7UI" }, "compId": 14 }, { "type": "BattleTishi5", "props": { "y": 162, "x": 0, "var": "ui_2", "name": "ui_2", "runtime": "ui.battle.BattleTishi5UI" }, "compId": 12 }, { "type": "BattleTishi6", "props": { "y": 224, "x": 0, "var": "ui_3", "name": "ui_3", "runtime": "ui.battle.BattleTishi6UI" }, "compId": 13 }], "loadList": [], "loadList3D": [] };
            battle.BattleStartTipUI = BattleStartTipUI;
            REG("ui.battle.BattleStartTipUI", BattleStartTipUI);
            class BattleStartTryHeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleStartTryHeroUI.uiView);
                }
            }
            BattleStartTryHeroUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 556 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554.5, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleBtnTry", "props": { "y": 508, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1186 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185.5, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1191 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Image", "props": { "y": 638, "x": 280, "width": 325, "var": "img_close", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 8, "name": "img_close", "height": 89 }, "compId": 1184, "child": [{ "type": "Label", "props": { "y": 22, "x": 86, "wordWrap": false, "width": 153, "var": "txt_no", "text": "不了，谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1185 }] }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png", "ui/img_UM_btn_BlueButton_2.png"], "loadList3D": [] };
            battle.BattleStartTryHeroUI = BattleStartTryHeroUI;
            REG("ui.battle.BattleStartTryHeroUI", BattleStartTryHeroUI);
            class BattleStartTryHero1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleStartTryHero1UI.uiView);
                }
            }
            BattleStartTryHero1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 556 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1188 }, { "type": "BattleBtnTry", "props": { "y": 508, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1186 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Label", "props": { "y": 652, "x": 366, "wordWrap": false, "width": 153, "var": "txt_no", "underline": true, "text": "不了谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1185 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            battle.BattleStartTryHero1UI = BattleStartTryHero1UI;
            REG("ui.battle.BattleStartTryHero1UI", BattleStartTryHero1UI);
            class BattleStartTryHero2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleStartTryHero2UI.uiView);
                }
            }
            BattleStartTryHero2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 556 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1188 }, { "type": "BattleBtnTry", "props": { "y": 508, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1186 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Label", "props": { "y": 652, "x": 366, "wordWrap": false, "width": 153, "var": "txt_no", "underline": true, "text": "不了谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1185 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            battle.BattleStartTryHero2UI = BattleStartTryHero2UI;
            REG("ui.battle.BattleStartTryHero2UI", BattleStartTryHero2UI);
            class BattleStartTryHero3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleStartTryHero3UI.uiView);
                }
            }
            BattleStartTryHero3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 556 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1188 }, { "type": "BattleBtnTry", "props": { "y": 508, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1186 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Label", "props": { "y": 652, "x": 366, "wordWrap": false, "width": 153, "var": "txt_no", "underline": true, "text": "不了谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1185 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            battle.BattleStartTryHero3UI = BattleStartTryHero3UI;
            REG("ui.battle.BattleStartTryHero3UI", BattleStartTryHero3UI);
            class BattleStartTryHero4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleStartTryHero4UI.uiView);
                }
            }
            BattleStartTryHero4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 556 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1188 }, { "type": "BattleBtnTry", "props": { "y": 524, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1186 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Label", "props": { "y": 652, "x": 366, "wordWrap": false, "width": 153, "var": "txt_no", "underline": true, "text": "不了谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1185 }, { "type": "Label", "props": { "y": 495.5, "x": 304, "width": 277, "underline": false, "text": "是否看视频立即试用", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 1192 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            battle.BattleStartTryHero4UI = BattleStartTryHero4UI;
            REG("ui.battle.BattleStartTryHero4UI", BattleStartTryHero4UI);
            class BattleTaskUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTaskUI.uiView);
                }
            }
            BattleTaskUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 78, "x": 154, "skin": "ui/img_UM_SponsorWall3.png" }, "compId": 1192 }, { "type": "Image", "props": { "y": 93, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 176, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "Box", "props": { "y": 273, "x": 465 }, "compId": 1201, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": 0, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1218 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 150, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1219 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 189, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1216 }, { "type": "GoodsItem8", "props": { "y": 14, "x": 39, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1217 }] }, { "type": "Box", "props": { "y": 491.6, "x": 427 }, "compId": 1215, "child": [{ "type": "Box", "props": { "y": 2.4, "x": 1, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 2.4, "x": 233, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get" }, "compId": 1208, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1213 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 1214 }] }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text17.png"], "loadList3D": [] };
            battle.BattleTaskUI = BattleTaskUI;
            REG("ui.battle.BattleTaskUI", BattleTaskUI);
            class BattleTask1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTask1UI.uiView);
                }
            }
            BattleTask1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 78, "x": 154, "skin": "ui/img_UM_SponsorWall3.png" }, "compId": 1192 }, { "type": "Image", "props": { "y": 93, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 176, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "Box", "props": { "y": 273, "x": 465 }, "compId": 1201, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": 0, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1220 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 150, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1221 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 189, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1218 }, { "type": "GoodsItem8", "props": { "y": 14, "x": 39, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1219 }] }, { "type": "Box", "props": { "y": 491.6, "x": 427 }, "compId": 1215, "child": [{ "type": "Box", "props": { "y": -36, "x": 373, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 136, "x": -170, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get" }, "compId": 1208, "child": [{ "type": "Label", "props": { "y": 52, "x": 10, "width": 85, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 50, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1217 }] }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleTask1UI = BattleTask1UI;
            REG("ui.battle.BattleTask1UI", BattleTask1UI);
            class BattleTask2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTask2UI.uiView);
                }
            }
            BattleTask2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 78, "x": 154, "skin": "ui/img_UM_SponsorWall3.png" }, "compId": 1192 }, { "type": "Image", "props": { "y": 93, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 176, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "Box", "props": { "y": 273, "x": 465 }, "compId": 1201, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": 0, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1218 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 150, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1219 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 189, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1216 }, { "type": "GoodsItem8", "props": { "y": 14, "x": 39, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1217 }] }, { "type": "Box", "props": { "y": 491.6, "x": 427 }, "compId": 1215, "child": [{ "type": "Box", "props": { "y": -36, "x": 373, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 85.4, "x": 373, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get" }, "compId": 1208, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1213 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 1214 }] }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text17.png"], "loadList3D": [] };
            battle.BattleTask2UI = BattleTask2UI;
            REG("ui.battle.BattleTask2UI", BattleTask2UI);
            class BattleTask3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTask3UI.uiView);
                }
            }
            BattleTask3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 67, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall3.png", "height": 617 }, "compId": 1192 }, { "type": "Image", "props": { "y": 82, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 165, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "Box", "props": { "y": 262, "x": 465 }, "compId": 1201, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": -266, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1220 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 408, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1221 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 447, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1218 }, { "type": "GoodsItem8", "props": { "y": 14, "x": -227, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1219 }] }, { "type": "Box", "props": { "y": 368, "x": 724 }, "compId": 1215, "child": [{ "type": "Box", "props": { "y": 140, "x": 198.8, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 208, "x": 256, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get" }, "compId": 1208, "child": [{ "type": "Label", "props": { "y": 35, "x": 10, "width": 110, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 62, "fontSize": 50, "font": "SimHei", "color": "#ffffff" }, "compId": 1217 }] }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleTask3UI = BattleTask3UI;
            REG("ui.battle.BattleTask3UI", BattleTask3UI);
            class BattleTask4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTask4UI.uiView);
                }
            }
            BattleTask4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 491.6, "x": 427 }, "compId": 1215, "child": [{ "type": "Image", "props": { "y": -425, "x": -273, "width": 971, "skin": "ui/img_UM_SponsorWall3.png", "height": 645 }, "compId": 1220 }, { "type": "Image", "props": { "y": -410, "x": -62, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1221 }, { "type": "Image", "props": { "y": -327, "x": -160, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1222 }, { "type": "Box", "props": { "y": -230, "x": 38 }, "compId": 1223, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": -266, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1224 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 408, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1225 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 447, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1226 }, { "type": "GoodsItem8", "props": { "y": 14, "x": -227, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1227 }] }, { "type": "Box", "props": { "y": -30, "x": 538, "width": 198.4, "height": 205.8 }, "compId": 1228, "child": [{ "type": "Box", "props": { "y": 22, "x": 0, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 121, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get" }, "compId": 1208, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1213 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 1214 }] }] }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text17.png"], "loadList3D": [] };
            battle.BattleTask4UI = BattleTask4UI;
            REG("ui.battle.BattleTask4UI", BattleTask4UI);
            class BattleTask5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTask5UI.uiView);
                }
            }
            BattleTask5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 67, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall3.png", "height": 617 }, "compId": 1192 }, { "type": "Image", "props": { "y": 102, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 185, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "Box", "props": { "y": 297, "x": 465 }, "compId": 1201, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": -266, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1220 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 408, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1221 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 447, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1218 }, { "type": "GoodsItem8", "props": { "y": 14, "x": -227, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1219 }] }, { "type": "Box", "props": { "y": 330, "x": 516 }, "compId": 1215, "child": [{ "type": "Box", "props": { "y": 0, "x": 0, "width": 247, "var": "box_get", "scaleY": 1, "scaleX": 1, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 269, "x": 81, "width": 105, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "height": 57 }, "compId": 1208, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 110, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 62, "fontSize": 50, "font": "SimHei", "color": "#ffffff" }, "compId": 1217 }] }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleTask5UI = BattleTask5UI;
            REG("ui.battle.BattleTask5UI", BattleTask5UI);
            class BattleTask6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTask6UI.uiView);
                }
            }
            BattleTask6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 67, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall3.png", "height": 617 }, "compId": 1192 }, { "type": "Image", "props": { "y": 102, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 185, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "Box", "props": { "y": 297, "x": 465 }, "compId": 1201, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": -266, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1220 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 408, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1221 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 447, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1218 }, { "type": "GoodsItem8", "props": { "y": 14, "x": -227, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1219 }] }, { "type": "Box", "props": { "y": 330, "x": 516 }, "compId": 1215, "child": [{ "type": "Box", "props": { "y": 0, "x": 0, "width": 247, "var": "box_get", "scaleY": 1, "scaleX": 1, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 109, "x": 87, "width": 105, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "height": 57 }, "compId": 1208, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 110, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 62, "fontSize": 50, "font": "SimHei", "color": "#ffffff" }, "compId": 1217 }] }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleTask6UI = BattleTask6UI;
            REG("ui.battle.BattleTask6UI", BattleTask6UI);
            class BattleTask7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTask7UI.uiView);
                }
            }
            BattleTask7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 67, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall3.png", "height": 617 }, "compId": 1192 }, { "type": "Image", "props": { "y": 102, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 185, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "Box", "props": { "y": 297, "x": 465 }, "compId": 1201, "child": [{ "type": "BattleHuXiAnim", "props": { "y": 0, "x": -266, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1220 }, { "type": "BattleHuXiAnim", "props": { "y": 0, "x": 408, "runtime": "ui.battle.BattleHuXiAnimUI" }, "compId": 1221 }, { "type": "GoodsItem7", "props": { "y": 14, "x": 447, "var": "ui_tong", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_tong", "runtime": "ui.goods.GoodsItem7UI" }, "compId": 1218 }, { "type": "GoodsItem8", "props": { "y": 14, "x": -227, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "runtime": "ui.goods.GoodsItem8UI" }, "compId": 1219 }] }, { "type": "Box", "props": { "y": 330, "x": 516 }, "compId": 1215, "child": [{ "type": "Box", "props": { "y": 0, "x": 0, "width": 247, "var": "box_get", "scaleY": 1, "scaleX": 1, "name": "box_get", "height": 98 }, "compId": 1207, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1209 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1210 }, { "type": "Image", "props": { "y": 25, "x": 79, "var": "img_double", "skin": "ui/img_UM_ui_text46.png", "name": "img_double" }, "compId": 1211 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "var": "img_ad2", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad2", "height": 33 }, "compId": 1212 }] }, { "type": "Box", "props": { "y": 109, "x": 87, "width": 105, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "height": 57 }, "compId": 1208, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 110, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 62, "fontSize": 50, "font": "SimHei", "color": "#ffffff" }, "compId": 1217 }] }, { "type": "CheckBox", "props": { "y": -53, "x": 23, "width": 50, "var": "check_ad", "toggle": false, "stateNum": 2, "skin": "ui/btn_UM_gouxuan.png", "selected": true, "scaleY": 1, "scaleX": 1, "name": "check_ad", "height": 51 }, "compId": 1225 }, { "type": "Label", "props": { "y": -39, "x": 83, "width": 141, "underline": false, "text": "看视频获得奖励", "stroke": 0, "name": "txt_ad", "height": 32, "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 1226 }] }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/btn_UM_gouxuan.png"], "loadList3D": [] };
            battle.BattleTask7UI = BattleTask7UI;
            REG("ui.battle.BattleTask7UI", BattleTask7UI);
            class BattleTaskBoxItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTaskBoxItemUI.uiView);
                }
            }
            BattleTaskBoxItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 82, "scaleY": 0.8, "scaleX": 0.8, "mouseThrough": false, "height": 75 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 50, "x": 50, "width": 106, "var": "img_frame", "skin": "ui/img_UM_battle_taskbox2.png", "pivotY": 53, "pivotX": 53, "name": "img_frame", "height": 106, "gray": false }, "compId": 1154 }, { "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "var": "img_box", "skin": "ui/img_UM_battle_taskbox.png", "name": "img_box", "height": 100, "gray": false }, "compId": 1152 }, { "type": "Image", "props": { "y": 37, "x": 6, "width": 87, "var": "img_receive", "skin": "ui/img_UM_ui_text37.png", "name": "img_receive", "height": 25 }, "compId": 1157 }, { "type": "BattleTaskBoxTip", "props": { "y": -35, "x": 3, "var": "ui_bubble", "name": "ui_bubble", "runtime": "ui.battle.BattleTaskBoxTipUI" }, "compId": 1159 }], "animations": [{ "nodes": [{ "target": 1154, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_battle_taskbox2.png", "ui/img_UM_battle_taskbox.png", "ui/img_UM_ui_text37.png"], "loadList3D": [] };
            battle.BattleTaskBoxItemUI = BattleTaskBoxItemUI;
            REG("ui.battle.BattleTaskBoxItemUI", BattleTaskBoxItemUI);
            class BattleTaskBoxTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTaskBoxTipUI.uiView);
                }
            }
            BattleTaskBoxTipUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 26, "x": 50, "width": 98, "skin": "ui/img_UM_ui_red2.png", "sizeGrid": "17,17,31,40", "pivotY": 27, "pivotX": 49, "height": 54 }, "compId": 1160 }, { "type": "Image", "props": { "y": 27, "x": 50, "width": 126, "var": "img_get", "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "scaleY": 0.7, "scaleX": 0.7, "pivotY": 31, "pivotX": 63, "name": "img_get", "height": 62 }, "compId": 1158 }, { "type": "Image", "props": { "y": 13, "x": 20, "width": 58, "var": "img_txt", "skin": "ui/img_UM_ui_text63.png", "name": "img_txt", "height": 17 }, "compId": 1159 }], "animations": [{ "nodes": [{ "target": 1160, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1160, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1160, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1160, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red2.png", "ui/img_UM_ui_red.png", "ui/img_UM_ui_text63.png"], "loadList3D": [] };
            battle.BattleTaskBoxTipUI = BattleTaskBoxTipUI;
            REG("ui.battle.BattleTaskBoxTipUI", BattleTaskBoxTipUI);
            class BattleTeamBlueUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTeamBlueUI.uiView);
                }
            }
            BattleTeamBlueUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 500, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 125, "x": 295, "width": 469, "pivotY": 116, "pivotX": 280, "height": 182 }, "compId": 1243, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 463, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 183 }, "compId": 1244 }, { "type": "List", "props": { "y": 82, "x": 26, "width": 351, "var": "list_1", "spaceX": -130, "repeatY": 1, "repeatX": 5, "name": "list_1", "height": 92 }, "compId": 1246, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "width": 200, "scaleY": 0.3, "scaleX": 0.3, "renderType": "render", "height": 319, "runtime": "ui.goods.GoodsItemUI" }, "compId": 1282 }] }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1250 }, { "type": "Label", "props": { "y": 33, "x": 92, "wordWrap": false, "width": 202, "var": "txt_name", "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1251 }, { "type": "Image", "props": { "y": 21, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1254 }, { "type": "Image", "props": { "y": 22, "x": 29, "width": 50, "var": "img_ico", "skin": "ui/img_UM_playerhead.png", "name": "img_ico", "height": 50 }, "compId": 1255 }] }, { "type": "Box", "props": { "y": 28, "x": 328, "width": 131, "height": 55 }, "compId": 1286, "child": [{ "type": "Image", "props": { "y": 4, "x": 16, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1283 }, { "type": "Image", "props": { "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1284 }, { "type": "Label", "props": { "y": 13, "x": 52, "wordWrap": false, "width": 77, "var": "txt_num", "text": "100", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1285 }] }], "loadList": ["ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png"], "loadList3D": [] };
            battle.BattleTeamBlueUI = BattleTeamBlueUI;
            REG("ui.battle.BattleTeamBlueUI", BattleTeamBlueUI);
            class BattleTeamHpUI extends Scene {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTeamHpUI.uiView);
                }
            }
            BattleTeamHpUI.uiView = { "type": "Scene", "props": { "width": 200, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 200, "skin": "ui/img_uj_ui_frame2.png", "sizeGrid": "0,34,0,37", "height": 60 }, "compId": 4 }, { "type": "Image", "props": { "y": 8, "x": 14, "skin": "ui/img_uj_ui_youjun.png" }, "compId": 5 }, { "type": "Label", "props": { "y": 14, "x": 57, "width": 82, "var": "txt_name", "text": "队友名称", "strokeColor": "#000000", "name": "txt_name", "italic": true, "height": 18, "fontSize": 14, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 6 }, { "type": "Image", "props": { "y": 30, "x": 47, "width": 134, "skin": "ui/img_uj_progress_progress4bg.png", "sizeGrid": "6,15,8,12", "height": 18 }, "compId": 7 }, { "type": "Image", "props": { "y": 30, "x": 48, "width": 132, "var": "bar_hp", "skin": "ui/img_uj_progress_progress4.png", "sizeGrid": "5,14,10,14", "name": "bar_hp", "height": 18 }, "compId": 8 }], "loadList": ["ui/img_uj_ui_frame2.png", "ui/img_uj_ui_youjun.png", "ui/img_uj_progress_progress4bg.png", "ui/img_uj_progress_progress4.png"], "loadList3D": [] };
            battle.BattleTeamHpUI = BattleTeamHpUI;
            REG("ui.battle.BattleTeamHpUI", BattleTeamHpUI);
            class BattleTeamRedUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTeamRedUI.uiView);
                }
            }
            BattleTeamRedUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 500, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 125, "x": 295, "width": 469, "pivotY": 116, "pivotX": 280, "height": 182 }, "compId": 1243, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 463, "skin": "ui/img_UM_ui_team_red.png", "sizeGrid": "30,30,30,30", "height": 183 }, "compId": 1244 }, { "type": "List", "props": { "y": 82, "x": 26, "width": 351, "var": "list_1", "spaceX": -130, "repeatY": 1, "repeatX": 5, "name": "list_1", "height": 92 }, "compId": 1246, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "width": 200, "scaleY": 0.3, "scaleX": 0.3, "renderType": "render", "height": 319, "runtime": "ui.goods.GoodsItemUI" }, "compId": 1281 }] }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1250 }, { "type": "Label", "props": { "y": 33, "x": 92, "wordWrap": false, "width": 202, "var": "txt_name", "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1251 }, { "type": "Image", "props": { "y": 21, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1254 }, { "type": "Image", "props": { "y": 23, "x": 29, "width": 50, "var": "img_ico", "skin": "ui/img_UM_playerhead.png", "name": "img_ico", "height": 50 }, "compId": 1255 }] }, { "type": "Box", "props": { "y": 28, "x": 328 }, "compId": 1285, "child": [{ "type": "Image", "props": { "y": 4, "x": 17, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1282 }, { "type": "Image", "props": { "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1283 }, { "type": "Label", "props": { "y": 13, "x": 52, "wordWrap": false, "width": 77, "var": "txt_num", "text": "100", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1284 }] }], "loadList": ["ui/img_UM_ui_team_red.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png"], "loadList3D": [] };
            battle.BattleTeamRedUI = BattleTeamRedUI;
            REG("ui.battle.BattleTeamRedUI", BattleTeamRedUI);
            class BattleTextTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTextTipUI.uiView);
                }
            }
            BattleTextTipUI.uiView = { "type": "View", "props": { "y": 150, "x": 0, "width": 320, "mouseThrough": true, "mouseEnabled": false, "height": 80, "centerX": 0 }, "compId": 2, "child": [{ "type": "Label", "props": { "y": 40, "x": 160, "wordWrap": true, "width": 468, "var": "txt_1", "text": "100", "strokeColor": "#212121", "stroke": 4, "name": "txt_1", "fontSize": 36, "font": "SimHei", "color": "#e5d9d9", "bold": true, "anchorY": 0.5, "anchorX": 0.5, "align": "center" }, "compId": 364 }], "animations": [{ "nodes": [{ "target": 364, "keyframes": { "scaleY": [{ "value": 0.5, "tweenMethod": "backOut", "tween": true, "target": 364, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 364, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 364, "label": null, "key": "scaleY", "index": 25 }, { "value": 1.2, "tweenMethod": "backOut", "tween": true, "target": 364, "label": null, "key": "scaleY", "index": 30 }], "scaleX": [{ "value": 0.5, "tweenMethod": "backOut", "tween": true, "target": 364, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 364, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 364, "label": null, "key": "scaleX", "index": 25 }, { "value": 1.2, "tweenMethod": "backOut", "tween": true, "target": 364, "label": null, "key": "scaleX", "index": 30 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 364, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 364, "key": "alpha", "index": 25 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 364, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 364, "key": "alpha", "index": 40 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": [], "loadList3D": [] };
            battle.BattleTextTipUI = BattleTextTipUI;
            REG("ui.battle.BattleTextTipUI", BattleTextTipUI);
            class BattleTishi1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTishi1UI.uiView);
                }
            }
            BattleTishi1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 800, "mouseThrough": true, "height": 59 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 35, "x": 400, "width": 713, "skin": "ui/img_uk_ui_battle_tsbg.png", "sizeGrid": "10,12,8,12", "pivotY": 25, "pivotX": 357, "height": 49, "alpha": 0.6 }, "compId": 972 }, { "type": "Label", "props": { "y": -2, "x": 55, "wordWrap": true, "width": 690, "var": "txt_con", "valign": "middle", "text": "敌人 5 秒内抵达战场，比赛即将开始", "strokeColor": "#191919", "stroke": 4, "name": "txt_con", "height": 50, "fontSize": 40, "font": "SimHei", "color": "#eadfdf", "bold": false, "align": "center" }, "compId": 973 }], "animations": [{ "nodes": [{ "target": 972, "keyframes": { "scaleX": [{ "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 45 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 47 }, { "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 52 }], "alpha": [{ "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 0 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 52 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 53 }] } }, { "target": 973, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 45 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_ui_battle_tsbg.png"], "loadList3D": [] };
            battle.BattleTishi1UI = BattleTishi1UI;
            REG("ui.battle.BattleTishi1UI", BattleTishi1UI);
            class BattleTishi2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTishi2UI.uiView);
                }
            }
            BattleTishi2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 800, "mouseThrough": true, "height": 59 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 35, "x": 400, "width": 713, "skin": "ui/img_uk_ui_battle_tsbg.png", "sizeGrid": "10,12,8,12", "pivotY": 25, "pivotX": 357, "height": 49, "alpha": 0.6 }, "compId": 972 }, { "type": "Label", "props": { "y": -2, "x": 55, "wordWrap": true, "width": 690, "var": "txt_title", "valign": "middle", "text": "任务目标1：坚持3分钟", "strokeColor": "#191919", "stroke": 4, "name": "txt_title", "height": 50, "fontSize": 40, "font": "SimHei", "color": "#ecdfdf", "bold": false, "align": "center" }, "compId": 973 }], "animations": [{ "nodes": [{ "target": 972, "keyframes": { "scaleX": [{ "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 45 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 47 }, { "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 52 }], "alpha": [{ "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 0 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 52 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 53 }] } }, { "target": 973, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 45 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_ui_battle_tsbg.png"], "loadList3D": [] };
            battle.BattleTishi2UI = BattleTishi2UI;
            REG("ui.battle.BattleTishi2UI", BattleTishi2UI);
            class BattleTishi3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTishi3UI.uiView);
                }
            }
            BattleTishi3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 800, "mouseThrough": true, "height": 59 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 35, "x": 400, "width": 713, "skin": "ui/img_uk_ui_battle_tsbg.png", "sizeGrid": "10,12,8,12", "pivotY": 25, "pivotX": 357, "height": 49, "alpha": 0.6 }, "compId": 972 }, { "type": "Label", "props": { "y": -2, "x": 55, "wordWrap": true, "width": 690, "valign": "middle", "text": "任务目标2：击败敌人", "strokeColor": "#191919", "stroke": 4, "height": 50, "fontSize": 40, "font": "SimHei", "color": "#eee1e1", "bold": false, "align": "center" }, "compId": 973 }], "animations": [{ "nodes": [{ "target": 972, "keyframes": { "scaleX": [{ "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 45 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 47 }, { "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 52 }], "alpha": [{ "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 0 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 52 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "alpha", "index": 53 }] } }, { "target": 973, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 45 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_ui_battle_tsbg.png"], "loadList3D": [] };
            battle.BattleTishi3UI = BattleTishi3UI;
            REG("ui.battle.BattleTishi3UI", BattleTishi3UI);
            class BattleTishi4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTishi4UI.uiView);
                }
            }
            BattleTishi4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 800, "mouseThrough": true, "height": 59 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 35, "x": 400, "width": 713, "skin": "ui/img_uk_ui_battle_tsbg.png", "sizeGrid": "10,12,8,12", "pivotY": 25, "pivotX": 357, "height": 49, "alpha": 0.6 }, "compId": 972 }, { "type": "Label", "props": { "y": -2, "x": 55, "wordWrap": true, "width": 690, "var": "txt_con", "valign": "middle", "text": "敌人 5 秒内抵达战场，比赛即将开始", "strokeColor": "#191919", "stroke": 4, "name": "txt_con", "height": 50, "fontSize": 40, "font": "SimHei", "color": "#efdede", "bold": false, "align": "center" }, "compId": 973 }], "animations": [{ "nodes": [{ "target": 972, "keyframes": { "scaleX": [{ "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 117 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 119 }, { "value": 0.01, "tweenMethod": "linearNone", "tween": true, "target": 972, "label": null, "key": "scaleX", "index": 122 }] } }, { "target": 973, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 114 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 973, "label": null, "key": "alpha", "index": 117 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_ui_battle_tsbg.png"], "loadList3D": [] };
            battle.BattleTishi4UI = BattleTishi4UI;
            REG("ui.battle.BattleTishi4UI", BattleTishi4UI);
            class BattleTishi5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTishi5UI.uiView);
                }
            }
            BattleTishi5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 80 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 40, "x": 640, "width": 730, "pivotY": 25, "pivotX": 365, "height": 50 }, "compId": 1143, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_tipsbg.png", "alpha": 0.6 }, "compId": 1144 }, { "type": "Image", "props": { "y": 9, "x": 158, "skin": "ui/img_UM_ui_text2.png", "scaleY": 0.8, "scaleX": 0.8 }, "compId": 1145 }] }], "animations": [{ "nodes": [{ "target": 1143, "keyframes": { "x": [{ "value": -365, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 0 }, { "value": 608, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 3 }, { "value": 664, "tweenMethod": "linearNone", "tween": true, "target": 1143, "label": null, "key": "x", "index": 40 }, { "value": 1645, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 43 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 43 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_ui_tipsbg.png", "ui/img_UM_ui_text2.png"], "loadList3D": [] };
            battle.BattleTishi5UI = BattleTishi5UI;
            REG("ui.battle.BattleTishi5UI", BattleTishi5UI);
            class BattleTishi6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTishi6UI.uiView);
                }
            }
            BattleTishi6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 80 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 40, "x": 640, "width": 730, "pivotY": 25, "pivotX": 365, "height": 50 }, "compId": 1149, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_tipsbg.png", "alpha": 0.6 }, "compId": 1150 }, { "type": "Image", "props": { "y": 9, "x": 220, "skin": "ui/img_UM_ui_text3.png", "scaleY": 0.8, "scaleX": 0.8 }, "compId": 1151 }] }], "animations": [{ "nodes": [{ "target": 1149, "keyframes": { "x": [{ "value": -365, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 0 }, { "value": 608, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 3 }, { "value": 664, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 40 }, { "value": 1645, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 43 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 43 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_ui_tipsbg.png", "ui/img_UM_ui_text3.png"], "loadList3D": [] };
            battle.BattleTishi6UI = BattleTishi6UI;
            REG("ui.battle.BattleTishi6UI", BattleTishi6UI);
            class BattleTishi7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTishi7UI.uiView);
                }
            }
            BattleTishi7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 80 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 40, "x": 640, "width": 730, "pivotY": 25, "pivotX": 365, "height": 50 }, "compId": 1143, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_tipsbg.png", "alpha": 0.6 }, "compId": 1144 }, { "type": "Image", "props": { "y": 9, "x": 158, "skin": "ui/img_UM_ui_text14.png", "scaleY": 0.8, "scaleX": 0.8 }, "compId": 1145 }] }], "animations": [{ "nodes": [{ "target": 1143, "keyframes": { "x": [{ "value": -365, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 0 }, { "value": 608, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 3 }, { "value": 664, "tweenMethod": "linearNone", "tween": true, "target": 1143, "label": null, "key": "x", "index": 40 }, { "value": 1645, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 43 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 43 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_ui_tipsbg.png", "ui/img_UM_ui_text14.png"], "loadList3D": [] };
            battle.BattleTishi7UI = BattleTishi7UI;
            REG("ui.battle.BattleTishi7UI", BattleTishi7UI);
            class BattleTopUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTopUI.uiView);
                }
            }
            BattleTopUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 720, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 200, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 10, "x": 306.5, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 3 }, { "type": "Image", "props": { "y": 4, "x": 336, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 4 }, { "type": "Label", "props": { "y": 40, "x": 305, "wordWrap": true, "width": 108, "var": "txt_time", "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_time", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 5 }, { "type": "List", "props": { "y": 70, "x": 425, "width": 201, "var": "list_foe", "name": "list_foe", "height": 47 }, "compId": 30, "child": [{ "type": "BattleNpcState", "props": { "y": 0, "x": 0, "renderType": "render", "runtime": "ui.battle.BattleNpcStateUI" }, "compId": 31 }] }, { "type": "List", "props": { "y": 70, "x": 94, "width": 201, "var": "list_team", "name": "list_team", "height": 47 }, "compId": 29, "child": [{ "type": "BattleNpcState", "props": { "y": 0, "x": 0, "renderType": "render", "runtime": "ui.battle.BattleNpcStateUI" }, "compId": 27 }] }, { "type": "Box", "props": { "y": 20, "x": 93, "width": 204, "height": 45 }, "compId": 6, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 18 }, { "type": "Image", "props": { "y": 3, "x": 2, "width": 334, "var": "img_blue", "skin": "ui/img_UM_progressbar_blue2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "name": "img_blue", "height": 64 }, "compId": 19 }, { "type": "Label", "props": { "y": -1, "x": 5, "wordWrap": true, "width": 197, "var": "txt_ph1", "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_ph1", "height": 46, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 10 }] }, { "type": "Box", "props": { "y": 20, "x": 420, "width": 211, "height": 45 }, "compId": 7, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 20 }, { "type": "Image", "props": { "y": 3, "x": 3, "width": 333, "var": "img_red", "skin": "ui/img_UM_progressbar_red2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "name": "img_red", "height": 64 }, "compId": 21 }, { "type": "Label", "props": { "y": 0, "x": 6, "wordWrap": true, "width": 198, "var": "txt_ph2", "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_ph2", "height": 44, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 13 }] }, { "type": "Label", "props": { "y": 93, "x": 251, "wordWrap": true, "width": 218, "var": "txt_inv", "text": "无敌时间 00:00", "strokeColor": "#000000", "stroke": 4, "name": "txt_inv", "height": 35, "fontSize": 25, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 14 }, { "type": "Label", "props": { "y": 130, "x": 67, "wordWrap": true, "width": 586, "var": "txt_airdrop", "text": "空投神器已到达,速去捡取!  00:00", "strokeColor": "#000000", "stroke": 4, "name": "txt_airdrop", "fontSize": 25, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 15 }, { "type": "Label", "props": { "y": 26, "x": -63, "wordWrap": false, "width": 108, "visible": true, "var": "txt_kill_1", "valign": "middle", "text": "1", "strokeColor": "#000000", "stroke": 3, "name": "txt_kill_1", "height": 35, "fontSize": 25, "font": "Helvetica", "color": "#ff634e", "bold": true, "align": "right" }, "compId": 16 }, { "type": "Label", "props": { "y": 26, "x": 617, "wordWrap": false, "width": 35, "visible": true, "var": "txt_kill_2", "valign": "middle", "text": "1", "strokeColor": "#000000", "stroke": 3, "name": "txt_kill_2", "height": 35, "fontSize": 25, "font": "Helvetica", "color": "#ff634e", "bold": true, "align": "right" }, "compId": 17 }, { "type": "Label", "props": { "y": 26, "x": -25, "wordWrap": false, "width": 108, "visible": true, "valign": "middle", "text": "/30", "strokeColor": "#000000", "stroke": 3, "height": 35, "fontSize": 25, "font": "Helvetica", "color": "#eeff2c", "bold": true, "align": "right" }, "compId": 23 }, { "type": "Label", "props": { "y": 26, "x": 655, "wordWrap": false, "width": 39, "visible": true, "valign": "middle", "text": "/30", "strokeColor": "#000000", "stroke": 3, "height": 35, "fontSize": 25, "font": "Helvetica", "color": "#f6ff2c", "bold": true, "align": "left" }, "compId": 25 }, { "type": "Box", "props": { "y": 9, "x": 127.60000000000002, "var": "box_lead2", "name": "box_lead2" }, "compId": 32, "child": [{ "type": "Image", "props": { "y": 0, "x": -47, "width": 228, "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "24,24,24,24", "height": 66 }, "compId": 39 }, { "type": "Image", "props": { "y": 2, "width": 466, "skin": "ui/img_UM_ribbon_bg_yellow2.png", "sizeGrid": "0,69,0,67", "scaleY": 0.3, "scaleX": 0.3, "height": 75 }, "compId": 33 }, { "type": "Image", "props": { "x": 52, "width": 37, "skin": "ui/img_UM_ui_text16.png", "height": 20 }, "compId": 34 }] }, { "type": "Box", "props": { "y": 9, "x": 454, "width": 139.79999999999998, "var": "box_lead1", "name": "box_lead1", "height": 24.5 }, "compId": 35, "child": [{ "type": "Image", "props": { "y": 0, "x": -46, "width": 228, "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "24,24,24,24", "height": 66 }, "compId": 40 }, { "type": "Image", "props": { "y": 2, "width": 466, "skin": "ui/img_UM_ribbon_bg_yellow2.png", "sizeGrid": "0,69,0,67", "scaleY": 0.3, "scaleX": 0.3, "height": 75 }, "compId": 36 }, { "type": "Image", "props": { "x": 52, "width": 37, "skin": "ui/img_UM_ui_text16.png", "height": 20 }, "compId": 37 }] }, { "type": "Label", "props": { "y": 25, "x": 103, "wordWrap": false, "width": 56, "visible": true, "valign": "middle", "text": "我方", "strokeColor": "#000000", "stroke": 3, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#eeff2c", "bold": true, "align": "left" }, "compId": 38 }], "loadList": ["ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_progressbar_blue2_1.png", "ui/img_UM_progressbar_blue2.png", "ui/img_UM_progressbar_red2.png", "ui/img_UM_rank_effectbk.png", "ui/img_UM_ribbon_bg_yellow2.png", "ui/img_UM_ui_text16.png"], "loadList3D": [] };
            battle.BattleTopUI = BattleTopUI;
            REG("ui.battle.BattleTopUI", BattleTopUI);
            class BattleTrialHeroAnim1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTrialHeroAnim1UI.uiView);
                }
            }
            BattleTrialHeroAnim1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 700, "mouseThrough": true, "height": 700 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 350, "x": 370, "width": 904, "skin": "ui/img_UM_effect_zi.png", "pivotY": 451, "pivotX": 472, "height": 902, "blendMode": "lighter", "alpha": 0.7 }, "compId": 1170 }], "animations": [{ "nodes": [{ "target": 1170, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 100 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_effect_zi.png"], "loadList3D": [] };
            battle.BattleTrialHeroAnim1UI = BattleTrialHeroAnim1UI;
            REG("ui.battle.BattleTrialHeroAnim1UI", BattleTrialHeroAnim1UI);
            class BattleTrialHeroAnim2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTrialHeroAnim2UI.uiView);
                }
            }
            BattleTrialHeroAnim2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 300 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 150, "x": 90, "width": 163, "skin": "ui/img_UM_herokill_bg_zi.png", "pivotY": 149, "pivotX": 82, "height": 298, "blendMode": "lighter" }, "compId": 1178 }, { "type": "Image", "props": { "y": 16, "x": 20, "width": 140, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 267, "alpha": 0.6 }, "compId": 1179 }, { "type": "Image", "props": { "y": 22, "x": 26, "width": 128, "var": "img_hero", "skin": "ui/img_UM_herohead_big.png", "name": "img_hero", "height": 256 }, "compId": 1180 }, { "type": "Image", "props": { "y": 1, "x": 4, "skin": "ui/img_UM_hero_text1.png" }, "compId": 1181 }], "animations": [{ "nodes": [{ "target": 1178, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleY", "index": 0 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "label": null, "key": "scaleY", "index": 10 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleX", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "label": null, "key": "scaleX", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png", "ui/img_UM_black.png", "ui/img_UM_herohead_big.png", "ui/img_UM_hero_text1.png"], "loadList3D": [] };
            battle.BattleTrialHeroAnim2UI = BattleTrialHeroAnim2UI;
            REG("ui.battle.BattleTrialHeroAnim2UI", BattleTrialHeroAnim2UI);
            class BattleTrialHeroAnim3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTrialHeroAnim3UI.uiView);
                }
            }
            BattleTrialHeroAnim3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 350, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 75, "x": 175, "width": 361, "skin": "ui/img_UM_herokill_bg_zi.png", "pivotY": 70, "pivotX": 181, "height": 139, "blendMode": "lighter", "alpha": 1 }, "compId": 1188 }, { "type": "Image", "props": { "y": 17, "x": 9, "width": 332, "skin": "ui/img_UM_ui_obj8.png", "sizeGrid": "30,30,30,30", "height": 120 }, "compId": 1183 }, { "type": "Image", "props": { "y": 7, "x": 9, "width": 96, "skin": "ui/img_UM_btn_purple.png", "height": 135 }, "compId": 1184 }, { "type": "Image", "props": { "y": 35, "x": 25, "width": 64, "var": "img_ico", "skin": "ui/img_UM_hero_skill_icon1.png", "name": "img_ico", "height": 61 }, "compId": 1185 }, { "type": "Label", "props": { "y": 25, "x": 143, "wordWrap": false, "width": 143, "var": "txt_name", "valign": "middle", "text": "技能名称", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#e2b0ff", "bold": true, "align": "center" }, "compId": 1186 }, { "type": "Label", "props": { "y": 57, "x": 105, "wordWrap": true, "width": 226, "var": "txt_info", "valign": "middle", "text": "技能描述内容", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 20, "font": "SimHei", "color": "#aaaaaa", "bold": true, "align": "left" }, "compId": 1187 }], "animations": [{ "nodes": [{ "target": 1188, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleY", "index": 0 }, { "value": 1.06, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "label": null, "key": "scaleY", "index": 10 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleX", "index": 0 }, { "value": 1.03, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleX", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "label": null, "key": "scaleX", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png", "ui/img_UM_ui_obj8.png", "ui/img_UM_btn_purple.png", "ui/img_UM_hero_skill_icon1.png"], "loadList3D": [] };
            battle.BattleTrialHeroAnim3UI = BattleTrialHeroAnim3UI;
            REG("ui.battle.BattleTrialHeroAnim3UI", BattleTrialHeroAnim3UI);
            class BattleTryBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTryBtnUI.uiView);
                }
            }
            BattleTryBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": false, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 29, "x": 31, "width": 138, "skin": "ui/img_UM_btn__Gold.png", "sizeGrid": "22,22,22,22", "height": 141 }, "compId": 1146 }, { "type": "Image", "props": { "y": 19, "x": 21, "width": 146, "skin": "ui/img_UM_img_shiyong.png", "height": 91 }, "compId": 1147 }, { "type": "Image", "props": { "y": 110, "x": 22, "width": 156, "skin": "ui/img_UM_btn_green.png", "height": 63 }, "compId": 1148, "child": [{ "type": "Image", "props": { "y": 18, "x": 53, "width": 89, "skin": "ui/img_UM_ui_text62.png", "height": 26 }, "compId": 1150 }, { "type": "Image", "props": { "y": 18, "x": 15, "width": 32, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 26 }, "compId": 1152 }] }, { "type": "Image", "props": { "y": 140, "x": 99, "width": 168, "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "33,33,33,33", "pivotY": 39, "pivotX": 84, "height": 77 }, "compId": 1151 }], "animations": [{ "nodes": [{ "target": 1151, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "label": null, "key": "alpha", "index": 25 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_btn__Gold.png", "ui/img_UM_img_shiyong.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text62.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_rank_effectbk.png"], "loadList3D": [] };
            battle.BattleTryBtnUI = BattleTryBtnUI;
            REG("ui.battle.BattleTryBtnUI", BattleTryBtnUI);
            class BattleTryHeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTryHeroUI.uiView);
                }
            }
            BattleTryHeroUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 557 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1186 }, { "type": "BattleBtnTry", "props": { "y": 508, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1185 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1188 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Image", "props": { "y": 638, "x": 284, "width": 315, "var": "img_close", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 8, "name": "img_close", "height": 91 }, "compId": 1184, "child": [{ "type": "Label", "props": { "y": 22, "x": 81, "wordWrap": false, "width": 153, "var": "txt_no", "text": "不了，谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1182 }] }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png", "ui/img_UM_btn_BlueButton_2.png"], "loadList3D": [] };
            battle.BattleTryHeroUI = BattleTryHeroUI;
            REG("ui.battle.BattleTryHeroUI", BattleTryHeroUI);
            class BattleTryHero1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTryHero1UI.uiView);
                }
            }
            BattleTryHero1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 557 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1188 }, { "type": "BattleBtnTry", "props": { "y": 508, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1185 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Label", "props": { "y": 658, "x": 353, "wordWrap": false, "width": 153, "var": "txt_no", "underline": true, "text": "不了谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1182 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            battle.BattleTryHero1UI = BattleTryHero1UI;
            REG("ui.battle.BattleTryHero1UI", BattleTryHero1UI);
            class BattleTryHero2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTryHero2UI.uiView);
                }
            }
            BattleTryHero2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 557 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1188 }, { "type": "BattleBtnTry", "props": { "y": 508, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1185 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Label", "props": { "y": 658, "x": 353, "wordWrap": false, "width": 153, "var": "txt_no", "underline": true, "text": "不了谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1182 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            battle.BattleTryHero2UI = BattleTryHero2UI;
            REG("ui.battle.BattleTryHero2UI", BattleTryHero2UI);
            class BattleTryHero3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTryHero3UI.uiView);
                }
            }
            BattleTryHero3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 557 }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1187 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 214, "x": 185, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1188 }, { "type": "BattleBtnTry", "props": { "y": 527, "x": 280, "var": "ui_try", "scaleY": 1.3, "scaleX": 1.3, "name": "ui_try", "runtime": "ui.battle.BattleBtnTryUI" }, "compId": 1185 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 223, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1189 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 355, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1190 }, { "type": "Box", "props": { "y": 143.5, "x": 750, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1183 }, { "type": "Label", "props": { "y": 658, "x": 353, "wordWrap": false, "width": 153, "var": "txt_no", "underline": true, "text": "不了谢谢", "strokeColor": "#000000", "stroke": 4, "name": "txt_no", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1182 }, { "type": "Label", "props": { "y": 498.5, "x": 304, "width": 277, "underline": false, "text": "是否看视频立即试用", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 1191 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            battle.BattleTryHero3UI = BattleTryHero3UI;
            REG("ui.battle.BattleTryHero3UI", BattleTryHero3UI);
            class BattleVictoryUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryUI.uiView);
                }
            }
            BattleVictoryUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "BattleVictoryAnim", "props": { "var": "ui_anim", "name": "ui_anim", "centerX": 0, "runtime": "ui.battle.BattleVictoryAnimUI" }, "compId": 754 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleVictoryUI = BattleVictoryUI;
            REG("ui.battle.BattleVictoryUI", BattleVictoryUI);
            class BattleVictory1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictory1UI.uiView);
                }
            }
            BattleVictory1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "BattleVictoryAnim1", "props": { "y": 361, "x": 313, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleVictoryAnim1UI" }, "compId": 765 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleVictory1UI = BattleVictory1UI;
            REG("ui.battle.BattleVictory1UI", BattleVictory1UI);
            class BattleVictory2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictory2UI.uiView);
                }
            }
            BattleVictory2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "BattleVictoryAnim2", "props": { "y": 439, "x": 340, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleVictoryAnim2UI" }, "compId": 768 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleVictory2UI = BattleVictory2UI;
            REG("ui.battle.BattleVictory2UI", BattleVictory2UI);
            class BattleVictory3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictory3UI.uiView);
                }
            }
            BattleVictory3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "BattleVictoryAnim3", "props": { "y": 532, "x": 403, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleVictoryAnim3UI" }, "compId": 766 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleVictory3UI = BattleVictory3UI;
            REG("ui.battle.BattleVictory3UI", BattleVictory3UI);
            class BattleVictory4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictory4UI.uiView);
                }
            }
            BattleVictory4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }, { "type": "BattleVictoryAnim4", "props": { "y": 537, "x": 475, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleVictoryAnim4UI" }, "compId": 767 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleVictory4UI = BattleVictory4UI;
            REG("ui.battle.BattleVictory4UI", BattleVictory4UI);
            class BattleVictory5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictory5UI.uiView);
                }
            }
            BattleVictory5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }, { "type": "BattleVictoryAnim5", "props": { "y": 408, "x": 613, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleVictoryAnim5UI" }, "compId": 768 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleVictory5UI = BattleVictory5UI;
            REG("ui.battle.BattleVictory5UI", BattleVictory5UI);
            class BattleVictory6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictory6UI.uiView);
                }
            }
            BattleVictory6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }, { "type": "BattleVictoryAnim6", "props": { "y": 692, "var": "ui_anim", "name": "ui_anim", "centerX": 0, "runtime": "ui.battle.BattleVictoryAnim6UI" }, "compId": 769 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            battle.BattleVictory6UI = BattleVictory6UI;
            REG("ui.battle.BattleVictory6UI", BattleVictory6UI);
            class BattleVictory7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictory7UI.uiView);
                }
            }
            BattleVictory7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 737 }, { "type": "Box", "props": { "y": 0, "x": 0, "right": 0 }, "compId": 755, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 757 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 758 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 759 }] }, { "type": "Box", "props": { "y": 57, "x": 0, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 760 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 762 }] }, { "type": "BattleVictoryAnim4", "props": { "y": 537, "x": 475, "var": "ui_anim", "name": "ui_anim", "runtime": "ui.battle.BattleVictoryAnim4UI" }, "compId": 767 }, { "type": "Box", "props": { "y": 234, "x": 0, "centerX": 0 }, "compId": 768, "child": [{ "type": "CheckBox", "props": { "width": 50, "var": "check_ad", "toggle": false, "stateNum": 2, "skin": "ui/btn_UM_gouxuan.png", "selected": true, "scaleY": 1, "scaleX": 1, "name": "check_ad", "height": 51 }, "compId": 769 }, { "type": "Label", "props": { "y": 18, "x": 58, "width": 141, "var": "txt_ad", "underline": false, "text": "看视频获得奖励", "stroke": 0, "name": "txt_ad", "height": 32, "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 770 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png", "ui/btn_UM_gouxuan.png"], "loadList3D": [] };
            battle.BattleVictory7UI = BattleVictory7UI;
            REG("ui.battle.BattleVictory7UI", BattleVictory7UI);
            class BattleVictoryAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryAnimUI.uiView);
                }
            }
            BattleVictoryAnimUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1302 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1300 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -0.5, "x": 301, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": -0.5, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }, { "type": "Label", "props": { "y": 777, "x": -557, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }, { "target": 1296, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 47 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleVictoryAnimUI = BattleVictoryAnimUI;
            REG("ui.battle.BattleVictoryAnimUI", BattleVictoryAnimUI);
            class BattleVictoryAnim1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryAnim1UI.uiView);
                }
            }
            BattleVictoryAnim1UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1300 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -0.5, "x": 460, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": 148, "x": -1050, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }, { "type": "Label", "props": { "y": 656, "x": 193, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleVictoryAnim1UI = BattleVictoryAnim1UI;
            REG("ui.battle.BattleVictoryAnim1UI", BattleVictoryAnim1UI);
            class BattleVictoryAnim2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryAnim2UI.uiView);
                }
            }
            BattleVictoryAnim2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1300 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -0.5, "x": 460, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": 108, "x": 460, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }, { "type": "Label", "props": { "y": 836, "x": -583, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleVictoryAnim2UI = BattleVictoryAnim2UI;
            REG("ui.battle.BattleVictoryAnim2UI", BattleVictoryAnim2UI);
            class BattleVictoryAnim3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryAnim3UI.uiView);
                }
            }
            BattleVictoryAnim3UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1300 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Image", "props": { "y": 655, "x": -695, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }, { "type": "Box", "props": { "y": 507, "right": 20 }, "compId": 1301, "child": [{ "type": "Image", "props": { "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 137, "x": 53, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }] }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleVictoryAnim3UI = BattleVictoryAnim3UI;
            REG("ui.battle.BattleVictoryAnim3UI", BattleVictoryAnim3UI);
            class BattleVictoryAnim4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryAnim4UI.uiView);
                }
            }
            BattleVictoryAnim4UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1300 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "var": "box_2", "pivotY": 103, "pivotX": 245, "name": "box_2", "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "var": "box_1", "pivotY": 101, "pivotX": 243, "name": "box_1", "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "var": "img_light", "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "name": "img_light", "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 504, "x": 499, "var": "box_3", "name": "box_3" }, "compId": 1301, "child": [{ "type": "Image", "props": { "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "var": "img_get3", "skin": "ui/img_UM_ui_text11.png", "name": "img_get3" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 103, "x": 53.5, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }, { "type": "Image", "props": { "y": 97, "x": 0, "width": 269, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            battle.BattleVictoryAnim4UI = BattleVictoryAnim4UI;
            REG("ui.battle.BattleVictoryAnim4UI", BattleVictoryAnim4UI);
            class BattleVictoryAnim5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryAnim5UI.uiView);
                }
            }
            BattleVictoryAnim5UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1300 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Image", "props": { "y": 655, "x": -695, "width": 269, "visible": false, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }, { "type": "Image", "props": { "y": 607.5, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "right": 50, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 643, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "left": 50, "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleVictoryAnim5UI = BattleVictoryAnim5UI;
            REG("ui.battle.BattleVictoryAnim5UI", BattleVictoryAnim5UI);
            class BattleVictoryAnim6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryAnim6UI.uiView);
                }
            }
            BattleVictoryAnim6UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 337, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "right": -150, "pivotY": 154, "pivotX": 640, "left": -150, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1300 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "BattleTeamBlue", "props": { "y": 0, "x": 0, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTeamBlueUI" }, "compId": 1298 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "BattleTeamRed", "props": { "y": 0, "x": 0, "var": "ui_right", "name": "ui_right", "runtime": "ui.battle.BattleTeamRedUI" }, "compId": 1299 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Image", "props": { "y": 655, "x": -695, "width": 269, "visible": false, "var": "img_one", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_one", "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }, { "type": "Image", "props": { "y": 594, "width": 269, "var": "img_three", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 0.8, "scaleX": 0.8, "right": 0, "name": "img_three", "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Label", "props": { "y": 621, "width": 162, "var": "txt_one", "underline": true, "text": "单倍领取", "stroke": 0, "name": "txt_one", "left": 50, "height": 49, "fontSize": 40, "font": "SimHei", "color": "#ffffff" }, "compId": 1297 }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            battle.BattleVictoryAnim6UI = BattleVictoryAnim6UI;
            REG("ui.battle.BattleVictoryAnim6UI", BattleVictoryAnim6UI);
            class BattleVictoryEffectUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryEffectUI.uiView);
                }
            }
            BattleVictoryEffectUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 520, "mouseThrough": true, "height": 520 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 260, "x": 260, "width": 520, "skin": "ui/img_UM_effect_gold.png", "pivotY": 260, "pivotX": 260, "height": 519, "blendMode": "lighter", "alpha": 0.7 }, "compId": 1240 }], "animations": [{ "nodes": [{ "target": 1240, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1240, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1240, "key": "rotation", "index": 100 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_effect_gold.png"], "loadList3D": [] };
            battle.BattleVictoryEffectUI = BattleVictoryEffectUI;
            REG("ui.battle.BattleVictoryEffectUI", BattleVictoryEffectUI);
            class BattleVictoryMvpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryMvpUI.uiView);
                }
            }
            BattleVictoryMvpUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "BattleVictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.battle.BattleVictoryEffectUI" }, "compId": 1309 }, { "type": "Image", "props": { "y": 140, "x": 633, "width": 500, "skin": "ui/img_UM_end_victorybg.png", "pivotY": 52, "pivotX": 250, "height": 130 }, "compId": 1242 }, { "type": "Image", "props": { "y": 121, "x": 640, "width": 256, "skin": "ui/img_UM_text_victory.png", "pivotY": 60, "pivotX": 128, "height": 119 }, "compId": 1239 }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "scaleY": 1, "scaleX": 1, "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter", "alpha": 0 }, "compId": 1285 }, { "type": "Image", "props": { "y": 512, "x": 293, "width": 693, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 124, "alpha": 0.4 }, "compId": 1297 }, { "type": "Box", "props": { "y": 518, "x": 300 }, "compId": 1307, "child": [{ "type": "Image", "props": { "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1298 }, { "type": "Label", "props": { "y": 34, "x": 39, "wordWrap": true, "width": 202, "text": "最大Frag连击", "strokeColor": "#000000", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1299 }, { "type": "Label", "props": { "y": 14, "x": 253, "wordWrap": false, "width": 66, "var": "txt_kill", "text": "8", "strokeColor": "#000000", "name": "txt_kill", "height": 69, "fontSize": 70, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1300 }] }, { "type": "Box", "props": { "y": 473, "x": 640 }, "compId": 1308, "child": [{ "type": "Image", "props": { "y": 45, "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1301 }, { "type": "Label", "props": { "y": 77, "x": 31, "wordWrap": true, "width": 202, "text": "MVP", "strokeColor": "#000000", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#141414", "bold": true, "align": "center" }, "compId": 1302 }, { "type": "BattleHeroCardItem", "props": { "y": 0, "x": 205, "var": "ui_npc", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_npc", "runtime": "ui.battle.BattleHeroCardItemUI" }, "compId": 1310 }] }], "animations": [{ "nodes": [{ "target": 1242, "keyframes": { "y": [{ "value": 233, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 0 }, { "value": 140, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 20 }], "scaleX": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 20 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 30 }] } }, { "target": 1239, "keyframes": { "y": [{ "value": 214, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 0 }, { "value": 121, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_ui_obj9.png"], "loadList3D": [] };
            battle.BattleVictoryMvpUI = BattleVictoryMvpUI;
            REG("ui.battle.BattleVictoryMvpUI", BattleVictoryMvpUI);
            class BattleVictoryNoticeUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleVictoryNoticeUI.uiView);
                }
            }
            BattleVictoryNoticeUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseEnabled": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 52, "x": 503, "width": 273, "skin": "ui/img_uk_ui2_obj19.png", "height": 273 }, "compId": 705 }, { "type": "Image", "props": { "y": 87, "x": 540, "skin": "ui/img_uk_icon_bg.png" }, "compId": 707 }, { "type": "Image", "props": { "y": 142, "x": 534, "skin": "ui/img_uk_text_victory.png" }, "compId": 704 }, { "type": "Box", "props": { "y": 496, "x": 274 }, "compId": 715, "child": [{ "type": "Image", "props": { "y": 5, "x": 0, "width": 277, "skin": "ui/img_uk_img_db.png", "height": 83 }, "compId": 712 }, { "type": "Label", "props": { "y": 7, "x": 295, "wordWrap": true, "width": 142, "valign": "middle", "text": "VS", "strokeColor": "#212121", "height": 80, "fontSize": 80, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 711 }, { "type": "Image", "props": { "y": 6, "x": 454, "width": 277, "skin": "ui/img_uk_img_db2.png", "height": 83 }, "compId": 716 }, { "type": "Label", "props": { "y": 30, "x": 29, "wordWrap": true, "width": 109, "valign": "middle", "text": "己方部队", "strokeColor": "#212121", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 717 }, { "type": "Label", "props": { "y": 22, "x": 170, "wordWrap": true, "width": 80, "var": "txt_kill_1", "valign": "middle", "text": "23", "strokeColor": "#001671", "stroke": 4, "name": "txt_kill_1", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#6bd5ff", "bold": false, "align": "left" }, "compId": 718 }, { "type": "Label", "props": { "y": 30, "x": 593, "wordWrap": true, "width": 109, "valign": "middle", "text": "敌方部队", "strokeColor": "#212121", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ff826a", "bold": false, "align": "left" }, "compId": 719 }, { "type": "Label", "props": { "y": 22, "x": 495, "wordWrap": true, "width": 80, "var": "txt_kill_2", "valign": "middle", "text": "23", "strokeColor": "#690100", "stroke": 4, "name": "txt_kill_2", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#ff826a", "bold": false, "align": "left" }, "compId": 720 }] }, { "type": "Label", "props": { "y": 14, "x": 253, "wordWrap": false, "width": 66, "var": "txt_kill", "text": "8", "strokeColor": "#000000", "name": "txt_kill", "height": 69, "fontSize": 70, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 722, "child": [{ "type": "Label", "props": { "y": 14, "x": 253, "wordWrap": false, "width": 66, "text": "8", "strokeColor": "#000000", "name": "txt_kill", "height": 69, "fontSize": 70, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 723 }] }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_bg.png", "ui/img_uk_text_victory.png", "ui/img_uk_img_db.png", "ui/img_uk_img_db2.png"], "loadList3D": [] };
            battle.BattleVictoryNoticeUI = BattleVictoryNoticeUI;
            REG("ui.battle.BattleVictoryNoticeUI", BattleVictoryNoticeUI);
            class BattleWaveTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleWaveTipUI.uiView);
                }
            }
            BattleWaveTipUI.uiView = { "type": "View", "props": { "width": 1280, "mouseThrough": true, "mouseEnabled": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Label", "props": { "y": 231, "x": 557, "wordWrap": true, "width": 165, "var": "txt_time", "valign": "middle", "text": "5", "strokeColor": "#191919", "stroke": 4, "name": "txt_time", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#ff0400", "bold": true, "align": "center" }, "compId": 12 }, { "type": "BattleTishi4", "props": { "y": 145, "x": 240, "var": "ui_2", "name": "ui_2", "runtime": "ui.battle.BattleTishi4UI" }, "compId": 18 }, { "type": "BattleTishi1", "props": { "y": 145, "x": 240, "var": "ui_1", "name": "ui_1", "runtime": "ui.battle.BattleTishi1UI" }, "compId": 20 }], "loadList": [], "loadList3D": [] };
            battle.BattleWaveTipUI = BattleWaveTipUI;
            REG("ui.battle.BattleWaveTipUI", BattleWaveTipUI);
            class BatttleTeamHpUI extends Scene {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BatttleTeamHpUI.uiView);
                }
            }
            BatttleTeamHpUI.uiView = { "type": "Scene", "props": { "width": 200, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 200, "skin": "ui/img_uj_ui_frame2.png", "sizeGrid": "0,34,0,37", "height": 60 }, "compId": 4 }, { "type": "Image", "props": { "y": 8, "x": 14, "skin": "ui/img_uj_ui_youjun.png" }, "compId": 5 }, { "type": "Label", "props": { "y": 14, "x": 57, "width": 82, "var": "txt_name", "text": "队友名称", "strokeColor": "#000000", "name": "txt_name", "italic": true, "height": 18, "fontSize": 14, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 6 }, { "type": "Image", "props": { "y": 30, "x": 47, "width": 134, "skin": "ui/img_uj_progress_progress4bg.png", "sizeGrid": "6,15,8,12", "height": 18 }, "compId": 7 }, { "type": "Image", "props": { "y": 30, "x": 48, "width": 132, "var": "bar_hp", "skin": "ui/img_uj_progress_progress4.png", "sizeGrid": "5,14,10,14", "name": "bar_hp", "height": 18 }, "compId": 8 }], "loadList": ["ui/img_uj_ui_frame2.png", "ui/img_uj_ui_youjun.png", "ui/img_uj_progress_progress4bg.png", "ui/img_uj_progress_progress4.png"], "loadList3D": [] };
            battle.BatttleTeamHpUI = BatttleTeamHpUI;
            REG("ui.battle.BatttleTeamHpUI", BatttleTeamHpUI);
            class Renwu1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Renwu1UI.uiView);
                }
            }
            Renwu1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 78, "x": 154, "skin": "ui/img_UM_SponsorWall3.png" }, "compId": 1192 }, { "type": "Image", "props": { "y": 93, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 176, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "huxiAnim", "props": { "y": 273, "x": 270, "runtime": "ui.test.huxiAnimUI" }, "compId": 1195 }, { "type": "Image", "props": { "y": 277, "x": 689, "width": 300, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "8,8,13,10", "height": 300 }, "compId": 1185 }, { "type": "huxiAnim", "props": { "y": 274, "x": 420, "runtime": "ui.test.huxiAnimUI" }, "compId": 1196 }, { "type": "heroCard3", "props": { "y": 286, "x": 309, "scaleY": 0.6, "scaleX": 0.6, "renderType": "render", "runtime": "ui.test.heroCard3UI" }, "compId": 1186 }, { "type": "GoodsCard", "props": { "y": 287, "x": 459, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardUI" }, "compId": 1188 }, { "type": "Label", "props": { "y": 404, "x": 806, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "广告", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1191 }, { "type": "renwuBtn", "props": { "y": 456, "x": 302, "runtime": "ui.test.renwuBtnUI" }, "compId": 1198 }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_UM_ui_Tips2.png"], "loadList3D": [] };
            battle.Renwu1UI = Renwu1UI;
            REG("ui.battle.Renwu1UI", Renwu1UI);
        })(battle = ui.battle || (ui.battle = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var comp;
        (function (comp) {
            class AlertUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(AlertUI.uiView);
                }
            }
            AlertUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 144, "x": 315, "var": "box_scale", "scaleX": 1, "name": "box_scale" }, "compId": 29, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 650, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "71,57,72,56", "height": 240 }, "compId": 16 }, { "type": "Label", "props": { "y": 24, "x": 71, "width": 508, "var": "txt_content", "valign": "middle", "text": "-", "styleSkin": "comp/label.png", "name": "txt_content", "height": 177, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 6 }, { "type": "Button", "props": { "y": 270, "x": 71, "width": 246, "var": "btn_no", "stateNum": 1, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "24,33,45,28", "name": "btn_no", "height": 97 }, "compId": 24, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "取消", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 26 }] }, { "type": "Button", "props": { "y": 270, "x": 337, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "29,53,77,45", "name": "btn_ok", "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "确定", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }] }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "comp/label.png", "ui/img_UM_btn_OrangeButton_2.png"], "loadList3D": [] };
            comp.AlertUI = AlertUI;
            REG("ui.comp.AlertUI", AlertUI);
            class Alert1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Alert1UI.uiView);
                }
            }
            Alert1UI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 144, "x": 315, "var": "box_scale", "scaleX": 1, "name": "box_scale" }, "compId": 29, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 650, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "71,57,72,56", "height": 240 }, "compId": 16 }, { "type": "Label", "props": { "y": 24, "x": 71, "width": 508, "var": "txt_content", "valign": "middle", "text": "-", "styleSkin": "comp/label.png", "name": "txt_content", "height": 177, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 6 }, { "type": "Button", "props": { "y": 347, "x": 413, "width": 246, "var": "btn_no", "stateNum": 1, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "24,33,45,28", "name": "btn_no", "height": 97 }, "compId": 24, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "取消", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 26 }] }, { "type": "Button", "props": { "y": 347, "x": -225, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "29,53,77,45", "name": "btn_ok", "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "确定", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }] }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "comp/label.png", "ui/img_UM_btn_OrangeButton_2.png"], "loadList3D": [] };
            comp.Alert1UI = Alert1UI;
            REG("ui.comp.Alert1UI", Alert1UI);
            class Alert2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Alert2UI.uiView);
                }
            }
            Alert2UI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 144, "x": 315, "var": "box_scale", "scaleX": 1, "name": "box_scale" }, "compId": 29, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 650, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "71,57,72,56", "height": 240 }, "compId": 16 }, { "type": "Label", "props": { "y": 24, "x": 71, "width": 508, "var": "txt_content", "valign": "middle", "text": "-", "styleSkin": "comp/label.png", "name": "txt_content", "height": 177, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 6 }, { "type": "Button", "props": { "y": 347, "x": 413, "width": 246, "var": "btn_no", "stateNum": 1, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "24,33,45,28", "name": "btn_no", "height": 97 }, "compId": 24, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "取消", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 26 }] }, { "type": "Button", "props": { "y": 458, "x": 413, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "29,53,77,45", "name": "btn_ok", "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "确定", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }] }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "comp/label.png", "ui/img_UM_btn_OrangeButton_2.png"], "loadList3D": [] };
            comp.Alert2UI = Alert2UI;
            REG("ui.comp.Alert2UI", Alert2UI);
            class Alert3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Alert3UI.uiView);
                }
            }
            Alert3UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "cacheAs": "none", "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 13, "centerX": 0 }, "compId": 32, "child": [{ "type": "Image", "props": { "width": 650, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "71,57,72,56", "height": 240 }, "compId": 16 }, { "type": "Label", "props": { "y": 24, "x": 71, "width": 508, "var": "txt_content", "valign": "middle", "text": "-", "styleSkin": "comp/label.png", "name": "txt_content", "height": 177, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 6 }] }, { "type": "Button", "props": { "y": 492, "width": 246, "var": "btn_no", "stateNum": 1, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "24,33,45,28", "right": 60, "name": "btn_no", "height": 97 }, "compId": 24, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "取消", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 26 }] }, { "type": "Button", "props": { "y": 491, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "29,53,77,45", "name": "btn_ok", "left": 60, "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "确定", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "comp/label.png", "ui/img_UM_btn_OrangeButton_2.png"], "loadList3D": [] };
            comp.Alert3UI = Alert3UI;
            REG("ui.comp.Alert3UI", Alert3UI);
            class Alert4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Alert4UI.uiView);
                }
            }
            Alert4UI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 67, "var": "box_scale", "scaleX": 1, "name": "box_scale", "centerX": 0 }, "compId": 29, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 650, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "71,57,72,56", "height": 240 }, "compId": 16 }, { "type": "Label", "props": { "y": 24, "x": 71, "width": 508, "var": "txt_content", "valign": "middle", "text": "-", "styleSkin": "comp/label.png", "name": "txt_content", "height": 177, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 6 }, { "type": "Button", "props": { "y": 257, "x": 380, "width": 246, "var": "btn_no", "stateNum": 1, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "24,33,45,28", "name": "btn_no", "height": 97 }, "compId": 24, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "取消", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 26 }] }, { "type": "Button", "props": { "y": 257, "x": 27, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "29,53,77,45", "name": "btn_ok", "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 22, "x": 87, "valign": "middle", "text": "确定", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }] }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "comp/label.png", "ui/img_UM_btn_OrangeButton_2.png"], "loadList3D": [] };
            comp.Alert4UI = Alert4UI;
            REG("ui.comp.Alert4UI", Alert4UI);
            class BangsUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BangsUI.uiView);
                }
            }
            BangsUI.uiView = { "type": "View", "props": { "width": 100, "height": 50 }, "compId": 2, "loadList": [], "loadList3D": [] };
            comp.BangsUI = BangsUI;
            REG("ui.comp.BangsUI", BangsUI);
            class LogUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LogUI.uiView);
                }
            }
            LogUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720 }, "compId": 2, "child": [{ "type": "TextInput", "props": { "y": 101, "x": 20, "width": 484, "var": "txt_cmd", "text": ">", "name": "txt_cmd", "mouseEnabled": true, "height": 51, "fontSize": 20, "color": "#ffffff", "bgColor": "#000000" }, "compId": 4 }, { "type": "Label", "props": { "y": 114, "x": 527, "width": 70, "var": "btn_cmd", "valign": "middle", "text": ">", "name": "btn_cmd", "height": 26, "fontSize": 24, "color": "#ffffff", "align": "center" }, "compId": 7 }, { "type": "Label", "props": { "y": 114, "x": 618, "width": 70, "var": "btn_close", "valign": "middle", "text": "X", "name": "btn_close", "height": 26, "fontSize": 24, "color": "#ffffff", "align": "center" }, "compId": 8 }, { "type": "Panel", "props": { "y": 150, "x": 20, "width": 1236, "vScrollBarSkin": "comp/vscroll.png", "height": 539 }, "compId": 9, "child": [{ "type": "Label", "props": { "wordWrap": true, "width": 1222, "var": "txt_content", "text": ">", "overflow": "scroll", "name": "txt_content", "height": 550, "fontSize": 20, "color": "#65ff00" }, "compId": 3 }] }, { "type": "Label", "props": { "y": 79, "x": 1114, "width": 91, "var": "btn_clear", "valign": "middle", "text": "_", "name": "btn_clear", "height": 68, "fontSize": 24, "color": "#ffffff", "align": "center" }, "compId": 10 }], "loadList": ["comp/vscroll.png"], "loadList3D": [] };
            comp.LogUI = LogUI;
            REG("ui.comp.LogUI", LogUI);
            class NoticeUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(NoticeUI.uiView);
                }
            }
            NoticeUI.uiView = { "type": "View", "props": { "width": 720, "height": 50 }, "compId": 2, "child": [{ "type": "Label", "props": { "y": 10, "x": 0, "width": 720, "var": "txt_content", "valign": "middle", "text": ">", "strokeColor": "#000000", "stroke": 3, "name": "txt_content", "fontSize": 30, "color": "#ffffff", "align": "center" }, "compId": 4 }], "loadList": [], "loadList3D": [] };
            comp.NoticeUI = NoticeUI;
            REG("ui.comp.NoticeUI", NoticeUI);
            class PromptUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PromptUI.uiView);
                }
            }
            PromptUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerX": 0, "cacheAs": "bitmap" }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 180, "x": 361 }, "compId": 7, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 558, "skin": "ui/img_uj_ui_bg2.png", "height": 50, "alpha": 0.2 }, "compId": 6 }, { "type": "Label", "props": { "y": 13, "x": 40, "width": 478, "var": "txt_content", "valign": "middle", "text": ">", "strokeColor": "#000000", "stroke": 4, "name": "txt_content", "fontSize": 24, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 4 }, { "type": "Image", "props": { "y": 9, "x": 4, "var": "img_ico", "skin": "comp/img_error.png", "name": "img_ico" }, "compId": 5 }] }], "loadList": ["ui/img_uj_ui_bg2.png", "comp/img_error.png"], "loadList3D": [] };
            comp.PromptUI = PromptUI;
            REG("ui.comp.PromptUI", PromptUI);
            class TempUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TempUI.uiView);
                }
            }
            TempUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720 }, "compId": 2, "child": [{ "type": "Clip", "props": { "y": 75, "x": 38, "skin": "comp/clip_tree_arrow.png" }, "compId": 3 }, { "type": "Sprite", "props": { "y": 124, "x": 157, "texture": "comp/hscroll$bar.png" }, "compId": 4 }, { "type": "Sprite", "props": { "y": 124, "x": 231, "texture": "comp/hscroll$down.png" }, "compId": 5 }, { "type": "Sprite", "props": { "y": 124, "x": 296, "texture": "comp/hscroll$up.png" }, "compId": 6 }, { "type": "HScrollBar", "props": { "y": 134, "x": 361, "skin": "comp/hscroll.png" }, "compId": 7 }, { "type": "Image", "props": { "y": 123, "x": 516, "skin": "comp/img_banned.png" }, "compId": 8 }, { "type": "Image", "props": { "y": 134, "x": 602, "skin": "comp/img_black.png" }, "compId": 9 }, { "type": "Image", "props": { "y": 134, "x": 667, "skin": "comp/img_blank.png" }, "compId": 10 }, { "type": "Image", "props": { "y": 123, "x": 732, "skin": "comp/img_error.png" }, "compId": 11 }, { "type": "Image", "props": { "y": 123, "x": 819, "skin": "comp/img_info.png" }, "compId": 12 }, { "type": "Image", "props": { "y": 123, "x": 905, "skin": "comp/img_ok.png" }, "compId": 13 }, { "type": "Image", "props": { "y": 123, "x": 992, "skin": "comp/img_warning.png" }, "compId": 14 }, { "type": "Image", "props": { "y": 245, "x": 69, "skin": "comp/img_white.png" }, "compId": 15 }, { "type": "Sprite", "props": { "y": 225, "x": 167, "texture": "comp/vscroll$bar.png" }, "compId": 16 }, { "type": "Sprite", "props": { "y": 164, "x": 212, "texture": "comp/vscroll$down.png" }, "compId": 17 }, { "type": "Sprite", "props": { "y": 153, "x": 299, "texture": "comp/vscroll$up.png" }, "compId": 18 }, { "type": "VScrollBar", "props": { "y": 158, "x": 387, "skin": "comp/vscroll.png" }, "compId": 19 }], "loadList": ["comp/clip_tree_arrow.png", "comp/hscroll$bar.png", "comp/hscroll$down.png", "comp/hscroll$up.png", "comp/hscroll.png", "comp/img_banned.png", "comp/img_black.png", "comp/img_blank.png", "comp/img_error.png", "comp/img_info.png", "comp/img_ok.png", "comp/img_warning.png", "comp/img_white.png", "comp/vscroll$bar.png", "comp/vscroll$down.png", "comp/vscroll$up.png", "comp/vscroll.png"], "loadList3D": [] };
            comp.TempUI = TempUI;
            REG("ui.comp.TempUI", TempUI);
            class TipsUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TipsUI.uiView);
                }
            }
            TipsUI.uiView = { "type": "View", "props": { "width": 720, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 114, "width": 491, "skin": "ui/img_ui_obj1.png", "sizeGrid": "40,40,40,40", "height": 97 }, "compId": 3 }, { "type": "Label", "props": { "y": 32, "x": 121, "width": 478, "var": "txt_content", "valign": "middle", "text": ">", "name": "txt_content", "height": 26, "fontSize": 30, "color": "#ffffff", "align": "center" }, "compId": 4 }], "loadList": ["ui/img_ui_obj1.png"], "loadList3D": [] };
            comp.TipsUI = TipsUI;
            REG("ui.comp.TipsUI", TipsUI);
        })(comp = ui.comp || (ui.comp = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var ep;
        (function (ep) {
            class EpAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpAnimUI.uiView);
                }
            }
            EpAnimUI.uiView = { "type": "View", "props": { "width": 100, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -78, "x": 70, "width": 150, "skin": "comp/img_white.png", "rotation": 45, "height": 20 }, "compId": 4 }, { "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "comp/img_white.png", "renderType": "mask", "height": 100 }, "compId": 5 }], "animations": [{ "nodes": [{ "target": 4, "keyframes": { "y": [{ "value": 50, "tweenMethod": "quadInOut", "tween": true, "target": 4, "key": "y", "index": 0 }, { "value": -78, "tweenMethod": "linearNone", "tween": true, "target": 4, "key": "y", "index": 15 }, { "value": -78, "tweenMethod": "linearNone", "tween": true, "target": 4, "label": null, "key": "y", "index": 30 }], "x": [{ "value": -60, "tweenMethod": "quadInOut", "tween": true, "target": 4, "key": "x", "index": 0 }, { "value": 70, "tweenMethod": "linearNone", "tween": true, "target": 4, "key": "x", "index": 15 }, { "value": 70, "tweenMethod": "linearNone", "tween": true, "target": 4, "label": null, "key": "x", "index": 30 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["comp/img_white.png"], "loadList3D": [] };
            ep.EpAnimUI = EpAnimUI;
            REG("ui.ep.EpAnimUI", EpAnimUI);
            class EpIcoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpIcoUI.uiView);
                }
            }
            EpIcoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 59, "x": 65, "width": 73, "skin": "ui/img_uk_icon_fx2.png", "pivotY": 37, "pivotX": 37, "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 28, "wordWrap": true, "width": 74, "valign": "middle", "text": "更多精彩", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 16, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 56, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx2.png"], "loadList3D": [] };
            ep.EpIcoUI = EpIcoUI;
            REG("ui.ep.EpIcoUI", EpIcoUI);
            class EpIcoFxUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpIcoFxUI.uiView);
                }
            }
            EpIcoFxUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 11, "x": 28, "width": 73, "skin": "ui/img_uk_icon_sc2.png", "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 27, "wordWrap": true, "width": 74, "valign": "middle", "text": "分享", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 11, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 9, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 11, "tweenMethod": "linearNone", "tween": true, "target": 787, "label": null, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_sc2.png"], "loadList3D": [] };
            ep.EpIcoFxUI = EpIcoFxUI;
            REG("ui.ep.EpIcoFxUI", EpIcoFxUI);
            class EpItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItemUI.uiView);
                }
            }
            EpItemUI.uiView = { "type": "View", "props": { "width": 95, "height": 110 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 2, "width": 90, "skin": "comp/img_white.png", "height": 110 }, "compId": 6 }, { "type": "Image", "props": { "y": 6, "x": 7, "width": 80, "var": "img_ico", "skin": "comp/img_black.png", "sizeGrid": "0,0,0,0", "name": "img_ico", "height": 80 }, "compId": 3 }, { "type": "Label", "props": { "y": 90, "x": 6, "width": 82, "var": "txt_name", "text": "名称", "strokeColor": "#2f2f2f", "name": "txt_name", "height": 20, "fontSize": 18, "font": "SimHei", "color": "#000000", "alpha": 1, "align": "center" }, "compId": 4 }, { "type": "EpAnim", "props": { "y": 9, "x": 10, "var": "ui_anim", "scaleY": 1.2, "scaleX": 1.2, "name": "ui_anim", "runtime": "ui.ep.EpAnimUI" }, "compId": 7 }], "loadList": ["comp/img_white.png", "comp/img_black.png"], "loadList3D": [] };
            ep.EpItemUI = EpItemUI;
            REG("ui.ep.EpItemUI", EpItemUI);
            class EpItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem1UI.uiView);
                }
            }
            EpItem1UI.uiView = { "type": "View", "props": { "width": 300, "mouseEnabled": true, "height": 205 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 4, "x": 0, "width": 300, "skin": "ui/img_bg.png", "sizeGrid": "20,20,20,20", "height": 195 }, "compId": 6 }, { "type": "Image", "props": { "y": 9, "x": 10, "width": 280, "var": "img_ico", "skin": "ui/img_ui_obj7_1.png", "sizeGrid": "20,20,20,20", "name": "img_ico", "height": 140 }, "compId": 3 }, { "type": "Label", "props": { "y": 155, "x": 6, "width": 288, "var": "txt_name", "text": "最多显示6个字", "strokeColor": "#2f2f2f", "stroke": 0, "name": "txt_name", "fontSize": 24, "font": "SimHei", "color": "#ffffff", "alpha": 1, "align": "center" }, "compId": 4 }], "loadList": ["ui/img_bg.png", "ui/img_ui_obj7_1.png"], "loadList3D": [] };
            ep.EpItem1UI = EpItem1UI;
            REG("ui.ep.EpItem1UI", EpItem1UI);
            class EpItem10UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem10UI.uiView);
                }
            }
            EpItem10UI.uiView = { "type": "View", "props": { "width": 140, "height": 140 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 10, "width": 120, "var": "img_ico", "skin": "ui/img_ui_obj7_1.png", "name": "img_ico", "height": 120 }, "compId": 3 }, { "type": "EpAnim", "props": { "y": 9, "x": 10, "var": "ui_anim", "scaleY": 1.2, "scaleX": 1.2, "name": "ui_anim", "runtime": "ui.ep.EpAnimUI" }, "compId": 7 }], "loadList": ["ui/img_ui_obj7_1.png"], "loadList3D": [] };
            ep.EpItem10UI = EpItem10UI;
            REG("ui.ep.EpItem10UI", EpItem10UI);
            class EpItem11UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem11UI.uiView);
                }
            }
            EpItem11UI.uiView = { "type": "View", "props": { "width": 170, "mouseEnabled": true, "height": 170 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 10, "x": 10, "width": 149, "skin": "ui/img_bg.png", "height": 149 }, "compId": 9 }, { "type": "Image", "props": { "y": 12, "x": 12, "width": 145, "var": "img_ico", "skin": "comp/img_white.png", "name": "img_ico", "height": 145 }, "compId": 3 }, { "type": "Image", "props": { "y": 133, "x": 12, "width": 145, "skin": "ui/img_ui_obj22.png", "height": 24, "alpha": 0.5 }, "compId": 10 }, { "type": "Label", "props": { "y": 134, "x": 17, "width": 135, "var": "txt_name", "text": "最多五个字", "strokeColor": "#2f2f2f", "stroke": 0, "name": "txt_name", "height": 25, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "alpha": 1, "align": "center" }, "compId": 4 }], "loadList": ["ui/img_bg.png", "comp/img_white.png", "ui/img_ui_obj22.png"], "loadList3D": [] };
            ep.EpItem11UI = EpItem11UI;
            REG("ui.ep.EpItem11UI", EpItem11UI);
            class EpItem12UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem12UI.uiView);
                }
            }
            EpItem12UI.uiView = { "type": "View", "props": { "width": 160, "mouseEnabled": true, "height": 160 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 6, "width": 148, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "height": 148 }, "compId": 10 }, { "type": "Image", "props": { "y": 12, "x": 12, "width": 137, "var": "img_ico", "skin": "ui/img_ui_obj7_1.png", "name": "img_ico", "height": 137 }, "compId": 3 }, { "type": "EpAnim", "props": { "y": 17, "x": 20, "var": "ui_anim", "scaleY": 1.2, "scaleX": 1.2, "name": "ui_anim", "runtime": "ui.ep.EpAnimUI" }, "compId": 7 }], "loadList": ["comp/img_white.png", "ui/img_ui_obj7_1.png"], "loadList3D": [] };
            ep.EpItem12UI = EpItem12UI;
            REG("ui.ep.EpItem12UI", EpItem12UI);
            class EpItem2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem2UI.uiView);
                }
            }
            EpItem2UI.uiView = { "type": "View", "props": { "width": 300, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "top": 0, "skin": "ui/img_ui_obj6.png", "sizeGrid": "0,26,0,25", "right": 0, "left": 0, "bottom": 0 }, "compId": 7 }, { "type": "Image", "props": { "y": 2, "x": 8, "width": 46, "var": "img_ico", "skin": "ui/img_ui_obj2.png", "name": "img_ico", "height": 46 }, "compId": 6 }, { "type": "Label", "props": { "y": 10, "x": 62, "width": 236, "var": "txt_name", "text": "名称", "strokeColor": "#2f2f2f", "stroke": 4, "name": "txt_name", "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "alpha": 1, "align": "left" }, "compId": 4 }], "loadList": ["ui/img_ui_obj6.png", "ui/img_ui_obj2.png"], "loadList3D": [] };
            ep.EpItem2UI = EpItem2UI;
            REG("ui.ep.EpItem2UI", EpItem2UI);
            class EpItem3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem3UI.uiView);
                }
            }
            EpItem3UI.uiView = { "type": "View", "props": { "width": 128, "mouseEnabled": true, "height": 128 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 110, "var": "img_bg", "skin": "ui/img_color1.png", "sizeGrid": "30,20,35,29", "name": "img_bg", "height": 110 }, "compId": 3 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 97, "var": "img_ico", "skin": "comp/img_black.png", "name": "img_ico", "height": 97 }, "compId": 11 }], "loadList": ["ui/img_color1.png", "comp/img_black.png"], "loadList3D": [] };
            ep.EpItem3UI = EpItem3UI;
            REG("ui.ep.EpItem3UI", EpItem3UI);
            class EpItem4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem4UI.uiView);
                }
            }
            EpItem4UI.uiView = { "type": "View", "props": { "width": 180, "height": 210 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 79, "x": 89, "width": 160, "skin": "comp/img_white.png", "rotation": 0, "name": "img_ico", "height": 160, "anchorY": 0.5, "anchorX": 0.5 }, "compId": 3, "child": [{ "type": "Image", "props": { "y": 83, "x": 81, "width": 125, "var": "img_ico", "skin": "ui/img_ui_obj7_1.png", "name": "img_ico", "height": 125, "anchorY": 0.5, "anchorX": 0.5 }, "compId": 7 }] }, { "type": "Label", "props": { "y": 166, "x": 20, "width": 140, "var": "txt_name", "text": "名称", "strokeColor": "#2f2f2f", "stroke": 4, "name": "txt_name", "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "alpha": 1, "align": "center" }, "compId": 4 }], "animations": [{ "nodes": [{ "target": 3, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "rotation", "index": 0 }, { "value": 10, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "rotation", "index": 5 }, { "value": -10, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "rotation", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "rotation", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "rotation", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["comp/img_white.png", "ui/img_ui_obj7_1.png"], "loadList3D": [] };
            ep.EpItem4UI = EpItem4UI;
            REG("ui.ep.EpItem4UI", EpItem4UI);
            class EpItem5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem5UI.uiView);
                }
            }
            EpItem5UI.uiView = { "type": "View", "props": { "width": 140, "height": 170 }, "compId": 2, "child": [{ "type": "Label", "props": { "y": 130, "x": 5, "width": 129, "valign": "middle", "text": "点击去玩", "strokeColor": "#2f2f2f", "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bgColor": "#3e3e3e", "alpha": 1, "align": "center" }, "compId": 4 }, { "type": "Image", "props": { "y": 65, "x": 70, "width": 129, "skin": "ui/img_uk_ui2_obj5.png", "pivotY": 65, "pivotX": 65, "height": 129 }, "compId": 7 }, { "type": "Image", "props": { "y": 63.5, "x": 69.5, "width": 118, "var": "img_ico", "skin": "comp/img_white.png", "name": "img_ico", "height": 118, "anchorY": 0.5, "anchorX": 0.5 }, "compId": 3 }], "animations": [{ "nodes": [{ "target": 3, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "key": "rotation", "index": 0 }, { "value": -10, "tweenMethod": "quadIn", "tween": true, "target": 3, "key": "rotation", "index": 5 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "label": null, "key": "rotation", "index": 10 }, { "value": 10, "tweenMethod": "quadIn", "tween": true, "target": 3, "key": "rotation", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "rotation", "index": 20 }, { "value": -10, "tweenMethod": "quadIn", "tween": true, "target": 3, "label": null, "key": "rotation", "index": 25 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "label": null, "key": "rotation", "index": 30 }, { "value": 10, "tweenMethod": "quadIn", "tween": true, "target": 3, "label": null, "key": "rotation", "index": 35 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 3, "label": null, "key": "rotation", "index": 40 }] } }, { "target": 7, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 0 }, { "value": -10, "tweenMethod": "quadIn", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 5 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 10 }, { "value": 10, "tweenMethod": "quadIn", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 20 }, { "value": -10, "tweenMethod": "quadIn", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 25 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 30 }, { "value": 10, "tweenMethod": "quadIn", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 35 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 7, "label": null, "key": "rotation", "index": 40 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_uk_ui2_obj5.png", "comp/img_white.png"], "loadList3D": [] };
            ep.EpItem5UI = EpItem5UI;
            REG("ui.ep.EpItem5UI", EpItem5UI);
            class EpItem6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem6UI.uiView);
                }
            }
            EpItem6UI.uiView = { "type": "View", "props": { "width": 130, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 5, "width": 120, "var": "img_ico", "skin": "ui/img_ui_obj7_1.png", "name": "img_ico", "height": 120 }, "compId": 3 }, { "type": "EpAnim", "props": { "y": 5, "x": 5, "var": "ui_anim", "scaleY": 1.2, "scaleX": 1.2, "name": "ui_anim", "runtime": "ui.ep.EpAnimUI" }, "compId": 7 }], "loadList": ["ui/img_ui_obj7_1.png"], "loadList3D": [] };
            ep.EpItem6UI = EpItem6UI;
            REG("ui.ep.EpItem6UI", EpItem6UI);
            class EpItem7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem7UI.uiView);
                }
            }
            EpItem7UI.uiView = { "type": "View", "props": { "width": 310, "mouseEnabled": true, "height": 210 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 5, "width": 300, "skin": "ui/img_ui_obj18.png", "height": 159 }, "compId": 8 }, { "type": "Image", "props": { "y": 164, "x": 5, "width": 300, "skin": "ui/img_ui_obj19.png", "height": 42 }, "compId": 9 }, { "type": "Label", "props": { "y": 173, "x": 11, "width": 288, "var": "txt_gameName", "text": "最多显示6个字", "strokeColor": "#2f2f2f", "stroke": 0, "name": "txt_gameName", "fontSize": 24, "font": "SimHei", "color": "#ffffff", "alpha": 1, "align": "center" }, "compId": 4 }, { "type": "Image", "props": { "y": 8, "x": 7, "width": 295, "var": "img_ico", "skin": "ui/img_ui_obj7_1.png", "sizeGrid": "20,20,20,20", "name": "img_ico", "height": 153 }, "compId": 11 }, { "type": "Clip", "props": { "y": 8, "x": 8, "width": 295, "var": "clip_ico", "skin": "comp/img_blank.png", "name": "clip_ico", "interval": 50, "height": 153, "clipY": 1, "clipX": 1, "clipWidth": 352, "clipHeight": 183, "autoPlay": true }, "compId": 10 }], "loadList": ["ui/img_ui_obj18.png", "ui/img_ui_obj19.png", "ui/img_ui_obj7_1.png", "comp/img_blank.png"], "loadList3D": [] };
            ep.EpItem7UI = EpItem7UI;
            REG("ui.ep.EpItem7UI", EpItem7UI);
            class EpItem8UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem8UI.uiView);
                }
            }
            EpItem8UI.uiView = { "type": "View", "props": { "width": 150, "mouseEnabled": true, "height": 190 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 150, "x": 0, "width": 150, "skin": "ui/img_ui_obj19.png", "height": 40 }, "compId": 13 }, { "type": "Image", "props": { "y": 0, "x": 0, "width": 150, "var": "img_ico", "skin": "ui/img_ui_obj22.png", "name": "img_ico", "height": 150 }, "compId": 14 }, { "type": "Label", "props": { "y": 157, "x": 0, "width": 150, "var": "txt_name", "text": "最多显示6个字", "strokeColor": "#2f2f2f", "stroke": 0, "name": "txt_name", "height": 24, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "alpha": 1, "align": "center" }, "compId": 4 }], "loadList": ["ui/img_ui_obj19.png", "ui/img_ui_obj22.png"], "loadList3D": [] };
            ep.EpItem8UI = EpItem8UI;
            REG("ui.ep.EpItem8UI", EpItem8UI);
            class EpItem9UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpItem9UI.uiView);
                }
            }
            EpItem9UI.uiView = { "type": "View", "props": { "width": 140, "height": 170 }, "compId": 2, "child": [{ "type": "Image", "props": { "width": 136, "top": 2, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "right": 2, "left": 2, "height": 140, "bottom": 2 }, "compId": 6 }, { "type": "Image", "props": { "y": 7, "x": 7, "width": 126, "var": "img_ico", "skin": "ui/img_ui_obj4.png", "name": "img_ico", "height": 129, "sizeGrid": "30,30,30,30" }, "compId": 3 }, { "type": "Label", "props": { "y": 144, "x": 1, "width": 137, "var": "txt_name", "text": "名称", "strokeColor": "#2f2f2f", "name": "txt_name", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#000000", "alpha": 1, "align": "center" }, "compId": 4 }, { "type": "EpAnim", "props": { "y": 9, "x": 10, "var": "ui_anim", "scaleY": 1.2, "scaleX": 1.2, "name": "ui_anim", "runtime": "ui.ep.EpAnimUI" }, "compId": 7 }], "loadList": ["comp/img_white.png", "ui/img_ui_obj4.png"], "loadList3D": [] };
            ep.EpItem9UI = EpItem9UI;
            REG("ui.ep.EpItem9UI", EpItem9UI);
            class EpPage02UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage02UI.uiView);
                }
            }
            EpPage02UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 25, "width": 180, "skin": "ui/img_uj_ui_frame11.png", "sizeGrid": "20,20,20,20", "right": 90, "height": 670 }, "compId": 20 }, { "type": "Image", "props": { "y": 25, "width": 180, "skin": "ui/img_uj_ui_frame11.png", "sizeGrid": "20,20,20,20", "left": 89, "height": 670 }, "compId": 19 }, { "type": "List", "props": { "y": 40, "width": 160, "var": "list_ad_1", "vScrollBarSkin": "comp/vscroll.png", "spaceY": 0, "spaceX": 0, "name": "list_ad_1", "left": 100, "height": 640 }, "compId": 10, "child": [{ "type": "EpItem12", "props": { "renderType": "render", "runtime": "ui.ep.EpItem12UI" }, "compId": 16 }] }, { "type": "List", "props": { "y": 40, "x": 1020, "width": 160, "var": "list_ad_2", "vScrollBarSkin": "comp/vscroll.png", "spaceY": 0, "spaceX": 0, "right": 100, "name": "list_ad_2", "height": 640 }, "compId": 12, "child": [{ "type": "EpItem12", "props": { "renderType": "render", "runtime": "ui.ep.EpItem12UI" }, "compId": 17 }] }], "loadList": ["ui/img_uj_ui_frame11.png", "comp/vscroll.png"], "loadList3D": [] };
            ep.EpPage02UI = EpPage02UI;
            REG("ui.ep.EpPage02UI", EpPage02UI);
            class EpPage06UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage06UI.uiView);
                }
            }
            EpPage06UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 720, "mouseThrough": true, "height": 1280 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 320, "x": 4, "var": "list_ad_3", "name": "list_ad_3", "height": 640, "bgColor": "#010101" }, "compId": 18, "child": [{ "type": "EpItem12", "props": { "runtime": "ui.ep.EpItem12UI" }, "compId": 22 }] }, { "type": "Box", "props": { "y": 320, "x": 554, "var": "list_ad_4", "name": "list_ad_4", "height": 640, "bgColor": "#010101" }, "compId": 20, "child": [{ "type": "EpItem12", "props": { "runtime": "ui.ep.EpItem12UI" }, "compId": 23 }] }], "animations": [{ "nodes": [{ "target": 8, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 0 }, { "value": -10, "tweenMethod": "quadIn", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 5 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 10 }, { "value": 10, "tweenMethod": "quadIn", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 20 }, { "value": -10, "tweenMethod": "quadIn", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 25 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 30 }, { "value": 10, "tweenMethod": "quadIn", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 35 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 8, "label": null, "key": "rotation", "index": 80 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": [], "loadList3D": [] };
            ep.EpPage06UI = EpPage06UI;
            REG("ui.ep.EpPage06UI", EpPage06UI);
            class EpPage09UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage09UI.uiView);
                }
            }
            EpPage09UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 112, "x": 813, "var": "box_game", "name": "box_game" }, "compId": 56, "child": [{ "type": "Image", "props": { "y": 4, "x": 2, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 57 }, { "type": "Image", "props": { "y": 81, "width": 107, "skin": "ui/img_UM_ui_text81.png", "height": 30 }, "compId": 58 }, { "type": "Image", "props": { "x": 13, "width": 78, "skin": "ui/img_UM_img_moregame.png", "height": 78 }, "compId": 59 }] }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text81.png", "ui/img_UM_img_moregame.png"], "loadList3D": [] };
            ep.EpPage09UI = EpPage09UI;
            REG("ui.ep.EpPage09UI", EpPage09UI);
            class EpPage09weixin1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage09weixin1UI.uiView);
                }
            }
            EpPage09weixin1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 59, "x": 65, "width": 73, "skin": "ui/img_uk_icon_fx2.png", "pivotY": 37, "pivotX": 37, "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 27, "wordWrap": true, "width": 74, "valign": "middle", "text": "更多", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 56, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx2.png"], "loadList3D": [] };
            ep.EpPage09weixin1UI = EpPage09weixin1UI;
            REG("ui.ep.EpPage09weixin1UI", EpPage09weixin1UI);
            class EpPage09weixin2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage09weixin2UI.uiView);
                }
            }
            EpPage09weixin2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 11, "x": 28, "width": 73, "skin": "ui/img_uk_icon_sc2.png", "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 27, "wordWrap": true, "width": 74, "valign": "middle", "text": "分享", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 11, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 9, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 11, "tweenMethod": "linearNone", "tween": true, "target": 787, "label": null, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_sc2.png"], "loadList3D": [] };
            ep.EpPage09weixin2UI = EpPage09weixin2UI;
            REG("ui.ep.EpPage09weixin2UI", EpPage09weixin2UI);
            class EpPage09weixin3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage09weixin3UI.uiView);
                }
            }
            EpPage09weixin3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 21, "x": 28, "width": 73, "skin": "ui/img_uk_icon_fx3.png", "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 27, "wordWrap": true, "width": 74, "valign": "middle", "text": "收藏", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 18, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "label": null, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx3.png"], "loadList3D": [] };
            ep.EpPage09weixin3UI = EpPage09weixin3UI;
            REG("ui.ep.EpPage09weixin3UI", EpPage09weixin3UI);
            class EpPage1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage1UI.uiView);
                }
            }
            EpPage1UI.uiView = { "type": "View", "props": { "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 143, "x": 0, "width": 720, "skin": "comp/img_black.png", "sizeGrid": "1,1,1,1", "height": 424, "alpha": 0.8 }, "compId": 11, "child": [{ "type": "Label", "props": { "y": 12, "x": 172, "width": 376, "var": "txt_lev", "text": "推荐去玩", "strokeColor": "#000000", "stroke": 4, "name": "txt_lev", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 17 }] }, { "type": "List", "props": { "y": 195, "x": 18, "width": 683, "var": "list_ad_1", "repeatY": 2, "name": "list_ad_1", "height": 344, "hScrollBarSkin": "comp/hscroll.png" }, "compId": 30, "child": [{ "type": "EpItem11", "props": { "renderType": "render", "runtime": "ui.ep.EpItem11UI" }, "compId": 15 }] }], "loadList": ["comp/img_black.png", "comp/hscroll.png"], "loadList3D": [] };
            ep.EpPage1UI = EpPage1UI;
            REG("ui.ep.EpPage1UI", EpPage1UI);
            class EpPage10UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage10UI.uiView);
                }
            }
            EpPage10UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 207, "x": 800, "var": "btn_export", "name": "btn_export" }, "compId": 60, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 61 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text81.png", "height": 30 }, "compId": 62 }, { "type": "Image", "props": { "y": 23, "x": 11, "width": 78, "skin": "ui/img_UM_img_moregame.png", "height": 78 }, "compId": 63 }] }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text81.png", "ui/img_UM_img_moregame.png"], "loadList3D": [] };
            ep.EpPage10UI = EpPage10UI;
            REG("ui.ep.EpPage10UI", EpPage10UI);
            class EpPage10ItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage10ItemUI.uiView);
                }
            }
            EpPage10ItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 59, "x": 65, "width": 73, "skin": "ui/img_uk_icon_fx2.png", "pivotY": 37, "pivotX": 37, "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 28, "wordWrap": true, "width": 74, "var": "txt_title", "valign": "middle", "text": "更多精彩", "strokeColor": "#4f1904", "stroke": 4, "name": "txt_title", "height": 35, "fontSize": 16, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 56, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx2.png"], "loadList3D": [] };
            ep.EpPage10ItemUI = EpPage10ItemUI;
            REG("ui.ep.EpPage10ItemUI", EpPage10ItemUI);
            class EpPage10oppo1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage10oppo1UI.uiView);
                }
            }
            EpPage10oppo1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 21, "x": 28, "width": 73, "skin": "ui/img_uk_icon_fx3.png", "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 27, "wordWrap": true, "width": 74, "valign": "middle", "text": "添加桌面", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 18, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 18, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "label": null, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx3.png"], "loadList3D": [] };
            ep.EpPage10oppo1UI = EpPage10oppo1UI;
            REG("ui.ep.EpPage10oppo1UI", EpPage10oppo1UI);
            class EpPage11UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage11UI.uiView);
                }
            }
            EpPage11UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "top": 0, "skin": "ui/img_uk_ui2_uibg2.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 26 }, { "type": "Box", "props": { "y": 75, "centerX": 0 }, "compId": 34, "child": [{ "type": "Image", "props": { "y": 110, "width": 1154, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "77,65,89,67", "height": 462 }, "compId": 31 }, { "type": "List", "props": { "y": 137, "x": -63, "width": 1084, "var": "list_ad_1", "name": "list_ad_1", "height": 415, "centerX": 0 }, "compId": 18, "child": [{ "type": "EpItem4", "props": { "y": 11, "x": 0, "renderType": "render", "runtime": "ui.ep.EpItem4UI" }, "compId": 24 }] }, { "type": "Image", "props": { "y": 0, "x": 307, "width": 540, "skin": "ui/img_uk_ui2_obj2.png", "height": 93 }, "compId": 33 }, { "type": "Image", "props": { "y": 3, "x": 487, "skin": "ui/img_uj_ui_text_gdhw.png" }, "compId": 32 }] }, { "type": "Box", "props": { "y": 67, "x": 63, "width": 169, "var": "btn_close", "name": "btn_close", "height": 95 }, "compId": 35, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 36 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 37 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 38 }] }], "loadList": ["ui/img_uk_ui2_uibg2.jpg", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj2.png", "ui/img_uj_ui_text_gdhw.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            ep.EpPage11UI = EpPage11UI;
            REG("ui.ep.EpPage11UI", EpPage11UI);
            class EpPage12UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage12UI.uiView);
                }
            }
            EpPage12UI.uiView = { "type": "View", "props": { "top": 0, "right": 0, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": -10, "skin": "ui/img_ui_2.png", "right": -10, "left": -10, "bottom": -10 }, "compId": 29 }, { "type": "Image", "props": { "y": 169, "x": 40, "width": 640, "skin": "ui/img_ui_obj23.png", "sizeGrid": "20,20,20,20", "height": 160 }, "compId": 43 }, { "type": "Box", "props": { "y": 183, "x": 50, "width": 620, "var": "list_ad_1", "name": "list_ad_1" }, "compId": 8, "child": [{ "type": "EpItem6", "props": { "y": 0, "x": 0, "runtime": "ui.ep.EpItem6UI" }, "compId": 32 }] }, { "type": "List", "props": { "x": 40, "width": 698, "var": "list_ad_2", "vScrollBarSkin": "comp/vscroll.png", "top": 450, "name": "list_ad_2", "bottom": 20 }, "compId": 45, "child": [{ "type": "EpItem7", "props": { "y": 0, "x": 0, "renderType": "render", "runtime": "ui.ep.EpItem7UI" }, "compId": 44 }] }, { "type": "Button", "props": { "x": 234.5, "width": 250, "var": "btn_next", "stateNum": 2, "skin": "ui/btn_ui_btn3.png", "name": "btn_next", "labelSize": 40, "labelFont": "SimHei", "labelColors": "#fff,#fff,#fff,#fff,", "labelBold": true, "label": "继续游戏", "height": 130, "bottom": 100, "sizeGrid": "50,50,50,50" }, "compId": 28 }, { "type": "Box", "props": { "y": 40, "x": 55, "var": "btn_close", "name": "btn_close" }, "compId": 39, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_fh.png" }, "compId": 36 }, { "type": "Text", "props": { "y": 10, "x": 70, "text": "返回", "strokeColor": "#9e551c", "fontSize": 30, "font": "SimHei", "color": "#ffffff", "cacheAs": "bitmap", "bold": true, "align": "center", "runtime": "laya.display.Text" }, "compId": 38 }] }, { "type": "Box", "props": { "y": 379, "x": 50 }, "compId": 46, "child": [{ "type": "Text", "props": { "x": 243, "text": "热门推荐", "strokeColor": "#1d9e1d", "fontSize": 30, "font": "SimHei", "color": "#ffffff", "cacheAs": "bitmap", "bold": true, "align": "center", "runtime": "laya.display.Text" }, "compId": 17 }, { "type": "Image", "props": { "y": 13, "width": 200, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "height": 1 }, "compId": 30 }, { "type": "Image", "props": { "y": 13, "x": 420, "width": 200, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "height": 1 }, "compId": 31 }] }, { "type": "Box", "props": { "y": 111, "x": 50 }, "compId": 47, "child": [{ "type": "Text", "props": { "x": 243, "text": "好友在玩", "strokeColor": "#9e551c", "fontSize": 30, "font": "SimHei", "color": "#ffffff", "cacheAs": "bitmap", "bold": true, "align": "center", "runtime": "laya.display.Text" }, "compId": 22 }, { "type": "Image", "props": { "y": 13, "width": 200, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "height": 1 }, "compId": 33 }, { "type": "Image", "props": { "y": 13, "x": 420, "width": 200, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "height": 1 }, "compId": 34 }] }], "loadList": ["ui/img_ui_2.png", "ui/img_ui_obj23.png", "comp/vscroll.png", "ui/btn_ui_btn3.png", "ui/img_fh.png", "comp/img_white.png"], "loadList3D": [] };
            ep.EpPage12UI = EpPage12UI;
            REG("ui.ep.EpPage12UI", EpPage12UI);
            class EpPage13UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage13UI.uiView);
                }
            }
            EpPage13UI.uiView = { "type": "View", "props": { "width": 720, "height": 1280 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 86, "x": 25, "width": 670, "skin": "ui/img_ui_obj4.png", "sizeGrid": "30,30,30,30", "height": 100 }, "compId": 16 }, { "type": "Text", "props": { "y": 116, "x": 130, "width": 459, "text": "热门推荐", "strokeColor": "#1d9e1d", "stroke": 5, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "cacheAs": "bitmap", "bold": true, "align": "center", "runtime": "laya.display.Text" }, "compId": 17 }, { "type": "Box", "props": { "y": 191, "x": 60, "width": 600, "var": "list_ad_1", "name": "list_ad_1", "height": 600 }, "compId": 18, "child": [{ "type": "EpItem1", "props": { "y": 0, "x": 0, "runtime": "ui.ep.EpItem1UI" }, "compId": 20 }] }, { "type": "Button", "props": { "y": 102, "x": 615, "width": 60, "var": "btn_close", "stateNum": 1, "skin": "ui/img_ug_close2.png", "name": "btn_close", "height": 60 }, "compId": 23 }, { "type": "Button", "props": { "y": 871, "x": 389, "width": 200, "stateNum": 1, "skin": "ui/btn_ui_btn3.png", "labelStrokeColor": "#5a320e", "labelStroke": 4, "labelSize": 30, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#ffffff,#ffffff", "labelBold": true, "label": "返回", "height": 100, "sizeGrid": "50,50,50,50" }, "compId": 24 }, { "type": "Button", "props": { "y": 871, "x": 154, "width": 200, "stateNum": 1, "skin": "ui/btn_ui_btn2.png", "labelStrokeColor": "#64450e", "labelStroke": 4, "labelSize": 30, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#ffffff,#ffffff", "labelBold": true, "label": "继续", "height": 100, "sizeGrid": "50,50,50,50" }, "compId": 29 }, { "type": "Clip", "props": { "y": 0, "x": 0, "width": 720, "var": "img_ad", "skin": "comp/img_blank.png", "name": "img_ad", "interval": 50, "height": 200, "clipY": 1, "clipX": 1, "clipWidth": 720, "clipHeight": 200, "bottom": 0, "autoPlay": true }, "compId": 32 }], "loadList": ["ui/img_ui_obj4.png", "ui/img_ug_close2.png", "ui/btn_ui_btn3.png", "ui/btn_ui_btn2.png", "comp/img_blank.png"], "loadList3D": [] };
            ep.EpPage13UI = EpPage13UI;
            REG("ui.ep.EpPage13UI", EpPage13UI);
            class EpPage14UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage14UI.uiView);
                }
            }
            EpPage14UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 136, "width": 386, "left": 473, "height": 454 }, "compId": 42, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 390, "skin": "ui/img_uj_ui_frame11.png", "sizeGrid": "20,20,20,20", "height": 458 }, "compId": 43 }, { "type": "Box", "props": { "y": 60, "x": 0, "width": 384, "var": "list_ad_1", "name": "list_ad_1", "height": 384 }, "compId": 44, "child": [{ "type": "EpItem3", "props": { "y": 0, "x": 0, "runtime": "ui.ep.EpItem3UI" }, "compId": 45 }] }, { "type": "Image", "props": { "y": 8, "x": 335, "width": 45, "var": "img_close", "skin": "ui/img_ug_close.png", "name": "img_close", "height": 45 }, "compId": 47 }] }], "loadList": ["ui/img_uj_ui_frame11.png", "ui/img_ug_close.png"], "loadList3D": [] };
            ep.EpPage14UI = EpPage14UI;
            REG("ui.ep.EpPage14UI", EpPage14UI);
            class EpPage15UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage15UI.uiView);
                }
            }
            EpPage15UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 17, "x": 436, "width": 408, "var": "list_ad_1", "right": 300, "name": "list_ad_1", "height": 115, "bgColor": "#060606" }, "compId": 12, "child": [{ "type": "EpItem", "props": { "y": 0, "x": 0, "runtime": "ui.ep.EpItemUI" }, "compId": 13 }] }], "loadList": [], "loadList3D": [] };
            ep.EpPage15UI = EpPage15UI;
            REG("ui.ep.EpPage15UI", EpPage15UI);
            class EpPage16qqUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage16qqUI.uiView);
                }
            }
            EpPage16qqUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 21, "x": 28, "width": 73, "skin": "ui/img_uk_icon_fx3.png", "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 27, "wordWrap": true, "width": 74, "valign": "middle", "text": "添加桌面", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 16, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 18, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "label": null, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx3.png"], "loadList3D": [] };
            ep.EpPage16qqUI = EpPage16qqUI;
            REG("ui.ep.EpPage16qqUI", EpPage16qqUI);
            class EpPage19UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage19UI.uiView);
                }
            }
            EpPage19UI.uiView = { "type": "View", "props": { "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "List", "props": { "x": 49, "width": 698, "var": "list_ad_2", "vScrollBarSkin": "comp/vscroll.png", "top": 188, "name": "list_ad_2", "bottom": 80 }, "compId": 45, "child": [{ "type": "EpItem7", "props": { "y": 0, "x": 0, "renderType": "render", "runtime": "ui.ep.EpItem7UI" }, "compId": 51 }] }, { "type": "Box", "props": { "y": 50, "x": 65, "var": "btn_close", "name": "btn_close" }, "compId": 47, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_fh.png" }, "compId": 52 }, { "type": "Text", "props": { "y": 10, "x": 70, "text": "返回", "strokeColor": "#9e551c", "fontSize": 30, "font": "SimHei", "color": "#ffffff", "cacheAs": "bitmap", "bold": true, "align": "center", "runtime": "laya.display.Text" }, "compId": 53 }] }, { "type": "Box", "props": { "y": 109, "x": 50 }, "compId": 48, "child": [{ "type": "Text", "props": { "y": 0, "x": 248, "text": "更多游戏", "strokeColor": "#1d9e1d", "fontSize": 30, "font": "SimHei", "color": "#ffffff", "cacheAs": "bitmap", "bold": true, "align": "center", "runtime": "laya.display.Text" }, "compId": 54 }, { "type": "Image", "props": { "y": 13, "width": 200, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "height": 2 }, "compId": 55 }, { "type": "Image", "props": { "y": 13, "x": 420, "width": 200, "skin": "comp/img_white.png", "sizeGrid": "1,1,1,1", "height": 2 }, "compId": 56 }] }, { "type": "Image", "props": { "y": 872, "x": 207, "width": 306, "var": "btn_next", "skin": "ui/img_ui_ui_btn_4.png", "sizeGrid": "41,47,49,47", "name": "btn_next", "height": 97 }, "compId": 61, "child": [{ "type": "Label", "props": { "y": 24, "x": 81, "valign": "middle", "text": "继续游戏", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 62 }] }], "loadList": ["comp/vscroll.png", "ui/img_fh.png", "comp/img_white.png", "ui/img_ui_ui_btn_4.png"], "loadList3D": [] };
            ep.EpPage19UI = EpPage19UI;
            REG("ui.ep.EpPage19UI", EpPage19UI);
            class EpPage2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage2UI.uiView);
                }
            }
            EpPage2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "mouseEnabled": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 185, "x": 1086, "width": 180, "skin": "ui/img_uj_ui_frame11.png", "sizeGrid": "20,20,20,20", "height": 350 }, "compId": 12 }, { "type": "Image", "props": { "y": 185, "width": 180, "skin": "ui/img_uj_ui_frame11.png", "sizeGrid": "20,20,20,20", "left": 10, "height": 350 }, "compId": 13 }, { "type": "Box", "props": { "y": 200, "width": 160, "var": "list_ad_1", "vScrollBarSkin": "comp/vscroll.png", "spaceY": 0, "spaceX": 0, "name": "list_ad_1", "left": 21, "height": 320 }, "compId": 14, "child": [{ "type": "EpItem12", "props": { "renderType": "render", "runtime": "ui.ep.EpItem12UI" }, "compId": 16 }] }, { "type": "Box", "props": { "y": 200, "x": 1096, "width": 160, "var": "list_ad_2", "vScrollBarSkin": "comp/vscroll.png", "spaceY": 0, "spaceX": 0, "name": "list_ad_2", "height": 320 }, "compId": 15, "child": [{ "type": "EpItem12", "props": { "renderType": "render", "runtime": "ui.ep.EpItem12UI" }, "compId": 17 }] }], "loadList": ["ui/img_uj_ui_frame11.png", "comp/vscroll.png"], "loadList3D": [] };
            ep.EpPage2UI = EpPage2UI;
            REG("ui.ep.EpPage2UI", EpPage2UI);
            class EpPage3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage3UI.uiView);
                }
            }
            EpPage3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "mouseEnabled": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 447, "width": 234, "skin": "ui/btn_uj_btn_gunlvup5.png", "sizeGrid": "20,20,20,20", "rotation": -90, "right": 757, "height": 670 }, "compId": 9 }, { "type": "Box", "props": { "y": 247, "x": 302, "width": 633, "var": "list_ad_2", "vScrollBarSkin": "comp/vscroll.png", "spaceY": 0, "spaceX": 0, "rotation": 0, "name": "list_ad_2", "height": 164 }, "compId": 10, "child": [{ "type": "EpItem12", "props": { "renderType": "render", "runtime": "ui.ep.EpItem12UI" }, "compId": 11 }] }], "loadList": ["ui/btn_uj_btn_gunlvup5.png", "comp/vscroll.png"], "loadList3D": [] };
            ep.EpPage3UI = EpPage3UI;
            REG("ui.ep.EpPage3UI", EpPage3UI);
            class EpPage4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage4UI.uiView);
                }
            }
            EpPage4UI.uiView = { "type": "View", "props": { "zOrder": 25, "top": 0, "right": 0, "mouseThrough": true, "mouseEnabled": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 250, "x": 10, "width": 700, "var": "img_ad", "name": "img_ad", "height": 300, "bgColor": "#fdf9f9" }, "compId": 6 }], "loadList": [], "loadList3D": [] };
            ep.EpPage4UI = EpPage4UI;
            REG("ui.ep.EpPage4UI", EpPage4UI);
            class EpPage5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage5UI.uiView);
                }
            }
            EpPage5UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 320, "x": 196, "var": "btn_box1", "name": "btn_box1" }, "compId": 20, "child": [{ "type": "EpItem5", "props": { "zOrder": 25, "var": "ico_1", "name": "ico_1", "runtime": "ui.ep.EpItem5UI" }, "compId": 10 }] }], "loadList": [], "loadList3D": [] };
            ep.EpPage5UI = EpPage5UI;
            REG("ui.ep.EpPage5UI", EpPage5UI);
            class EpPage6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage6UI.uiView);
                }
            }
            EpPage6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 275, "x": 30, "var": "btn_box1", "name": "btn_box1" }, "compId": 14, "child": [{ "type": "EpItem5", "props": { "zOrder": 25, "var": "ico_1", "name": "ico_1", "runtime": "ui.ep.EpItem5UI" }, "compId": 15 }] }], "loadList": [], "loadList3D": [] };
            ep.EpPage6UI = EpPage6UI;
            REG("ui.ep.EpPage6UI", EpPage6UI);
            class EpPage7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage7UI.uiView);
                }
            }
            EpPage7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "mouseEnabled": true, "height": 720 }, "compId": 2, "loadList": [], "loadList3D": [] };
            ep.EpPage7UI = EpPage7UI;
            REG("ui.ep.EpPage7UI", EpPage7UI);
            class EpPage8UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage8UI.uiView);
                }
            }
            EpPage8UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "mouseEnabled": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 74, "x": 230, "var": "btn_box1", "name": "btn_box1" }, "compId": 53, "child": [{ "type": "EpItem5", "props": { "zOrder": 25, "var": "ico_1", "name": "ico_1", "runtime": "ui.ep.EpItem5UI" }, "compId": 54 }] }], "loadList": [], "loadList3D": [] };
            ep.EpPage8UI = EpPage8UI;
            REG("ui.ep.EpPage8UI", EpPage8UI);
            class EpPage9UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(EpPage9UI.uiView);
                }
            }
            EpPage9UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "mouseEnabled": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "width": 701, "skin": "ui/img_uj_ui_frame11.png", "sizeGrid": "20,20,20,20", "rotation": 0, "pivotY": 152, "pivotX": 343, "height": 335, "centerY": 0, "centerX": 0 }, "compId": 9, "child": [{ "type": "Box", "props": { "y": 14, "x": 11, "width": 678, "var": "list_ad_2", "vScrollBarSkin": "comp/vscroll.png", "spaceY": 0, "spaceX": 0, "rotation": 0, "name": "list_ad_2", "height": 309 }, "compId": 10, "child": [{ "type": "EpItem12", "props": { "renderType": "render", "runtime": "ui.ep.EpItem12UI" }, "compId": 11 }] }] }, { "type": "Box", "props": { "y": 10, "x": 62, "var": "box_close", "name": "box_close" }, "compId": 12, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 13 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 14 }] }], "loadList": ["ui/img_uj_ui_frame11.png", "comp/vscroll.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png"], "loadList3D": [] };
            ep.EpPage9UI = EpPage9UI;
            REG("ui.ep.EpPage9UI", EpPage9UI);
        })(ep = ui.ep || (ui.ep = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var excode;
        (function (excode) {
            class ExcodeUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ExcodeUI.uiView);
                }
            }
            ExcodeUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "top": 0, "skin": "ui/img_uj_ui_bg.png", "right": -100, "left": -100, "bottom": 0 }, "compId": 48 }, { "type": "Box", "props": { "y": 53, "centerX": 0 }, "compId": 50, "child": [{ "type": "Image", "props": { "x": 128, "width": 361, "skin": "ui/img_ui_ui_skin_bg.png", "sizeGrid": "0,48,0,44", "height": 76 }, "compId": 21 }, { "type": "Label", "props": { "y": 14, "x": 194, "width": 238, "valign": "middle", "text": "精品兑换处", "strokeColor": "#000000", "height": 49, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 22 }, { "type": "Image", "props": { "y": 82, "x": 240, "width": 144, "skin": "ui/img_uj_icon_dhm.png", "height": 144 }, "compId": 32 }, { "type": "Box", "props": { "y": 510, "x": 320, "var": "btn_ok", "name": "btn_ok" }, "compId": 41, "child": [{ "type": "Image", "props": { "y": 0, "x": 12, "width": 240, "skin": "ui/img_ui_ui_btn_4.png", "sizeGrid": "41,45,49,47", "height": 97 }, "compId": 37 }, { "type": "Label", "props": { "y": 19, "x": 102, "valign": "middle", "text": "确定", "strokeColor": "#ad3e35", "stroke": 4, "height": 49, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 39 }] }, { "type": "Box", "props": { "y": 511, "x": 60, "var": "btn_close", "name": "btn_close" }, "compId": 42, "child": [{ "type": "Image", "props": { "y": 0, "x": 12, "width": 240, "skin": "ui/img_ui_ui_btn_2.png", "sizeGrid": "41,45,49,47", "height": 97 }, "compId": 38 }, { "type": "Label", "props": { "y": 19, "x": 102, "valign": "middle", "text": "取消", "strokeColor": "#7635ad", "stroke": 4, "height": 49, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 40 }] }, { "type": "Label", "props": { "y": 277, "width": 634, "valign": "middle", "text": "请在下方输入您的兑换码", "strokeColor": "#000000", "height": 49, "fontSize": 40, "font": "SimHei", "color": "#eeb145", "bold": true, "align": "center" }, "compId": 45 }, { "type": "TextInput", "props": { "y": 369, "x": 81, "width": 472, "var": "txt_excode", "valign": "middle", "type": "number", "skin": "ui/img_ui_ui_panel1.png", "sizeGrid": "25,25,25,25", "name": "txt_excode", "height": 82, "fontSize": 30, "align": "center" }, "compId": 46 }] }], "loadList": ["ui/img_uj_ui_bg.png", "ui/img_ui_ui_skin_bg.png", "ui/img_uj_icon_dhm.png", "ui/img_ui_ui_btn_4.png", "ui/img_ui_ui_btn_2.png", "ui/img_ui_ui_panel1.png"], "loadList3D": [] };
            excode.ExcodeUI = ExcodeUI;
            REG("ui.excode.ExcodeUI", ExcodeUI);
        })(excode = ui.excode || (ui.excode = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var goods;
        (function (goods) {
            class GoodsAdUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsAdUI.uiView);
                }
            }
            GoodsAdUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 50, "mouseThrough": true, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 25, "x": 25, "width": 32, "skin": "ui/img_uk_ui2_guanggao2.png", "pivotY": 16, "pivotX": 16, "height": 32 }, "compId": 1166 }, { "type": "Image", "props": { "y": 25, "x": 25, "width": 32, "skin": "ui/img_uk_ui2_guanggao2.png", "pivotY": 16, "pivotX": 16, "height": 32, "blendMode": "lighter" }, "compId": 1167 }], "animations": [{ "nodes": [{ "target": 1167, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleY", "index": 0 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleY", "index": 10 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "label": null, "key": "scaleY", "index": 30 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleX", "index": 0 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleX", "index": 10 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "label": null, "key": "scaleX", "index": 30 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "alpha", "index": 10 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1167, "label": null, "key": "alpha", "index": 30 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_guanggao2.png"], "loadList3D": [] };
            goods.GoodsAdUI = GoodsAdUI;
            REG("ui.goods.GoodsAdUI", GoodsAdUI);
            class GoodsCardFloatUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsCardFloatUI.uiView);
                }
            }
            GoodsCardFloatUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": false, "mouseEnabled": true, "height": 280 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 398 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 399 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "var": "img_img", "skin": "ui/img_UM_herohead_card.png", "name": "img_img", "height": 232 }, "compId": 400 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": false, "width": 118, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 402 }, { "type": "Label", "props": { "y": 3, "x": 123, "wordWrap": false, "width": 66, "visible": false, "var": "txt_num", "text": "11", "strokeColor": "#272727", "stroke": 4, "overflow": "hidden", "name": "txt_num", "height": 53, "fontSize": 60, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 404 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png"], "loadList3D": [] };
            goods.GoodsCardFloatUI = GoodsCardFloatUI;
            REG("ui.goods.GoodsCardFloatUI", GoodsCardFloatUI);
            class GoodsExhUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsExhUI.uiView);
                }
            }
            GoodsExhUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -22, "width": 774, "scaleY": 0.9, "scaleX": 0.9, "height": 675, "centerX": 0 }, "compId": 1043, "child": [{ "type": "Image", "props": { "width": 774, "skin": "ui/img_uk_ui2_obj19.png", "height": 650 }, "compId": 1027 }, { "type": "Image", "props": { "y": 125, "x": 47, "width": 685, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 550, "alpha": 1 }, "compId": 876 }, { "type": "Image", "props": { "y": 152, "x": 147, "width": 486, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "43,81,40,78", "height": 254, "alpha": 0.7 }, "compId": 1022 }, { "type": "Image", "props": { "y": 409, "x": 158, "width": 464, "skin": "ui/img_uk_ui2_obj13.png", "height": 169 }, "compId": 946 }, { "type": "Image", "props": { "y": 284, "x": 182, "width": 416, "skin": "ui/img_uk_ui2_obj3.png", "height": 125 }, "compId": 1026 }, { "type": "Label", "props": { "y": 174, "x": 254, "wordWrap": false, "width": 271, "var": "txt_name", "valign": "middle", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1019 }, { "type": "Image", "props": { "y": 219, "x": 200, "var": "img_1", "skin": "ui/img_uk_icon_gunimg.png", "name": "img_1" }, "compId": 1028 }, { "type": "Box", "props": { "y": 578, "x": 163 }, "compId": 1032, "child": [{ "type": "Box", "props": { "y": 2, "var": "btn_ok", "name": "btn_ok" }, "compId": 937, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 918 }, { "type": "Label", "props": { "y": 11, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "确定", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 919 }] }, { "type": "Box", "props": { "x": 233, "var": "btn_use", "name": "btn_use" }, "compId": 1023, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1024 }, { "type": "Label", "props": { "y": 11, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即使用", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1025 }] }] }, { "type": "Image", "props": { "y": 45, "x": 67, "skin": "ui/img_uk_text_gxhd.png" }, "compId": 1034 }, { "type": "Label", "props": { "y": 439, "x": 231, "wordWrap": true, "width": 128, "var": "txt_ctype", "text": "类型：步枪", "strokeColor": "#e26740", "stroke": 0, "name": "txt_ctype", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1035 }, { "type": "Label", "props": { "y": 439, "x": 429, "wordWrap": true, "width": 128, "var": "txt_quality", "text": "品质：良", "strokeColor": "#e26740", "stroke": 0, "name": "txt_quality", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1036 }, { "type": "Label", "props": { "y": 465, "x": 231, "wordWrap": true, "width": 128, "var": "txt_attStype", "text": "口径：7.62mm", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attStype", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1037 }, { "type": "Label", "props": { "y": 465, "x": 429, "wordWrap": true, "width": 128, "var": "txt_attBulletMax", "text": "弹容：25", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletMax", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1038 }, { "type": "Label", "props": { "y": 500, "x": 231, "wordWrap": true, "width": 128, "var": "txt_att", "text": "伤害：50", "strokeColor": "#e26740", "stroke": 0, "name": "txt_att", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1039 }, { "type": "Label", "props": { "y": 500, "x": 429, "wordWrap": true, "width": 128, "var": "txt_attCd", "text": "射速：20", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attCd", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1040 }, { "type": "Label", "props": { "y": 529, "x": 231, "wordWrap": true, "width": 128, "var": "txt_attAcc", "text": "精度：90", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attAcc", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1041 }, { "type": "Label", "props": { "y": 529, "x": 429, "wordWrap": true, "width": 128, "var": "txt_attBulletTime", "text": "换弹：10", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletTime", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1042 }] }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_ui2_obj3.png", "ui/img_uk_icon_gunimg.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_text_gxhd.png"], "loadList3D": [] };
            goods.GoodsExhUI = GoodsExhUI;
            REG("ui.goods.GoodsExhUI", GoodsExhUI);
            class GoodsGetUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGetUI.uiView);
                }
            }
            GoodsGetUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 477, "x": 344, "var": "box_btn", "name": "box_btn", "centerX": 0 }, "compId": 461, "child": [{ "type": "Box", "props": { "x": 0, "var": "btn_ok", "name": "btn_ok" }, "compId": 488, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 489 }, { "type": "Label", "props": { "y": 21, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "获取奖励", "strokeColor": "#000000", "stroke": 5, "height": 65, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 490 }] }, { "type": "Box", "props": { "x": 301.5, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 262, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 79, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 219, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGetUI = GoodsGetUI;
            REG("ui.goods.GoodsGetUI", GoodsGetUI);
            class GoodsGet1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet1UI.uiView);
                }
            }
            GoodsGet1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 477, "var": "box_btn", "name": "box_btn", "centerX": 0 }, "compId": 461, "child": [{ "type": "Box", "props": { "y": 181, "x": 255, "var": "btn_get", "name": "btn_get" }, "compId": 506, "child": [{ "type": "Box", "props": { "y": 17, "x": 1, "var": "btn_ok", "name": "btn_ok" }, "compId": 509, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 129, "var": "txt_ad", "underline": true, "text": "获取奖励", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 507 }] }] }, { "type": "Box", "props": { "y": -74, "x": 516, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 233, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 50, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 190, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGet1UI = GoodsGet1UI;
            REG("ui.goods.GoodsGet1UI", GoodsGet1UI);
            class GoodsGet2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet2UI.uiView);
                }
            }
            GoodsGet2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 477, "x": 344, "var": "box_btn", "name": "box_btn", "centerX": 0 }, "compId": 461, "child": [{ "type": "Box", "props": { "y": 61, "x": 519, "var": "btn_ok", "name": "btn_ok" }, "compId": 488, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 489 }, { "type": "Label", "props": { "y": 21, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "获取奖励", "strokeColor": "#000000", "stroke": 5, "height": 65, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 490 }] }, { "type": "Box", "props": { "y": -74, "x": 516, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 262, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 79, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 219, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGet2UI = GoodsGet2UI;
            REG("ui.goods.GoodsGet2UI", GoodsGet2UI);
            class GoodsGet3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet3UI.uiView);
                }
            }
            GoodsGet3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 474, "var": "box_btn", "right": 20, "name": "box_btn" }, "compId": 461, "child": [{ "type": "Box", "props": { "y": 144, "x": 81, "var": "btn_get", "name": "btn_get" }, "compId": 506, "child": [{ "type": "Box", "props": { "y": 17, "x": 1, "var": "btn_ok", "name": "btn_ok" }, "compId": 509, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 129, "var": "txt_ad", "underline": true, "text": "获取奖励", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 507 }] }] }, { "type": "Box", "props": { "y": -11, "x": 0, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 233, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 50, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 190, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGet3UI = GoodsGet3UI;
            REG("ui.goods.GoodsGet3UI", GoodsGet3UI);
            class GoodsGet4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet4UI.uiView);
                }
            }
            GoodsGet4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 477, "var": "box_btn", "right": 20, "name": "box_btn" }, "compId": 461, "child": [{ "type": "Box", "props": { "y": 61, "x": 0, "var": "btn_ok", "name": "btn_ok" }, "compId": 488, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 489 }, { "type": "Label", "props": { "y": 21, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "获取奖励", "strokeColor": "#000000", "stroke": 5, "height": 65, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 490 }] }, { "type": "Box", "props": { "y": -74, "x": 0, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 262, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 79, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 219, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGet4UI = GoodsGet4UI;
            REG("ui.goods.GoodsGet4UI", GoodsGet4UI);
            class GoodsGet5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet5UI.uiView);
                }
            }
            GoodsGet5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 389, "var": "box_btn", "right": 314, "name": "box_btn" }, "compId": 461, "child": [{ "type": "Box", "props": { "y": -11, "x": 0, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 233, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 50, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 190, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }, { "type": "Box", "props": { "x": 456, "var": "btn_get", "name": "btn_get", "bottom": 38 }, "compId": 506, "child": [{ "type": "Box", "props": { "y": 17, "x": 1, "var": "btn_ok", "name": "btn_ok" }, "compId": 509, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 129, "var": "txt_ad", "underline": true, "text": "获取奖励", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 507 }] }] }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGet5UI = GoodsGet5UI;
            REG("ui.goods.GoodsGet5UI", GoodsGet5UI);
            class GoodsGet6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet6UI.uiView);
                }
            }
            GoodsGet6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 389, "var": "box_btn", "right": 314, "name": "box_btn" }, "compId": 461, "child": [{ "type": "Box", "props": { "y": -11, "x": 0, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 233, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 50, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 190, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }, { "type": "Box", "props": { "y": 406, "x": 437, "var": "btn_get", "name": "btn_get" }, "compId": 506, "child": [{ "type": "Box", "props": { "y": 17, "x": 1, "var": "btn_ok", "name": "btn_ok" }, "compId": 509, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 129, "var": "txt_ad", "underline": true, "text": "获取奖励", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 507 }] }] }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGet6UI = GoodsGet6UI;
            REG("ui.goods.GoodsGet6UI", GoodsGet6UI);
            class GoodsGet7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet7UI.uiView);
                }
            }
            GoodsGet7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 233, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 50, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 190, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }, { "type": "Box", "props": { "y": 426, "centerX": 0 }, "compId": 513, "child": [{ "type": "Box", "props": { "y": 66, "var": "box_btn", "right": 0, "name": "box_btn" }, "compId": 461, "child": [{ "type": "Box", "props": { "y": -11, "x": 0, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 199, "x": 79, "var": "btn_get", "name": "btn_get" }, "compId": 506, "child": [{ "type": "Box", "props": { "y": 17, "x": 1, "var": "btn_ok", "name": "btn_ok" }, "compId": 509, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 129, "var": "txt_ad", "underline": true, "text": "获取奖励", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 507 }] }] }, { "type": "Label", "props": { "x": 5, "width": 277, "underline": false, "text": "是否看视频双倍领取", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 512 }] }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_box_rankbox2.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png"], "loadList3D": [] };
            goods.GoodsGet7UI = GoodsGet7UI;
            REG("ui.goods.GoodsGet7UI", GoodsGet7UI);
            class GoodsGet8UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsGet8UI.uiView);
                }
            }
            GoodsGet8UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 453 }, { "type": "Box", "props": { "y": 429, "width": 291, "var": "box_btn", "name": "box_btn", "height": 232, "centerX": 0 }, "compId": 461, "child": [{ "type": "Box", "props": { "y": 113, "x": 0, "var": "btn_ok", "name": "btn_ok" }, "compId": 488, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 489 }, { "type": "Label", "props": { "y": 21, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "获取奖励", "strokeColor": "#000000", "stroke": 5, "height": 65, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 490 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "var": "btn_share", "name": "btn_share", "mouseEnabled": true }, "compId": 491, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 286, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,19,29,19", "height": 118 }, "compId": 492 }, { "type": "Label", "props": { "y": 21, "x": 62, "wordWrap": true, "width": 227, "var": "txt_double", "valign": "middle", "text": "双倍获取", "strokeColor": "#000000", "stroke": 5, "name": "txt_double", "height": 67, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 493 }, { "type": "Image", "props": { "y": 40, "x": 39, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 501 }] }] }, { "type": "Box", "props": { "y": 262, "var": "box_list", "name": "box_list", "centerX": 0 }, "compId": 498 }, { "type": "Image", "props": { "y": 79, "width": 140, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 140, "centerX": 0 }, "compId": 504 }, { "type": "Label", "props": { "y": 219, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "centerX": 0, "bold": true, "align": "center" }, "compId": 505 }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_box_rankbox2.png"], "loadList3D": [] };
            goods.GoodsGet8UI = GoodsGet8UI;
            REG("ui.goods.GoodsGet8UI", GoodsGet8UI);
            class GoodsItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItemUI.uiView);
                }
            }
            GoodsItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": false, "mouseEnabled": true, "height": 319 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 398 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 399 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "var": "img_img", "skin": "ui/img_UM_herohead_card.png", "name": "img_img", "height": 232 }, "compId": 400 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": false, "width": 143, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 402 }, { "type": "Label", "props": { "y": 276, "x": 1, "wordWrap": false, "width": 196, "var": "txt_name1", "valign": "middle", "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name1", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#e5e2da", "bold": true, "align": "center" }, "compId": 404 }, { "type": "Label", "props": { "y": 3, "x": 130, "wordWrap": false, "width": 59, "visible": true, "var": "txt_lv", "text": "11", "strokeColor": "#272727", "stroke": 4, "name": "txt_lv", "height": 53, "fontSize": 60, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 405 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png"], "loadList3D": [] };
            goods.GoodsItemUI = GoodsItemUI;
            REG("ui.goods.GoodsItemUI", GoodsItemUI);
            class GoodsItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItem1UI.uiView);
                }
            }
            GoodsItem1UI.uiView = { "type": "View", "props": { "width": 102, "scaleY": 1, "scaleX": 1, "mouseEnabled": true, "height": 144 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": -1, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "scaleY": 0.5, "scaleX": 0.5, "height": 287, "alpha": 0.5 }, "compId": 40 }, { "type": "Image", "props": { "y": 3, "x": 2, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "scaleY": 0.5, "scaleX": 0.5, "height": 277 }, "compId": 41 }, { "type": "Image", "props": { "y": 22, "x": 5, "var": "img_img", "skin": "ui/img_UM_herohead_card.png", "scaleY": 0.5, "scaleX": 0.5, "name": "img_img" }, "compId": 42 }, { "type": "Label", "props": { "y": 3, "x": 5, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "名称", "strokeColor": "#000000", "stroke": 4, "scaleY": 0.5, "scaleX": 0.5, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 43 }, { "type": "Label", "props": { "y": 108, "x": 6, "wordWrap": false, "width": 180, "text": "77", "strokeColor": "#0a0101", "stroke": 5, "scaleY": 0.5, "scaleX": 0.5, "name": "txt_num", "height": 61, "fontSize": 65, "font": "SimHei", "color": "#fdfdfd", "bold": true, "align": "right" }, "compId": 44 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png"], "loadList3D": [] };
            goods.GoodsItem1UI = GoodsItem1UI;
            REG("ui.goods.GoodsItem1UI", GoodsItem1UI);
            class GoodsItem2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItem2UI.uiView);
                }
            }
            GoodsItem2UI.uiView = { "type": "View", "props": { "width": 170, "mouseEnabled": true, "height": 190 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 139, "x": 7, "width": 153, "skin": "ui/img_uk_ui2_obj11.png", "height": 39 }, "compId": 31 }, { "type": "Image", "props": { "y": 23, "x": 6, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 33 }, { "type": "Clip", "props": { "y": -10, "x": -40, "width": 244, "var": "selectBox", "skin": "ui/clip_uk_ui2_uieffect_1.png", "name": "selectBox", "height": 178, "clipY": 2 }, "compId": 42 }, { "type": "Label", "props": { "y": 149, "x": 21, "wordWrap": false, "width": 126, "var": "txt_name", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 32 }, { "type": "Image", "props": { "y": 6, "x": 9, "width": 150, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico", "height": 150 }, "compId": 34 }, { "type": "Label", "props": { "y": 33, "x": 20, "wordWrap": true, "width": 63, "var": "txt_lv", "text": "Lv.15", "strokeColor": "#444444", "stroke": 2, "name": "txt_lv", "height": 22, "fontSize": 18, "font": "SimHei", "color": "#dbff4c", "bold": true, "align": "left" }, "compId": 35 }, { "type": "Image", "props": { "y": 107, "x": 102, "width": 53, "var": "img_perm", "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 36 }, { "type": "Image", "props": { "y": 21, "x": 146, "width": 20, "visible": true, "var": "img_isNew", "skin": "ui/img_uk_icon_tanhao.png", "name": "img_isNew", "mouseEnabled": true, "height": 20 }, "compId": 37 }, { "type": "Label", "props": { "y": 5, "x": 22, "wordWrap": true, "width": 63, "visible": true, "var": "txt_state", "text": "已装备", "strokeColor": "#402600", "stroke": 2, "name": "txt_state", "height": 22, "fontSize": 18, "font": "SimHei", "color": "#ffe000", "bold": true, "align": "left" }, "compId": 4 }], "loadList": ["ui/img_uk_ui2_obj11.png", "ui/img_uk_ui2_obj8.png", "ui/clip_uk_ui2_uieffect_1.png", "ui/img_uk_icon_gunicon.png", "ui/img_uk_text_yj.png", "ui/img_uk_icon_tanhao.png"], "loadList3D": [] };
            goods.GoodsItem2UI = GoodsItem2UI;
            REG("ui.goods.GoodsItem2UI", GoodsItem2UI);
            class GoodsItem3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItem3UI.uiView);
                }
            }
            GoodsItem3UI.uiView = { "type": "View", "props": { "width": 160, "mouseEnabled": true, "height": 190 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 135, "x": 1, "width": 153, "skin": "ui/img_uk_ui2_obj11.png", "height": 39 }, "compId": 31 }, { "type": "Clip", "props": { "y": 6, "x": -42, "width": 244, "var": "selectBox", "skin": "ui/clip_uk_ui2_uieffect_1.png", "name": "selectBox", "height": 178, "clipY": 2 }, "compId": 42 }, { "type": "Label", "props": { "y": 143, "x": 15, "wordWrap": false, "width": 126, "var": "txt_name", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 32 }, { "type": "Image", "props": { "y": 17, "x": 2, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 46 }, { "type": "Image", "props": { "y": -14, "x": -41, "width": 241, "skin": "ui/img_uk_ui2_uieffect.png", "height": 172 }, "compId": 44 }, { "type": "Image", "props": { "y": 73, "x": 80, "width": 168, "skin": "ui/img_uk_ui2_obj19.png", "pivotY": 84, "pivotX": 84, "height": 168, "blendMode": "lighter" }, "compId": 45 }, { "type": "Image", "props": { "y": -2, "x": 5, "width": 150, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico", "height": 150 }, "compId": 34 }], "animations": [{ "nodes": [{ "target": 45, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 45, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 45, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 45, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_obj11.png", "ui/clip_uk_ui2_uieffect_1.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_uieffect.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_gunicon.png"], "loadList3D": [] };
            goods.GoodsItem3UI = GoodsItem3UI;
            REG("ui.goods.GoodsItem3UI", GoodsItem3UI);
            class GoodsItem5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItem5UI.uiView);
                }
            }
            GoodsItem5UI.uiView = { "type": "View", "props": { "width": 170, "mouseEnabled": true, "height": 150 }, "compId": 2, "child": [{ "type": "ShopBgAnim", "props": { "y": 12, "x": -12, "runtime": "ui.shop.ShopBgAnimUI" }, "compId": 34 }, { "type": "Image", "props": { "y": 15, "x": 1, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 35 }, { "type": "Image", "props": { "y": -2, "x": 4, "width": 150, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico", "height": 150 }, "compId": 36 }, { "type": "Image", "props": { "y": 99, "x": 97, "width": 53, "var": "img_perm", "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 37 }], "loadList": ["ui/img_uk_ui2_obj8.png", "ui/img_uk_icon_gunicon.png", "ui/img_uk_text_yj.png"], "loadList3D": [] };
            goods.GoodsItem5UI = GoodsItem5UI;
            REG("ui.goods.GoodsItem5UI", GoodsItem5UI);
            class GoodsItem6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItem6UI.uiView);
                }
            }
            GoodsItem6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 122, "scaleY": 0.6, "scaleX": 0.6, "mouseThrough": false, "mouseEnabled": true, "height": 204 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 313, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 306 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_img", "skin": "ui/img_UM_herohead_card.png", "name": "img_img" }, "compId": 1146 }, { "type": "Image", "props": { "y": -1, "x": 153, "var": "txt_lv", "skin": "ui/img_ui_num_7.png", "name": "txt_lv" }, "compId": 1151 }, { "type": "Label", "props": { "y": 1, "x": 12, "wordWrap": true, "width": 133, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1156 }, { "type": "Image", "props": { "y": 271, "x": -4, "width": 208, "var": "img_use", "skin": "ui/img_UM_btn_BlueButton_2.png", "scaleY": 1, "scaleX": 1, "name": "img_use", "mouseEnabled": true, "height": 73 }, "compId": 1154 }, { "type": "Image", "props": { "y": 284.5, "x": 48, "var": "img_use2", "skin": "ui/img_UM_ui_text15.png", "name": "img_use2" }, "compId": 1155 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text15.png"], "loadList3D": [] };
            goods.GoodsItem6UI = GoodsItem6UI;
            REG("ui.goods.GoodsItem6UI", GoodsItem6UI);
            class GoodsItem7UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItem7UI.uiView);
                }
            }
            GoodsItem7UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_goodsCard1.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "金币", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 210, "x": 109, "wordWrap": false, "width": 80, "var": "txt_num", "text": "77", "strokeColor": "#0a0101", "stroke": 5, "name": "txt_num", "height": 61, "fontSize": 65, "font": "SimHei", "color": "#fdfdfd", "bold": true, "align": "right" }, "compId": 1158 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_goodsCard1.png"], "loadList3D": [] };
            goods.GoodsItem7UI = GoodsItem7UI;
            REG("ui.goods.GoodsItem7UI", GoodsItem7UI);
            class GoodsItem8UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsItem8UI.uiView);
                }
            }
            GoodsItem8UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "名称", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 212, "x": 109, "wordWrap": false, "width": 80, "var": "txt_num", "text": "77", "strokeColor": "#0a0101", "stroke": 5, "name": "txt_num", "height": 61, "fontSize": 65, "font": "SimHei", "color": "#fdfdfd", "bold": true, "align": "right" }, "compId": 1158 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png"], "loadList3D": [] };
            goods.GoodsItem8UI = GoodsItem8UI;
            REG("ui.goods.GoodsItem8UI", GoodsItem8UI);
            class GoodsLvUpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsLvUpUI.uiView);
                }
            }
            GoodsLvUpUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "skin": "ui/img_UM_ui_bg7.jpg", "right": -100, "left": -100 }, "compId": 1585 }, { "type": "Box", "props": { "y": -808, "centerX": 0 }, "compId": 1628, "child": [{ "type": "Image", "props": { "width": 2353, "skin": "ui/img_UM_effect_zi.png", "height": 1656, "alpha": 0.8 }, "compId": 1586 }, { "type": "Image", "props": { "y": 660, "x": 738, "width": 904, "skin": "ui/img_UM_effect_blue.png", "height": 522, "alpha": 1 }, "compId": 1587 }, { "type": "Box", "props": { "y": 1149, "x": 669 }, "compId": 1595, "child": [{ "type": "Image", "props": { "y": 30.5, "width": 327, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 166, "alpha": 0.5 }, "compId": 1582 }, { "type": "Image", "props": { "y": 0, "x": 29, "width": 64, "skin": "ui/img_UM_icon_lvup_1.png", "height": 64 }, "compId": 1588 }, { "type": "Image", "props": { "y": 96.5, "x": 19, "skin": "ui/img_UM_heroinfo_tiao.png", "alpha": 0.5 }, "compId": 1589 }, { "type": "Image", "props": { "y": 105.5, "x": 29, "width": 42, "skin": "ui/img_UM_icon_heroInfo3.png", "height": 42 }, "compId": 1590 }, { "type": "Label", "props": { "y": 121.5, "x": 84, "wordWrap": false, "width": 104, "var": "txt_hp1", "text": "233", "strokeColor": "#272727", "stroke": 4, "name": "txt_hp1", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1591 }, { "type": "Label", "props": { "y": 100.5, "x": 82, "wordWrap": true, "width": 104, "text": "生命值", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#4598ad", "bold": true, "align": "left" }, "compId": 1592 }, { "type": "Label", "props": { "y": 108.5, "x": 213, "wordWrap": false, "width": 104, "var": "txt_hp2", "text": "+65", "strokeColor": "#272727", "stroke": 4, "name": "txt_hp2", "height": 57, "fontSize": 50, "font": "SimHei", "color": "#00ff5b", "bold": true, "align": "left" }, "compId": 1593 }, { "type": "Label", "props": { "y": 14.5, "x": 103, "wordWrap": true, "width": 147, "text": "我的高塔", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1594 }] }, { "type": "Box", "props": { "y": 1149, "x": 1035 }, "compId": 1596, "child": [{ "type": "Image", "props": { "y": 30.5, "width": 327, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 166, "alpha": 0.5 }, "compId": 1597 }, { "type": "Image", "props": { "y": -0.5, "x": 29, "width": 64, "skin": "ui/img_UM_icon_lvup_3.png", "height": 64 }, "compId": 1598 }, { "type": "Image", "props": { "y": 96.5, "x": 19, "skin": "ui/img_UM_heroinfo_tiao.png", "alpha": 0.5 }, "compId": 1599 }, { "type": "Image", "props": { "y": 105.5, "x": 29, "width": 42, "skin": "ui/img_UM_icon_heroInfo2.png", "height": 42 }, "compId": 1600 }, { "type": "Label", "props": { "y": 121.5, "x": 84, "wordWrap": false, "width": 104, "var": "txt_integral1", "text": "233", "strokeColor": "#272727", "stroke": 4, "name": "txt_integral1", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1601 }, { "type": "Label", "props": { "y": 100.5, "x": 82, "wordWrap": true, "width": 104, "text": "积分", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#4598ad", "bold": true, "align": "left" }, "compId": 1602 }, { "type": "Label", "props": { "y": 108.5, "x": 213, "wordWrap": false, "width": 104, "var": "txt_integral2", "text": "+65", "strokeColor": "#272727", "stroke": 4, "name": "txt_integral2", "height": 57, "fontSize": 50, "font": "SimHei", "color": "#00ff5b", "bold": true, "align": "left" }, "compId": 1603 }, { "type": "Label", "props": { "y": 15, "x": 103, "wordWrap": true, "width": 196, "text": "每击杀积分", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1604 }] }, { "type": "Box", "props": { "y": 1149, "x": 1401 }, "compId": 1605, "child": [{ "type": "Image", "props": { "y": 30.5, "width": 327, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 166, "alpha": 0.5 }, "compId": 1606 }, { "type": "Image", "props": { "y": -0.5, "x": 29, "width": 64, "skin": "ui/img_UM_icon_lvup_2.png", "height": 64 }, "compId": 1607 }, { "type": "Image", "props": { "y": 96.5, "x": 19, "skin": "ui/img_UM_heroinfo_tiao.png", "alpha": 0.5 }, "compId": 1608 }, { "type": "Image", "props": { "y": 105.5, "x": 29, "width": 42, "skin": "ui/img_UM_icon_heroInfo4.png", "height": 42 }, "compId": 1609 }, { "type": "Label", "props": { "y": 121.5, "x": 84, "wordWrap": false, "width": 104, "var": "txt_trophy1", "text": "233", "strokeColor": "#272727", "stroke": 4, "name": "txt_trophy1", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1610 }, { "type": "Label", "props": { "y": 100.5, "x": 82, "wordWrap": true, "width": 104, "text": "奖杯", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#4598ad", "bold": true, "align": "left" }, "compId": 1611 }, { "type": "Label", "props": { "y": 108.5, "x": 213, "wordWrap": false, "width": 104, "var": "txt_trophy2", "text": "+65", "strokeColor": "#272727", "stroke": 4, "name": "txt_trophy2", "height": 57, "fontSize": 50, "font": "SimHei", "color": "#00ff5b", "bold": true, "align": "left" }, "compId": 1612 }, { "type": "Label", "props": { "y": 15, "x": 103, "wordWrap": true, "width": 201, "text": "胜利获得奖杯", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1613 }] }, { "type": "Image", "props": { "y": 988, "x": 1224, "skin": "ui/img_UM_xpicon.png" }, "compId": 1614 }, { "type": "Box", "props": { "y": 1378, "x": 1062, "var": "box_close", "name": "box_close", "mouseEnabled": true }, "compId": 1616, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1617 }, { "type": "Image", "props": { "y": 25, "x": 84, "skin": "ui/img_UM_ui_text32.png" }, "compId": 1619 }] }, { "type": "Image", "props": { "y": 1012, "x": 1062, "width": 85, "skin": "ui/img_UM_xpicon.png", "height": 87 }, "compId": 1620 }, { "type": "Image", "props": { "y": 1029, "x": 1157, "width": 60, "skin": "ui/img_UM_ui_jt.png", "height": 40 }, "compId": 1625 }, { "type": "Image", "props": { "y": 885, "x": 1109, "skin": "ui/img_UM_ui_text35.png" }, "compId": 1626 }, { "type": "Label", "props": { "y": 1020, "x": 1260, "wordWrap": false, "width": 54, "var": "txt_nextLv", "text": "5", "strokeColor": "#272727", "stroke": 4, "name": "txt_nextLv", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1629 }, { "type": "Label", "props": { "y": 1034, "x": 1091, "wordWrap": false, "width": 27, "var": "txt_lv", "text": "5", "strokeColor": "#272727", "stroke": 4, "name": "txt_lv", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1630 }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_effect_zi.png", "ui/img_UM_effect_blue.png", "ui/img_UM_ui_black2.png", "ui/img_UM_icon_lvup_1.png", "ui/img_UM_heroinfo_tiao.png", "ui/img_UM_icon_heroInfo3.png", "ui/img_UM_icon_lvup_3.png", "ui/img_UM_icon_heroInfo2.png", "ui/img_UM_icon_lvup_2.png", "ui/img_UM_icon_heroInfo4.png", "ui/img_UM_xpicon.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text32.png", "ui/img_UM_ui_jt.png", "ui/img_UM_ui_text35.png"], "loadList3D": [] };
            goods.GoodsLvUpUI = GoodsLvUpUI;
            REG("ui.goods.GoodsLvUpUI", GoodsLvUpUI);
        })(goods = ui.goods || (ui.goods = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var guide;
        (function (guide) {
            class GuideArrowUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideArrowUI.uiView);
                }
            }
            GuideArrowUI.uiView = { "type": "View", "props": { "y": -35, "width": 50, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -35, "x": -6, "width": 90, "var": "img_arrow", "skin": "ui/img_UM_guide_Hand.png", "pivotY": 120, "name": "img_arrow", "height": 120, "anchorX": 0.5 }, "compId": 3 }], "animations": [{ "nodes": [{ "target": 3, "keyframes": { "y": [{ "value": -35, "tweenMethod": "quadInOut", "tween": true, "target": 3, "key": "y", "index": 0 }, { "value": -99, "tweenMethod": "quadInOut", "tween": true, "target": 3, "key": "y", "index": 15 }, { "value": -35, "tweenMethod": "linearNone", "tween": true, "target": 3, "label": null, "key": "y", "index": 30 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }, { "nodes": [{ "target": 3, "keyframes": { "y": [{ "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "key": "y", "index": 0 }, { "value": 100, "tweenMethod": "quadIn", "tween": true, "target": 3, "key": "y", "index": 10 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "key": "y", "index": 20 }, { "value": -100, "tweenMethod": "quadIn", "tween": true, "target": 3, "key": "y", "index": 30 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "label": null, "key": "y", "index": 40 }], "x": [{ "value": -100, "tweenMethod": "quadIn", "tween": true, "target": 3, "key": "x", "index": 0 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "key": "x", "index": 10 }, { "value": 100, "tweenMethod": "quadIn", "tween": true, "target": 3, "key": "x", "index": 20 }, { "value": 0, "tweenMethod": "quadOut", "tween": true, "target": 3, "key": "x", "index": 30 }, { "value": -100, "tweenMethod": "quartIn", "tween": true, "target": 3, "label": null, "key": "x", "index": 40 }] } }], "name": "ani2", "id": 2, "frameRate": 24, "action": 0 }, { "nodes": [{ "target": 3, "keyframes": { "x": [{ "value": -200, "tweenMethod": "quadInOut", "tween": true, "target": 3, "key": "x", "index": 0 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "x", "index": 20 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 3, "label": null, "key": "x", "index": 25 }] } }], "name": "ani3", "id": 3, "frameRate": 24, "action": 0 }, { "nodes": [{ "target": 3, "keyframes": { "y": [{ "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "y", "index": 0 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "y", "index": 20 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 3, "label": null, "key": "y", "index": 25 }] } }], "name": "ani4", "id": 4, "frameRate": 24, "action": 0 }, { "nodes": [{ "target": 3, "keyframes": { "x": [{ "value": 200, "tweenMethod": "quadInOut", "tween": true, "target": 3, "key": "x", "index": 0 }, { "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "x", "index": 20 }, { "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 3, "label": null, "key": "x", "index": 25 }] } }], "name": "ani5", "id": 5, "frameRate": 24, "action": 0 }, { "nodes": [{ "target": 3, "keyframes": { "y": [{ "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "y", "index": 0 }, { "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 3, "key": "y", "index": 20 }, { "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 3, "label": null, "key": "y", "index": 25 }] } }], "name": "ani6", "id": 6, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_guide_Hand.png"], "loadList3D": [] };
            guide.GuideArrowUI = GuideArrowUI;
            REG("ui.guide.GuideArrowUI", GuideArrowUI);
            class GuideBattleUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideBattleUI.uiView);
                }
            }
            GuideBattleUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "visible": true, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "GuideItem1", "props": { "y": 342, "x": -53, "width": 400, "var": "ui_left", "name": "ui_left", "height": 400, "runtime": "ui.guide.GuideItem1UI" }, "compId": 706 }], "loadList": [], "loadList3D": [] };
            guide.GuideBattleUI = GuideBattleUI;
            REG("ui.guide.GuideBattleUI", GuideBattleUI);
            class GuideBattleAimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideBattleAimUI.uiView);
                }
            }
            GuideBattleAimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "visible": true, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "GuideItem2", "props": { "y": 315, "right": 72, "runtime": "ui.guide.GuideItem2UI" }, "compId": 707 }], "loadList": [], "loadList3D": [] };
            guide.GuideBattleAimUI = GuideBattleAimUI;
            REG("ui.guide.GuideBattleAimUI", GuideBattleAimUI);
            class GuideBattleAttUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideBattleAttUI.uiView);
                }
            }
            GuideBattleAttUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "visible": true, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "GuideItem3", "props": { "y": 174, "x": -96, "runtime": "ui.guide.GuideItem3UI" }, "compId": 709 }, { "type": "GuideItem3", "props": { "y": 316, "right": 64, "runtime": "ui.guide.GuideItem3UI" }, "compId": 710 }], "loadList": [], "loadList3D": [] };
            guide.GuideBattleAttUI = GuideBattleAttUI;
            REG("ui.guide.GuideBattleAttUI", GuideBattleAttUI);
            class GuideBattleSkillUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideBattleSkillUI.uiView);
                }
            }
            GuideBattleSkillUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "visible": true, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "GuideItem4", "props": { "y": 265, "right": -123, "runtime": "ui.guide.GuideItem4UI" }, "compId": 709 }], "loadList": [], "loadList3D": [] };
            guide.GuideBattleSkillUI = GuideBattleSkillUI;
            REG("ui.guide.GuideBattleSkillUI", GuideBattleSkillUI);
            class GuideDialogUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideDialogUI.uiView);
                }
            }
            GuideDialogUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 183, "x": 38, "width": 527, "var": "img_guider", "skin": "ui/img_UM_ui_hero2.png", "name": "img_guider", "height": 537 }, "compId": 9, "child": [{ "type": "Box", "props": { "y": -83, "x": 445, "var": "box_info", "name": "box_info" }, "compId": 7, "child": [{ "type": "Image", "props": { "width": 545, "skin": "ui/img_UM_paopao.png", "sizeGrid": "20,38,45,105", "height": 218 }, "compId": 4 }, { "type": "Image", "props": { "y": 229, "x": 188, "skin": "ui/img_UM_ui_text58.png" }, "compId": 5 }, { "type": "Image", "props": { "y": 31, "x": 33, "width": 497, "var": "img_info", "skin": "ui/img_UM_ui_guide_1.png", "name": "img_info", "height": 148 }, "compId": 6 }] }] }], "loadList": ["ui/img_UM_ui_hero2.png", "ui/img_UM_paopao.png", "ui/img_UM_ui_text58.png", "ui/img_UM_ui_guide_1.png"], "loadList3D": [] };
            guide.GuideDialogUI = GuideDialogUI;
            REG("ui.guide.GuideDialogUI", GuideDialogUI);
            class GuideItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideItem1UI.uiView);
                }
            }
            GuideItem1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 200, "x": 200, "width": 280, "skin": "ui/img_UM_guide_obj1.png", "pivotY": 140, "pivotX": 140, "height": 280 }, "compId": 1155 }, { "type": "Image", "props": { "y": -44, "x": 115, "skin": "ui/img_UM_guide_obj2.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": -67, "x": 71, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1158 }], "animations": [{ "nodes": [{ "target": 1155, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj1.png", "ui/img_UM_guide_obj2.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            guide.GuideItem1UI = GuideItem1UI;
            REG("ui.guide.GuideItem1UI", GuideItem1UI);
            class GuideItem2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideItem2UI.uiView);
                }
            }
            GuideItem2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 200, "x": 200, "width": 280, "skin": "ui/img_UM_guide_obj1.png", "pivotY": 140, "pivotX": 140, "height": 280 }, "compId": 1155 }, { "type": "Image", "props": { "y": -44, "x": 115, "skin": "ui/img_UM_guide_obj3.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": -69, "x": 71, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1158 }], "animations": [{ "nodes": [{ "target": 1155, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj1.png", "ui/img_UM_guide_obj3.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            guide.GuideItem2UI = GuideItem2UI;
            REG("ui.guide.GuideItem2UI", GuideItem2UI);
            class GuideItem3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideItem3UI.uiView);
                }
            }
            GuideItem3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 179, "x": 179, "width": 161, "skin": "ui/img_UM_guide_obj6.png", "pivotY": 60, "pivotX": 60, "height": 161 }, "compId": 1157 }, { "type": "Image", "props": { "y": 28, "x": 115, "skin": "ui/img_UM_guide_obj4.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 4, "x": 71, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1160 }], "animations": [{ "nodes": [{ "target": 1157, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj6.png", "ui/img_UM_guide_obj4.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            guide.GuideItem3UI = GuideItem3UI;
            REG("ui.guide.GuideItem3UI", GuideItem3UI);
            class GuideItem4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GuideItem4UI.uiView);
                }
            }
            GuideItem4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 200, "x": 200, "width": 148, "skin": "ui/img_UM_guide_obj7.png", "pivotY": 74, "pivotX": 74, "height": 148 }, "compId": 1157 }, { "type": "Image", "props": { "y": 39, "x": 115, "skin": "ui/img_UM_guide_obj5.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 17, "x": 24, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1159 }], "animations": [{ "nodes": [{ "target": 1157, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj7.png", "ui/img_UM_guide_obj5.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            guide.GuideItem4UI = GuideItem4UI;
            REG("ui.guide.GuideItem4UI", GuideItem4UI);
        })(guide = ui.guide || (ui.guide = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var hero;
        (function (hero) {
            class HeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroUI.uiView);
                }
            }
            HeroUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "skin": "ui/img_UM_cardbg3.png", "sizeGrid": "4,5,3,5", "right": -100, "left": -100, "height": 750 }, "compId": 1214 }, { "type": "Box", "props": { "y": 98, "centerX": 18 }, "compId": 1398, "child": [{ "type": "Image", "props": { "y": -281, "x": -134, "width": 916, "skin": "ui/img_UM_effect_blue.png", "height": 914, "blendMode": "lighter", "alpha": 0.5 }, "compId": 1289 }, { "type": "Image", "props": { "y": 385, "x": 144, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1283 }, { "type": "Box", "props": { "y": 0, "x": 190, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1397 }, { "type": "Image", "props": { "y": 139, "x": 104, "var": "img_left", "skin": "ui/img_UM_btn_jiantou.png", "name": "img_left" }, "compId": 1386 }, { "type": "Image", "props": { "y": 141, "x": 501, "var": "img_right", "skin": "ui/img_UM_btn_jiantou2.png", "name": "img_right" }, "compId": 1387 }, { "type": "Label", "props": { "y": 272, "wordWrap": true, "width": 681, "var": "txt_info1", "text": "解锁条件：XXXXXXXXXXXXXXXXXXXXXXXXX", "strokeColor": "#000000", "stroke": 4, "name": "txt_info1", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1389 }, { "type": "PageRedAnim3", "props": { "y": 85, "x": 501, "var": "ui_change", "name": "ui_change", "runtime": "ui.page.PageRedAnim3UI" }, "compId": 1436 }, { "type": "Image", "props": { "y": 121, "x": 286, "var": "img_lock", "skin": "ui/img_UM_ui_lock.png", "name": "img_lock" }, "compId": 1388 }] }, { "type": "Box", "props": { "y": 4, "width": 392, "left": 14, "height": 619 }, "compId": 1399, "child": [{ "type": "Box", "props": { "x": 52, "var": "box_close", "name": "box_close" }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 119, "x": 2, "skin": "ui/img_UM_heronamebg.png" }, "compId": 1288 }, { "type": "Label", "props": { "y": 270, "x": 37, "wordWrap": true, "width": 276, "var": "txt_info", "text": "丹是国际参赛选手中最知名的一位：他的粉丝群体有20亿！过去的3届锦标赛冠军都被他收入囊中，这次的第4届，他也是虎视眈眈。", "strokeColor": "#09192c", "stroke": 4, "name": "txt_info", "height": 241, "fontSize": 24, "font": "SimHei", "color": "#6197ca", "bold": true, "align": "left" }, "compId": 1291 }, { "type": "Image", "props": { "y": 175, "x": 158, "width": 68, "var": "img_att", "skin": "ui/img_UM_heroname_text_1.png", "rotation": -3, "name": "img_att", "height": 36 }, "compId": 1294 }, { "type": "Image", "props": { "y": 212, "x": 244, "width": 111, "var": "img_quality", "skin": "ui/img_UM_heropz_text_1.png", "rotation": -2, "name": "img_quality", "height": 33 }, "compId": 1295 }, { "type": "Image", "props": { "y": 110, "width": 382, "var": "img_name", "skin": "ui/img_UM_hero_text_1.png", "rotation": -3, "name": "img_name", "height": 80 }, "compId": 1296 }, { "type": "Box", "props": { "y": 417, "x": 23 }, "compId": 1426, "child": [{ "type": "Image", "props": { "width": 118, "skin": "ui/img_UM_btn_purple2.png", "sizeGrid": "45,40,45,43", "height": 140 }, "compId": 1371 }, { "type": "Image", "props": { "y": 6, "x": 18, "width": 80, "var": "img_skill", "skin": "ui/img_UM_skillicon_white.png", "name": "img_skill", "height": 80 }, "compId": 1409 }, { "type": "Label", "props": { "y": 91, "x": 4, "wordWrap": true, "width": 110, "var": "txt_skill", "text": "技能名称", "strokeColor": "#5d330c", "stroke": 3, "name": "txt_skill", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1373 }] }, { "type": "Box", "props": { "y": 417, "x": 161 }, "compId": 1427, "child": [{ "type": "Image", "props": { "width": 118, "skin": "ui/img_UM_btn_purple2.png", "sizeGrid": "27,32,45,36", "height": 140 }, "compId": 1372 }, { "type": "Image", "props": { "y": 6, "x": 21, "width": 80, "var": "img_gun", "skin": "ui/img_UM_hero_skill_icon1.png", "name": "img_gun", "height": 80 }, "compId": 1412 }, { "type": "Label", "props": { "y": 91, "x": 5, "wordWrap": false, "width": 110, "var": "txt_gun", "text": "武器名称", "strokeColor": "#5d330c", "stroke": 3, "overflow": "hidden", "name": "txt_gun", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1394 }] }] }, { "type": "List", "props": { "y": 553, "x": 18, "width": 1244, "var": "list_hero", "selectEnable": false, "name": "list_hero", "mouseEnabled": true, "height": 183, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true, "centerX": 0 }, "compId": 1429, "child": [{ "type": "HeroCardItem", "props": { "y": 14, "x": 0, "width": 152, "renderType": "render", "mouseThrough": false, "height": 163, "runtime": "ui.hero.HeroCardItemUI" }, "compId": 1428 }] }, { "type": "Box", "props": { "y": 63, "width": 327, "right": 20, "mouseEnabled": true, "height": 502 }, "compId": 1400, "child": [{ "type": "Image", "props": { "y": 346, "x": 18, "width": 289, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "height": 41 }, "compId": 1245 }, { "type": "Box", "props": { "y": 56, "x": 0, "width": 327, "height": 72 }, "compId": 1312, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao2.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1302 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1303 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo3.png", "height": 50 }, "compId": 1304 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": false, "width": 104, "var": "txt_hp", "text": "233", "strokeColor": "#272727", "stroke": 4, "overflow": "hidden", "name": "txt_hp", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1305 }, { "type": "Label", "props": { "y": 11.5, "x": 65, "wordWrap": true, "width": 104, "text": "生命值", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1306 }, { "type": "Image", "props": { "y": 32.5, "x": 169, "width": 32, "skin": "ui/img_UM_heroinfo_ArrowBack.png", "height": 32 }, "compId": 1376 }, { "type": "Label", "props": { "y": 32.5, "x": 223, "wordWrap": false, "width": 104, "var": "txt_hp1", "text": "233", "strokeColor": "#272727", "stroke": 4, "overflow": "hidden", "name": "txt_hp1", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffe73b", "bold": true, "align": "left" }, "compId": 1377 }] }, { "type": "HeroUpBtn", "props": { "y": 382, "x": 154, "width": 160, "var": "ui_up", "name": "ui_up", "height": 120, "runtime": "ui.hero.HeroUpBtnUI" }, "compId": 1434 }, { "type": "Box", "props": { "x": 20 }, "compId": 1352, "child": [{ "type": "Image", "props": { "y": 17, "width": 217, "skin": "ui/img_UM_loading_barbg.png", "sizeGrid": "8,36,6,30", "scaleY": 1.3, "scaleX": 1.3, "height": 30 }, "compId": 1299 }, { "type": "Label", "props": { "y": 18, "x": 59, "wordWrap": true, "width": 104, "text": "英雄等级", "strokeColor": "#09192c", "stroke": 4, "height": 32, "fontSize": 24, "font": "SimHei", "color": "#b7b7b7", "bold": true, "align": "left" }, "compId": 1300 }, { "type": "Label", "props": { "x": 172, "wordWrap": true, "width": 92, "var": "txt_lv", "text": "5", "strokeColor": "#09192c", "stroke": 4, "name": "txt_lv", "height": 50, "fontSize": 50, "font": "SimHei", "color": "#b7b7b7", "bold": true, "align": "left" }, "compId": 1301 }] }, { "type": "Box", "props": { "y": 128, "x": 0 }, "compId": 1353, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao2.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1354 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1355 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo2.png", "height": 50 }, "compId": 1356 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": false, "width": 104, "var": "txt_att", "text": "43", "strokeColor": "#272727", "stroke": 4, "overflow": "hidden", "name": "txt_att", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1357 }, { "type": "Label", "props": { "y": 11.5, "x": 65, "wordWrap": true, "width": 104, "text": "每秒伤害", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1358 }, { "type": "Image", "props": { "y": 30, "x": 169, "width": 32, "skin": "ui/img_UM_heroinfo_ArrowBack.png", "height": 32 }, "compId": 1378 }, { "type": "Label", "props": { "y": 30, "x": 223, "wordWrap": false, "width": 104, "var": "txt_att1", "text": "44", "strokeColor": "#272727", "stroke": 4, "overflow": "hidden", "name": "txt_att1", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffe73b", "bold": true, "align": "left" }, "compId": 1379 }] }, { "type": "Box", "props": { "y": 200, "x": 0 }, "compId": 1359, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1360 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1361 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo4.png", "height": 50 }, "compId": 1362 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": false, "width": 104, "var": "txt_range", "text": "30m", "strokeColor": "#272727", "stroke": 4, "name": "txt_range", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1363 }, { "type": "Label", "props": { "y": 11.5, "x": 65, "wordWrap": true, "width": 104, "text": "武器射程", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1364 }] }, { "type": "Box", "props": { "y": 269, "x": 0 }, "compId": 1365, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1366 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1367 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo1.png", "height": 50 }, "compId": 1368 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": true, "width": 104, "var": "txt_cooling", "text": "15.00s", "strokeColor": "#272727", "stroke": 4, "name": "txt_cooling", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1369 }, { "type": "Label", "props": { "y": 12, "x": 65, "wordWrap": true, "width": 245, "text": "技能冷却时间", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1370 }] }, { "type": "Image", "props": { "y": 346, "x": 18, "width": 290, "var": "img_bar", "skin": "ui/img_UM_bar_green.png", "sizeGrid": "0,18,0,20", "name": "img_bar", "height": 40 }, "compId": 1374 }, { "type": "Label", "props": { "y": 353, "x": 113, "wordWrap": false, "width": 108, "var": "txt_total", "text": "5/55", "strokeColor": "#272727", "stroke": 4, "name": "txt_total", "height": 32, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1381 }, { "type": "Box", "props": { "y": 390, "x": -2, "width": 159, "var": "box_ad", "name": "box_ad", "mouseEnabled": true, "height": 102 }, "compId": 1404, "child": [{ "type": "Image", "props": { "y": -4, "x": 1, "width": 157, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1405 }, { "type": "Image", "props": { "y": 29, "x": 69, "width": 101, "skin": "ui/img_UM_ui_text31.png", "scaleY": 0.8, "scaleX": 0.8, "height": 46 }, "compId": 1406 }, { "type": "Image", "props": { "y": 29, "x": 18, "width": 69, "skin": "ui/img_UM_ui2_guanggao3.png", "scaleY": 0.8, "scaleX": 0.8, "height": 47 }, "compId": 1407 }] }, { "type": "Box", "props": { "y": 390, "x": -2, "width": 159, "var": "box_noLoc", "name": "box_noLoc", "height": 102 }, "compId": 1401, "child": [{ "type": "Image", "props": { "y": -4, "x": 1, "width": 157, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1402 }, { "type": "Image", "props": { "y": 27, "x": 26, "width": 133, "skin": "ui/img_UM_ui_text15.png", "scaleY": 0.8, "scaleX": 0.8, "height": 50 }, "compId": 1403 }] }, { "type": "Box", "props": { "y": 390, "x": -2, "width": 159, "var": "box_loc", "name": "box_loc", "mouseEnabled": true, "height": 102 }, "compId": 1285, "child": [{ "type": "Image", "props": { "y": -4, "x": 1, "width": 157, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1286 }, { "type": "Image", "props": { "y": 33, "x": 21, "width": 142, "skin": "ui/img_UM_ui_text20.png", "scaleY": 0.8, "scaleX": 0.8, "height": 40 }, "compId": 1287 }] }, { "type": "GuideArrow", "props": { "y": 401, "x": 238, "width": 50, "var": "ui_hand", "rotation": 180, "name": "ui_hand", "height": 50, "anchorX": 0, "runtime": "ui.guide.GuideArrowUI" }, "compId": 1430 }, { "type": "Box", "props": { "y": 306, "x": -148, "var": "box_gift", "name": "box_gift" }, "compId": 1433, "child": [{ "type": "HeroGift", "props": { "width": 100, "var": "ui_gift", "scaleY": 1.4, "scaleX": 1.4, "name": "ui_gift", "height": 133, "runtime": "ui.hero.HeroGiftUI" }, "compId": 1432 }] }] }, { "type": "Box", "props": { "y": -8, "width": 231, "right": 274, "height": 73 }, "compId": 1413, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1414 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 1415 }, { "type": "Image", "props": { "y": 7, "x": 163, "var": "img_tong", "skin": "ui/img_UM_btn__btn_2.png", "name": "img_tong", "mouseThrough": false, "mouseEnabled": true }, "compId": 1416 }, { "type": "Label", "props": { "y": 16, "x": 81, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1418 }] }, { "type": "Box", "props": { "y": -8, "right": 20 }, "compId": 1419, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1420 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 1421 }, { "type": "Image", "props": { "y": 7, "x": 163, "var": "img_jin", "skin": "ui/img_UM_btn__btn_2.png", "name": "img_jin", "mouseThrough": false, "mouseEnabled": true }, "compId": 1422 }, { "type": "Label", "props": { "y": 16, "x": 89, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1424 }] }], "loadList": ["ui/img_UM_cardbg3.png", "ui/img_UM_effect_blue.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_btn_jiantou.png", "ui/img_UM_btn_jiantou2.png", "ui/img_UM_ui_lock.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_heronamebg.png", "ui/img_UM_heroname_text_1.png", "ui/img_UM_heropz_text_1.png", "ui/img_UM_hero_text_1.png", "ui/img_UM_btn_purple2.png", "ui/img_UM_skillicon_white.png", "ui/img_UM_hero_skill_icon1.png", "comp/hscroll.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_heroinfo_tiao2.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_icon_heroInfo3.png", "ui/img_UM_heroinfo_ArrowBack.png", "ui/img_UM_loading_barbg.png", "ui/img_UM_icon_heroInfo2.png", "ui/img_UM_heroinfo_tiao.png", "ui/img_UM_icon_heroInfo4.png", "ui/img_UM_icon_heroInfo1.png", "ui/img_UM_bar_green.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text31.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text15.png", "ui/img_UM_ui_text20.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_btn__btn_2.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            hero.HeroUI = HeroUI;
            REG("ui.hero.HeroUI", HeroUI);
            class HeroBtnLocUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroBtnLocUI.uiView);
                }
            }
            HeroBtnLocUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": false, "height": 120 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 60, "x": 150, "width": 303, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 152, "height": 110 }, "compId": 1173 }, { "type": "Label", "props": { "y": 53, "x": 78, "wordWrap": false, "width": 63, "var": "txt_tong", "text": "5", "strokeColor": "#272727", "stroke": 4, "name": "txt_tong", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1179 }, { "type": "Image", "props": { "y": 53, "x": 152, "width": 32, "skin": "ui/img_UM_xpicon.png", "height": 32 }, "compId": 1181 }, { "type": "Label", "props": { "y": 18, "x": 82, "wordWrap": false, "width": 135, "underlineColor": "#f1f1e7", "text": "申请出战", "stroke": 5, "name": "txt_tong", "height": 32, "fontSize": 32, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1182 }], "animations": [{ "nodes": [{ "target": 1173, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_btn_green.png", "ui/img_UM_xpicon.png"], "loadList3D": [] };
            hero.HeroBtnLocUI = HeroBtnLocUI;
            REG("ui.hero.HeroBtnLocUI", HeroBtnLocUI);
            class HeroCardItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroCardItemUI.uiView);
                }
            }
            HeroCardItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 136, "scaleY": 0.9, "scaleX": 0.9, "mouseThrough": false, "height": 144 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": 5, "width": 142, "var": "img_bg", "skin": "ui/img_UM_btn_textBubble.png", "sizeGrid": "33,33,33,33", "name": "img_bg", "mouseEnabled": true, "height": 157 }, "compId": 1157 }, { "type": "Image", "props": { "y": 9, "x": 13, "width": 126, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "name": "", "height": 134 }, "compId": 1145 }, { "type": "Image", "props": { "y": 24, "x": 18, "width": 115, "var": "img_ico", "skin": "ui/img_UM_hero3.png", "name": "img_ico", "height": 115 }, "compId": 1156 }, { "type": "Label", "props": { "y": -3, "x": 100, "wordWrap": false, "width": 38, "var": "txt_lv", "valign": "middle", "text": "7", "strokeColor": "#000000", "stroke": 4, "name": "txt_lv", "height": 48, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1163 }, { "type": "Label", "props": { "y": -6, "x": 20, "wordWrap": false, "width": 87, "var": "txt_name", "valign": "middle", "text": "英雄名称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 43, "fontSize": 20, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 5, "x": 8, "width": 135, "var": "img_mask", "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "name": "img_mask", "height": 148, "alpha": 0.5 }, "compId": 1158 }, { "type": "Label", "props": { "y": 50, "x": 14, "wordWrap": true, "width": 123, "var": "txt_lock", "valign": "middle", "text": "奖杯100", "strokeColor": "#000000", "stroke": 4, "name": "txt_lock", "height": 40, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1166, "child": [{ "type": "Label", "props": { "y": 32, "x": 12, "wordWrap": true, "width": 100, "valign": "middle", "text": "可解锁", "strokeColor": "#000000", "stroke": 4, "name": "txt_lock", "height": 40, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1167 }] }, { "type": "Clip", "props": { "y": -28, "x": -18, "width": 185, "var": "selectBox", "skin": "ui/img_UM_rank_effectbk1.png", "name": "selectBox", "height": 204, "clipY": 2 }, "compId": 1162 }, { "type": "Image", "props": { "y": 130, "x": 17, "width": 118, "var": "img_isNew", "skin": "ui/img_UM_ribbon_bg_red2.png", "name": "img_isNew", "height": 41 }, "compId": 1164, "child": [{ "type": "Image", "props": { "y": 3, "x": 23, "width": 71, "skin": "ui/img_UM_ui_text69.png", "height": 24 }, "compId": 1165 }] }, { "type": "Image", "props": { "y": 120, "x": 12, "width": 254, "var": "img_ad", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "scaleY": 0.5, "scaleX": 0.5, "name": "img_ad", "mouseThrough": false, "mouseEnabled": true, "height": 105 }, "compId": 1170, "child": [{ "type": "Label", "props": { "y": 29, "x": 79, "wordWrap": true, "width": 150, "valign": "middle", "text": "直接解锁", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1171 }] }, { "type": "Image", "props": { "y": 134, "x": 22, "width": 32, "var": "img_ad2", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad2", "height": 24 }, "compId": 1172 }], "loadList": ["ui/img_UM_btn_textBubble.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_hero3.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_rank_effectbk1.png", "ui/img_UM_ribbon_bg_red2.png", "ui/img_UM_ui_text69.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            hero.HeroCardItemUI = HeroCardItemUI;
            REG("ui.hero.HeroCardItemUI", HeroCardItemUI);
            class HeroCardItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroCardItem1UI.uiView);
                }
            }
            HeroCardItem1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Image", "props": { "y": -10, "x": 134.5, "width": 76, "skin": "ui/img_UM_levelUpArrow.png", "height": 76 }, "compId": 1155 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": false, "width": 122, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 7, "x": 149, "wordWrap": false, "width": 47, "var": "txt_lv", "text": "30", "strokeColor": "#272727", "stroke": 4, "name": "txt_lv", "height": 53, "fontSize": 36, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1156 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_UM_levelUpArrow.png"], "loadList3D": [] };
            hero.HeroCardItem1UI = HeroCardItem1UI;
            REG("ui.hero.HeroCardItem1UI", HeroCardItem1UI);
            class HeroGiftUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroGiftUI.uiView);
                }
            }
            HeroGiftUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 133 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1144 }, { "type": "Image", "props": { "y": 7, "x": 7, "width": 85, "var": "img_hero", "skin": "ui/img_UM_hero2.png", "name": "img_hero", "height": 85 }, "compId": 1147 }, { "type": "Box", "props": { "y": 111, "x": 52, "width": 125, "scaleX": 1, "pivotY": 30, "pivotX": 63, "height": 59 }, "compId": 1152, "child": [{ "type": "Image", "props": { "width": 122, "skin": "ui/img_UM_herokill_bg_yellow.png", "height": 57 }, "compId": 1151 }, { "type": "Image", "props": { "y": 23, "x": 61, "width": 219, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "19,24,33,23", "scaleY": 0.5, "scaleX": 0.5, "pivotY": 37, "pivotX": 110, "height": 96 }, "compId": 1148 }] }, { "type": "Image", "props": { "y": 99, "x": 6, "width": 21, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 17 }, "compId": 1149 }, { "type": "Image", "props": { "y": 97, "x": 27, "width": 66, "var": "img_lv", "skin": "ui/img_UM_ui_text73.png", "name": "img_lv", "height": 20 }, "compId": 1150 }, { "type": "Label", "props": { "y": 65, "x": -3, "wordWrap": false, "width": 93, "var": "txt_num", "text": "x28", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_num", "height": 21, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1153 }], "animations": [{ "nodes": [{ "target": 1152, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 10 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 17 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 10 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_hero2.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text73.png"], "loadList3D": [] };
            hero.HeroGiftUI = HeroGiftUI;
            REG("ui.hero.HeroGiftUI", HeroGiftUI);
            class HeroLvUpAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroLvUpAnimUI.uiView);
                }
            }
            HeroLvUpAnimUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "skin": "ui/img_UM_ui_bg9.jpg", "right": -100, "left": -100 }, "compId": 1395 }, { "type": "HeroLvUpAnimItem", "props": { "y": 0, "width": 1280, "var": "ui_aim", "name": "ui_aim", "height": 720, "centerX": 0, "anchorX": 0, "runtime": "ui.hero.HeroLvUpAnimItemUI" }, "compId": 1432 }], "loadList": ["ui/img_UM_ui_bg9.jpg"], "loadList3D": [] };
            hero.HeroLvUpAnimUI = HeroLvUpAnimUI;
            REG("ui.hero.HeroLvUpAnimUI", HeroLvUpAnimUI);
            class HeroLvUpAnimItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroLvUpAnimItemUI.uiView);
                }
            }
            HeroLvUpAnimItemUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 456, "x": 495, "width": 289, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "height": 70, "alpha": 0 }, "compId": 1245 }, { "type": "Image", "props": { "y": 457, "x": 494, "width": 10, "skin": "ui/img_UM_bar_green.png", "sizeGrid": "15,53,22,21", "height": 69, "alpha": 0 }, "compId": 1374 }, { "type": "Box", "props": { "y": 472, "x": 602, "alpha": 0 }, "compId": 1384, "child": [{ "type": "Label", "props": { "y": 1, "x": 10, "wordWrap": false, "width": 21, "var": "txt_card", "text": "5/55", "strokeColor": "#272727", "stroke": 4, "name": "txt_card", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1381 }] }, { "type": "HeroCardItem1", "props": { "y": 304, "x": 640, "width": 200, "var": "ui_card", "scaleY": 1, "scaleX": 1, "pivotY": 155, "pivotX": 100, "name": "ui_card", "height": 310, "runtime": "ui.hero.HeroCardItem1UI" }, "compId": 1446 }, { "type": "Image", "props": { "y": 467, "x": 503, "width": 80, "skin": "ui/img_UM_lvupeffect.png", "rotation": 360, "pivotY": 40, "pivotX": 40, "height": 80, "alpha": 0 }, "compId": 1406 }, { "type": "Image", "props": { "y": 506, "x": 503, "width": 80, "skin": "ui/img_UM_lvupeffect.png", "rotation": 360, "pivotY": 40, "pivotX": 40, "height": 80, "alpha": 0 }, "compId": 1407 }, { "type": "Image", "props": { "y": 286, "x": 640, "width": 256, "skin": "ui/img_UM_levelUpArrow.png", "scaleY": 3, "scaleX": 3, "pivotY": 128, "pivotX": 128, "height": 256, "alpha": 0 }, "compId": 1408 }, { "type": "Image", "props": { "y": 340, "x": 946, "width": 358, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "31,31,31,28", "pivotY": 78, "pivotX": 179, "height": 156, "alpha": 0.5 }, "compId": 1409 }, { "type": "Box", "props": { "y": 315, "x": 953, "width": 337, "pivotY": 29, "pivotX": 169, "height": 57, "alpha": 1 }, "compId": 1420, "child": [{ "type": "Box", "props": {}, "compId": 1413, "child": [{ "type": "Image", "props": { "y": 2, "width": 50, "skin": "ui/img_UM_rank_jlbg2.png", "height": 50 }, "compId": 1411 }, { "type": "Image", "props": { "width": 50, "skin": "ui/img_UM_icon_heroInfo3.png", "height": 50 }, "compId": 1412 }] }, { "type": "Label", "props": { "y": 0, "x": 55, "wordWrap": true, "width": 90, "text": "生命值", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#45d9ff", "bold": true, "align": "left" }, "compId": 1417 }, { "type": "Label", "props": { "y": 28, "x": 56, "wordWrap": true, "width": 90, "var": "txt_hp1", "text": "2988", "strokeColor": "#000000", "stroke": 4, "name": "txt_hp1", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1418 }, { "type": "Label", "props": { "y": 14, "x": 228, "wordWrap": true, "width": 109, "var": "txt_hp2", "text": "+288", "strokeColor": "#000000", "stroke": 4, "name": "txt_hp2", "height": 41, "fontSize": 40, "font": "SimHei", "color": "#47fd0d", "bold": true, "align": "left" }, "compId": 1419 }] }, { "type": "Box", "props": { "y": 372, "x": 953, "width": 338, "pivotY": 29, "pivotX": 169, "height": 57, "alpha": 1 }, "compId": 1421, "child": [{ "type": "Box", "props": {}, "compId": 1422, "child": [{ "type": "Image", "props": { "y": 2, "width": 50, "skin": "ui/img_UM_rank_jlbg2.png", "height": 50 }, "compId": 1423 }, { "type": "Image", "props": { "width": 50, "skin": "ui/img_UM_icon_heroInfo2.png", "height": 50 }, "compId": 1424 }] }, { "type": "Label", "props": { "y": 0, "x": 55, "wordWrap": true, "width": 158, "text": "最大每秒伤害", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#45d9ff", "bold": true, "align": "left" }, "compId": 1425 }, { "type": "Label", "props": { "y": 28, "x": 56, "wordWrap": true, "width": 90, "var": "txt_att1", "text": "2988", "strokeColor": "#000000", "stroke": 4, "name": "txt_att1", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1426 }, { "type": "Label", "props": { "y": 14, "x": 229, "wordWrap": true, "width": 109, "var": "txt_att2", "text": "+288", "strokeColor": "#000000", "stroke": 4, "name": "txt_att2", "height": 41, "fontSize": 40, "font": "SimHei", "color": "#47fd0d", "bold": true, "align": "left" }, "compId": 1427 }] }, { "type": "Label", "props": { "y": 238, "x": 921, "wordWrap": true, "width": 249, "var": "txt_lv", "text": "等级7", "strokeColor": "#920b00", "stroke": 8, "pivotY": 37, "pivotX": 125, "name": "txt_lv", "height": 73, "fontSize": 50, "font": "SimHei", "color": "#f1da33", "bold": false, "alpha": 1, "align": "center" }, "compId": 1429 }, { "type": "Box", "props": { "y": 451, "x": 490, "var": "box_get", "name": "box_get", "alpha": 1 }, "compId": 1431, "child": [{ "type": "HeroBtnLoc", "props": { "y": 0, "x": 0, "var": "ui_get", "name": "ui_get", "runtime": "ui.hero.HeroBtnLocUI" }, "compId": 1445 }, { "type": "GuideArrow", "props": { "y": 68, "x": 33, "width": 50, "rotation": -88, "height": 50, "anchorX": 0, "runtime": "ui.guide.GuideArrowUI" }, "compId": 1439 }] }, { "type": "Box", "props": { "y": 14, "x": 16, "visible": true }, "compId": 1432, "child": [{ "type": "Image", "props": { "y": -7, "x": -6, "skin": "ui/img_UM_playerinfo.png" }, "compId": 1433 }, { "type": "Image", "props": { "y": 68, "x": 122, "width": 195, "var": "bar_exp", "skin": "ui/img_UM_playerEXPbar.png", "name": "bar_exp", "height": 46 }, "compId": 1434 }, { "type": "Label", "props": { "y": 35, "x": 132, "wordWrap": false, "width": 173, "var": "txt_name", "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1435 }, { "type": "Image", "props": { "y": 12, "x": 15, "width": 95, "var": "img_head", "skin": "ui/img_UM_playerhead.png", "name": "img_head", "height": 95 }, "compId": 1436 }, { "type": "Label", "props": { "y": 63, "x": 117, "wordWrap": true, "width": 192, "var": "txt_ep", "valign": "middle", "text": "45/50", "strokeColor": "#000000", "stroke": 4, "name": "txt_ep", "height": 55, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1437 }, { "type": "Label", "props": { "y": 42.5, "x": 336, "wordWrap": true, "width": 56, "var": "txt_lv2", "valign": "middle", "text": "20", "strokeColor": "#000000", "stroke": 4, "name": "txt_lv2", "height": 55, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1438 }] }, { "type": "Box", "props": { "y": 586, "x": 491, "width": 297, "var": "box_close", "name": "box_close", "height": 107, "alpha": 1 }, "compId": 1444, "child": [{ "type": "Image", "props": { "y": 55, "x": 152, "width": 303, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 152, "height": 110 }, "compId": 1440 }, { "type": "Label", "props": { "y": 48, "x": 80, "wordWrap": false, "width": 63, "var": "txt_tong", "text": "5", "strokeColor": "#272727", "stroke": 4, "name": "txt_tong", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1441 }, { "type": "Image", "props": { "y": 48, "x": 154, "width": 32, "skin": "ui/img_UM_xpicon.png", "height": 32 }, "compId": 1442 }, { "type": "Label", "props": { "y": 13, "x": 84, "wordWrap": false, "width": 135, "underlineColor": "#f1f1e7", "text": "低调走开", "stroke": 5, "name": "txt_tong", "height": 32, "fontSize": 32, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1443 }] }], "animations": [{ "nodes": [{ "target": 1408, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleY", "index": 15 }, { "value": 3, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleY", "index": 25 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleX", "index": 15 }, { "value": 3, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleX", "index": 25 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 15 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 25 }] } }, { "target": 1374, "keyframes": { "width": [{ "value": 292, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "width", "index": 0 }, { "value": 10, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "width", "index": 15 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "alpha", "index": 20 }] } }, { "target": 1406, "keyframes": { "x": [{ "value": 772, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "x", "index": 0 }, { "value": 503, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "x", "index": 15 }], "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "rotation", "index": 15 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "alpha", "index": 20 }] } }, { "target": 1407, "keyframes": { "x": [{ "value": 773, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "x", "index": 0 }, { "value": 503, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "x", "index": 15 }], "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "rotation", "index": 15 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "alpha", "index": 20 }] } }, { "target": 1446, "keyframes": { "var": [{ "value": "ui_card", "tweenMethod": "linearNone", "tween": false, "target": 1446, "key": "var", "index": 0 }, { "value": "ui_card", "tweenMethod": "linearNone", "tween": false, "target": 1446, "key": "var", "index": 45 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleY", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleY", "index": 15 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleY", "index": 18 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleY", "index": 20 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleY", "index": 22 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleY", "index": 24 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleX", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleX", "index": 15 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleX", "index": 18 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleX", "index": 20 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleX", "index": 22 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1446, "key": "scaleX", "index": 24 }], "name": [{ "value": "", "tweenMethod": "linearNone", "tween": false, "target": 1446, "key": "name", "index": 0 }, { "value": "ui_card", "tweenMethod": "linearNone", "tween": false, "target": 1446, "key": "name", "index": 45 }] } }, { "target": 1245, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1245, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1245, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1245, "key": "alpha", "index": 20 }] } }, { "target": 1384, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1384, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1384, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1384, "key": "alpha", "index": 20 }] } }, { "target": 1429, "keyframes": { "y": [{ "value": 231, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 0 }, { "value": 273, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 15 }, { "value": 238, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 25 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 25 }] } }, { "target": 1409, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1409, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1409, "key": "alpha", "index": 30 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1409, "key": "alpha", "index": 40 }] } }, { "target": 1420, "keyframes": { "y": [{ "value": 315, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "y", "index": 0 }, { "value": 292, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "y", "index": 25 }, { "value": 315, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "y", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "alpha", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "alpha", "index": 35 }] } }, { "target": 1421, "keyframes": { "y": [{ "value": 372, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "y", "index": 0 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "y", "index": 35 }, { "value": 372, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "y", "index": 45 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "alpha", "index": 35 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "alpha", "index": 45 }] } }, { "target": 1431, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1431, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1431, "key": "alpha", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1431, "key": "alpha", "index": 35 }] } }, { "target": 1444, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1444, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1444, "key": "alpha", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1444, "key": "alpha", "index": 35 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_ui_head_namebg.png", "ui/img_UM_bar_green.png", "ui/img_UM_lvupeffect.png", "ui/img_UM_levelUpArrow.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_rank_jlbg2.png", "ui/img_UM_icon_heroInfo3.png", "ui/img_UM_icon_heroInfo2.png", "ui/img_UM_playerinfo.png", "ui/img_UM_playerEXPbar.png", "ui/img_UM_playerhead.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_xpicon.png"], "loadList3D": [] };
            hero.HeroLvUpAnimItemUI = HeroLvUpAnimItemUI;
            REG("ui.hero.HeroLvUpAnimItemUI", HeroLvUpAnimItemUI);
            class HeroLvUpTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroLvUpTipUI.uiView);
                }
            }
            HeroLvUpTipUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "skin": "ui/img_UM_ui_bg7.jpg", "right": -100, "left": -100 }, "compId": 1395 }, { "type": "Box", "props": { "var": "box_close", "top": 30, "name": "box_close", "left": 30 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Box", "props": { "y": -18, "width": 961, "height": 690, "centerX": 0 }, "compId": 1406, "child": [{ "type": "Image", "props": { "y": 378, "x": 413, "width": 289, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "height": 41 }, "compId": 1245 }, { "type": "Label", "props": { "y": 222, "x": 417, "wordWrap": false, "width": 285, "var": "txt_name", "text": "卡牌名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 60, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1246 }, { "type": "Image", "props": { "width": 592, "skin": "ui/img_UM_effect_blue.png", "height": 663, "blendMode": "lighter", "alpha": 0.5 }, "compId": 1289 }, { "type": "Image", "props": { "y": 375, "x": 411, "width": 293, "skin": "ui/img_UM_bar_green.png", "sizeGrid": "15,53,22,21", "height": 46 }, "compId": 1374 }, { "type": "Box", "props": { "y": 383, "x": 520 }, "compId": 1384, "child": [{ "type": "BattleHeroCardItem", "props": { "y": -191, "x": -330, "var": "ui_card", "scaleY": 1, "scaleX": 1, "name": "ui_card", "runtime": "ui.battle.BattleHeroCardItemUI" }, "compId": 1407 }, { "type": "Label", "props": { "y": 0, "x": 2, "wordWrap": false, "width": 77, "var": "txt_card", "text": "5/55", "strokeColor": "#272727", "stroke": 4, "name": "txt_card", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1381 }] }, { "type": "Image", "props": { "y": 181, "x": 330, "width": 76, "skin": "ui/img_UM_levelUpArrow.png", "height": 76 }, "compId": 1397 }, { "type": "Label", "props": { "y": 282, "x": 417, "wordWrap": true, "width": 135, "var": "txt_quality", "text": "稀有", "strokeColor": "#000000", "stroke": 4, "name": "txt_quality", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1398 }, { "type": "Label", "props": { "y": 429, "x": 464, "wordWrap": true, "width": 217, "text": "有升级可用", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 33, "fontSize": 24, "font": "SimHei", "color": "#23c02a", "bold": true, "align": "center" }, "compId": 1399 }, { "type": "Box", "props": { "y": 586, "x": 149, "width": 576, "height": 104 }, "compId": 1403, "child": [{ "type": "Box", "props": { "y": 3, "var": "box_no", "name": "box_no" }, "compId": 1285, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1286 }, { "type": "Image", "props": { "y": 26, "x": 43, "skin": "ui/img_UM_ui_text49.png" }, "compId": 1400 }] }, { "type": "Image", "props": { "y": 0, "x": 273, "width": 303, "var": "img_lv", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "27,30,40,37", "name": "img_lv", "mouseEnabled": true, "height": 110 }, "compId": 1401, "child": [{ "type": "Image", "props": { "y": 29, "x": 80, "skin": "ui/img_UM_ui_text50.png" }, "compId": 1402 }] }] }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_effect_blue.png", "ui/img_UM_bar_green.png", "ui/img_UM_levelUpArrow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text49.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text50.png"], "loadList3D": [] };
            hero.HeroLvUpTipUI = HeroLvUpTipUI;
            REG("ui.hero.HeroLvUpTipUI", HeroLvUpTipUI);
            class HeroNewUnlockTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroNewUnlockTipUI.uiView);
                }
            }
            HeroNewUnlockTipUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 62, "x": 154, "skin": "ui/img_UM_SponsorWall.png" }, "compId": 1152 }, { "type": "Image", "props": { "y": 533, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": -1, "x": 130, "skin": "ui/img_UM_ui_text80.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1200 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 196, "x": 185.5, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1201 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 205, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1202 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 337, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1203 }, { "type": "Image", "props": { "y": 618, "x": 263, "width": 227, "var": "img_ok", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,48,33", "name": "img_ok", "height": 99 }, "compId": 1189, "child": [{ "type": "Label", "props": { "y": 25, "x": 0, "wordWrap": true, "width": 226, "valign": "middle", "text": "确定", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1192 }] }, { "type": "Image", "props": { "y": 488, "x": 263, "width": 227, "var": "img_go", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "name": "img_go", "height": 98 }, "compId": 1195, "child": [{ "type": "Label", "props": { "y": 23, "x": 38, "wordWrap": true, "width": 150, "valign": "middle", "text": "前往强化", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1196 }] }, { "type": "Box", "props": { "y": 153, "x": 760, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1198 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text80.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_green.png"], "loadList3D": [] };
            hero.HeroNewUnlockTipUI = HeroNewUnlockTipUI;
            REG("ui.hero.HeroNewUnlockTipUI", HeroNewUnlockTipUI);
            class HeroUnlockTipUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroUnlockTipUI.uiView);
                }
            }
            HeroUnlockTipUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 62, "x": 154, "skin": "ui/img_UM_SponsorWall.png" }, "compId": 1152 }, { "type": "Image", "props": { "y": 533, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": -1, "x": 130, "skin": "ui/img_UM_ui_text80.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1200 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 196, "x": 185.5, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1201 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 205, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1202 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 337, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1203 }, { "type": "Label", "props": { "y": 487, "x": 185.5, "wordWrap": true, "width": 226, "valign": "middle", "text": "英雄解锁进度：", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1187 }, { "type": "Box", "props": { "y": 520, "x": 199 }, "compId": 1188, "child": [{ "type": "Image", "props": { "y": 6, "x": 23, "width": 445, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "33,33,33,33", "height": 52 }, "compId": 1184 }, { "type": "Image", "props": { "y": 9, "x": 26, "width": 624, "var": "img_bar", "skin": "ui/img_UM_btn__Gold.png", "sizeGrid": "33,33,33,33", "scaleY": 0.7, "scaleX": 0.7, "name": "img_bar", "height": 66 }, "compId": 1185 }, { "type": "Image", "props": { "width": 57, "skin": "ui/img_UM_icon_cup.png", "height": 62 }, "compId": 1183 }, { "type": "Label", "props": { "y": 17, "x": 114, "wordWrap": false, "width": 226, "var": "txt_info", "valign": "middle", "text": "100%", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1186 }] }, { "type": "Image", "props": { "y": 619, "x": 199, "width": 227, "var": "img_ok", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,48,33", "name": "img_ok", "height": 99 }, "compId": 1189, "child": [{ "type": "Label", "props": { "y": 25, "x": 0, "wordWrap": true, "width": 226, "valign": "middle", "text": "确定", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1192 }] }, { "type": "Image", "props": { "y": 620, "x": 445, "width": 227, "var": "img_ad", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "name": "img_ad", "height": 98 }, "compId": 1190, "child": [{ "type": "Label", "props": { "y": 23, "x": 60, "wordWrap": true, "width": 150, "valign": "middle", "text": "直接解锁", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1193 }, { "type": "Image", "props": { "y": 27.5, "x": 22, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1194 }] }, { "type": "Image", "props": { "y": 621, "x": 445, "width": 227, "var": "img_go", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "name": "img_go", "height": 98 }, "compId": 1195, "child": [{ "type": "Label", "props": { "y": 23, "x": 38, "wordWrap": true, "width": 150, "valign": "middle", "text": "前往强化", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1196 }] }, { "type": "Box", "props": { "y": 153, "x": 760, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1198 }, { "type": "Button", "props": { "y": 74.5, "x": 1043, "var": "btn_close", "stateNum": 1, "skin": "ui/btn_uj_btn_close.png", "name": "btn_close" }, "compId": 1199 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text80.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_btn__Gold.png", "ui/img_UM_icon_cup.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui2_guanggao3.png", "ui/btn_uj_btn_close.png"], "loadList3D": [] };
            hero.HeroUnlockTipUI = HeroUnlockTipUI;
            REG("ui.hero.HeroUnlockTipUI", HeroUnlockTipUI);
            class HeroUnlockTip1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroUnlockTip1UI.uiView);
                }
            }
            HeroUnlockTip1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 62, "x": 154, "skin": "ui/img_UM_SponsorWall.png" }, "compId": 1152 }, { "type": "Image", "props": { "y": 533, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": -1, "x": 130, "skin": "ui/img_UM_ui_text80.png" }, "compId": 1143 }, { "type": "BattleTrialHeroAnim1", "props": { "y": -9, "x": 554, "runtime": "ui.battle.BattleTrialHeroAnim1UI" }, "compId": 1205 }, { "type": "BattleTrialHeroAnim2", "props": { "y": 196, "x": 185.5, "var": "ui_left", "name": "ui_left", "runtime": "ui.battle.BattleTrialHeroAnim2UI" }, "compId": 1206 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 205, "x": 345, "var": "ui_up", "name": "ui_up", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1207 }, { "type": "BattleTrialHeroAnim3", "props": { "y": 337, "x": 345, "var": "ui_down", "name": "ui_down", "runtime": "ui.battle.BattleTrialHeroAnim3UI" }, "compId": 1208 }, { "type": "Label", "props": { "y": 487, "x": 185.5, "wordWrap": true, "width": 226, "valign": "middle", "text": "英雄解锁进度：", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1187 }, { "type": "Label", "props": { "y": 487, "x": 382, "wordWrap": false, "width": 289, "var": "txt_unlock", "valign": "middle", "text": "（再战N场可成功解锁）", "strokeColor": "#0d0d0d", "stroke": 5, "name": "txt_unlock", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#c6b817", "bold": true, "align": "left" }, "compId": 1203 }, { "type": "Box", "props": { "y": 520, "x": 199 }, "compId": 1188, "child": [{ "type": "Image", "props": { "y": 6, "x": 23, "width": 445, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "33,33,33,33", "height": 52 }, "compId": 1184 }, { "type": "Image", "props": { "y": 9, "x": 26, "width": 624, "var": "img_bar", "skin": "ui/img_UM_btn__Gold.png", "sizeGrid": "33,33,33,33", "scaleY": 0.7, "scaleX": 0.7, "name": "img_bar", "height": 66 }, "compId": 1185 }, { "type": "Image", "props": { "width": 57, "skin": "ui/img_UM_icon_cup.png", "height": 62 }, "compId": 1183 }, { "type": "Label", "props": { "y": 17, "x": 114, "wordWrap": false, "width": 226, "var": "txt_info", "valign": "middle", "text": "100%", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1186 }] }, { "type": "Image", "props": { "y": 619, "x": 199, "width": 227, "var": "img_battle", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,48,33", "name": "img_battle", "height": 99 }, "compId": 1189, "child": [{ "type": "Label", "props": { "y": 25, "x": 0, "wordWrap": true, "width": 226, "valign": "middle", "text": "再战一场", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1192 }] }, { "type": "Image", "props": { "y": 619, "x": 199, "width": 227, "var": "img_use", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,48,33", "name": "img_use", "height": 99 }, "compId": 1200, "child": [{ "type": "Label", "props": { "y": 25, "x": 0, "wordWrap": true, "width": 226, "valign": "middle", "text": "马上使用", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1201 }] }, { "type": "Image", "props": { "y": 620, "x": 445, "width": 227, "var": "img_ad", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "name": "img_ad", "height": 98 }, "compId": 1190, "child": [{ "type": "Label", "props": { "y": 23, "x": 60, "wordWrap": true, "width": 150, "valign": "middle", "text": "直接解锁", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1193 }, { "type": "Image", "props": { "y": 27.5, "x": 22, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1194 }] }, { "type": "Image", "props": { "y": 621, "x": 445, "width": 227, "var": "img_go", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "name": "img_go", "height": 98 }, "compId": 1195, "child": [{ "type": "Label", "props": { "y": 23, "x": 60, "wordWrap": true, "width": 150, "valign": "middle", "text": "强化使用", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1196 }, { "type": "Image", "props": { "y": 27, "x": 22, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1202 }] }, { "type": "Box", "props": { "y": 153, "x": 760, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1198 }, { "type": "Button", "props": { "y": 74.5, "x": 1043, "var": "btn_close", "stateNum": 1, "skin": "ui/btn_uj_btn_close.png", "name": "btn_close" }, "compId": 1199 }, { "type": "Label", "props": { "y": 683, "x": 455, "wordWrap": false, "width": 203, "var": "txt_tip", "valign": "middle", "text": "！马上获得新英雄！", "strokeColor": "#f1110c", "stroke": 5, "name": "txt_tip", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#c6b817", "bold": true, "align": "center" }, "compId": 1204 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text80.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_btn__Gold.png", "ui/img_UM_icon_cup.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui2_guanggao3.png", "ui/btn_uj_btn_close.png"], "loadList3D": [] };
            hero.HeroUnlockTip1UI = HeroUnlockTip1UI;
            REG("ui.hero.HeroUnlockTip1UI", HeroUnlockTip1UI);
            class HeroUpBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroUpBtnUI.uiView);
                }
            }
            HeroUpBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 160, "mouseThrough": false, "height": 120 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 60, "x": 80, "width": 160, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 80, "height": 110 }, "compId": 1173 }, { "type": "Image", "props": { "y": 17, "x": 45, "width": 74, "skin": "ui/img_UM_ui_text24.png", "height": 29 }, "compId": 1176 }, { "type": "Image", "props": { "y": 52, "x": 84, "width": 33, "skin": "ui/img_UM_gold.png", "height": 33 }, "compId": 1177 }, { "type": "Label", "props": { "y": 53, "x": 10, "wordWrap": false, "width": 63, "var": "txt_tong", "text": "5", "strokeColor": "#272727", "stroke": 4, "name": "txt_tong", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1179 }], "animations": [{ "nodes": [{ "target": 1173, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text24.png", "ui/img_UM_gold.png"], "loadList3D": [] };
            hero.HeroUpBtnUI = HeroUpBtnUI;
            REG("ui.hero.HeroUpBtnUI", HeroUpBtnUI);
        })(hero = ui.hero || (ui.hero = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var lead;
        (function (lead) {
            class LeadUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LeadUI.uiView);
                }
            }
            LeadUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100, "height": 864 }, "compId": 731 }, { "type": "Box", "props": { "y": 0, "x": 0, "var": "box_scene", "name": "box_scene" }, "compId": 727 }, { "type": "Box", "props": { "y": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 710, "child": [{ "type": "Image", "props": { "y": 367, "x": 16, "width": 371, "skin": "ui/img_uk_ui2_obj13.png", "sizeGrid": "48,73,48,112", "height": 345 }, "compId": 746 }, { "type": "Box", "props": { "y": 528, "x": 39, "var": "box_1", "name": "box_1" }, "compId": 737, "child": [{ "type": "ShopBgAnim", "props": { "y": 10, "x": -11, "runtime": "ui.shop.ShopBgAnimUI" }, "compId": 761 }, { "type": "Image", "props": { "y": 133, "x": 1, "width": 153, "skin": "ui/img_uk_ui2_obj11.png", "height": 39 }, "compId": 738 }, { "type": "Label", "props": { "y": 143, "x": 15, "wordWrap": false, "width": 126, "var": "txt_name1", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name1", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 739 }, { "type": "Image", "props": { "y": 17, "x": 0, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 740 }, { "type": "Image", "props": { "y": 0, "x": 3, "width": 150, "var": "img_reward1", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_reward1", "height": 150 }, "compId": 741 }, { "type": "Image", "props": { "y": 101, "x": 96, "width": 53, "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 743 }] }, { "type": "Box", "props": { "y": 528, "x": 204, "var": "box_2", "name": "box_2" }, "compId": 752, "child": [{ "type": "ShopBgAnim", "props": { "y": 14, "x": -13, "runtime": "ui.shop.ShopBgAnimUI" }, "compId": 762 }, { "type": "Image", "props": { "y": 133, "x": 1, "width": 153, "skin": "ui/img_uk_ui2_obj11.png", "height": 39 }, "compId": 753 }, { "type": "Label", "props": { "y": 143, "x": 15, "wordWrap": false, "width": 126, "var": "txt_name2", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 754 }, { "type": "Image", "props": { "y": 17, "x": 0, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 755 }, { "type": "Image", "props": { "y": 0, "x": 3, "width": 150, "var": "img_reward2", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_reward2", "height": 150 }, "compId": 756 }, { "type": "Image", "props": { "y": 101, "x": 96, "width": 53, "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 758 }] }, { "type": "Image", "props": { "y": 0, "x": 884, "width": 383, "var": "img_list", "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "name": "img_list", "height": 724, "alpha": 1 }, "compId": 736 }, { "type": "List", "props": { "y": 14, "x": 896, "width": 360, "var": "list_lead", "name": "list_lead", "height": 689 }, "compId": 709, "child": [{ "type": "LeadItem", "props": { "renderType": "render", "runtime": "ui.lead.LeadItemUI" }, "compId": 661 }] }, { "type": "Image", "props": { "y": 143, "x": 9, "var": "img_one", "skin": "ui/img_uk_rank_icon1.png", "name": "img_one" }, "compId": 714, "child": [{ "type": "Image", "props": { "y": -6, "x": 82, "width": 35, "var": "box_star_1", "skin": "ui/img_uk_star2.png", "name": "box_star_1", "height": 33 }, "compId": 770 }, { "type": "Box", "props": { "y": -6, "x": 65, "var": "box_star_2", "name": "box_star_2" }, "compId": 773, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "name": "img_1", "height": 33 }, "compId": 771 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "name": "img_1", "height": 33 }, "compId": 772 }] }] }, { "type": "Label", "props": { "y": 111, "x": 24, "wordWrap": true, "width": 170, "var": "txt_one", "valign": "middle", "text": "当前军衔", "strokeColor": "#7a7a7a", "stroke": 5, "name": "txt_one", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 711 }, { "type": "Box", "props": { "y": 111, "x": 204, "var": "box_next", "name": "box_next" }, "compId": 726, "child": [{ "type": "Image", "props": { "y": 78, "x": 32, "width": 110, "var": "img_next", "skin": "ui/img_uk_rank_icon2.png", "name": "img_next", "height": 110 }, "compId": 715 }, { "type": "Image", "props": { "y": 126, "width": 32, "skin": "ui/img_uk_ui_new_ui30.png", "name": "img_arrow", "height": 25 }, "compId": 713 }, { "type": "Label", "props": { "y": 1, "x": 2, "wordWrap": true, "width": 170, "var": "txt_next", "valign": "middle", "text": "下一军衔", "strokeColor": "#7a7a7a", "stroke": 5, "name": "txt_next", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 712 }, { "type": "Image", "props": { "y": 52, "x": 69.5, "width": 35, "var": "box_star_3", "skin": "ui/img_uk_star2.png", "name": "box_star_3", "height": 33 }, "compId": 778 }, { "type": "Box", "props": { "y": 52, "x": 52, "var": "box_star_4", "name": "box_star_4" }, "compId": 779, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "name": "img_1", "height": 33 }, "compId": 780 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "name": "img_1", "height": 33 }, "compId": 781 }] }] }, { "type": "Label", "props": { "y": 418, "x": 59, "wordWrap": true, "width": 282, "var": "txt_hp", "valign": "middle", "text": "血量上限+10%", "strokeColor": "#3e3e3e", "stroke": 5, "name": "txt_hp", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffdc51", "bold": false, "align": "center" }, "compId": 748 }, { "type": "Label", "props": { "y": 445, "x": 59, "wordWrap": true, "width": 282, "var": "txt_jin", "valign": "middle", "text": "金币奖励+10%", "strokeColor": "#3e3e3e", "stroke": 5, "name": "txt_jin", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffdc51", "bold": false, "align": "center" }, "compId": 749 }, { "type": "Label", "props": { "y": 475, "x": 59, "wordWrap": true, "width": 282, "var": "txt_tong", "valign": "middle", "text": "钻石奖励+10%", "strokeColor": "#3e3e3e", "stroke": 5, "name": "txt_tong", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffdc51", "bold": false, "align": "center" }, "compId": 750 }, { "type": "Label", "props": { "y": 387, "x": 111, "wordWrap": true, "width": 170, "var": "img_top", "valign": "middle", "text": "军衔加成", "strokeColor": "#3b3b3b", "stroke": 5, "name": "img_top", "height": 35, "fontSize": 23, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 751 }, { "type": "Label", "props": { "y": 507, "x": 66, "wordWrap": true, "width": 282, "valign": "middle", "text": "下一军衔奖励：", "strokeColor": "#3e3e3e", "stroke": 5, "height": 35, "fontSize": 23, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 760 }, { "type": "Box", "props": { "y": 524, "x": 441, "var": "btn_up", "name": "btn_up" }, "compId": 768, "child": [{ "type": "Image", "props": { "y": 55, "x": 30, "width": 286, "skin": "ui/img_uk_btn_btn1.png", "sizeGrid": "16,18,16,16", "height": 91 }, "compId": 723 }, { "type": "Label", "props": { "y": 82, "x": 60, "wordWrap": true, "width": 227, "valign": "middle", "text": "军衔提升", "strokeColor": "#9c7227", "height": 43, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 724 }, { "type": "Image", "props": { "y": 80, "x": 273, "width": 27, "skin": "ui/img_uk_ui_new_ui30.png", "rotation": -90, "height": 25 }, "compId": 725 }, { "type": "LeadObj", "props": { "var": "btn_anm", "name": "btn_anm", "centerY": 11, "centerX": 6, "runtime": "ui.lead.LeadObjUI" }, "compId": 766 }] }] }, { "type": "Box", "props": { "y": 17, "x": 31, "var": "btn_close", "name": "btn_close" }, "compId": 732, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 733 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 734 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 735 }] }], "animations": [{ "nodes": [{ "target": 538, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleY", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleY", "index": 30 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleY", "index": 45 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleY", "index": 65 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleX", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleX", "index": 30 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleX", "index": 45 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "scaleX", "index": 65 }], "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "rotation", "index": 0 }, { "value": 83, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "rotation", "index": 15 }, { "value": 166, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "rotation", "index": 30 }, { "value": 249, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "rotation", "index": 45 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 538, "key": "rotation", "index": 65 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_ui2_obj13.png", "ui/img_uk_ui2_obj11.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_icon_gunicon.png", "ui/img_uk_text_yj.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_rank_icon1.png", "ui/img_uk_star2.png", "ui/img_uk_rank_icon2.png", "ui/img_uk_ui_new_ui30.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            lead.LeadUI = LeadUI;
            REG("ui.lead.LeadUI", LeadUI);
            class LeadItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LeadItemUI.uiView);
                }
            }
            LeadItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 360, "height": 140 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 356, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "89,91,40,86", "height": 135, "alpha": 0.7 }, "compId": 856 }, { "type": "Image", "props": { "y": 13, "x": 8, "width": 344, "skin": "ui/img_uk_ui2_obj23.png", "sizeGrid": "11,9,14,11", "height": 34, "alpha": 0.6 }, "compId": 857 }, { "type": "Label", "props": { "y": 45, "x": 45, "wordWrap": true, "width": 261, "var": "txt_info", "valign": "middle", "text": "吃鸡 3 次    （2/3）", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_info", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 841 }, { "type": "Label", "props": { "y": 80, "x": 167, "wordWrap": true, "width": 68, "valign": "middle", "text": "奖励：", "strokeColor": "#3b3b3b", "stroke": 5, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 845 }, { "type": "Image", "props": { "y": 81, "x": 292, "width": 36, "var": "img_1", "skin": "ui/img_uk_Icon_zs.png", "scaleY": 0.9, "scaleX": 0.9, "name": "img_1", "height": 36 }, "compId": 846 }, { "type": "Label", "props": { "y": 80, "x": 230, "wordWrap": true, "width": 54, "var": "txt_reward", "valign": "middle", "text": "100", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_reward", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 848 }, { "type": "Label", "props": { "y": 14, "x": 20, "wordWrap": true, "width": 262, "valign": "middle", "text": "任务目标1", "strokeColor": "#252534", "stroke": 4, "height": 31, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 858 }, { "type": "Image", "props": { "y": 76, "x": 17, "width": 115, "skin": "ui/img_uk_ui2_btn2.png", "height": 46 }, "compId": 859 }, { "type": "Label", "props": { "y": 81, "x": -26, "wordWrap": true, "width": 142, "var": "txt_go", "valign": "middle", "text": "立即前往", "strokeColor": "#1e6208", "stroke": 5, "name": "txt_go", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed28", "bold": false, "align": "right" }, "compId": 844 }], "loadList": ["ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_obj23.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_ui2_btn2.png"], "loadList3D": [] };
            lead.LeadItemUI = LeadItemUI;
            REG("ui.lead.LeadItemUI", LeadItemUI);
            class LeadObjUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LeadObjUI.uiView);
                }
            }
            LeadObjUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 320, "mouseThrough": false, "height": 160 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 38, "x": 284, "width": 50, "skin": "ui/img_uk_ui2_zy2.png", "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 725 }, { "type": "Image", "props": { "y": 126, "x": 35, "width": 50, "skin": "ui/img_uk_ui2_zy3.png", "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 726 }, { "type": "Image", "props": { "y": 38, "x": 35, "width": 50, "skin": "ui/img_uk_ui2_zy2.png", "scaleX": -1, "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 731 }, { "type": "Image", "props": { "y": 126, "x": 284, "width": 50, "skin": "ui/img_uk_ui2_zy3.png", "scaleX": -1, "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 732 }], "animations": [{ "nodes": [{ "target": 726, "keyframes": { "y": [{ "value": 126, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "y", "index": 0 }, { "value": 126.5, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "y", "index": 5 }, { "value": 131, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "y", "index": 10 }, { "value": 126, "tweenMethod": "linearNone", "tween": true, "target": 726, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 35, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "x", "index": 0 }, { "value": 33, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "x", "index": 5 }, { "value": 28, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "x", "index": 10 }, { "value": 35, "tweenMethod": "linearNone", "tween": true, "target": 726, "label": null, "key": "x", "index": 20 }] } }, { "target": 725, "keyframes": { "y": [{ "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "y", "index": 0 }, { "value": 33, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "y", "index": 5 }, { "value": 28, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "y", "index": 10 }, { "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 725, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 284, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "x", "index": 0 }, { "value": 287, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "x", "index": 5 }, { "value": 292, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "x", "index": 10 }, { "value": 284, "tweenMethod": "linearNone", "tween": true, "target": 725, "label": null, "key": "x", "index": 20 }] } }, { "target": 731, "keyframes": { "y": [{ "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "y", "index": 0 }, { "value": 33, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "y", "index": 5 }, { "value": 29, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "y", "index": 10 }, { "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 731, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 35, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "x", "index": 0 }, { "value": 33, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "x", "index": 5 }, { "value": 29, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "x", "index": 10 }, { "value": 35, "tweenMethod": "linearNone", "tween": true, "target": 731, "label": null, "key": "x", "index": 20 }] } }, { "target": 732, "keyframes": { "y": [{ "value": 126, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "y", "index": 0 }, { "value": 126.5, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "y", "index": 5 }, { "value": 131, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "y", "index": 10 }, { "value": 126, "tweenMethod": "linearNone", "tween": true, "target": 732, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 284, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "x", "index": 0 }, { "value": 287, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "x", "index": 5 }, { "value": 291, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "x", "index": 10 }, { "value": 284, "tweenMethod": "linearNone", "tween": true, "target": 732, "label": null, "key": "x", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_zy2.png", "ui/img_uk_ui2_zy3.png"], "loadList3D": [] };
            lead.LeadObjUI = LeadObjUI;
            REG("ui.lead.LeadObjUI", LeadObjUI);
            class LeadUpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LeadUpUI.uiView);
                }
            }
            LeadUpUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerY": 0, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 421, "x": 497, "var": "btn_get", "name": "btn_get" }, "compId": 482, "child": [{ "type": "Image", "props": { "y": 7, "x": -1, "width": 286, "var": "btn_up", "skin": "ui/img_uk_btn_btn1.png", "sizeGrid": "16,18,16,16", "name": "btn_up", "height": 91 }, "compId": 483 }, { "type": "Label", "props": { "y": 36.5, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "确定", "strokeColor": "#9c7227", "height": 43, "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 484 }] }, { "type": "Image", "props": { "y": 66, "x": 482, "width": 315, "skin": "ui/img_uk_ui2_obj19.png", "height": 211 }, "compId": 495 }, { "type": "Image", "props": { "y": 133, "x": 390, "skin": "ui/img_uk_ui_obj.png" }, "compId": 494 }, { "type": "Image", "props": { "y": 135, "x": 483, "skin": "ui/img_uk_text_jxts.png" }, "compId": 496 }, { "type": "Label", "props": { "y": 87, "x": 492, "wordWrap": true, "width": 125, "var": "txt_name", "valign": "middle", "text": "列兵", "strokeColor": "#000000", "stroke": 5, "name": "txt_name", "italic": true, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 497 }, { "type": "Image", "props": { "y": 85, "x": 608, "width": 64, "skin": "ui/img_uk_leadup.png", "height": 46 }, "compId": 498 }, { "type": "Label", "props": { "y": 87, "x": 672, "wordWrap": true, "width": 125, "var": "txt_name2", "valign": "middle", "text": "列兵", "strokeColor": "#000000", "stroke": 5, "name": "txt_name2", "italic": true, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 500 }, { "type": "Image", "props": { "y": 322, "x": 381, "width": 517, "skin": "ui/img_uk_ui_new_ui33.png", "height": 33, "alpha": 0.5 }, "compId": 513 }, { "type": "Label", "props": { "y": 240, "x": 554, "wordWrap": true, "width": 171, "valign": "middle", "text": "军衔加成", "strokeColor": "#000000", "stroke": 3, "italic": true, "height": 43, "fontSize": 22, "font": "SimHei", "color": "#ffbd16", "bold": true, "align": "center" }, "compId": 501 }, { "type": "Image", "props": { "y": 284, "x": 381, "width": 517, "skin": "ui/img_uk_ui_new_ui33.png", "height": 33, "alpha": 0.5 }, "compId": 510 }, { "type": "Image", "props": { "y": 360, "x": 381, "width": 517, "skin": "ui/img_uk_ui_new_ui33.png", "height": 33, "alpha": 0.5 }, "compId": 514 }, { "type": "Image", "props": { "y": 316, "x": 608, "width": 64, "skin": "ui/img_uk_leadup.png", "height": 46 }, "compId": 503 }, { "type": "Label", "props": { "y": 286, "x": 445, "wordWrap": true, "width": 149, "var": "txt_hp", "valign": "middle", "text": "血量上限+5%", "strokeColor": "#000000", "stroke": 3, "name": "txt_hp", "italic": true, "height": 30, "fontSize": 22, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 504 }, { "type": "Label", "props": { "y": 324, "x": 445, "wordWrap": true, "width": 149, "var": "txt_tong", "valign": "middle", "text": "金币奖励+10%", "strokeColor": "#000000", "stroke": 3, "name": "txt_tong", "italic": true, "height": 30, "fontSize": 22, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 505 }, { "type": "Label", "props": { "y": 362, "x": 445, "wordWrap": true, "width": 149, "var": "txt_jin", "valign": "middle", "text": "钻石奖励+10%", "strokeColor": "#000000", "stroke": 3, "name": "txt_jin", "italic": true, "height": 30, "fontSize": 22, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 506 }, { "type": "Label", "props": { "y": 285, "x": 689, "wordWrap": true, "width": 149, "var": "txt_hp2", "valign": "middle", "text": "血量上限+5%", "strokeColor": "#000000", "stroke": 3, "name": "txt_hp2", "italic": true, "height": 30, "fontSize": 22, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 507 }, { "type": "Label", "props": { "y": 323, "x": 689, "wordWrap": true, "width": 149, "var": "txt_tong2", "valign": "middle", "text": "金币奖励+10%", "strokeColor": "#000000", "stroke": 3, "name": "txt_tong2", "italic": true, "height": 30, "fontSize": 22, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 508 }, { "type": "Label", "props": { "y": 361, "x": 689, "wordWrap": true, "width": 149, "var": "txt_jin2", "valign": "middle", "text": "钻石奖励+10%", "strokeColor": "#000000", "stroke": 3, "name": "txt_jin2", "italic": true, "height": 30, "fontSize": 22, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 509 }], "loadList": ["ui/img_uk_btn_btn1.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_ui_obj.png", "ui/img_uk_text_jxts.png", "ui/img_uk_leadup.png", "ui/img_uk_ui_new_ui33.png"], "loadList3D": [] };
            lead.LeadUpUI = LeadUpUI;
            REG("ui.lead.LeadUpUI", LeadUpUI);
        })(lead = ui.lead || (ui.lead = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var loading;
        (function (loading) {
            class LoadingLoginUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LoadingLoginUI.uiView);
                }
            }
            LoadingLoginUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "skin": "ui/img_UM_loading.jpg", "right": -100, "left": -100, "height": 720 }, "compId": 19 }, { "type": "Box", "props": { "width": 374, "height": 280, "centerX": 0, "bottom": 73 }, "compId": 15, "child": [{ "type": "Image", "props": { "y": 169, "x": -336, "width": 1045, "skin": "ui/img_UM_loadingBarbg.png", "sizeGrid": "0,32,0,32", "height": 40 }, "compId": 28 }, { "type": "Image", "props": { "y": 169, "x": -331, "width": 1036, "var": "img_act", "skin": "ui/img_UM_loadingBar.png", "name": "img_act", "height": 40 }, "compId": 29 }, { "type": "Label", "props": { "y": 178, "var": "txt_load", "text": "60%", "name": "txt_load", "fontSize": 24, "font": "SimHei", "color": "#ffffff", "centerX": 0 }, "compId": 9 }, { "type": "Box", "props": { "y": 218, "x": -255 }, "compId": 31, "child": [{ "type": "Image", "props": { "y": 32, "x": 0, "width": 473, "skin": "ui/img_UM_loading_text1.png", "height": 38 }, "compId": 32 }, { "type": "Image", "props": { "y": 32, "x": 582, "skin": "ui/img_UM_loading_text2.png" }, "compId": 33 }, { "type": "Image", "props": { "y": 77, "x": -186, "skin": "ui/img_UM_loading_text3.png", "alpha": 1 }, "compId": 30 }, { "type": "Image", "props": { "y": -7, "x": 350, "width": 193, "skin": "ui/img_UM_loading_text4.png", "height": 38 }, "compId": 34 }] }] }, { "type": "Label", "props": { "y": 8, "x": 13, "var": "txt_ver", "text": "v 1.0.0", "name": "txt_ver", "fontSize": 20, "font": "SimHei", "color": "#b2b2b2" }, "compId": 16 }], "loadList": ["ui/img_UM_loading.jpg", "ui/img_UM_loadingBarbg.png", "ui/img_UM_loadingBar.png", "ui/img_UM_loading_text1.png", "ui/img_UM_loading_text2.png", "ui/img_UM_loading_text3.png", "ui/img_UM_loading_text4.png"], "loadList3D": [] };
            loading.LoadingLoginUI = LoadingLoginUI;
            REG("ui.loading.LoadingLoginUI", LoadingLoginUI);
            class LoadingOfflineUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LoadingOfflineUI.uiView);
                }
            }
            LoadingOfflineUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "top": 0, "right": 0, "left": 0, "bottom": 0, "bgColor": "#000000" }, "compId": 19 }, { "type": "Label", "props": { "y": 348, "x": 418, "var": "txt_load", "text": "当前网络环境较差,请检查网络后重启游戏", "name": "txt_load", "fontSize": 26, "font": "SimHei", "color": "#ffffff", "centerX": 0 }, "compId": 9 }], "loadList": [], "loadList3D": [] };
            loading.LoadingOfflineUI = LoadingOfflineUI;
            REG("ui.loading.LoadingOfflineUI", LoadingOfflineUI);
        })(loading = ui.loading || (ui.loading = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var lottery;
        (function (lottery) {
            class LotteryUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LotteryUI.uiView);
                }
            }
            LotteryUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100, "height": 720 }, "compId": 647 }, { "type": "Box", "props": { "y": 40, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "centerX": 0 }, "compId": 693, "child": [{ "type": "Image", "props": { "y": -2, "x": 211, "skin": "ui/img_uk_ui_obj.png" }, "compId": 649 }, { "type": "Image", "props": { "y": 0, "x": 308, "skin": "ui/img_uk_text_wzbj.png" }, "compId": 650 }, { "type": "Box", "props": { "y": -36, "x": 942 }, "compId": 787, "child": [{ "type": "Image", "props": { "y": 4, "width": 254, "var": "img_list", "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "name": "img_list", "height": 706, "alpha": 1 }, "compId": 781 }, { "type": "Label", "props": { "y": 575, "x": 45, "wordWrap": true, "width": 164, "var": "txt_getNum", "valign": "middle", "text": "当前累计次数：5", "strokeColor": "#212121", "stroke": 4, "name": "txt_getNum", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffc32c", "bold": false, "align": "center" }, "compId": 732 }, { "type": "Box", "props": { "y": 424, "x": 28 }, "compId": 744, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 736 }, { "type": "Image", "props": { "y": -6, "x": 37, "width": 123, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico", "height": 123 }, "compId": 739 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 735 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 738 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj1.png", "height": 42 }, "compId": 745 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 285, "x": 28 }, "compId": 760, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 761 }, { "type": "Image", "props": { "y": -6, "x": 37, "width": 123, "var": "img_ico2", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico2", "height": 123 }, "compId": 762 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 764 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name2", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 765 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj2.png", "height": 42 }, "compId": 766 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc2", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc2" }, "compId": 784 }] }, { "type": "Box", "props": { "y": 147, "x": 28 }, "compId": 767, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 768 }, { "type": "Image", "props": { "y": -8, "x": 37, "width": 123, "var": "img_ico3", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico3", "height": 123 }, "compId": 769 }, { "type": "Image", "props": { "y": 68, "x": 140, "width": 53, "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 770 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 771 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name3", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name3", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 772 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj3.png", "height": 42 }, "compId": 773 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc3", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc3" }, "compId": 785 }] }, { "type": "Box", "props": { "y": 8, "x": 28 }, "compId": 774, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 775 }, { "type": "Image", "props": { "y": -8, "x": 37, "width": 123, "var": "img_ico4", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico4", "height": 123 }, "compId": 776 }, { "type": "Image", "props": { "y": 68, "x": 140, "width": 53, "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 777 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 778 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name4", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name4", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 779 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj4.png", "height": 42 }, "compId": 780 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc4", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc4" }, "compId": 786 }] }, { "type": "Box", "props": { "y": 611, "x": 10, "var": "btn_get", "name": "btn_get", "mouseEnabled": true }, "compId": 729, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 234, "skin": "ui/img_uk_btn_btn1.png", "height": 68 }, "compId": 730 }, { "type": "Label", "props": { "y": 20, "x": 22, "wordWrap": true, "width": 190, "valign": "middle", "text": "获取奖励", "strokeColor": "#0f3367", "stroke": 5, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 731 }] }] }, { "type": "Box", "props": { "y": 43, "x": -43, "var": "img_bg", "name": "img_bg" }, "compId": 789, "child": [{ "type": "Image", "props": { "y": 221, "x": 53, "var": "item11", "skin": "ui/img_uk_shop_bg5.png", "name": "item11" }, "compId": 652, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs1.png", "height": 138 }, "compId": 664 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x100", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 665 }] }, { "type": "Image", "props": { "y": 221, "x": 776, "var": "item5", "skin": "ui/img_uk_shop_bg5.png", "name": "item5" }, "compId": 653, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs3.png", "height": 138 }, "compId": 666 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x500", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 667 }] }, { "type": "Image", "props": { "y": 394, "x": 53, "var": "item10", "skin": "ui/img_uk_shop_bg6.png", "name": "item10" }, "compId": 654, "child": [{ "type": "LotteryObj2", "props": { "y": -30, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 723 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods11", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods11", "height": 138 }, "compId": 668 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品装备", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 669 }] }, { "type": "Image", "props": { "y": 396, "x": 234, "var": "item9", "skin": "ui/img_uk_shop_bg4.png", "name": "item9" }, "compId": 655, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold3.png", "height": 138 }, "compId": 670 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x1000", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 671 }] }, { "type": "Image", "props": { "y": 396, "x": 415, "var": "item8", "skin": "ui/img_uk_shop_bg5.png", "name": "item8" }, "compId": 656, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs4.png", "height": 138 }, "compId": 672 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x1000", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 673 }] }, { "type": "Image", "props": { "y": 396, "x": 596, "var": "item7", "skin": "ui/img_uk_shop_bg4.png", "name": "item7" }, "compId": 657, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold2.png", "height": 138 }, "compId": 674 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x600", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 675 }] }, { "type": "Image", "props": { "y": 396, "x": 776, "var": "item6", "skin": "ui/img_uk_shop_bg6.png", "name": "item6" }, "compId": 658, "child": [{ "type": "LotteryObj2", "props": { "y": -32, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 725 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods7", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods7", "height": 138 }, "compId": 676 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品装备", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 677 }] }, { "type": "Image", "props": { "y": 49, "x": 52, "var": "item0", "skin": "ui/img_uk_shop_bg6.png", "name": "item0" }, "compId": 678, "child": [{ "type": "LotteryObj2", "props": { "y": -30, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 722 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods1", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods1", "height": 138 }, "compId": 679 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品武器", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 680 }] }, { "type": "Image", "props": { "y": 49, "x": 233, "var": "item1", "skin": "ui/img_uk_shop_bg4.png", "name": "item1" }, "compId": 681, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold1.png", "height": 138 }, "compId": 682 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 683 }] }, { "type": "Image", "props": { "y": 49, "x": 414, "var": "item2", "skin": "ui/img_uk_shop_bg5.png", "name": "item2" }, "compId": 684, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs2.png", "height": 138 }, "compId": 685 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x200", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 686 }] }, { "type": "Image", "props": { "y": 49, "x": 595, "var": "item3", "skin": "ui/img_uk_shop_bg4.png", "name": "item3" }, "compId": 687, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold4.png", "height": 138 }, "compId": 688 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x2000", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 689 }] }, { "type": "Image", "props": { "y": 49, "x": 776, "var": "item4", "skin": "ui/img_uk_shop_bg6.png", "name": "item4" }, "compId": 690, "child": [{ "type": "LotteryObj2", "props": { "y": -32, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 724 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods5", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods5", "height": 138 }, "compId": 691 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品装备", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 692 }] }, { "type": "Image", "props": { "y": 52, "x": 55, "width": 286, "var": "img_frame", "skin": "ui/img_uk_ui2_uieffect.png", "pivotY": 52, "pivotX": 55, "name": "img_frame", "height": 267 }, "compId": 702 }] }, { "type": "Box", "props": { "y": 268, "x": 306 }, "compId": 788, "child": [{ "type": "Label", "props": { "y": 112, "x": 38, "wordWrap": true, "width": 226, "var": "txt_num", "valign": "middle", "text": "5次之后必得稀有物品", "strokeColor": "#212121", "stroke": 4, "name": "txt_num", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 659 }, { "type": "LotteryObj1", "props": { "var": "btn_ok", "name": "btn_ok", "runtime": "ui.lottery.LotteryObj1UI" }, "compId": 721 }] }] }, { "type": "Box", "props": { "y": 26, "x": 41, "var": "btn_close", "name": "btn_close", "mouseEnabled": true }, "compId": 698, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 699 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 700 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 701 }] }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_ui_obj.png", "ui/img_uk_text_wzbj.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_icon_gunicon.png", "ui/img_uk_ui2_obj11.png", "ui/img_uk_text_lj1.png", "ui/img_uk_ui2_ylq.png", "ui/img_uk_text_lj2.png", "ui/img_uk_text_yj.png", "ui/img_uk_text_lj3.png", "ui/img_uk_text_lj4.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_shop_bg5.png", "ui/img_uk_icon_zs1.png", "ui/img_uk_icon_zs3.png", "ui/img_uk_shop_bg6.png", "ui/img_uk_icon_gunicon4.png", "ui/img_uk_shop_bg4.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_icon_zs4.png", "ui/img_uk_icon_gold2.png", "ui/img_uk_icon_gold1.png", "ui/img_uk_icon_zs2.png", "ui/img_uk_icon_gold4.png", "ui/img_uk_ui2_uieffect.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            lottery.LotteryUI = LotteryUI;
            REG("ui.lottery.LotteryUI", LotteryUI);
            class Lottery1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Lottery1UI.uiView);
                }
            }
            Lottery1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100, "height": 720 }, "compId": 647 }, { "type": "Box", "props": { "y": 40, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "centerX": 0 }, "compId": 693, "child": [{ "type": "Image", "props": { "y": -2, "x": 211, "skin": "ui/img_uk_ui_obj.png" }, "compId": 649 }, { "type": "Image", "props": { "y": 0, "x": 308, "skin": "ui/img_uk_text_wzbj.png" }, "compId": 650 }, { "type": "Box", "props": { "y": -36, "x": 942 }, "compId": 787, "child": [{ "type": "Image", "props": { "y": 4, "width": 254, "var": "img_list", "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "name": "img_list", "height": 706, "alpha": 1 }, "compId": 781 }, { "type": "Label", "props": { "y": 575, "x": 45, "wordWrap": true, "width": 164, "var": "txt_getNum", "valign": "middle", "text": "当前累计次数：5", "strokeColor": "#212121", "stroke": 4, "name": "txt_getNum", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffc32c", "bold": false, "align": "center" }, "compId": 732 }, { "type": "Box", "props": { "y": 424, "x": 28 }, "compId": 744, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 736 }, { "type": "Image", "props": { "y": -6, "x": 37, "width": 123, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico", "height": 123 }, "compId": 739 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 735 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 738 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj1.png", "height": 42 }, "compId": 745 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc" }, "compId": 783 }] }, { "type": "Box", "props": { "y": 285, "x": 28 }, "compId": 760, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 761 }, { "type": "Image", "props": { "y": -6, "x": 37, "width": 123, "var": "img_ico2", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico2", "height": 123 }, "compId": 762 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 764 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name2", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 765 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj2.png", "height": 42 }, "compId": 766 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc2", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc2" }, "compId": 784 }] }, { "type": "Box", "props": { "y": 147, "x": 28 }, "compId": 767, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 768 }, { "type": "Image", "props": { "y": -8, "x": 37, "width": 123, "var": "img_ico3", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico3", "height": 123 }, "compId": 769 }, { "type": "Image", "props": { "y": 68, "x": 140, "width": 53, "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 770 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 771 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name3", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name3", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 772 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj3.png", "height": 42 }, "compId": 773 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc3", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc3" }, "compId": 785 }] }, { "type": "Box", "props": { "y": 8, "x": 28 }, "compId": 774, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 396, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "91,88,36,92", "scaleY": 0.5, "scaleX": 0.5, "height": 170, "alpha": 0.7 }, "compId": 775 }, { "type": "Image", "props": { "y": -8, "x": 37, "width": 123, "var": "img_ico4", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico4", "height": 123 }, "compId": 776 }, { "type": "Image", "props": { "y": 68, "x": 140, "width": 53, "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 777 }, { "type": "Image", "props": { "y": 107, "x": 1, "width": 194, "skin": "ui/img_uk_ui2_obj11.png", "height": 34 }, "compId": 778 }, { "type": "Label", "props": { "y": 114, "x": 36, "wordWrap": false, "width": 126, "var": "txt_name4", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name4", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 779 }, { "type": "Image", "props": { "y": 19, "x": 0, "width": 86, "skin": "ui/img_uk_text_lj4.png", "height": 42 }, "compId": 780 }, { "type": "Image", "props": { "y": 19, "x": 0, "visible": false, "var": "img_loc4", "skin": "ui/img_uk_ui2_ylq.png", "name": "img_loc4" }, "compId": 786 }] }, { "type": "Box", "props": { "y": 611, "x": 10, "var": "btn_get", "name": "btn_get", "mouseEnabled": true }, "compId": 729, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 234, "skin": "ui/img_uk_btn_btn1.png", "height": 68 }, "compId": 730 }, { "type": "Label", "props": { "y": 20, "x": 22, "wordWrap": true, "width": 190, "valign": "middle", "text": "获取奖励", "strokeColor": "#0f3367", "stroke": 5, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 731 }] }] }, { "type": "Box", "props": { "y": 43, "x": -43, "var": "img_bg", "name": "img_bg" }, "compId": 789, "child": [{ "type": "Image", "props": { "y": 221, "x": 53, "var": "item11", "skin": "ui/img_uk_shop_bg5.png", "name": "item11" }, "compId": 652, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs1.png", "height": 138 }, "compId": 664 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x100", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 665 }] }, { "type": "Image", "props": { "y": 221, "x": 776, "var": "item5", "skin": "ui/img_uk_shop_bg5.png", "name": "item5" }, "compId": 653, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs3.png", "height": 138 }, "compId": 666 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x500", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 667 }] }, { "type": "Image", "props": { "y": 394, "x": 53, "var": "item10", "skin": "ui/img_uk_shop_bg6.png", "name": "item10" }, "compId": 654, "child": [{ "type": "LotteryObj2", "props": { "y": -30, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 723 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods11", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods11", "height": 138 }, "compId": 668 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品装备", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 669 }] }, { "type": "Image", "props": { "y": 396, "x": 234, "var": "item9", "skin": "ui/img_uk_shop_bg4.png", "name": "item9" }, "compId": 655, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold3.png", "height": 138 }, "compId": 670 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x1000", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 671 }] }, { "type": "Image", "props": { "y": 396, "x": 415, "var": "item8", "skin": "ui/img_uk_shop_bg5.png", "name": "item8" }, "compId": 656, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs4.png", "height": 138 }, "compId": 672 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x1000", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 673 }] }, { "type": "Image", "props": { "y": 396, "x": 596, "var": "item7", "skin": "ui/img_uk_shop_bg4.png", "name": "item7" }, "compId": 657, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold2.png", "height": 138 }, "compId": 674 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x600", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 675 }] }, { "type": "Image", "props": { "y": 396, "x": 776, "var": "item6", "skin": "ui/img_uk_shop_bg6.png", "name": "item6" }, "compId": 658, "child": [{ "type": "LotteryObj2", "props": { "y": -32, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 725 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods7", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods7", "height": 138 }, "compId": 676 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品装备", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 677 }] }, { "type": "Image", "props": { "y": 49, "x": 52, "var": "item0", "skin": "ui/img_uk_shop_bg6.png", "name": "item0" }, "compId": 678, "child": [{ "type": "LotteryObj2", "props": { "y": -30, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 722 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods1", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods1", "height": 138 }, "compId": 679 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品武器", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 680 }] }, { "type": "Image", "props": { "y": 49, "x": 233, "var": "item1", "skin": "ui/img_uk_shop_bg4.png", "name": "item1" }, "compId": 681, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold1.png", "height": 138 }, "compId": 682 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 683 }] }, { "type": "Image", "props": { "y": 49, "x": 414, "var": "item2", "skin": "ui/img_uk_shop_bg5.png", "name": "item2" }, "compId": 684, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_zs2.png", "height": 138 }, "compId": 685 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石x200", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 686 }] }, { "type": "Image", "props": { "y": 49, "x": 595, "var": "item3", "skin": "ui/img_uk_shop_bg4.png", "name": "item3" }, "compId": 687, "child": [{ "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "skin": "ui/img_uk_icon_gold4.png", "height": 138 }, "compId": 688 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "金币x2000", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 689 }] }, { "type": "Image", "props": { "y": 49, "x": 776, "var": "item4", "skin": "ui/img_uk_shop_bg6.png", "name": "item4" }, "compId": 690, "child": [{ "type": "LotteryObj2", "props": { "y": -32, "x": -10, "runtime": "ui.lottery.LotteryObj2UI" }, "compId": 724 }, { "type": "Image", "props": { "y": -9, "x": 21, "width": 138, "var": "img_goods5", "skin": "ui/img_uk_icon_gunicon4.png", "name": "img_goods5", "height": 138 }, "compId": 691 }, { "type": "Label", "props": { "y": 129, "x": 8, "wordWrap": true, "width": 164, "valign": "middle", "text": "极品装备", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 692 }] }, { "type": "Image", "props": { "y": 52, "x": 55, "width": 286, "var": "img_frame", "skin": "ui/img_uk_ui2_uieffect.png", "pivotY": 52, "pivotX": 55, "name": "img_frame", "height": 267 }, "compId": 702 }] }, { "type": "Box", "props": { "y": 268, "x": 306 }, "compId": 788, "child": [{ "type": "Label", "props": { "y": 112, "x": 38, "wordWrap": true, "width": 226, "var": "txt_num", "valign": "middle", "text": "5次之后必得稀有物品", "strokeColor": "#212121", "stroke": 4, "name": "txt_num", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 659 }, { "type": "LotteryObj1", "props": { "y": 16, "x": -86, "var": "btn_ok", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_ok", "runtime": "ui.lottery.LotteryObj1UI" }, "compId": 721 }, { "type": "Box", "props": { "y": 16, "x": 185, "var": "btn_close2", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_close2" }, "compId": 793, "child": [{ "type": "Image", "props": { "y": 23, "x": 0, "width": 257, "skin": "ui/img_uk_ui2_btn1.png", "height": 87 }, "compId": 794 }, { "type": "Label", "props": { "y": 37, "x": 59, "wordWrap": true, "width": 139, "var": "txt_ok", "valign": "middle", "text": "不了,谢谢", "strokeColor": "#275f9c", "stroke": 4, "name": "txt_ok", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 795 }] }] }] }, { "type": "Box", "props": { "y": 26, "x": 41, "var": "btn_close", "name": "btn_close", "mouseEnabled": true }, "compId": 698, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 699 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 700 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 701 }] }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_ui_obj.png", "ui/img_uk_text_wzbj.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_icon_gunicon.png", "ui/img_uk_ui2_obj11.png", "ui/img_uk_text_lj1.png", "ui/img_uk_ui2_ylq.png", "ui/img_uk_text_lj2.png", "ui/img_uk_text_yj.png", "ui/img_uk_text_lj3.png", "ui/img_uk_text_lj4.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_shop_bg5.png", "ui/img_uk_icon_zs1.png", "ui/img_uk_icon_zs3.png", "ui/img_uk_shop_bg6.png", "ui/img_uk_icon_gunicon4.png", "ui/img_uk_shop_bg4.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_icon_zs4.png", "ui/img_uk_icon_gold2.png", "ui/img_uk_icon_gold1.png", "ui/img_uk_icon_zs2.png", "ui/img_uk_icon_gold4.png", "ui/img_uk_ui2_uieffect.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            lottery.Lottery1UI = Lottery1UI;
            REG("ui.lottery.Lottery1UI", Lottery1UI);
            class LotteryBtnOkUI extends Scene {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LotteryBtnOkUI.uiView);
                }
            }
            LotteryBtnOkUI.uiView = { "type": "Scene", "props": { "width": 260, "height": 100 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 6, "x": 1 }, "compId": 7, "child": [{ "type": "Image", "props": { "width": 257, "skin": "ui/img_uk_ui2_btn1.png", "height": 87 }, "compId": 3 }, { "type": "Label", "props": { "y": 15, "x": 83, "wordWrap": true, "width": 139, "valign": "middle", "text": "免费补给", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 4 }, { "type": "Image", "props": { "y": -2.5, "x": 211, "width": 46, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao.png", "name": "img_ad", "height": 46 }, "compId": 5 }, { "type": "Label", "props": { "y": 23, "x": 22, "wordWrap": true, "width": 212, "valign": "middle", "text": "免费补给", "strokeColor": "#9c7227", "fontSize": 40, "font": "SimHei", "color": "#fff9f4", "bold": true, "align": "center" }, "compId": 6 }] }], "loadList": ["ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_guanggao.png"], "loadList3D": [] };
            lottery.LotteryBtnOkUI = LotteryBtnOkUI;
            REG("ui.lottery.LotteryBtnOkUI", LotteryBtnOkUI);
            class LotteryObj1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LotteryObj1UI.uiView);
                }
            }
            LotteryObj1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": false, "height": 150 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 32, "x": 17 }, "compId": 719, "child": [{ "type": "Box", "props": { "y": -24, "x": 6 }, "compId": 720, "child": [{ "type": "Image", "props": { "y": 23, "x": 0, "width": 257, "skin": "ui/img_uk_ui2_btn1.png", "height": 87 }, "compId": 721 }, { "type": "Label", "props": { "y": 37, "x": 74, "wordWrap": true, "width": 139, "var": "txt_ok", "valign": "middle", "text": "免费补给", "strokeColor": "#275f9c", "stroke": 4, "name": "txt_ok", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 722 }, { "type": "Image", "props": { "y": 51, "x": 41, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 733 }] }] }, { "type": "Image", "props": { "y": 38, "x": 274, "width": 50, "skin": "ui/img_uk_ui2_zy2.png", "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 725 }, { "type": "Image", "props": { "y": 112, "x": 32, "width": 50, "skin": "ui/img_uk_ui2_zy3.png", "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 726 }, { "type": "Image", "props": { "y": 38, "x": 32, "width": 50, "skin": "ui/img_uk_ui2_zy2.png", "scaleX": -1, "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 731 }, { "type": "Image", "props": { "y": 112, "x": 274, "width": 50, "skin": "ui/img_uk_ui2_zy3.png", "scaleX": -1, "pivotY": 25, "pivotX": 25, "height": 50 }, "compId": 732 }], "animations": [{ "nodes": [{ "target": 726, "keyframes": { "y": [{ "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "y", "index": 0 }, { "value": 122, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "y", "index": 10 }, { "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 726, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "x", "index": 0 }, { "value": 22, "tweenMethod": "linearNone", "tween": true, "target": 726, "key": "x", "index": 10 }, { "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 726, "label": null, "key": "x", "index": 20 }] } }, { "target": 725, "keyframes": { "y": [{ "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "y", "index": 0 }, { "value": 28, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "y", "index": 10 }, { "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 725, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 275, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "x", "index": 0 }, { "value": 285, "tweenMethod": "linearNone", "tween": true, "target": 725, "key": "x", "index": 10 }, { "value": 275, "tweenMethod": "linearNone", "tween": true, "target": 725, "label": null, "key": "x", "index": 20 }] } }, { "target": 731, "keyframes": { "y": [{ "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "y", "index": 0 }, { "value": 28, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "y", "index": 10 }, { "value": 38, "tweenMethod": "linearNone", "tween": true, "target": 731, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "x", "index": 0 }, { "value": 22, "tweenMethod": "linearNone", "tween": true, "target": 731, "key": "x", "index": 10 }, { "value": 32, "tweenMethod": "linearNone", "tween": true, "target": 731, "label": null, "key": "x", "index": 20 }] } }, { "target": 732, "keyframes": { "y": [{ "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "y", "index": 0 }, { "value": 122, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "y", "index": 10 }, { "value": 112, "tweenMethod": "linearNone", "tween": true, "target": 732, "label": null, "key": "y", "index": 20 }], "x": [{ "value": 274, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "x", "index": 0 }, { "value": 284, "tweenMethod": "linearNone", "tween": true, "target": 732, "key": "x", "index": 10 }, { "value": 274, "tweenMethod": "linearNone", "tween": true, "target": 732, "label": null, "key": "x", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_ui2_zy2.png", "ui/img_uk_ui2_zy3.png"], "loadList3D": [] };
            lottery.LotteryObj1UI = LotteryObj1UI;
            REG("ui.lottery.LotteryObj1UI", LotteryObj1UI);
            class LotteryObj2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LotteryObj2UI.uiView);
                }
            }
            LotteryObj2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": false, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 100, "x": 100, "width": 168, "skin": "ui/img_uk_ui2_obj18.png", "pivotY": 84, "pivotX": 84, "height": 168, "blendMode": "lighter" }, "compId": 733 }], "animations": [{ "nodes": [{ "target": 733, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 733, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 733, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 733, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_obj18.png"], "loadList3D": [] };
            lottery.LotteryObj2UI = LotteryObj2UI;
            REG("ui.lottery.LotteryObj2UI", LotteryObj2UI);
            class LotteryObj3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LotteryObj3UI.uiView);
                }
            }
            LotteryObj3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": false, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 100, "x": 100, "width": 168, "skin": "ui/img_uk_ui2_obj19.png", "pivotY": 84, "pivotX": 84, "height": 168, "blendMode": "lighter" }, "compId": 733 }], "animations": [{ "nodes": [{ "target": 733, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 733, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 733, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 733, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_obj19.png"], "loadList3D": [] };
            lottery.LotteryObj3UI = LotteryObj3UI;
            REG("ui.lottery.LotteryObj3UI", LotteryObj3UI);
            class LotteryObj4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LotteryObj4UI.uiView);
                }
            }
            LotteryObj4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": false, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 100, "x": 100, "width": 168, "skin": "ui/img_uk_ui2_obj20.png", "pivotY": 84, "pivotX": 84, "height": 168, "blendMode": "lighter" }, "compId": 733 }], "animations": [{ "nodes": [{ "target": 733, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 733, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 733, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 733, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_obj20.png"], "loadList3D": [] };
            lottery.LotteryObj4UI = LotteryObj4UI;
            REG("ui.lottery.LotteryObj4UI", LotteryObj4UI);
        })(lottery = ui.lottery || (ui.lottery = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var online;
        (function (online) {
            class OnlineUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(OnlineUI.uiView);
                }
            }
            OnlineUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "width": 1480, "top": 0, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "height": 720, "bottom": 0 }, "compId": 513 }, { "type": "Box", "props": { "y": 175, "width": 1259, "var": "box_scale", "name": "box_scale", "height": 509, "centerX": 0 }, "compId": 527, "child": [{ "type": "Label", "props": { "y": 467, "x": 451, "wordWrap": true, "width": 297, "var": "txt_total", "valign": "middle", "text": "已累计在线时长：20分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_total", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 519 }, { "type": "List", "props": { "y": 0, "x": 3, "width": 1253, "var": "list_1", "name": "list_1", "height": 309, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 498, "child": [{ "type": "OnlinesItem", "props": { "renderType": "render", "runtime": "ui.online.OnlinesItemUI" }, "compId": 497 }] }, { "type": "Box", "props": { "y": 379, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98, "centerX": 100 }, "compId": 522, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 535 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 562 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 563 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 564 }] }, { "type": "Box", "props": { "y": 379, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "centerX": -100 }, "compId": 565, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 566 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 567 }] }] }, { "type": "Box", "props": { "y": 27, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 528, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 557 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 558 }] }, { "type": "Box", "props": { "y": 63, "centerX": 0 }, "compId": 561, "child": [{ "type": "Image", "props": { "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 559 }, { "type": "Image", "props": { "x": 392, "skin": "ui/img_UM_ui_text48.png" }, "compId": 560 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "comp/hscroll.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png"], "loadList3D": [] };
            online.OnlineUI = OnlineUI;
            REG("ui.online.OnlineUI", OnlineUI);
            class Online1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Online1UI.uiView);
                }
            }
            Online1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1480, "top": 0, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "height": 720, "bottom": 0 }, "compId": 557 }, { "type": "Box", "props": { "y": 175, "x": 0, "width": 1259, "var": "box_scale", "name": "box_scale", "height": 509, "centerX": 0 }, "compId": 558, "child": [{ "type": "Label", "props": { "y": 268, "x": 722, "wordWrap": true, "width": 297, "var": "txt_total", "valign": "middle", "text": "已累计在线时长：20分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_total", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 561 }, { "type": "List", "props": { "y": -42, "x": 3, "width": 1253, "var": "list_1", "name": "list_1", "height": 309, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 562, "child": [{ "type": "OnlinesItem", "props": { "renderType": "render", "runtime": "ui.online.OnlinesItemUI" }, "compId": 563 }] }, { "type": "Box", "props": { "y": 302, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98, "centerX": 259 }, "compId": 564, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 565 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 566 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 567 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 568 }] }, { "type": "Box", "props": { "y": 483, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "centerX": -382 }, "compId": 569, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 95, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 52, "fontSize": 45, "font": "SimHei", "color": "#ffffff" }, "compId": 576 }] }] }, { "type": "Box", "props": { "y": 27, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 559, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 572 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 573 }] }, { "type": "Box", "props": { "y": 56, "centerX": 0 }, "compId": 560, "child": [{ "type": "Image", "props": { "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 574 }, { "type": "Image", "props": { "x": 392, "skin": "ui/img_UM_ui_text48.png" }, "compId": 575 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "comp/hscroll.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png"], "loadList3D": [] };
            online.Online1UI = Online1UI;
            REG("ui.online.Online1UI", Online1UI);
            class Online2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Online2UI.uiView);
                }
            }
            Online2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "width": 1480, "top": 0, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "height": 720, "bottom": 0 }, "compId": 513 }, { "type": "Box", "props": { "y": 175, "width": 1259, "var": "box_scale", "name": "box_scale", "height": 509, "centerX": 0 }, "compId": 527, "child": [{ "type": "Label", "props": { "y": 268.5, "x": 915, "wordWrap": true, "width": 297, "var": "txt_total", "valign": "middle", "text": "已累计在线时长：20分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_total", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 519 }, { "type": "List", "props": { "y": -41, "x": 3, "width": 1253, "var": "list_1", "name": "list_1", "height": 309, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 498, "child": [{ "type": "OnlinesItem", "props": { "renderType": "render", "runtime": "ui.online.OnlinesItemUI" }, "compId": 497 }] }, { "type": "Box", "props": { "y": 302, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98, "centerX": 432 }, "compId": 522, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 535 }, { "type": "Image", "props": { "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 562 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 563 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 564 }] }, { "type": "Box", "props": { "y": 403, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "centerX": 432 }, "compId": 565, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 566 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 567 }] }] }, { "type": "Box", "props": { "y": 27, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 528, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 557 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 558 }] }, { "type": "Box", "props": { "y": 63, "centerX": 0 }, "compId": 561, "child": [{ "type": "Image", "props": { "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 559 }, { "type": "Image", "props": { "x": 392, "skin": "ui/img_UM_ui_text48.png" }, "compId": 560 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "comp/hscroll.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png"], "loadList3D": [] };
            online.Online2UI = Online2UI;
            REG("ui.online.Online2UI", Online2UI);
            class Online3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Online3UI.uiView);
                }
            }
            Online3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1480, "top": 0, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "height": 720, "bottom": 0 }, "compId": 557 }, { "type": "Box", "props": { "y": 175, "x": 0, "width": 1259, "var": "box_scale", "name": "box_scale", "height": 509, "centerX": 0 }, "compId": 558, "child": [{ "type": "Label", "props": { "y": 249, "x": 481, "wordWrap": true, "width": 297, "var": "txt_total", "valign": "middle", "text": "已累计在线时长：20分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_total", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 561 }, { "type": "List", "props": { "y": -42, "x": 3, "width": 1253, "var": "list_1", "name": "list_1", "height": 309, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 562, "child": [{ "type": "OnlinesItem", "props": { "renderType": "render", "runtime": "ui.online.OnlinesItemUI" }, "compId": 563 }] }, { "type": "Box", "props": { "y": 329, "right": 20 }, "compId": 577, "child": [{ "type": "Box", "props": { "x": 0, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98 }, "compId": 564, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 565 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 566 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 567 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 568 }] }, { "type": "Box", "props": { "y": 111, "x": 63, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get" }, "compId": 569, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 95, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 52, "fontSize": 45, "font": "SimHei", "color": "#ffffff" }, "compId": 576 }] }] }] }, { "type": "Box", "props": { "y": 27, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 559, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 572 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 573 }] }, { "type": "Box", "props": { "y": 56, "centerX": 0 }, "compId": 560, "child": [{ "type": "Image", "props": { "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 574 }, { "type": "Image", "props": { "x": 392, "skin": "ui/img_UM_ui_text48.png" }, "compId": 575 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "comp/hscroll.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png"], "loadList3D": [] };
            online.Online3UI = Online3UI;
            REG("ui.online.Online3UI", Online3UI);
            class Online4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Online4UI.uiView);
                }
            }
            Online4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "width": 1480, "top": 0, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "height": 720, "bottom": 0 }, "compId": 513 }, { "type": "Box", "props": { "y": 175, "width": 1259, "var": "box_scale", "name": "box_scale", "height": 509, "centerX": 0 }, "compId": 527, "child": [{ "type": "Label", "props": { "y": 249, "x": 481, "wordWrap": true, "width": 297, "var": "txt_total", "valign": "middle", "text": "已累计在线时长：20分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_total", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 519 }, { "type": "List", "props": { "y": -41, "x": 3, "width": 1253, "var": "list_1", "name": "list_1", "height": 309, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 498, "child": [{ "type": "OnlinesItem", "props": { "renderType": "render", "runtime": "ui.online.OnlinesItemUI" }, "compId": 497 }] }, { "type": "Box", "props": { "y": 302, "right": 20 }, "compId": 568, "child": [{ "type": "Box", "props": { "x": 0, "width": 247, "var": "box_get", "scaleY": 0.8, "scaleX": 0.8, "name": "box_get", "height": 98 }, "compId": 522, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 535 }, { "type": "Image", "props": { "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 562 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 563 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 564 }] }, { "type": "Box", "props": { "y": 101, "x": 0, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get" }, "compId": 565, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 566 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 567 }] }] }] }, { "type": "Box", "props": { "y": 27, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 528, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 557 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 558 }] }, { "type": "Box", "props": { "y": 63, "centerX": 0 }, "compId": 561, "child": [{ "type": "Image", "props": { "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 559 }, { "type": "Image", "props": { "x": 392, "skin": "ui/img_UM_ui_text48.png" }, "compId": 560 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "comp/hscroll.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png"], "loadList3D": [] };
            online.Online4UI = Online4UI;
            REG("ui.online.Online4UI", Online4UI);
            class Online5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Online5UI.uiView);
                }
            }
            Online5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1480, "top": 0, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "height": 720, "bottom": 0 }, "compId": 557 }, { "type": "Box", "props": { "y": 175, "x": 0, "width": 1259, "var": "box_scale", "name": "box_scale", "height": 509, "centerX": 0 }, "compId": 558, "child": [{ "type": "Label", "props": { "y": -71, "x": 481, "wordWrap": true, "width": 297, "var": "txt_total", "valign": "middle", "text": "已累计在线时长：20分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_total", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 561 }, { "type": "List", "props": { "y": -42, "x": 3, "width": 1253, "var": "list_1", "name": "list_1", "height": 309, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 562, "child": [{ "type": "OnlinesItem", "props": { "renderType": "render", "runtime": "ui.online.OnlinesItemUI" }, "compId": 563 }] }, { "type": "Box", "props": { "y": 406, "scaleY": 1, "scaleX": 1, "right": -6 }, "compId": 577, "child": [{ "type": "Box", "props": { "x": 0, "width": 247, "var": "box_get", "scaleY": 1, "scaleX": 1, "name": "box_get", "height": 98 }, "compId": 564, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 565 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 566 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 567 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 568 }] }] }] }, { "type": "Box", "props": { "y": 27, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 559, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 572 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 573 }] }, { "type": "Box", "props": { "y": 56, "centerX": 0 }, "compId": 560, "child": [{ "type": "Image", "props": { "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 574 }, { "type": "Image", "props": { "x": 392, "skin": "ui/img_UM_ui_text48.png" }, "compId": 575 }] }, { "type": "Box", "props": { "y": 603, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "left": 164 }, "compId": 569, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 95, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 52, "fontSize": 45, "font": "SimHei", "color": "#ffffff" }, "compId": 576 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "comp/hscroll.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png"], "loadList3D": [] };
            online.Online5UI = Online5UI;
            REG("ui.online.Online5UI", Online5UI);
            class Online6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Online6UI.uiView);
                }
            }
            Online6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1480, "top": 0, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "height": 720, "bottom": 0 }, "compId": 557 }, { "type": "Box", "props": { "y": 175, "x": 0, "width": 1259, "var": "box_scale", "name": "box_scale", "height": 509, "centerX": 0 }, "compId": 558, "child": [{ "type": "Label", "props": { "y": -71, "x": 481, "wordWrap": true, "width": 297, "var": "txt_total", "valign": "middle", "text": "已累计在线时长：20分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_total", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 561 }, { "type": "List", "props": { "y": -42, "x": 3, "width": 1253, "var": "list_1", "name": "list_1", "height": 309, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true }, "compId": 562, "child": [{ "type": "OnlinesItem", "props": { "renderType": "render", "runtime": "ui.online.OnlinesItemUI" }, "compId": 563 }] }] }, { "type": "Box", "props": { "y": 27, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 559, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 572 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 573 }] }, { "type": "Box", "props": { "y": 56, "centerX": 0 }, "compId": 560, "child": [{ "type": "Image", "props": { "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 574 }, { "type": "Image", "props": { "x": 392, "skin": "ui/img_UM_ui_text48.png" }, "compId": 575 }] }, { "type": "Box", "props": { "y": 575, "scaleY": 1, "scaleX": 1, "right": 20 }, "compId": 577, "child": [{ "type": "Box", "props": { "x": 0, "width": 247, "var": "box_get", "scaleY": 1, "scaleX": 1, "name": "box_get", "height": 98 }, "compId": 564, "child": [{ "type": "Image", "props": { "y": 33, "x": 47, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 565 }, { "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 566 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 567 }, { "type": "Image", "props": { "y": 28, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 568 }] }] }, { "type": "Box", "props": { "y": 603, "var": "btn_get", "scaleY": 0.8, "scaleX": 0.8, "name": "btn_get", "left": 164 }, "compId": 569, "child": [{ "type": "Label", "props": { "y": 0, "x": 0, "width": 95, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 52, "fontSize": 45, "font": "SimHei", "color": "#ffffff" }, "compId": 576 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "comp/hscroll.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            online.Online6UI = Online6UI;
            REG("ui.online.Online6UI", Online6UI);
            class OnlinesItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(OnlinesItemUI.uiView);
                }
            }
            OnlinesItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 264, "mouseThrough": false, "mouseEnabled": true, "height": 299 }, "compId": 2, "child": [{ "type": "Label", "props": { "y": 264, "x": 49, "wordWrap": true, "width": 164, "var": "txt_time", "valign": "middle", "text": "5分钟", "strokeColor": "#212121", "stroke": 4, "name": "txt_time", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 382 }, { "type": "Image", "props": { "y": 131, "x": 131, "width": 260, "var": "img_bg", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "name": "img_bg", "height": 260, "alpha": 1 }, "compId": 390 }, { "type": "Image", "props": { "y": -20, "x": -21, "width": 321, "var": "img_bg2", "skin": "ui/img_UM_effect_gold.png", "name": "img_bg2", "height": 320, "blendMode": "lighter" }, "compId": 398 }, { "type": "Image", "props": { "y": 66, "x": 65, "width": 131, "skin": "ui/img_UM_tong.png", "height": 131 }, "compId": 391 }, { "type": "Image", "props": { "y": 190, "x": 63, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 392 }, { "type": "Label", "props": { "y": 189, "x": 49, "wordWrap": true, "width": 164, "var": "txt_num", "valign": "middle", "text": "金币x30", "strokeColor": "#212121", "stroke": 4, "name": "txt_num", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 381 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 260, "var": "img_mask", "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "name": "img_mask", "height": 260, "alpha": 0.5 }, "compId": 394 }, { "type": "Image", "props": { "y": 20, "x": 208, "width": 31, "var": "img_state", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state", "height": 33 }, "compId": 396 }, { "type": "Box", "props": { "y": 1, "x": 1, "width": 260, "var": "box_has", "name": "box_has", "height": 263 }, "compId": 368, "child": [{ "type": "Image", "props": { "y": 74, "x": -9, "visible": true, "skin": "ui/img_UM_ui_text47.png", "rotation": -31 }, "compId": 397 }] }, { "type": "Image", "props": { "y": 112, "x": 60, "var": "img_state1", "skin": "ui/img_UM_ui_text37.png", "name": "img_state1" }, "compId": 395 }], "loadList": ["ui/img_UM_rank_jlbg3.png", "ui/img_UM_effect_gold.png", "ui/img_UM_tong.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_text47.png", "ui/img_UM_ui_text37.png"], "loadList3D": [] };
            online.OnlinesItemUI = OnlinesItemUI;
            REG("ui.online.OnlinesItemUI", OnlinesItemUI);
        })(online = ui.online || (ui.online = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var page;
        (function (page) {
            class PageUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageUI.uiView);
                }
            }
            PageUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "scaleY": 1, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": -1, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 984 }, { "type": "Box", "props": { "y": 312, "x": 138, "width": 495, "height": 357, "centerX": -255, "bottom": 51 }, "compId": 1146, "child": [{ "type": "Image", "props": { "y": 217, "x": 60, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1142 }, { "type": "Box", "props": { "y": -160, "x": 87, "width": 301, "var": "box_scene", "name": "box_scene", "height": 433 }, "compId": 1127 }, { "type": "Image", "props": { "y": -1, "x": 0, "var": "img_left", "skin": "ui/img_UM_btn_jiantou.png", "name": "img_left" }, "compId": 1144 }, { "type": "Image", "props": { "y": -1, "x": 395, "var": "img_right", "skin": "ui/img_UM_btn_jiantou2.png", "name": "img_right" }, "compId": 1145 }, { "type": "Image", "props": { "y": -41, "x": 191, "var": "img_lock", "skin": "ui/img_UM_ui_lock.png", "name": "img_lock" }, "compId": 1164 }, { "type": "Label", "props": { "y": 114, "x": -93, "wordWrap": true, "width": 681, "var": "txt_info", "text": "解锁条件：XXXXXXXXXXXXXXXXXXXXXXXXX", "strokeColor": "#000000", "stroke": 4, "name": "txt_info", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1165 }, { "type": "Box", "props": { "y": 166, "x": 159, "width": 176, "visible": true, "var": "box_noLoc", "name": "box_noLoc", "height": 80 }, "compId": 1167, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 176, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 83, "gray": true }, "compId": 1170 }, { "type": "Image", "props": { "y": 14, "x": 37, "skin": "ui/img_UM_ui_text15.png" }, "compId": 1171 }] }, { "type": "Box", "props": { "y": 166, "x": 159, "width": 176, "var": "box_loc", "name": "box_loc", "height": 80 }, "compId": 1166, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 176, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 83 }, "compId": 1168 }, { "type": "Image", "props": { "y": 15, "x": 21, "width": 133, "skin": "ui/img_UM_ui_text20.png", "height": 38 }, "compId": 1169 }] }, { "type": "PageRedAnim3", "props": { "y": -60, "x": 424, "var": "ui_change", "name": "ui_change", "runtime": "ui.page.PageRedAnim3UI" }, "compId": 1214 }] }, { "type": "Box", "props": { "width": 1280, "scaleY": 1, "scaleX": 1, "right": 0, "mouseThrough": true, "height": 720, "bottom": 0 }, "compId": 1129, "child": [{ "type": "Box", "props": { "y": 109, "width": 518, "right": 0, "height": 430 }, "compId": 1158, "child": [{ "type": "Box", "props": { "y": 173, "x": 29, "var": "box_start2", "name": "box_start2" }, "compId": 1093, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_gameMode_5v5.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1156 }] }, { "type": "PageGameMode1", "props": { "var": "ui_start4", "scaleY": 0.9, "scaleX": 0.9, "right": 0, "name": "ui_start4", "runtime": "ui.page.PageGameMode1UI" }, "compId": 1131 }, { "type": "PageGameMode2", "props": { "y": 0, "width": 277, "var": "ui_start3", "scaleY": 0.9, "scaleX": 0.9, "name": "ui_start3", "left": 35, "height": 199, "runtime": "ui.page.PageGameMode2UI" }, "compId": 1132 }] }, { "type": "Image", "props": { "y": 158, "x": 1031, "width": 99, "skin": "ui/img_UM_biaoqian.png", "height": 50 }, "compId": 1194 }, { "type": "Image", "props": { "y": 158, "x": 808, "skin": "ui/img_UM_biaoqian.png" }, "compId": 1193 }, { "type": "PageStarGame", "props": { "y": 573, "x": 844, "width": 384, "var": "ui_start", "name": "ui_start", "height": 113, "runtime": "ui.page.PageStarGameUI" }, "compId": 1159 }, { "type": "PageBtnTianjiang", "props": { "y": 409, "x": 688, "visible": true, "var": "ui_box", "name": "ui_box", "runtime": "ui.page.PageBtnTianjiangUI" }, "compId": 1206 }] }, { "type": "Box", "props": { "y": 22, "x": 443, "width": 237, "height": 94 }, "compId": 1003, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1002 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_tl.png", "height": 64 }, "compId": 985 }, { "type": "Label", "props": { "y": 22, "x": 63, "wordWrap": true, "width": 108, "var": "txt_phy", "valign": "middle", "text": "45/50", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1004 }, { "type": "Label", "props": { "y": 59, "x": 57, "wordWrap": false, "width": 85, "var": "txt_phyTime", "valign": "middle", "text": "05:59", "strokeColor": "#000000", "stroke": 4, "name": "txt_phyTime", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1017 }, { "type": "Image", "props": { "y": 62, "x": 142, "width": 30, "skin": "ui/img_UM_tl.png", "height": 30 }, "compId": 1018 }, { "type": "Label", "props": { "y": 59, "x": 117, "wordWrap": false, "width": 32, "var": "txt_jia", "valign": "middle", "text": "+1", "strokeColor": "#000000", "stroke": 4, "name": "txt_jia", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1130 }, { "type": "Image", "props": { "y": 7, "x": 163, "width": 68, "var": "img_phy", "skin": "ui/img_UM_btn__btn_2.png", "name": "img_phy", "mouseThrough": false, "mouseEnabled": true, "height": 66 }, "compId": 996 }] }, { "type": "Box", "props": { "y": 21, "x": 688 }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 1007 }, { "type": "Image", "props": { "y": 7, "x": 163, "var": "img_tong", "skin": "ui/img_UM_btn__btn_2.png", "name": "img_tong", "mouseThrough": false, "mouseEnabled": true }, "compId": 1008 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1010 }] }, { "type": "Box", "props": { "y": 20, "x": 932 }, "compId": 1011, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1012 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 1013 }, { "type": "Image", "props": { "y": 7, "x": 163, "var": "img_jin", "skin": "ui/img_UM_btn__btn_2.png", "name": "img_jin", "mouseThrough": false, "mouseEnabled": true }, "compId": 1014 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1016 }] }, { "type": "Box", "props": { "y": 4, "visible": true, "left": 5 }, "compId": 1123, "child": [{ "type": "Image", "props": { "y": -7, "x": -6, "skin": "ui/img_UM_playerinfo.png" }, "compId": 1136 }, { "type": "PageHead", "props": { "y": 8, "x": 12, "var": "ui_head", "name": "ui_head", "runtime": "ui.page.PageHeadUI" }, "compId": 1204 }, { "type": "Image", "props": { "y": 68, "x": 122, "width": 195, "var": "bar_exp", "skin": "ui/img_UM_playerEXPbar.png", "name": "bar_exp", "height": 46 }, "compId": 1137 }, { "type": "Label", "props": { "y": 35, "x": 132, "wordWrap": false, "width": 173, "var": "txt_name", "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1138 }, { "type": "Label", "props": { "y": 63, "x": 117, "wordWrap": true, "width": 192, "var": "txt_ep", "valign": "middle", "text": "45/50", "strokeColor": "#000000", "stroke": 4, "name": "txt_ep", "height": 55, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1160 }, { "type": "Label", "props": { "y": 42.5, "x": 336, "wordWrap": true, "width": 56, "var": "txt_lv", "valign": "middle", "text": "20", "strokeColor": "#000000", "stroke": 4, "name": "txt_lv", "height": 55, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1162 }] }, { "type": "Box", "props": { "y": 117, "var": "box_sign", "name": "box_sign", "left": 11 }, "compId": 1179, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1181 }, { "type": "Image", "props": { "y": 107, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text45.png", "height": 30 }, "compId": 1182 }, { "type": "Image", "props": { "y": 36.5, "x": 12, "width": 77, "skin": "ui/img_UM_icon_qiandao.png", "height": 76 }, "compId": 1183 }, { "type": "PageRedAnim1", "props": { "y": 28, "x": 60, "var": "ui_sign", "name": "ui_sign", "runtime": "ui.page.PageRedAnim1UI" }, "compId": 1207 }] }, { "type": "Box", "props": { "y": 247, "var": "box_online", "name": "box_online", "left": 11 }, "compId": 1180, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1184 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text44.png", "height": 30 }, "compId": 1185 }, { "type": "Image", "props": { "y": 30.5, "x": 10, "width": 78, "skin": "ui/img_UM_icon_zaixian2.png", "height": 77 }, "compId": 1186 }, { "type": "PageRedAnim1", "props": { "y": 28, "x": 61, "var": "ui_online", "name": "ui_online", "runtime": "ui.page.PageRedAnim1UI" }, "compId": 1208 }] }, { "type": "Box", "props": { "width": 57, "top": -7, "left": -4, "height": 80 }, "compId": 1192, "child": [{ "type": "Image", "props": { "y": -1, "x": 3, "width": 50, "var": "img_seg", "skin": "ui/img_UM_1_1.png", "name": "img_seg", "height": 50 }, "compId": 1190 }, { "type": "Label", "props": { "y": 40, "x": 0, "wordWrap": false, "width": 56, "var": "txt_seg", "valign": "middle", "text": "王者Ⅳ", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_seg", "height": 25, "fontSize": 15, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1191 }] }, { "type": "Box", "props": { "left": -8, "bottom": 22 }, "compId": 1196, "child": [{ "type": "Image", "props": { "y": 9, "width": 225, "var": "img_shop", "skin": "ui/img_UM_fun_btn_1.png", "name": "img_shop", "height": 124 }, "compId": 1150 }, { "type": "Image", "props": { "y": 9, "x": 390, "width": 225, "var": "img_task", "skin": "ui/img_UM_fun_btn_3.png", "name": "img_task", "height": 124 }, "compId": 1154 }, { "type": "Image", "props": { "y": 9, "x": 196, "width": 225, "var": "img_segment", "skin": "ui/img_UM_fun_btn_2.png", "name": "img_segment", "height": 124 }, "compId": 1155 }, { "type": "Image", "props": { "y": 9, "x": 596, "width": 225, "var": "img_hero", "skin": "ui/img_UM_fun_btn_4.png", "name": "img_hero", "height": 124 }, "compId": 1153 }, { "type": "PageRedAnim1", "props": { "y": 0, "x": 112, "var": "ui_shop", "name": "ui_shop", "runtime": "ui.page.PageRedAnim1UI" }, "compId": 1209 }, { "type": "PageRedAnim1", "props": { "y": 0, "x": 305, "var": "ui_segment", "name": "ui_segment", "runtime": "ui.page.PageRedAnim1UI" }, "compId": 1210 }, { "type": "PageRedAnim1", "props": { "y": 0, "x": 496, "var": "ui_task", "name": "ui_task", "runtime": "ui.page.PageRedAnim1UI" }, "compId": 1211 }, { "type": "PageRedAnim2", "props": { "y": 0, "x": 708, "var": "ui_hero", "name": "ui_hero", "runtime": "ui.page.PageRedAnim2UI" }, "compId": 1213 }] }, { "type": "PageGiftBtn", "props": { "y": 406, "visible": true, "var": "ui_gift", "name": "ui_gift", "left": 11, "runtime": "ui.page.PageGiftBtnUI" }, "compId": 1205 }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_ui_obj7.png", "ui/img_UM_btn_jiantou.png", "ui/img_UM_btn_jiantou2.png", "ui/img_UM_ui_lock.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text15.png", "ui/img_UM_ui_text20.png", "ui/img_UM_gameMode_5v5.png", "ui/img_UM_biaoqian.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_tl.png", "ui/img_UM_btn__btn_2.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png", "ui/img_UM_playerinfo.png", "ui/img_UM_playerEXPbar.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text45.png", "ui/img_UM_icon_qiandao.png", "ui/img_UM_ui_text44.png", "ui/img_UM_icon_zaixian2.png", "ui/img_UM_1_1.png", "ui/img_UM_fun_btn_1.png", "ui/img_UM_fun_btn_3.png", "ui/img_UM_fun_btn_2.png", "ui/img_UM_fun_btn_4.png"], "loadList3D": [] };
            page.PageUI = PageUI;
            REG("ui.page.PageUI", PageUI);
            class PageAdditionUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageAdditionUI.uiView);
                }
            }
            PageAdditionUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -17, "width": 1247, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 650, "centerX": 0 }, "compId": 1019, "child": [{ "type": "Image", "props": { "y": 84, "x": 98, "width": 1049, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "83,65,83,53", "height": 532 }, "compId": 997 }, { "type": "Image", "props": { "y": 0, "x": 783, "width": 511, "skin": "ui/img_uk_text_zm.png", "pivotY": -230, "pivotX": 218, "height": 58 }, "compId": 1020 }, { "type": "Image", "props": { "skin": "ui/img_uk_ui2_obj19.png" }, "compId": 1004 }, { "type": "Image", "props": { "y": 115, "x": 607, "skin": "ui/img_uk_text_tjyl.png" }, "compId": 998 }, { "type": "Image", "props": { "y": 27, "x": 69, "skin": "ui/img_uk_img_body.png" }, "compId": 1002 }, { "type": "Image", "props": { "y": 301, "x": 580, "width": 500, "skin": "ui/img_uk_ui2_obj13.png", "height": 155 }, "compId": 1010 }, { "type": "Image", "props": { "y": 288, "x": 649, "width": 142, "skin": "ui/img_uk_icon_zs2.png", "height": 142 }, "compId": 1011 }, { "type": "Image", "props": { "y": 287, "x": 850, "width": 146, "skin": "ui/img_uk_icon_gold3.png", "height": 146 }, "compId": 1012 }, { "type": "Label", "props": { "y": 398, "x": 684, "wordWrap": true, "width": 72, "valign": "middle", "text": "200", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1013 }, { "type": "Label", "props": { "y": 398, "x": 887, "wordWrap": true, "width": 72, "valign": "middle", "text": "2000", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1014 }, { "type": "Image", "props": { "y": 399, "x": 753, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 1015 }, { "type": "Image", "props": { "y": 400, "x": 961, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 1016 }, { "type": "Box", "props": { "y": 459, "x": 676, "var": "btn_ok", "name": "btn_ok" }, "compId": 1018, "child": [{ "type": "Image", "props": { "width": 308, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "58,52,59,43", "height": 132 }, "compId": 1000 }, { "type": "Label", "props": { "y": 28, "x": 32, "wordWrap": true, "width": 253, "valign": "middle", "text": "添加到桌面", "strokeColor": "#01344c", "stroke": 6, "height": 76, "fontSize": 48, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1017 }] }] }, { "type": "Box", "props": { "y": 79, "x": 1106, "width": 94, "var": "btn_close", "name": "btn_close", "height": 122 }, "compId": 1005, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 1006 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 1007 }, { "type": "Label", "props": { "y": 66, "x": 7, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1008 }] }], "loadList": ["ui/img_uk_ui2_obj5.png", "ui/img_uk_text_zm.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_text_tjyl.png", "ui/img_uk_img_body.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_icon_zs2.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_ui2_obj17.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            page.PageAdditionUI = PageAdditionUI;
            REG("ui.page.PageAdditionUI", PageAdditionUI);
            class PageBenefitsUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageBenefitsUI.uiView);
                }
            }
            PageBenefitsUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 180 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 15, "width": 149, "skin": "ui/img_uk_ui2_goldgun.png", "height": 105, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": -11, "x": 3, "width": 173, "skin": "ui/img_uk_ui2_goldguneffect.png", "height": 127, "blendMode": "lighter" }, "compId": 1015 }, { "type": "Image", "props": { "y": 111, "x": 16, "width": 149, "skin": "ui/img_uk_ui2_btn2.png", "height": 52 }, "compId": 1021 }, { "type": "Box", "props": { "y": 115, "x": 22 }, "compId": 1022, "child": [{ "type": "Label", "props": { "y": 4, "x": 11, "wordWrap": true, "width": 117, "valign": "middle", "text": "劳动节福利", "strokeColor": "#563d16", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffff64", "bold": false, "align": "center" }, "compId": 1023 }] }, { "type": "Image", "props": { "y": 40, "x": 29, "width": 72, "skin": "ui/img_uk_Icon_goldnew2.png", "height": 60 }, "compId": 1028 }, { "type": "Image", "props": { "y": 28.5, "x": 90, "width": 58, "skin": "ui/img_uk_Icon_goldnew1.png", "height": 62 }, "compId": 1027 }, { "type": "Image", "props": { "y": 9, "x": 15, "width": 149, "skin": "ui/img_uk_ui_new_ui33.png", "height": 24 }, "compId": 1016 }, { "type": "Image", "props": { "y": 4, "x": 16, "width": 135, "skin": "ui/img_uk_text_groot.png", "height": 33 }, "compId": 1029 }, { "type": "Image", "props": { "y": 81, "x": 109, "width": 52, "skin": "ui/img_uk_text_yj.png", "height": 25 }, "compId": 1018 }], "animations": [{ "nodes": [{ "target": 1015, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_goldgun.png", "ui/img_uk_ui2_goldguneffect.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_Icon_goldnew2.png", "ui/img_uk_Icon_goldnew1.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_text_groot.png", "ui/img_uk_text_yj.png"], "loadList3D": [] };
            page.PageBenefitsUI = PageBenefitsUI;
            REG("ui.page.PageBenefitsUI", PageBenefitsUI);
            class PageBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageBtnUI.uiView);
                }
            }
            PageBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 290, "mouseThrough": true, "height": 90 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -1, "x": 2, "width": 286, "skin": "ui/img_uk_btn_btn1.png", "sizeGrid": "16,18,16,16", "height": 91 }, "compId": 559 }, { "type": "Box", "props": { "y": 6, "x": 7.5 }, "compId": 562, "child": [{ "type": "Image", "props": { "width": 275, "skin": "ui/img_uk_ui_new_ui38.png", "renderType": "mask", "height": 76 }, "compId": 561 }, { "type": "Image", "props": { "y": -5, "x": -128, "skin": "ui/img_uk_effect_btn.png", "blendMode": "lighter" }, "compId": 560 }] }], "animations": [{ "nodes": [{ "target": 560, "keyframes": { "x": [{ "value": -128, "tweenMethod": "linearNone", "tween": true, "target": 560, "key": "x", "index": 0 }, { "value": 271, "tweenMethod": "linearNone", "tween": true, "target": 560, "key": "x", "index": 10 }, { "value": 271, "tweenMethod": "linearNone", "tween": true, "target": 560, "label": null, "key": "x", "index": 40 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_btn_btn1.png", "ui/img_uk_ui_new_ui38.png", "ui/img_uk_effect_btn.png"], "loadList3D": [] };
            page.PageBtnUI = PageBtnUI;
            REG("ui.page.PageBtnUI", PageBtnUI);
            class PageBtnAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageBtnAnimUI.uiView);
                }
            }
            PageBtnAnimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 50, "mouseThrough": true, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 25, "x": 25, "width": 32, "skin": "ui/img_uk_ui2_guanggao.png", "pivotY": 16, "pivotX": 16, "height": 32 }, "compId": 1166 }, { "type": "Image", "props": { "y": 25, "x": 25, "width": 32, "skin": "ui/img_uk_ui2_guanggao.png", "pivotY": 16, "pivotX": 16, "height": 32, "blendMode": "lighter" }, "compId": 1167 }], "animations": [{ "nodes": [{ "target": 1167, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleY", "index": 0 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleY", "index": 10 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "label": null, "key": "scaleY", "index": 30 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleX", "index": 0 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "scaleX", "index": 10 }, { "value": 1.5, "tweenMethod": "linearNone", "tween": true, "target": 1167, "label": null, "key": "scaleX", "index": 30 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1167, "key": "alpha", "index": 10 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1167, "label": null, "key": "alpha", "index": 30 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_guanggao.png"], "loadList3D": [] };
            page.PageBtnAnimUI = PageBtnAnimUI;
            REG("ui.page.PageBtnAnimUI", PageBtnAnimUI);
            class PageBtnTianjiangUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageBtnTianjiangUI.uiView);
                }
            }
            PageBtnTianjiangUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1144 }, { "type": "Box", "props": { "y": 111, "x": 52, "width": 125, "scaleX": 1, "pivotY": 30, "pivotX": 63, "height": 59 }, "compId": 1152, "child": [{ "type": "Image", "props": { "width": 122, "skin": "ui/img_UM_herokill_bg_yellow.png", "height": 57 }, "compId": 1151 }, { "type": "Image", "props": { "y": 23, "x": 61, "width": 219, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,24,33,23", "scaleY": 0.5, "scaleX": 0.5, "pivotY": 37, "pivotX": 110, "height": 96 }, "compId": 1148 }] }, { "type": "Image", "props": { "y": 99, "x": 6, "width": 21, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 17 }, "compId": 1149 }, { "type": "Image", "props": { "y": 97, "x": 27, "width": 66, "skin": "ui/img_UM_ui_text74.png", "height": 20 }, "compId": 1150 }, { "type": "Image", "props": { "y": 46, "x": 51, "width": 95, "var": "img_box", "skin": "ui/img_UM_box_rankbox3.png", "pivotY": 48, "pivotX": 48, "name": "img_box", "height": 95 }, "compId": 1153 }], "animations": [{ "nodes": [{ "target": 1152, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 10 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 17 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 10 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 17 }] } }, { "target": 1153, "keyframes": { "y": [{ "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "y", "index": 0 }, { "value": 51, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "y", "index": 3 }, { "value": 34, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "y", "index": 6 }, { "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 10 }, { "value": 49, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 13 }, { "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 15 }, { "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 17 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 6 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 10 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "scaleY", "index": 15 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 6 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 10 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text74.png", "ui/img_UM_box_rankbox3.png"], "loadList3D": [] };
            page.PageBtnTianjiangUI = PageBtnTianjiangUI;
            REG("ui.page.PageBtnTianjiangUI", PageBtnTianjiangUI);
            class PageCollectionUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageCollectionUI.uiView);
                }
            }
            PageCollectionUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -17, "width": 1247, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 650, "centerX": 0 }, "compId": 1019, "child": [{ "type": "Image", "props": { "y": 84, "x": 98, "width": 1049, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "83,65,83,53", "height": 532 }, "compId": 997 }, { "type": "Image", "props": { "skin": "ui/img_uk_ui2_obj19.png" }, "compId": 1004 }, { "type": "Image", "props": { "y": 115, "x": 607, "skin": "ui/img_uk_text_scyl.png" }, "compId": 998 }, { "type": "Image", "props": { "y": 27, "x": 69, "skin": "ui/img_uk_img_body.png" }, "compId": 1002 }, { "type": "Image", "props": { "y": 240, "x": 526, "width": 609, "skin": "ui/img_uk_text_tj.png", "height": 47 }, "compId": 999 }, { "type": "Image", "props": { "y": 301, "x": 580, "width": 500, "skin": "ui/img_uk_ui2_obj13.png", "height": 155 }, "compId": 1010 }, { "type": "Image", "props": { "y": 288, "x": 649, "width": 142, "skin": "ui/img_uk_icon_zs2.png", "height": 142 }, "compId": 1011 }, { "type": "Image", "props": { "y": 287, "x": 850, "width": 146, "skin": "ui/img_uk_icon_gold3.png", "height": 146 }, "compId": 1012 }, { "type": "Label", "props": { "y": 398, "x": 684, "wordWrap": true, "width": 72, "valign": "middle", "text": "200", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1013 }, { "type": "Label", "props": { "y": 398, "x": 887, "wordWrap": true, "width": 72, "valign": "middle", "text": "2000", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1014 }, { "type": "Image", "props": { "y": 399, "x": 753, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 1015 }, { "type": "Image", "props": { "y": 400, "x": 961, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 1016 }, { "type": "Box", "props": { "y": 459, "x": 676, "var": "btn_ok", "name": "btn_ok" }, "compId": 1018, "child": [{ "type": "Image", "props": { "width": 308, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "58,52,59,43", "height": 132 }, "compId": 1000 }, { "type": "Label", "props": { "y": 28, "x": 32, "wordWrap": true, "width": 253, "valign": "middle", "text": "立即领取", "strokeColor": "#01344c", "stroke": 6, "height": 76, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1017 }] }] }, { "type": "Box", "props": { "y": 79, "x": 1106, "width": 94, "var": "btn_close", "name": "btn_close", "height": 122 }, "compId": 1005, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 1006 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 1007 }, { "type": "Label", "props": { "y": 66, "x": 7, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1008 }] }], "loadList": ["ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_text_scyl.png", "ui/img_uk_img_body.png", "ui/img_uk_text_tj.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_icon_zs2.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_ui2_obj17.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            page.PageCollectionUI = PageCollectionUI;
            REG("ui.page.PageCollectionUI", PageCollectionUI);
            class PageGameMode1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageGameMode1UI.uiView);
                }
            }
            PageGameMode1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 284, "mouseThrough": false, "height": 213 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_gameMode_2v2.png", "scaleY": 1, "scaleX": 1 }, "compId": 1078 }], "loadList": ["ui/img_UM_gameMode_2v2.png"], "loadList3D": [] };
            page.PageGameMode1UI = PageGameMode1UI;
            REG("ui.page.PageGameMode1UI", PageGameMode1UI);
            class PageGameMode2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageGameMode2UI.uiView);
                }
            }
            PageGameMode2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 277, "mouseThrough": false, "height": 199 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_gameMode_dibao.png", "scaleY": 1, "scaleX": 1 }, "compId": 1078 }], "loadList": ["ui/img_UM_gameMode_dibao.png"], "loadList3D": [] };
            page.PageGameMode2UI = PageGameMode2UI;
            REG("ui.page.PageGameMode2UI", PageGameMode2UI);
            class PageGiftBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageGiftBtnUI.uiView);
                }
            }
            PageGiftBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 135 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1144 }, { "type": "Image", "props": { "y": 7, "x": 7, "width": 85, "var": "img_hero", "skin": "ui/img_UM_hero2.png", "name": "img_hero", "height": 85 }, "compId": 1147 }, { "type": "Box", "props": { "y": 111, "x": 52, "width": 125, "scaleX": 1, "pivotY": 30, "pivotX": 63, "height": 59 }, "compId": 1152, "child": [{ "type": "Image", "props": { "width": 122, "skin": "ui/img_UM_herokill_bg_yellow.png", "height": 57 }, "compId": 1151 }, { "type": "Image", "props": { "y": 23, "x": 61, "width": 219, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,24,33,23", "scaleY": 0.5, "scaleX": 0.5, "pivotY": 37, "pivotX": 110, "height": 96 }, "compId": 1148 }] }, { "type": "Image", "props": { "y": 99, "x": 6, "width": 21, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 17 }, "compId": 1149 }, { "type": "Image", "props": { "y": 97, "x": 27, "width": 66, "skin": "ui/img_UM_ui_text73_2.png", "height": 20 }, "compId": 1150 }, { "type": "Label", "props": { "y": 65, "x": -3, "wordWrap": false, "width": 93, "var": "txt_num", "text": "x28", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_num", "height": 21, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1153 }], "animations": [{ "nodes": [{ "target": 1152, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 10 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 17 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 10 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_hero2.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text73_2.png"], "loadList3D": [] };
            page.PageGiftBtnUI = PageGiftBtnUI;
            REG("ui.page.PageGiftBtnUI", PageGiftBtnUI);
            class PageGoldGunUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageGoldGunUI.uiView);
                }
            }
            PageGoldGunUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 180 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 15, "width": 149, "skin": "ui/img_uk_ui2_goldgun.png", "height": 105, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": -11, "x": 3, "width": 173, "skin": "ui/img_uk_ui2_goldguneffect.png", "height": 127, "blendMode": "lighter" }, "compId": 1015 }, { "type": "Image", "props": { "y": 9, "x": 15, "width": 106, "skin": "ui/img_uk_ui_new_ui33.png", "height": 24 }, "compId": 1016 }, { "type": "Image", "props": { "y": 58, "x": 92, "width": 142, "skin": "ui/img_uk_Icon_goldgun.png", "pivotY": 54, "pivotX": 71, "height": 107 }, "compId": 1017 }, { "type": "Image", "props": { "y": 9, "x": 17, "width": 90, "skin": "ui/img_uk_text_goldgun1.png", "height": 23 }, "compId": 1013 }, { "type": "Image", "props": { "y": 81, "x": 109, "width": 52, "skin": "ui/img_uk_text_yj.png", "height": 25 }, "compId": 1018 }, { "type": "Image", "props": { "y": 111, "x": 16, "width": 149, "skin": "ui/img_uk_ui2_btn2.png", "height": 52 }, "compId": 1021 }, { "type": "Box", "props": { "y": 115, "x": 22 }, "compId": 1022, "child": [{ "type": "Label", "props": { "y": 5, "x": 41, "wordWrap": true, "width": 98, "valign": "middle", "text": "免费领取", "strokeColor": "#563d16", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffff64", "bold": false, "align": "center" }, "compId": 1023 }, { "type": "Image", "props": { "y": 8, "x": 9, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1026 }] }], "animations": [{ "nodes": [{ "target": 1015, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "label": null, "key": "alpha", "index": 20 }] } }, { "target": 1017, "keyframes": { "y": [{ "value": 71, "tweenMethod": "linearNone", "tween": true, "target": 1017, "key": "y", "index": 0 }, { "value": 67, "tweenMethod": "linearNone", "tween": true, "target": 1017, "key": "y", "index": 10 }, { "value": 71, "tweenMethod": "linearNone", "tween": true, "target": 1017, "label": null, "key": "y", "index": 20 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1017, "key": "scaleY", "index": 0 }, { "value": 1.02, "tweenMethod": "linearNone", "tween": true, "target": 1017, "key": "scaleY", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1017, "label": null, "key": "scaleY", "index": 20 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1017, "key": "scaleX", "index": 0 }, { "value": 1.02, "tweenMethod": "linearNone", "tween": true, "target": 1017, "key": "scaleX", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1017, "label": null, "key": "scaleX", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_goldgun.png", "ui/img_uk_ui2_goldguneffect.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_Icon_goldgun.png", "ui/img_uk_text_goldgun1.png", "ui/img_uk_text_yj.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png"], "loadList3D": [] };
            page.PageGoldGunUI = PageGoldGunUI;
            REG("ui.page.PageGoldGunUI", PageGoldGunUI);
            class PageGoldGunGetUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageGoldGunGetUI.uiView);
                }
            }
            PageGoldGunGetUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -10, "width": 1063, "height": 541, "centerX": 74 }, "compId": 1113, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 565, "skin": "ui/img_uk_ui2_obj19.png", "height": 474 }, "compId": 1027 }, { "type": "Image", "props": { "y": 82, "x": 3, "width": 896, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 429, "alpha": 1 }, "compId": 876 }, { "type": "Box", "props": { "y": 101, "x": 24, "var": "img_bg", "name": "img_bg" }, "compId": 1112, "child": [{ "type": "Image", "props": { "width": 486, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "43,81,40,78", "height": 254, "alpha": 0.7 }, "compId": 1022 }, { "type": "Image", "props": { "y": 17, "x": 492, "width": 366, "skin": "ui/img_uk_ui2_obj13.png", "height": 225 }, "compId": 946 }] }, { "type": "Image", "props": { "y": 230, "x": 58, "width": 416, "skin": "ui/img_uk_ui2_obj3.png", "height": 125 }, "compId": 1026 }, { "type": "Box", "props": { "y": 367, "x": 263 }, "compId": 1032, "child": [{ "type": "Box", "props": { "y": 2, "var": "btn_close", "name": "btn_close" }, "compId": 937, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 918 }, { "type": "Label", "props": { "y": 11, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "残忍拒绝", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 919 }] }, { "type": "Box", "props": { "x": 233, "var": "btn_use", "name": "btn_use" }, "compId": 1023, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1024 }, { "type": "Label", "props": { "y": 11, "x": 61, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即领取", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1025 }, { "type": "Image", "props": { "y": 25, "x": 29, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1114 }] }] }, { "type": "Image", "props": { "y": 38, "x": 306, "width": 368, "skin": "ui/img_uk_text_goldgun3.png", "height": 40 }, "compId": 1044 }, { "type": "Image", "props": { "y": 316, "x": 131, "width": 270, "skin": "ui/img_uk_ui2_obj6.png", "sizeGrid": "5,5,5,5", "height": 20 }, "compId": 1066 }, { "type": "Image", "props": { "y": 322, "x": 136, "width": 260, "var": "bar_ad", "skin": "ui/img_uk_ui2_obj7.png", "sizeGrid": "2,2,2,2", "name": "bar_ad", "height": 10 }, "compId": 1067 }, { "type": "Label", "props": { "y": 313, "x": 179, "wordWrap": true, "width": 173, "var": "txt_bar", "text": "0%", "strokeColor": "#000000", "stroke": 4, "name": "txt_bar", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1068 }, { "type": "Label", "props": { "y": 455, "x": 254, "wordWrap": true, "width": 470, "var": "txt_tt", "valign": "middle", "text": "观看N个广告可领取奖励", "strokeColor": "#4f1904", "stroke": 2, "name": "txt_tt", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 1069 }, { "type": "Box", "props": { "y": 184, "x": 897, "width": 169, "var": "box_next_money", "name": "box_next_money", "height": 230 }, "compId": 1082, "child": [{ "type": "Image", "props": { "y": 165, "x": 11, "width": 148, "skin": "ui/img_uk_ui_new_ui33.png", "height": 65, "alpha": 0.6 }, "compId": 1083 }, { "type": "Image", "props": { "width": 169, "skin": "ui/img_uk_text_xyjl.png", "name": "txt_next", "height": 43 }, "compId": 1084 }, { "type": "Image", "props": { "y": 49, "x": 6, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 1085 }, { "type": "Image", "props": { "y": 60, "x": 17, "width": 130, "skin": "ui/img_uk_StoreMainDiamonds.png", "height": 112 }, "compId": 1086 }, { "type": "Image", "props": { "y": 168, "x": 109, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 1087 }, { "type": "Image", "props": { "y": 197, "x": 110, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 1088 }, { "type": "Label", "props": { "y": 172, "x": 26, "wordWrap": true, "width": 99, "var": "txt_num", "text": "5000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_num", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1089 }, { "type": "Label", "props": { "y": 201, "x": 26, "wordWrap": true, "width": 99, "var": "txt_num2", "text": "5000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_num2", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1090 }] }, { "type": "Box", "props": { "y": 122.5, "x": 82, "var": "box_gun", "name": "box_gun" }, "compId": 1093, "child": [{ "type": "Label", "props": { "x": 54, "wordWrap": false, "width": 271, "var": "txt_name", "valign": "middle", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1019 }, { "type": "Image", "props": { "y": 45, "var": "img_1", "skin": "ui/img_uk_icon_gunimg.png", "name": "img_1" }, "compId": 1028 }, { "type": "Label", "props": { "y": 37, "x": 485, "wordWrap": true, "width": 128, "var": "txt_ctype", "text": "类型：步枪", "strokeColor": "#e26740", "stroke": 0, "name": "txt_ctype", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1035 }, { "type": "Label", "props": { "y": 37, "x": 648, "wordWrap": true, "width": 128, "var": "txt_quality", "text": "品质：良", "strokeColor": "#e26740", "stroke": 0, "name": "txt_quality", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1036 }, { "type": "Label", "props": { "y": 63, "x": 485, "wordWrap": true, "width": 128, "var": "txt_attStype", "text": "口径：7.62mm", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attStype", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1037 }, { "type": "Label", "props": { "y": 63, "x": 648, "wordWrap": true, "width": 128, "var": "txt_attBulletMax", "text": "弹容：25", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletMax", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1038 }, { "type": "Label", "props": { "y": 98, "x": 485, "wordWrap": true, "width": 128, "var": "txt_att", "text": "伤害：50", "strokeColor": "#e26740", "stroke": 0, "name": "txt_att", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1039 }, { "type": "Label", "props": { "y": 98, "x": 648, "wordWrap": true, "width": 128, "var": "txt_attCd", "text": "射速：20", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attCd", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1040 }, { "type": "Label", "props": { "y": 127, "x": 485, "wordWrap": true, "width": 128, "var": "txt_attAcc", "text": "精度：90", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attAcc", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1041 }, { "type": "Label", "props": { "y": 127, "x": 648, "wordWrap": true, "width": 128, "var": "txt_attBulletTime", "text": "换弹：10", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletTime", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1042 }, { "type": "Image", "props": { "y": 179, "x": 325, "skin": "ui/img_uk_text_yj.png" }, "compId": 1043 }] }, { "type": "Box", "props": { "y": 120.5, "x": 136, "var": "box_money", "name": "box_money" }, "compId": 1094, "child": [{ "type": "Label", "props": { "wordWrap": false, "width": 271, "valign": "middle", "text": "金币与钻石", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1095 }, { "type": "Label", "props": { "y": 68, "x": 470, "wordWrap": true, "width": 151, "var": "txt_info", "text": "金币：3000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_info", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1096 }, { "type": "Image", "props": { "y": 42, "x": 39, "width": 192, "skin": "ui/img_uk_StoreMainDiamonds.png", "height": 166 }, "compId": 1097 }, { "type": "Image", "props": { "y": 59, "x": 611, "width": 40, "skin": "ui/img_uk_Icon_jinbi.png", "height": 40 }, "compId": 1098 }, { "type": "Image", "props": { "y": 105, "x": 612, "width": 40, "skin": "ui/img_uk_Icon_zs.png", "height": 40 }, "compId": 1099 }, { "type": "Label", "props": { "y": 115, "x": 470, "wordWrap": true, "width": 151, "var": "txt_info2", "text": "钻石：3000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_info2", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1100 }] }, { "type": "Box", "props": { "y": 184, "x": 897, "width": 173, "var": "box_next_gun", "name": "box_next_gun", "height": 241 }, "compId": 1101, "child": [{ "type": "Image", "props": { "y": 194.5, "x": 10, "width": 148, "skin": "ui/img_uk_ui_new_ui33.png", "height": 46, "alpha": 0.6 }, "compId": 1102 }, { "type": "Image", "props": { "y": -0.5, "x": 2, "width": 169, "skin": "ui/img_uk_text_xyjl.png", "name": "txt_next", "height": 43 }, "compId": 1103 }, { "type": "Image", "props": { "y": 162.5, "x": 7, "width": 153, "skin": "ui/img_uk_ui2_obj11.png", "height": 39 }, "compId": 1104 }, { "type": "Image", "props": { "y": 48.5, "x": 8, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 1105 }, { "type": "Clip", "props": { "y": 16.5, "width": 172, "var": "selectBox", "skin": "ui/clip_uk_ui2_uieffect_1.png", "rotation": 0, "name": "selectBox", "height": 178, "clipY": 2 }, "compId": 1106 }, { "type": "Label", "props": { "y": 174.5, "x": 23, "wordWrap": false, "width": 126, "var": "txt_name2", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1107 }, { "type": "Image", "props": { "y": 31.5, "x": 11, "width": 150, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico", "height": 150 }, "compId": 1108 }, { "type": "Image", "props": { "y": 132.5, "x": 104, "width": 53, "var": "img_perm", "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 1109 }, { "type": "Label", "props": { "y": 210.5, "x": 21, "wordWrap": false, "width": 126, "var": "txt_att2", "text": "伤害：50", "strokeColor": "#000000", "stroke": 0, "name": "txt_att2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#a5a85c", "bold": false, "align": "center" }, "compId": 1110 }] }] }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_ui2_obj3.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_text_goldgun3.png", "ui/img_uk_ui2_obj6.png", "ui/img_uk_ui2_obj7.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_text_xyjl.png", "ui/img_uk_StoreMainDiamonds.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_icon_gunimg.png", "ui/img_uk_text_yj.png", "ui/img_uk_ui2_obj11.png", "ui/clip_uk_ui2_uieffect_1.png", "ui/img_uk_icon_gunicon.png"], "loadList3D": [] };
            page.PageGoldGunGetUI = PageGoldGunGetUI;
            REG("ui.page.PageGoldGunGetUI", PageGoldGunGetUI);
            class PageGoldGunGet1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageGoldGunGet1UI.uiView);
                }
            }
            PageGoldGunGet1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -14, "width": 779, "height": 713, "centerX": -2 }, "compId": 1113, "child": [{ "type": "Image", "props": { "y": 0, "x": 2, "width": 774, "skin": "ui/img_uk_ui2_obj19.png", "height": 650 }, "compId": 1027 }, { "type": "Image", "props": { "y": 124, "x": 47, "width": 685, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 550, "alpha": 1 }, "compId": 876 }, { "type": "Box", "props": { "y": 150, "x": 147, "var": "img_bg", "name": "img_bg" }, "compId": 1112, "child": [{ "type": "Image", "props": { "width": 486, "skin": "ui/img_uk_ui2_obj8.png", "sizeGrid": "43,81,40,78", "height": 254, "alpha": 0.7 }, "compId": 1022 }, { "type": "Image", "props": { "y": 257, "x": 11, "width": 464, "skin": "ui/img_uk_ui2_obj13.png", "height": 169 }, "compId": 946 }] }, { "type": "Image", "props": { "y": 283, "x": 182, "width": 416, "skin": "ui/img_uk_ui2_obj3.png", "height": 125 }, "compId": 1026 }, { "type": "Box", "props": { "y": 577, "x": 163 }, "compId": 1032, "child": [{ "type": "Box", "props": { "y": 2, "var": "btn_close", "name": "btn_close" }, "compId": 937, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 918 }, { "type": "Label", "props": { "y": 11, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "残忍拒绝", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 919 }] }, { "type": "Box", "props": { "x": 233, "var": "btn_use", "name": "btn_use" }, "compId": 1023, "child": [{ "type": "Image", "props": { "y": 0, "width": 220, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1024 }, { "type": "Label", "props": { "y": 11, "x": 61, "wordWrap": true, "width": 139, "valign": "middle", "text": "立即领取", "strokeColor": "#9c7227", "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1025 }, { "type": "Image", "props": { "y": 25, "x": 29, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1114 }] }] }, { "type": "Image", "props": { "y": 46, "x": 63, "width": 654, "skin": "ui/img_uk_text_goldgun3.png", "height": 71 }, "compId": 1044 }, { "type": "Image", "props": { "y": 370, "x": 255, "width": 270, "skin": "ui/img_uk_ui2_obj6.png", "sizeGrid": "5,5,5,5", "height": 20 }, "compId": 1066 }, { "type": "Image", "props": { "y": 376, "x": 260, "width": 260, "var": "bar_ad", "skin": "ui/img_uk_ui2_obj7.png", "sizeGrid": "2,2,2,2", "name": "bar_ad", "height": 10 }, "compId": 1067 }, { "type": "Label", "props": { "y": 367, "x": 303, "wordWrap": true, "width": 173, "var": "txt_bar", "text": "0%", "strokeColor": "#000000", "stroke": 4, "name": "txt_bar", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1068 }, { "type": "Label", "props": { "y": 678, "x": 155, "wordWrap": true, "width": 470, "var": "txt_tt", "valign": "middle", "text": "观看N个广告可领取奖励", "strokeColor": "#4f1904", "stroke": 2, "name": "txt_tt", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 1069 }, { "type": "Box", "props": { "y": 254, "x": 797, "width": 169, "var": "box_next_money", "name": "box_next_money", "height": 230 }, "compId": 1082, "child": [{ "type": "Image", "props": { "y": 165, "x": 11, "width": 148, "skin": "ui/img_uk_ui_new_ui33.png", "height": 65, "alpha": 0.6 }, "compId": 1083 }, { "type": "Image", "props": { "width": 169, "skin": "ui/img_uk_text_xyjl.png", "name": "txt_next", "height": 43 }, "compId": 1084 }, { "type": "Image", "props": { "y": 49, "x": 6, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 1085 }, { "type": "Image", "props": { "y": 60, "x": 17, "width": 130, "skin": "ui/img_uk_StoreMainDiamonds.png", "height": 112 }, "compId": 1086 }, { "type": "Image", "props": { "y": 168, "x": 109, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 1087 }, { "type": "Image", "props": { "y": 197, "x": 110, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 1088 }, { "type": "Label", "props": { "y": 172, "x": 26, "wordWrap": true, "width": 99, "var": "txt_num", "text": "5000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_num", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1089 }, { "type": "Label", "props": { "y": 201, "x": 26, "wordWrap": true, "width": 99, "var": "txt_num2", "text": "5000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_num2", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1090 }] }, { "type": "Box", "props": { "y": 173, "x": 200, "var": "box_gun", "name": "box_gun" }, "compId": 1093, "child": [{ "type": "Label", "props": { "x": 54, "wordWrap": false, "width": 271, "var": "txt_name", "valign": "middle", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1019 }, { "type": "Image", "props": { "y": 45, "var": "img_1", "skin": "ui/img_uk_icon_gunimg.png", "name": "img_1" }, "compId": 1028 }, { "type": "Label", "props": { "y": 265, "x": 31, "wordWrap": true, "width": 128, "var": "txt_ctype", "text": "类型：步枪", "strokeColor": "#e26740", "stroke": 0, "name": "txt_ctype", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1035 }, { "type": "Label", "props": { "y": 265, "x": 229, "wordWrap": true, "width": 128, "var": "txt_quality", "text": "品质：良", "strokeColor": "#e26740", "stroke": 0, "name": "txt_quality", "height": 18, "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1036 }, { "type": "Label", "props": { "y": 291, "x": 31, "wordWrap": true, "width": 128, "var": "txt_attStype", "text": "口径：7.62mm", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attStype", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1037 }, { "type": "Label", "props": { "y": 291, "x": 229, "wordWrap": true, "width": 128, "var": "txt_attBulletMax", "text": "弹容：25", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletMax", "height": "", "fontSize": 18, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1038 }, { "type": "Label", "props": { "y": 326, "x": 31, "wordWrap": true, "width": 128, "var": "txt_att", "text": "伤害：50", "strokeColor": "#e26740", "stroke": 0, "name": "txt_att", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1039 }, { "type": "Label", "props": { "y": 326, "x": 229, "wordWrap": true, "width": 128, "var": "txt_attCd", "text": "射速：20", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attCd", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1040 }, { "type": "Label", "props": { "y": 355, "x": 31, "wordWrap": true, "width": 128, "var": "txt_attAcc", "text": "精度：90", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attAcc", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1041 }, { "type": "Label", "props": { "y": 355, "x": 229, "wordWrap": true, "width": 128, "var": "txt_attBulletTime", "text": "换弹：10", "strokeColor": "#e26740", "stroke": 0, "name": "txt_attBulletTime", "height": "", "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "left" }, "compId": 1042 }, { "type": "Image", "props": { "y": 179, "x": 325, "skin": "ui/img_uk_text_yj.png" }, "compId": 1043 }] }, { "type": "Box", "props": { "y": 173, "x": 254, "var": "box_money", "name": "box_money" }, "compId": 1094, "child": [{ "type": "Label", "props": { "wordWrap": false, "width": 271, "valign": "middle", "text": "金币与钻石", "strokeColor": "#000000", "stroke": 0, "name": "txt_name", "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1095 }, { "type": "Label", "props": { "y": 285, "x": 46, "wordWrap": true, "width": 151, "var": "txt_info", "text": "金币：3000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_info", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1096 }, { "type": "Image", "props": { "y": 42, "x": 39, "width": 192, "skin": "ui/img_uk_StoreMainDiamonds.png", "height": 166 }, "compId": 1097 }, { "type": "Image", "props": { "y": 276, "x": 187, "width": 40, "skin": "ui/img_uk_Icon_jinbi.png", "height": 40 }, "compId": 1098 }, { "type": "Image", "props": { "y": 322, "x": 188, "width": 40, "skin": "ui/img_uk_Icon_zs.png", "height": 40 }, "compId": 1099 }, { "type": "Label", "props": { "y": 332, "x": 46, "wordWrap": true, "width": 151, "var": "txt_info2", "text": "钻石：3000", "strokeColor": "#e26740", "stroke": 0, "name": "txt_info2", "height": 22, "fontSize": 22, "font": "SimHei", "color": "#f3f3f3", "bold": false, "align": "center" }, "compId": 1100 }] }, { "type": "Box", "props": { "y": 254, "x": 797, "width": 173, "var": "box_next_gun", "name": "box_next_gun", "height": 241 }, "compId": 1101, "child": [{ "type": "Image", "props": { "y": 194.5, "x": 10, "width": 148, "skin": "ui/img_uk_ui_new_ui33.png", "height": 46, "alpha": 0.6 }, "compId": 1102 }, { "type": "Image", "props": { "y": -0.5, "x": 2, "width": 169, "skin": "ui/img_uk_text_xyjl.png", "name": "txt_next", "height": 43 }, "compId": 1103 }, { "type": "Image", "props": { "y": 162.5, "x": 7, "width": 153, "skin": "ui/img_uk_ui2_obj11.png", "height": 39 }, "compId": 1104 }, { "type": "Image", "props": { "y": 48.5, "x": 8, "width": 155, "skin": "ui/img_uk_ui2_obj8.png", "height": 115, "alpha": 0.7 }, "compId": 1105 }, { "type": "Clip", "props": { "y": 16.5, "width": 172, "var": "selectBox", "skin": "ui/clip_uk_ui2_uieffect_1.png", "rotation": 0, "name": "selectBox", "height": 178, "clipY": 2 }, "compId": 1106 }, { "type": "Label", "props": { "y": 174.5, "x": 23, "wordWrap": false, "width": 126, "var": "txt_name2", "text": "AK-103", "strokeColor": "#000000", "stroke": 0, "name": "txt_name2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1107 }, { "type": "Image", "props": { "y": 31.5, "x": 11, "width": 150, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico", "height": 150 }, "compId": 1108 }, { "type": "Image", "props": { "y": 132.5, "x": 104, "width": 53, "var": "img_perm", "skin": "ui/img_uk_text_yj.png", "name": "img_perm", "height": 27 }, "compId": 1109 }, { "type": "Label", "props": { "y": 210.5, "x": 21, "wordWrap": false, "width": 126, "var": "txt_att2", "text": "伤害：50", "strokeColor": "#000000", "stroke": 0, "name": "txt_att2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#a5a85c", "bold": false, "align": "center" }, "compId": 1110 }] }] }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj8.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_ui2_obj3.png", "ui/img_uk_ui2_btn1.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_text_goldgun3.png", "ui/img_uk_ui2_obj6.png", "ui/img_uk_ui2_obj7.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_text_xyjl.png", "ui/img_uk_StoreMainDiamonds.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_icon_gunimg.png", "ui/img_uk_text_yj.png", "ui/img_uk_ui2_obj11.png", "ui/clip_uk_ui2_uieffect_1.png", "ui/img_uk_icon_gunicon.png"], "loadList3D": [] };
            page.PageGoldGunGet1UI = PageGoldGunGet1UI;
            REG("ui.page.PageGoldGunGet1UI", PageGoldGunGet1UI);
            class PageHeadUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageHeadUI.uiView);
                }
            }
            PageHeadUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 50, "x": 50, "width": 110, "pivotY": 55, "pivotX": 55, "height": 110 }, "compId": 1154, "child": [{ "type": "Image", "props": { "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1155 }, { "type": "Image", "props": { "y": 3, "x": 4, "var": "img_head", "skin": "ui/img_UM_head.png", "renderType": "render", "name": "img_head" }, "compId": 1156 }] }], "animations": [{ "nodes": [{ "target": 1154, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 17 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn__btn1.png", "ui/img_UM_head.png"], "loadList3D": [] };
            page.PageHeadUI = PageHeadUI;
            REG("ui.page.PageHeadUI", PageHeadUI);
            class PageIcoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageIcoUI.uiView);
                }
            }
            PageIcoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 30, "mouseThrough": true, "height": 30 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 15, "width": 40, "visible": false, "skin": "ui/img_uk_ui2_obj18.png", "pivotY": 20, "pivotX": 20, "height": 40 }, "compId": 893 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 20, "skin": "ui/img_uk_icon_tanhao.png", "pivotY": 10, "pivotX": 10, "height": 20 }, "compId": 892 }], "animations": [{ "nodes": [{ "target": 892, "keyframes": { "y": [{ "value": 15, "tweenMethod": "linearNone", "tween": true, "target": 892, "key": "y", "index": 0 }, { "value": 14, "tweenMethod": "linearNone", "tween": true, "target": 892, "key": "y", "index": 10 }, { "value": 11, "tweenMethod": "linearNone", "tween": true, "target": 892, "key": "y", "index": 13 }, { "value": 15, "tweenMethod": "linearNone", "tween": true, "target": 892, "key": "y", "index": 16 }, { "value": 14, "tweenMethod": "linearNone", "tween": true, "target": 892, "key": "y", "index": 18 }, { "value": 15, "tweenMethod": "linearNone", "tween": true, "target": 892, "label": null, "key": "y", "index": 25 }] } }, { "target": 893, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 893, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 893, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 893, "label": null, "key": "alpha", "index": 25 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_obj18.png", "ui/img_uk_icon_tanhao.png"], "loadList3D": [] };
            page.PageIcoUI = PageIcoUI;
            REG("ui.page.PageIcoUI", PageIcoUI);
            class PageRedAnim1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRedAnim1UI.uiView);
                }
            }
            PageRedAnim1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 50, "width": 93, "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "pivotY": 31, "pivotX": 47, "height": 62 }, "compId": 1174 }, { "type": "Image", "props": { "y": 22, "x": 49, "width": 68, "skin": "ui/img_UM_ui_text18.png", "pivotY": 14, "pivotX": 34, "height": 27 }, "compId": 1175 }], "animations": [{ "nodes": [{ "target": 1174, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red.png", "ui/img_UM_ui_text18.png"], "loadList3D": [] };
            page.PageRedAnim1UI = PageRedAnim1UI;
            REG("ui.page.PageRedAnim1UI", PageRedAnim1UI);
            class PageRedAnim2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRedAnim2UI.uiView);
                }
            }
            PageRedAnim2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 50, "width": 93, "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "pivotY": 31, "pivotX": 47, "height": 62 }, "compId": 1174 }, { "type": "Image", "props": { "y": 22, "x": 49, "width": 68, "skin": "ui/img_UM_ui_text19.png", "pivotY": 14, "pivotX": 34, "height": 27 }, "compId": 1175 }], "animations": [{ "nodes": [{ "target": 1174, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red.png", "ui/img_UM_ui_text19.png"], "loadList3D": [] };
            page.PageRedAnim2UI = PageRedAnim2UI;
            REG("ui.page.PageRedAnim2UI", PageRedAnim2UI);
            class PageRedAnim3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRedAnim3UI.uiView);
                }
            }
            PageRedAnim3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 50, "width": 110, "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "pivotY": 31, "pivotX": 47, "height": 62 }, "compId": 1174 }, { "type": "Image", "props": { "y": 9, "x": 16, "width": 87, "skin": "ui/img_UM_ui_text25.png", "height": 25 }, "compId": 1177 }], "animations": [{ "nodes": [{ "target": 1174, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red.png", "ui/img_UM_ui_text25.png"], "loadList3D": [] };
            page.PageRedAnim3UI = PageRedAnim3UI;
            REG("ui.page.PageRedAnim3UI", PageRedAnim3UI);
            class PageRewardUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRewardUI.uiView);
                }
            }
            PageRewardUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerY": 0, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 51, "x": 332, "var": "box_scale", "name": "box_scale" }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 47, "x": -9, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1007 }, { "type": "Image", "props": { "y": 112, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1008 }, { "type": "Image", "props": { "y": 391, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1009 }, { "type": "Image", "props": { "y": 58, "x": 218, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1010 }, { "type": "Box", "props": { "y": 410, "x": 173, "width": 270, "var": "btn_ad", "name": "btn_ad", "height": 107 }, "compId": 1011, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1013 }, { "type": "Image", "props": { "y": 23, "x": 92, "width": 153, "var": "img_free", "skin": "ui/img_UM_ui_text56.png", "name": "img_free", "height": 44 }, "compId": 1014 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 46 }, "compId": 1015 }] }, { "type": "Box", "props": { "y": -4, "x": -284, "var": "img_no", "name": "img_no" }, "compId": 1016, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1017 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1018 }] }, { "type": "Image", "props": { "y": 151, "x": 218, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1019 }, { "type": "Image", "props": { "y": 217, "x": 239, "width": 137, "var": "img_ico2", "skin": "ui/img_UM_box_gold.png", "name": "img_ico2", "height": 137 }, "compId": 1020 }, { "type": "Image", "props": { "y": 167, "x": 333, "width": 36, "var": "img_ico", "skin": "ui/img_UM_gold.png", "name": "img_ico", "height": 36 }, "compId": 1022 }, { "type": "Image", "props": { "y": 555, "x": 173, "width": 270, "var": "img_close", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 8, "name": "img_close", "height": 107 }, "compId": 1024, "child": [{ "type": "Label", "props": { "y": 35, "x": 46, "wordWrap": true, "width": 166, "var": "txt_close", "text": "不了，谢谢", "strokeColor": "#272727", "stroke": 4, "name": "txt_close", "height": 39, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1012 }] }, { "type": "Label", "props": { "y": 161, "x": 229, "wordWrap": false, "width": 96, "var": "txt_num", "valign": "middle", "text": "1000", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 48, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1023 }] }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_ui_text55.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png", "ui/img_UM_btn_BlueButton_2.png"], "loadList3D": [] };
            page.PageRewardUI = PageRewardUI;
            REG("ui.page.PageRewardUI", PageRewardUI);
            class PageReward1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageReward1UI.uiView);
                }
            }
            PageReward1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 51, "x": 332, "width": 813, "var": "box_scale", "name": "box_scale", "height": 551 }, "compId": 1020, "child": [{ "type": "Image", "props": { "y": 47, "x": -9, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1021 }, { "type": "Image", "props": { "y": 112, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1022 }, { "type": "Image", "props": { "y": 391, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1023 }, { "type": "Image", "props": { "y": 58, "x": 218, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1024 }, { "type": "Box", "props": { "y": 410, "x": 419, "width": 269, "var": "btn_ad", "name": "btn_ad", "mouseEnabled": true, "height": 107 }, "compId": 1025, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "var": "img_ad1", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_ad1", "height": 109 }, "compId": 1026 }, { "type": "Image", "props": { "y": 23, "x": 92, "width": 153, "var": "img_free", "skin": "ui/img_UM_ui_text56.png", "name": "img_free", "height": 44 }, "compId": 1027 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 46 }, "compId": 1028 }] }, { "type": "Box", "props": { "y": -4, "x": -284, "var": "img_no", "name": "img_no" }, "compId": 1029, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1030 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1031 }] }, { "type": "Image", "props": { "y": 151, "x": 218, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1032 }, { "type": "Image", "props": { "y": 217, "x": 239, "width": 137, "var": "img_ico2", "skin": "ui/img_UM_box_gold.png", "name": "img_ico2", "height": 137 }, "compId": 1033 }, { "type": "Image", "props": { "y": 167, "x": 333, "width": 36, "var": "img_ico", "skin": "ui/img_UM_gold.png", "name": "img_ico", "height": 36 }, "compId": 1034 }, { "type": "Label", "props": { "y": 161, "x": 229, "wordWrap": false, "width": 96, "var": "txt_num", "valign": "middle", "text": "1000", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 48, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1037 }] }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_ui_text55.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png"], "loadList3D": [] };
            page.PageReward1UI = PageReward1UI;
            REG("ui.page.PageReward1UI", PageReward1UI);
            class PageReward2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageReward2UI.uiView);
                }
            }
            PageReward2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerY": 0, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 51, "x": 332, "var": "box_scale", "name": "box_scale" }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 47, "x": -9, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1007 }, { "type": "Image", "props": { "y": 112, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1008 }, { "type": "Image", "props": { "y": 391, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1009 }, { "type": "Image", "props": { "y": 58, "x": 218, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1010 }, { "type": "Box", "props": { "y": 401, "x": 419, "width": 270, "var": "btn_ad", "name": "btn_ad", "height": 107 }, "compId": 1011, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1013 }, { "type": "Image", "props": { "y": 23, "x": 92, "width": 153, "var": "img_free", "skin": "ui/img_UM_ui_text56.png", "name": "img_free", "height": 44 }, "compId": 1014 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 46 }, "compId": 1015 }] }, { "type": "Box", "props": { "y": -4, "x": -284, "var": "img_no", "name": "img_no" }, "compId": 1016, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1017 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1018 }] }, { "type": "Image", "props": { "y": 151, "x": 218, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1019 }, { "type": "Image", "props": { "y": 217, "x": 239, "width": 137, "var": "img_ico2", "skin": "ui/img_UM_box_gold.png", "name": "img_ico2", "height": 137 }, "compId": 1020 }, { "type": "Image", "props": { "y": 167, "x": 333, "width": 36, "var": "img_ico", "skin": "ui/img_UM_gold.png", "name": "img_ico", "height": 36 }, "compId": 1022 }, { "type": "Image", "props": { "y": 544, "x": 419, "width": 270, "var": "img_close", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 8, "name": "img_close", "height": 107 }, "compId": 1024, "child": [{ "type": "Label", "props": { "y": 35, "x": 46, "wordWrap": true, "width": 166, "var": "txt_close", "text": "不了，谢谢", "strokeColor": "#272727", "stroke": 4, "name": "txt_close", "height": 39, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1012 }] }, { "type": "Label", "props": { "y": 161, "x": 229, "wordWrap": false, "width": 96, "var": "txt_num", "valign": "middle", "text": "1000", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 48, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1023 }] }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_ui_text55.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png", "ui/img_UM_btn_BlueButton_2.png"], "loadList3D": [] };
            page.PageReward2UI = PageReward2UI;
            REG("ui.page.PageReward2UI", PageReward2UI);
            class PageReward3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageReward3UI.uiView);
                }
            }
            PageReward3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 51, "x": 332, "width": 813, "var": "box_scale", "name": "box_scale", "height": 551 }, "compId": 1020, "child": [{ "type": "Image", "props": { "y": 47, "x": -9, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1021 }, { "type": "Image", "props": { "y": 112, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1022 }, { "type": "Image", "props": { "y": 391, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1023 }, { "type": "Image", "props": { "y": 58, "x": 218, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1024 }, { "type": "Box", "props": { "y": 409.5, "x": 673, "width": 269, "var": "btn_ad", "name": "btn_ad", "mouseEnabled": true, "height": 107 }, "compId": 1025, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "var": "img_ad1", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_ad1", "height": 109 }, "compId": 1026 }, { "type": "Image", "props": { "y": 23, "x": 92, "width": 153, "var": "img_free", "skin": "ui/img_UM_ui_text56.png", "name": "img_free", "height": 44 }, "compId": 1027 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 46 }, "compId": 1028 }] }, { "type": "Box", "props": { "y": -4, "x": -284, "var": "img_no", "name": "img_no" }, "compId": 1029, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1030 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1031 }] }, { "type": "Image", "props": { "y": 151, "x": 218, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1032 }, { "type": "Image", "props": { "y": 217, "x": 239, "width": 137, "var": "img_ico2", "skin": "ui/img_UM_box_gold.png", "name": "img_ico2", "height": 137 }, "compId": 1033 }, { "type": "Image", "props": { "y": 167, "x": 333, "width": 36, "var": "img_ico", "skin": "ui/img_UM_gold.png", "name": "img_ico", "height": 36 }, "compId": 1034 }, { "type": "Label", "props": { "y": 161, "x": 229, "wordWrap": false, "width": 96, "var": "txt_num", "valign": "middle", "text": "1000", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 48, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1037 }] }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_ui_text55.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png"], "loadList3D": [] };
            page.PageReward3UI = PageReward3UI;
            REG("ui.page.PageReward3UI", PageReward3UI);
            class PageReward4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageReward4UI.uiView);
                }
            }
            PageReward4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -47, "x": 332, "width": 813, "var": "box_scale", "name": "box_scale", "height": 551 }, "compId": 1020, "child": [{ "type": "Image", "props": { "y": 47, "x": -9, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1021 }, { "type": "Image", "props": { "y": 112, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1022 }, { "type": "Image", "props": { "y": 391, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1023 }, { "type": "Image", "props": { "y": 58, "x": 218, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1024 }, { "type": "Box", "props": { "y": 409, "x": 175, "width": 269, "var": "btn_ad", "name": "btn_ad", "mouseEnabled": true, "height": 107 }, "compId": 1025, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "var": "img_ad1", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_ad1", "height": 109 }, "compId": 1026 }, { "type": "Image", "props": { "y": 23, "x": 92, "width": 153, "var": "img_free", "skin": "ui/img_UM_ui_text56.png", "name": "img_free", "height": 44 }, "compId": 1027 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 46 }, "compId": 1028 }] }, { "type": "Box", "props": { "y": 96, "x": -282, "var": "img_no", "name": "img_no" }, "compId": 1029, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1030 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1031 }] }, { "type": "Image", "props": { "y": 151, "x": 218, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1032 }, { "type": "Image", "props": { "y": 217, "x": 239, "width": 137, "var": "img_ico2", "skin": "ui/img_UM_box_gold.png", "name": "img_ico2", "height": 137 }, "compId": 1033 }, { "type": "Image", "props": { "y": 167, "x": 333, "width": 36, "var": "img_ico", "skin": "ui/img_UM_gold.png", "name": "img_ico", "height": 36 }, "compId": 1034 }, { "type": "Label", "props": { "y": 161, "x": 229, "wordWrap": false, "width": 96, "var": "txt_num", "valign": "middle", "text": "1000", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 48, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1037 }] }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_ui_text55.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png"], "loadList3D": [] };
            page.PageReward4UI = PageReward4UI;
            REG("ui.page.PageReward4UI", PageReward4UI);
            class PageReward5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageReward5UI.uiView);
                }
            }
            PageReward5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -47, "x": 332, "width": 813, "var": "box_scale", "name": "box_scale", "height": 551 }, "compId": 1020, "child": [{ "type": "Image", "props": { "y": 47, "x": -9, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1021 }, { "type": "Image", "props": { "y": 112, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1022 }, { "type": "Image", "props": { "y": 391, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1023 }, { "type": "Image", "props": { "y": 58, "x": 218, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1024 }, { "type": "Box", "props": { "y": 409, "x": 175, "width": 269, "var": "btn_ad", "name": "btn_ad", "mouseEnabled": true, "height": 107 }, "compId": 1025, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "var": "img_ad1", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_ad1", "height": 109 }, "compId": 1026 }, { "type": "Image", "props": { "y": 23, "x": 92, "width": 153, "var": "img_free", "skin": "ui/img_UM_ui_text56.png", "name": "img_free", "height": 44 }, "compId": 1027 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 46 }, "compId": 1028 }] }, { "type": "Box", "props": { "y": 96, "x": -282, "var": "img_no", "name": "img_no" }, "compId": 1029, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1030 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1031 }] }, { "type": "Image", "props": { "y": 151, "x": 218, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1032 }, { "type": "Image", "props": { "y": 217, "x": 239, "width": 137, "var": "img_ico2", "skin": "ui/img_UM_box_gold.png", "name": "img_ico2", "height": 137 }, "compId": 1033 }, { "type": "Image", "props": { "y": 167, "x": 333, "width": 36, "var": "img_ico", "skin": "ui/img_UM_gold.png", "name": "img_ico", "height": 36 }, "compId": 1034 }, { "type": "Label", "props": { "y": 161, "x": 229, "wordWrap": false, "width": 96, "var": "txt_num", "valign": "middle", "text": "1000", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 48, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1037 }] }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_ui_text55.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png"], "loadList3D": [] };
            page.PageReward5UI = PageReward5UI;
            REG("ui.page.PageReward5UI", PageReward5UI);
            class PageReward6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageReward6UI.uiView);
                }
            }
            PageReward6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -16, "x": 332, "width": 617, "var": "box_scale", "name": "box_scale", "height": 551 }, "compId": 1020, "child": [{ "type": "Image", "props": { "y": 47, "x": -9, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1021 }, { "type": "Image", "props": { "y": 112, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1022 }, { "type": "Image", "props": { "y": 391, "x": 4, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1023 }, { "type": "Image", "props": { "y": 58, "x": 218, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1024 }, { "type": "Box", "props": { "y": 409, "x": 175, "width": 269, "var": "btn_ad", "name": "btn_ad", "mouseEnabled": true, "height": 107 }, "compId": 1025, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "var": "img_ad1", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "name": "img_ad1", "height": 109 }, "compId": 1026 }, { "type": "Image", "props": { "y": 23, "x": 92, "width": 153, "var": "img_free", "skin": "ui/img_UM_ui_text56.png", "name": "img_free", "height": 44 }, "compId": 1027 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 46 }, "compId": 1028 }] }, { "type": "Box", "props": { "y": 96, "x": -282, "var": "img_no", "name": "img_no" }, "compId": 1029, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1030 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1031 }] }, { "type": "Image", "props": { "y": 151, "x": 218, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1032 }, { "type": "Image", "props": { "y": 217, "x": 239, "width": 137, "var": "img_ico2", "skin": "ui/img_UM_box_gold.png", "name": "img_ico2", "height": 137 }, "compId": 1033 }, { "type": "Image", "props": { "y": 167, "x": 333, "width": 36, "var": "img_ico", "skin": "ui/img_UM_gold.png", "name": "img_ico", "height": 36 }, "compId": 1034 }, { "type": "Label", "props": { "y": 161, "x": 229, "wordWrap": false, "width": 96, "var": "txt_num", "valign": "middle", "text": "1000", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 48, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1037 }, { "type": "Label", "props": { "y": 556, "x": 170, "width": 277, "underline": false, "text": "是否看视频双倍领取", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 1038 }] }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_ui_text55.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png"], "loadList3D": [] };
            page.PageReward6UI = PageReward6UI;
            REG("ui.page.PageReward6UI", PageReward6UI);
            class PageShareUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageShareUI.uiView);
                }
            }
            PageShareUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -23, "width": 1236, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 650, "centerX": 0 }, "compId": 1022, "child": [{ "type": "Image", "props": { "y": 84, "x": 98, "width": 1049, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "83,65,83,53", "height": 532 }, "compId": 997 }, { "type": "Image", "props": { "skin": "ui/img_uk_ui2_obj19.png" }, "compId": 1004 }, { "type": "Image", "props": { "y": 115, "x": 607, "skin": "ui/img_uk_text_zqwz.png" }, "compId": 998 }, { "type": "Image", "props": { "y": 301, "x": 580, "width": 500, "skin": "ui/img_uk_ui2_obj13.png", "height": 155 }, "compId": 1010 }, { "type": "Image", "props": { "y": 288, "x": 649, "width": 142, "skin": "ui/img_uk_icon_zs2.png", "height": 142 }, "compId": 1011 }, { "type": "Image", "props": { "y": 287, "x": 850, "width": 146, "skin": "ui/img_uk_icon_gold3.png", "height": 146 }, "compId": 1012 }, { "type": "Label", "props": { "y": 398, "x": 684, "wordWrap": true, "width": 72, "valign": "middle", "text": "200", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1013 }, { "type": "Label", "props": { "y": 398, "x": 887, "wordWrap": true, "width": 72, "valign": "middle", "text": "2000", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1014 }, { "type": "Image", "props": { "y": 399, "x": 753, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 1015 }, { "type": "Image", "props": { "y": 400, "x": 961, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 1016 }, { "type": "Image", "props": { "y": 107, "x": 25, "skin": "ui/img_uk_img_body2.png" }, "compId": 1019 }, { "type": "Image", "props": { "y": 217, "x": 601, "width": 501, "skin": "ui/img_uk_text_fxtext.png", "height": 85 }, "compId": 1020 }, { "type": "Box", "props": { "y": 459, "x": 676, "var": "btn_ok", "name": "btn_ok" }, "compId": 1021, "child": [{ "type": "Image", "props": { "width": 308, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "58,52,59,43", "height": 132 }, "compId": 1000 }, { "type": "Label", "props": { "y": 28, "x": 32, "wordWrap": true, "width": 253, "valign": "middle", "text": "挑战全网", "strokeColor": "#01344c", "stroke": 6, "height": 76, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1017 }] }] }, { "type": "Box", "props": { "y": 79, "x": 1106, "width": 94, "var": "btn_close", "name": "btn_close", "height": 122 }, "compId": 1005, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 1006 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 1007 }, { "type": "Label", "props": { "y": 66, "x": 7, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1008 }] }], "loadList": ["ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_text_zqwz.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_icon_zs2.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_img_body2.png", "ui/img_uk_text_fxtext.png", "ui/img_uk_ui2_obj17.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            page.PageShareUI = PageShareUI;
            REG("ui.page.PageShareUI", PageShareUI);
            class PageStarGameUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageStarGameUI.uiView);
                }
            }
            PageStarGameUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 385, "mouseThrough": true, "height": 116 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 45, "x": 191, "width": 458, "skin": "ui/img_UM_game_star.png", "scaleY": 0.9, "scaleX": 0.9, "pivotY": 89, "pivotX": 229, "mouseEnabled": true, "height": 178 }, "compId": 1147 }], "animations": [{ "nodes": [{ "target": 1147, "keyframes": { "y": [{ "value": 45, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "y", "index": 0 }], "x": [{ "value": 192, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "x", "index": 0 }], "scaleY": [{ "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 2 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 4 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 8 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 10 }, { "value": 0.93, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 12 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 14 }, { "value": 0.91, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 16 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 18 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "label": null, "key": "scaleY", "index": 40 }], "scaleX": [{ "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 2 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 4 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 6 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 8 }, { "value": 0.93, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 10 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 12 }, { "value": 0.91, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 14 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 16 }] } }, { "target": 2, "keyframes": { "width": [{ "value": 385, "tweenMethod": "linearNone", "tween": true, "target": 2, "key": "width", "index": 0 }], "height": [{ "value": 117, "tweenMethod": "linearNone", "tween": true, "target": 2, "key": "height", "index": 0 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_game_star.png"], "loadList3D": [] };
            page.PageStarGameUI = PageStarGameUI;
            REG("ui.page.PageStarGameUI", PageStarGameUI);
        })(page = ui.page || (ui.page = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var platform;
        (function (platform) {
            class PlatformAddIcoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformAddIcoUI.uiView);
                }
            }
            PlatformAddIcoUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 79, "x": 800, "var": "btn_ico", "name": "btn_ico" }, "compId": 84, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 88 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text82.png", "height": 30 }, "compId": 89 }, { "type": "Image", "props": { "y": 23, "x": 11, "width": 78, "skin": "ui/img_UM_img_desktop.png", "height": 78 }, "compId": 90 }] }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text82.png", "ui/img_UM_img_desktop.png"], "loadList3D": [] };
            platform.PlatformAddIcoUI = PlatformAddIcoUI;
            REG("ui.platform.PlatformAddIcoUI", PlatformAddIcoUI);
            class PlatformAddIcoAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformAddIcoAnimUI.uiView);
                }
            }
            PlatformAddIcoAnimUI.uiView = { "type": "View", "props": { "width": 150, "positionVariance_0": 100, "maxPartices": 100, "height": 300 }, "compId": 1, "child": [{ "type": "Image", "props": { "y": 10, "x": 26, "skin": "ui/img_ui_obj25.png" }, "compId": 76 }, { "type": "Label", "props": { "y": 113, "x": 13, "text": "桌面图标", "strokeColor": "#a63c3a", "stroke": 4, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true }, "compId": 77 }, { "type": "Image", "props": { "y": 205, "x": 75, "width": 110, "skin": "ui/img_icon_hand.png", "pivotY": 59, "pivotX": 55, "height": 118 }, "compId": 78 }], "animations": [{ "nodes": [{ "target": 78, "keyframes": { "y": [{ "value": 205, "tweenMethod": "linearIn", "tween": true, "target": 78, "key": "y", "index": 0 }, { "value": 240, "tweenMethod": "backOut", "tween": true, "target": 78, "key": "y", "index": 10 }, { "value": 205, "tweenMethod": "linearNone", "tween": true, "target": 78, "label": null, "key": "y", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_ui_obj25.png", "ui/img_icon_hand.png"], "loadList3D": [] };
            platform.PlatformAddIcoAnimUI = PlatformAddIcoAnimUI;
            REG("ui.platform.PlatformAddIcoAnimUI", PlatformAddIcoAnimUI);
            class PlatformAdditionUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformAdditionUI.uiView);
                }
            }
            PlatformAdditionUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -17, "width": 1247, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 650, "centerX": 0 }, "compId": 1019, "child": [{ "type": "Image", "props": { "y": 84, "x": 98, "width": 1049, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "83,65,83,53", "height": 532 }, "compId": 997 }, { "type": "Image", "props": { "y": 0, "x": 783, "width": 511, "skin": "ui/img_uk_text_zm.png", "pivotY": -230, "pivotX": 218, "height": 58 }, "compId": 1020 }, { "type": "Image", "props": { "skin": "ui/img_uk_ui2_obj19.png" }, "compId": 1004 }, { "type": "Image", "props": { "y": 115, "x": 607, "skin": "ui/img_uk_text_tjyl.png" }, "compId": 998 }, { "type": "Image", "props": { "y": 27, "x": 69, "skin": "ui/img_uk_img_body.png" }, "compId": 1002 }, { "type": "Image", "props": { "y": 301, "x": 580, "width": 500, "skin": "ui/img_uk_ui2_obj13.png", "height": 155 }, "compId": 1010 }, { "type": "Image", "props": { "y": 288, "x": 649, "width": 142, "skin": "ui/img_uk_icon_zs2.png", "height": 142 }, "compId": 1011 }, { "type": "Image", "props": { "y": 287, "x": 850, "width": 146, "skin": "ui/img_uk_icon_gold3.png", "height": 146 }, "compId": 1012 }, { "type": "Label", "props": { "y": 398, "x": 684, "wordWrap": true, "width": 72, "valign": "middle", "text": "200", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1013 }, { "type": "Label", "props": { "y": 398, "x": 874, "wordWrap": true, "width": 89, "valign": "middle", "text": "2000", "strokeColor": "#01344c", "stroke": 5, "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1014 }, { "type": "Image", "props": { "y": 399, "x": 753, "width": 30, "skin": "ui/img_uk_Icon_zs.png", "height": 30 }, "compId": 1015 }, { "type": "Image", "props": { "y": 400, "x": 961, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 1016 }, { "type": "Box", "props": { "y": 459, "x": 676, "var": "btn_ok", "name": "btn_ok" }, "compId": 1018, "child": [{ "type": "Image", "props": { "width": 308, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "58,52,59,43", "height": 132 }, "compId": 1000 }, { "type": "Label", "props": { "y": 28, "x": 32, "wordWrap": true, "width": 253, "var": "txt_title", "valign": "middle", "text": "添加到桌面", "strokeColor": "#01344c", "stroke": 6, "name": "txt_title", "height": 76, "fontSize": 48, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1017 }] }] }, { "type": "Box", "props": { "y": 79, "x": 1106, "width": 94, "var": "btn_close", "name": "btn_close", "height": 122 }, "compId": 1005, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 1006 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 1007 }, { "type": "Label", "props": { "y": 66, "x": 7, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1008 }] }], "loadList": ["ui/img_uk_ui2_obj5.png", "ui/img_uk_text_zm.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_text_tjyl.png", "ui/img_uk_img_body.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_icon_zs2.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_ui2_obj17.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            platform.PlatformAdditionUI = PlatformAdditionUI;
            REG("ui.platform.PlatformAdditionUI", PlatformAdditionUI);
            class PlatformAddMIniUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformAddMIniUI.uiView);
                }
            }
            PlatformAddMIniUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 162, "width": 955, "skin": "ui/img_uk_text_tj2.png", "height": 102 }, "compId": 1018 }, { "type": "Box", "props": { "y": 46, "x": 36, "width": 94, "var": "btn_close", "name": "btn_close", "height": 122 }, "compId": 1020, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 1021 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 1022 }, { "type": "Label", "props": { "y": 66, "x": 7, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1023 }] }, { "type": "Box", "props": { "y": 172, "x": 119 }, "compId": 1044, "child": [{ "type": "Image", "props": { "width": 334, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "67,69,81,59", "height": 481 }, "compId": 1019, "child": [{ "type": "Image", "props": { "y": -27, "x": -60, "width": 454, "skin": "ui/img_uk_ui2_obj19.png", "height": 454 }, "compId": 1024 }, { "type": "Image", "props": { "y": 119, "x": 37, "width": 260, "skin": "ui/img_uk_weixin_img1.png", "height": 177 }, "compId": 1025 }, { "type": "Label", "props": { "y": 2, "x": 40, "wordWrap": true, "width": 253, "valign": "middle", "text": "步骤1", "strokeColor": "#003149", "stroke": 4, "height": 76, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1038 }, { "type": "Label", "props": { "y": 357, "x": 52, "wordWrap": true, "width": 98, "valign": "middle", "text": "点击", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1041 }, { "type": "Image", "props": { "y": 364, "x": 135, "width": 63, "skin": "ui/img_uk_weixin_img3.png", "height": 32 }, "compId": 1042 }, { "type": "Label", "props": { "y": 357, "x": 185, "wordWrap": true, "width": 98, "valign": "middle", "text": "选择", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1045 }, { "type": "Label", "props": { "y": 401, "x": -7, "wordWrap": true, "width": 348, "valign": "middle", "text": "【添加到我的小程序】", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1046 }] }] }, { "type": "Box", "props": { "y": 171, "x": 487 }, "compId": 1047, "child": [{ "type": "Image", "props": { "width": 334, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "67,69,81,59", "height": 481 }, "compId": 1048, "child": [{ "type": "Image", "props": { "y": -27, "x": -60, "width": 454, "skin": "ui/img_uk_ui2_obj19.png", "height": 454 }, "compId": 1049 }, { "type": "Label", "props": { "y": 2, "x": 40, "wordWrap": true, "width": 253, "valign": "middle", "text": "步骤2", "strokeColor": "#003149", "stroke": 4, "height": 76, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1051 }, { "type": "Label", "props": { "y": 357, "x": 21, "wordWrap": true, "width": 98, "valign": "middle", "text": "从", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1052 }, { "type": "Image", "props": { "y": 66, "x": 55, "width": 223, "skin": "ui/img_uk_weixin_img2.png", "height": 282 }, "compId": 1056 }, { "type": "Label", "props": { "y": 355, "x": 70, "wordWrap": true, "width": 220, "valign": "middle", "text": "【我的小程序】", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1057 }, { "type": "Label", "props": { "y": 404, "x": 10, "wordWrap": true, "width": 313, "valign": "middle", "text": "中启动玩具兵大作战", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1058 }] }] }, { "type": "Box", "props": { "y": 170, "x": 854 }, "compId": 1059, "child": [{ "type": "Image", "props": { "y": 3, "x": 0, "width": 334, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "67,69,81,59", "height": 481 }, "compId": 1060, "child": [{ "type": "Image", "props": { "y": -27, "x": -60, "width": 454, "skin": "ui/img_uk_ui2_obj19.png", "height": 454 }, "compId": 1061 }, { "type": "Label", "props": { "y": 2, "x": 40, "wordWrap": true, "width": 253, "valign": "middle", "text": "步骤2", "strokeColor": "#003149", "stroke": 4, "height": 76, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1062 }, { "type": "Label", "props": { "y": 357, "x": 19, "wordWrap": true, "width": 296, "valign": "middle", "text": "进入游戏后获取", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1063 }, { "type": "Label", "props": { "y": 401, "x": 57, "wordWrap": true, "width": 220, "valign": "middle", "text": "【大礼包】", "strokeColor": "#000000", "stroke": 4, "height": 46, "fontSize": 30, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1065 }, { "type": "Box", "props": { "y": 93, "x": 5, "width": 324, "height": 224 }, "compId": 1068, "child": [{ "type": "Image", "props": { "y": 0, "x": 38.5, "width": 248, "skin": "ui/img_uk_StoreMainDiamonds.png", "height": 214 }, "compId": 1069 }, { "type": "Image", "props": { "y": 26, "x": 0, "width": 226, "skin": "ui/img_uk_icon_gold3.png", "height": 226 }, "compId": 1070 }, { "type": "Image", "props": { "y": 59, "x": 99, "width": 225, "skin": "ui/img_uk_icon_zs3.png", "height": 225 }, "compId": 1071 }] }] }] }], "loadList": ["ui/img_uk_text_tj2.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_weixin_img1.png", "ui/img_uk_weixin_img3.png", "ui/img_uk_weixin_img2.png", "ui/img_uk_StoreMainDiamonds.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_icon_zs3.png"], "loadList3D": [] };
            platform.PlatformAddMIniUI = PlatformAddMIniUI;
            REG("ui.platform.PlatformAddMIniUI", PlatformAddMIniUI);
            class PlatformClauseUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformClauseUI.uiView);
                }
            }
            PlatformClauseUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Panel", "props": { "y": 55, "x": 40, "width": 1200, "vScrollBarSkin": "comp/vscroll.png", "height": 558 }, "compId": 47, "child": [{ "type": "Label", "props": { "wordWrap": true, "width": 1200, "var": "txt_content", "overflow": "visible", "name": "txt_content", "mouseThrough": false, "mouseEnabled": true, "height": 1500, "fontSize": 20, "editable": false, "color": "#ffffff" }, "compId": 40 }] }, { "type": "Button", "props": { "y": 636, "x": 575, "width": 133, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "20,19,22,15", "name": "btn_ok", "labelStrokeColor": "#f9f3f3", "labelSize": 35, "labelFont": "SimHei", "labelColors": "#f9f3f3", "label": "同意", "height": 67 }, "compId": 45 }], "loadList": ["comp/vscroll.png", "ui/img_UM_rank_jlbg3.png"], "loadList3D": [] };
            platform.PlatformClauseUI = PlatformClauseUI;
            REG("ui.platform.PlatformClauseUI", PlatformClauseUI);
            class PlatformFollowUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollowUI.uiView);
                }
            }
            PlatformFollowUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 70, "width": 1236, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 650, "centerX": 86 }, "compId": 1022, "child": [{ "type": "Image", "props": { "y": 84, "x": 132, "width": 820, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "83,65,83,53", "height": 386 }, "compId": 997 }, { "type": "Image", "props": { "y": 23, "x": 557, "width": 444, "skin": "ui/img_uk_ui2_obj19.png", "height": 454 }, "compId": 1004 }, { "type": "Image", "props": { "y": 252, "x": 179, "width": 456, "skin": "ui/img_uk_ui2_obj13.png", "height": 168 }, "compId": 1010 }] }, { "type": "Box", "props": { "y": 123, "x": 197, "width": 94, "var": "btn_close", "name": "btn_close", "height": 122 }, "compId": 1005, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 1006 }, { "type": "Image", "props": { "y": 12, "x": 46, "width": 550, "skin": "ui/img_uk_ui2_goldguneffect.png", "height": 200, "alpha": 0.9 }, "compId": 1053 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 1007 }, { "type": "Label", "props": { "y": 66, "x": 7, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1008 }] }, { "type": "Label", "props": { "y": 484, "x": 336.5, "wordWrap": true, "width": 348, "valign": "middle", "text": "*关注抖音号领取游戏福利", "strokeColor": "#000000", "stroke": 0, "height": 46, "fontSize": 22, "font": "SimHei", "color": "#ffd34a", "bold": true, "align": "center" }, "compId": 1027 }, { "type": "Image", "props": { "y": 173, "x": 317, "skin": "ui/img_uk_text_gzyl.png" }, "compId": 1028 }, { "type": "Image", "props": { "y": 134, "x": 715, "width": 342, "skin": "ui/img_uk_ui2_uifengxiang.png", "height": 399 }, "compId": 1029 }, { "type": "Image", "props": { "y": 272, "x": 358, "width": 33, "skin": "ui/img_uk_ui_new_ui39.png", "height": 33 }, "compId": 1033 }, { "type": "Label", "props": { "y": 273, "x": 400, "wordWrap": true, "width": 310, "valign": "middle", "text": "关注即送永久防具套装", "strokeColor": "#6c6c6c", "stroke": 5, "height": 35, "fontSize": 25, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 1034 }, { "type": "Box", "props": { "y": 374, "x": 706, "var": "btn_ok", "name": "btn_ok" }, "compId": 1023, "child": [{ "type": "Image", "props": { "y": 30, "x": 73, "width": 243, "skin": "ui/img_uk_ui2_btn2.png", "height": 78 }, "compId": 1024 }, { "type": "LotteryObj4", "props": { "y": 25, "x": -11, "scaleY": 0.5, "scaleX": 2, "runtime": "ui.lottery.LotteryObj4UI" }, "compId": 1025 }, { "type": "Label", "props": { "y": 40, "x": 128, "wordWrap": true, "width": 139, "valign": "middle", "text": "关注领取", "strokeColor": "#0d7f36", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1026 }] }, { "type": "GoodsItem5", "props": { "y": 333, "x": 344, "var": "ui_goods", "name": "ui_goods", "runtime": "ui.goods.GoodsItem5UI" }, "compId": 1057 }, { "type": "GoodsItem5", "props": { "y": 331, "x": 540, "var": "ui_goods1", "name": "ui_goods1", "runtime": "ui.goods.GoodsItem5UI" }, "compId": 1055 }], "loadList": ["ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_goldguneffect.png", "ui/img_uk_ui2_back.png", "ui/img_uk_text_gzyl.png", "ui/img_uk_ui2_uifengxiang.png", "ui/img_uk_ui_new_ui39.png", "ui/img_uk_ui2_btn2.png"], "loadList3D": [] };
            platform.PlatformFollowUI = PlatformFollowUI;
            REG("ui.platform.PlatformFollowUI", PlatformFollowUI);
            class PlatformFollow1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollow1UI.uiView);
                }
            }
            PlatformFollow1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "positionVariance_0": 100, "maxPartices": 100, "height": 720, "centerX": 0 }, "compId": 1, "child": [{ "type": "Image", "props": { "y": 357, "x": 640, "width": 700, "skin": "ui/img_ui_ui_effect.png", "scaleY": 1, "scaleX": 1, "rotation": 360, "pivotY": 350, "pivotX": 350, "height": 700 }, "compId": 96 }, { "type": "Box", "props": { "y": 173, "x": 341 }, "compId": 97, "child": [{ "type": "Box", "props": { "y": 118, "x": 52 }, "compId": 98, "child": [{ "type": "Image", "props": { "width": 493, "skin": "ui/img_uj_ui_panel.png", "sizeGrid": "20,20,20,20", "height": 242 }, "compId": 99 }, { "type": "Button", "props": { "y": 181, "x": 151, "width": 173, "var": "btn_ok", "stateNum": 1, "skin": "ui/btn_uj_btn_gunlvup.png", "sizeGrid": "20,20,20,20", "name": "btn_ok", "height": 72 }, "compId": 100, "child": [{ "type": "Image", "props": { "y": 6, "x": 16, "skin": "ui/img_uj_text_follow2.png" }, "compId": 101 }] }, { "type": "Image", "props": { "y": 203, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 102 }, { "type": "Image", "props": { "y": 196, "x": 44, "width": 27, "skin": "ui/img_ug_star.png", "height": 28 }, "compId": 103 }, { "type": "Image", "props": { "y": 191, "x": 442, "width": 24, "skin": "ui/img_ug_star.png", "height": 24 }, "compId": 104 }, { "type": "Image", "props": { "y": 26, "x": 44, "width": 395, "skin": "ui/img_uj_ui_frame10.png", "sizeGrid": "30,30,30,30", "height": 150, "alpha": 0.2 }, "compId": 105 }, { "type": "Label", "props": { "y": 56, "x": 78, "wordWrap": true, "width": 357, "text": "关注官方“抖音”账号", "strokeColor": "#9c670a", "stroke": 4, "height": 60, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 106 }, { "type": "Label", "props": { "y": 116, "x": 136, "wordWrap": true, "width": 219, "text": "免费领专属皮肤", "strokeColor": "#9c670a", "stroke": 4, "height": 60, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 107 }, { "type": "Image", "props": { "y": 204.5, "x": 460, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 108 }, { "type": "Image", "props": { "y": 234, "x": 400, "width": 22, "skin": "ui/img_ug_star.png", "height": 24 }, "compId": 109 }] }, { "type": "Box", "props": {}, "compId": 110, "child": [{ "type": "Image", "props": { "y": 69, "x": 67, "width": 428, "skin": "ui/img_ug_ribbon1.png", "height": 89 }, "compId": 111 }, { "type": "Box", "props": { "pivotY": 0, "pivotX": 0 }, "compId": 112, "child": [{ "type": "Image", "props": { "y": 27, "x": 442, "width": 77, "skin": "ui/img_ug_star.png", "height": 79 }, "compId": 113 }, { "type": "Image", "props": { "y": 27, "x": 39, "width": 100, "skin": "ui/img_ug_star.png", "rotation": 7, "height": 100 }, "compId": 114 }, { "type": "Image", "props": { "y": 60, "x": 488, "width": 45, "skin": "ui/img_ug_star.png", "height": 46 }, "compId": 115 }, { "type": "Image", "props": { "y": 127, "x": 19, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 116 }, { "type": "Image", "props": { "y": 93, "x": 75, "width": 73, "skin": "ui/img_ug_star.png", "rotation": 20, "height": 75 }, "compId": 117 }, { "type": "Image", "props": { "y": 77, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 118 }, { "type": "Image", "props": { "x": 394, "width": 100, "skin": "ui/img_ug_star.png", "rotation": 23, "height": 100 }, "compId": 119 }, { "type": "Image", "props": { "x": 99, "width": 117, "skin": "ui/img_ug_star.png", "rotation": 13, "height": 113 }, "compId": 120 }, { "type": "Image", "props": { "y": 43, "x": 148, "width": 68, "skin": "ui/img_ug_star.png", "rotation": -30, "height": 67 }, "compId": 121 }, { "type": "Image", "props": { "y": 44, "x": 344, "width": 50, "skin": "ui/img_ug_star.png", "rotation": -11, "height": 49 }, "compId": 122 }, { "type": "Image", "props": { "y": 41, "x": 406, "width": 92, "skin": "ui/img_uj_ui_box.png", "rotation": 14, "height": 107 }, "compId": 123 }, { "type": "Image", "props": { "y": 68, "x": 66, "width": 99, "skin": "ui/img_uj_fun_7day.png", "rotation": -19, "height": 96 }, "compId": 124 }, { "type": "Image", "props": { "y": 56, "x": 127, "width": 315, "skin": "ui/img_uj_text_follow1.png", "height": 99 }, "compId": 125 }] }] }] }, { "type": "Button", "props": { "y": 303, "x": 815, "var": "btn_close", "stateNum": 1, "skin": "ui/btn_uj_btn_close.png", "name": "btn_close" }, "compId": 94 }], "loadList": ["ui/img_ui_ui_effect.png", "ui/img_uj_ui_panel.png", "ui/btn_uj_btn_gunlvup.png", "ui/img_uj_text_follow2.png", "ui/img_ug_star.png", "ui/img_uj_ui_frame10.png", "ui/img_ug_ribbon1.png", "ui/img_uj_ui_box.png", "ui/img_uj_fun_7day.png", "ui/img_uj_text_follow1.png", "ui/btn_uj_btn_close.png"], "loadList3D": [] };
            platform.PlatformFollow1UI = PlatformFollow1UI;
            REG("ui.platform.PlatformFollow1UI", PlatformFollow1UI);
            class PlatformFollowIcoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollowIcoUI.uiView);
                }
            }
            PlatformFollowIcoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "positionVariance_0": 100, "mouseEnabled": true, "maxPartices": 100, "height": 200 }, "compId": 1, "child": [{ "type": "PlatformFollowIcoItem", "props": { "y": 15, "x": 17, "var": "btn_follow", "name": "btn_follow", "mouseThrough": true, "runtime": "ui.platform.PlatformFollowIcoItemUI" }, "compId": 97 }], "loadList": [], "loadList3D": [] };
            platform.PlatformFollowIcoUI = PlatformFollowIcoUI;
            REG("ui.platform.PlatformFollowIcoUI", PlatformFollowIcoUI);
            class PlatformFollowIco1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollowIco1UI.uiView);
                }
            }
            PlatformFollowIco1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 120, "positionVariance_0": 100, "mouseEnabled": true, "maxPartices": 100, "height": 100 }, "compId": 1, "child": [{ "type": "PlatformFollowItem", "props": { "y": 0, "x": 0, "var": "btn_follow", "name": "btn_follow", "runtime": "ui.platform.PlatformFollowItemUI" }, "compId": 96 }], "loadList": [], "loadList3D": [] };
            platform.PlatformFollowIco1UI = PlatformFollowIco1UI;
            REG("ui.platform.PlatformFollowIco1UI", PlatformFollowIco1UI);
            class PlatformFollowIcoItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollowIcoItemUI.uiView);
                }
            }
            PlatformFollowIcoItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 180 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 15, "width": 149, "skin": "ui/img_uk_ui2_goldgun.png", "height": 105, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": -11, "x": 3, "width": 173, "skin": "ui/img_uk_ui2_goldguneffect.png", "height": 127, "blendMode": "lighter" }, "compId": 1015 }, { "type": "Image", "props": { "y": 9, "x": 15, "width": 106, "skin": "ui/img_uk_ui_new_ui33.png", "height": 24 }, "compId": 1016 }, { "type": "Image", "props": { "y": 16, "x": 41, "width": 99, "skin": "ui/img_uk_Icon_jia.png", "height": 99 }, "compId": 1027 }, { "type": "Image", "props": { "y": 81, "x": 109, "width": 52, "skin": "ui/img_uk_text_yj.png", "height": 25 }, "compId": 1018 }, { "type": "Image", "props": { "y": 7, "x": 12.5, "width": 99, "skin": "ui/img_uk_text_gzjl.png", "height": 28 }, "compId": 1029 }, { "type": "Image", "props": { "y": 111, "x": 16, "width": 149, "skin": "ui/img_uk_ui2_btn2.png", "height": 52 }, "compId": 1021 }, { "type": "Label", "props": { "y": 118, "x": 42, "wordWrap": true, "width": 98, "valign": "middle", "text": "关注抖音", "strokeColor": "#563d16", "stroke": 4, "height": 35, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 1023 }], "animations": [{ "nodes": [{ "target": 1015, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1015, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1015, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_goldgun.png", "ui/img_uk_ui2_goldguneffect.png", "ui/img_uk_ui_new_ui33.png", "ui/img_uk_Icon_jia.png", "ui/img_uk_text_yj.png", "ui/img_uk_text_gzjl.png", "ui/img_uk_ui2_btn2.png"], "loadList3D": [] };
            platform.PlatformFollowIcoItemUI = PlatformFollowIcoItemUI;
            REG("ui.platform.PlatformFollowIcoItemUI", PlatformFollowIcoItemUI);
            class PlatformFollowItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollowItemUI.uiView);
                }
            }
            PlatformFollowItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 120, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 10, "skin": "ui/img_uj_ui_frame4.png" }, "compId": 538 }, { "type": "Image", "props": { "y": 36, "x": 60, "width": 67, "skin": "ui/img_uj_fun_7day.png", "pivotY": 34, "pivotX": 34, "height": 67 }, "compId": 540 }, { "type": "Image", "props": { "y": 62, "x": 12, "skin": "ui/img_uj_gzyl.png" }, "compId": 547 }], "animations": [{ "nodes": [{ "target": 540, "keyframes": { "y": [{ "value": 36, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "y", "index": 0 }, { "value": 36, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "y", "index": 20 }, { "value": 36, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "y", "index": 22 }, { "value": 36, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "y", "index": 26 }, { "value": 36, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "y", "index": 28 }, { "value": 36, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "y", "index": 30 }, { "value": 36, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "y", "index": 50 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleY", "index": 20 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleY", "index": 22 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleY", "index": 24 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleY", "index": 26 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleY", "index": 28 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleY", "index": 30 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleY", "index": 50 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleX", "index": 20 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleX", "index": 22 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 540, "key": "scaleX", "index": 24 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleX", "index": 26 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleX", "index": 28 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleX", "index": 30 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 540, "label": null, "key": "scaleX", "index": 50 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uj_ui_frame4.png", "ui/img_uj_fun_7day.png", "ui/img_uj_gzyl.png"], "loadList3D": [] };
            platform.PlatformFollowItemUI = PlatformFollowItemUI;
            REG("ui.platform.PlatformFollowItemUI", PlatformFollowItemUI);
            class PlatformFollowRewardUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollowRewardUI.uiView);
                }
            }
            PlatformFollowRewardUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "positionVariance_0": 100, "maxPartices": 100, "height": 720, "centerX": 0 }, "compId": 1, "child": [{ "type": "Image", "props": { "y": 10, "x": 10, "top": 0, "skin": "ui/img_uk_ui2_uibg2.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 128 }, { "type": "Image", "props": { "y": 270, "x": -90, "var": "img_bg", "skin": "ui/img_uk_ui_new_ui38.png", "sizeGrid": "9,8,10,9", "right": -100, "pivotY": 0, "pivotX": 0, "name": "img_bg", "left": -100, "height": 200, "alpha": 0.6 }, "compId": 129 }, { "type": "Box", "props": { "y": 487, "x": 497, "var": "box_btn", "name": "box_btn", "centerX": 0 }, "compId": 130, "child": [{ "type": "Box", "props": { "x": 0, "var": "btn_ok", "name": "btn_ok" }, "compId": 133, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_btn_btn1.png", "sizeGrid": "16,18,16,16", "height": 91 }, "compId": 134 }, { "type": "Label", "props": { "y": 28, "x": 29, "wordWrap": true, "width": 227, "var": "btn_title", "valign": "middle", "text": "获取奖励", "strokeColor": "#000000", "stroke": 5, "name": "btn_title", "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 135 }] }] }, { "type": "Box", "props": { "y": 25, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 149, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 150 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 151 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 152 }] }, { "type": "Box", "props": { "y": 487, "x": 497, "var": "img_ok", "name": "img_ok" }, "compId": 158, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_btn_btn1.png", "sizeGrid": "16,18,16,16", "height": 91 }, "compId": 159 }, { "type": "Label", "props": { "y": 28, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "已领取", "strokeColor": "#000000", "stroke": 5, "name": "btn_title", "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 160 }] }, { "type": "Image", "props": { "y": 32, "x": 123, "width": 1034, "skin": "ui/img_uk_ui2_obj19.png", "height": 568, "alpha": 0.5 }, "compId": 169 }, { "type": "Image", "props": { "y": 177, "x": 325, "width": 688, "skin": "ui/img_uk_ui2_obj2.png", "sizeGrid": "0,50,0,55", "height": 93 }, "compId": 170 }, { "type": "Image", "props": { "y": 138, "x": 302, "width": 676, "skin": "ui/img_uk_ui2_obj3.png", "height": 125 }, "compId": 171 }, { "type": "Image", "props": { "y": 208, "x": 300, "width": 680, "skin": "ui/img_uk_ui_vseffect.png", "height": 93, "alpha": 0.8 }, "compId": 173 }, { "type": "Image", "props": { "y": 411, "x": 300, "width": 680, "skin": "ui/img_uk_ui_vseffect.png", "height": 93, "alpha": 0.8 }, "compId": 174 }, { "type": "GoodsItem5", "props": { "y": 285, "x": 461, "var": "ui_goods", "name": "ui_goods", "runtime": "ui.goods.GoodsItem5UI" }, "compId": 142 }, { "type": "GoodsItem5", "props": { "y": 286, "x": 649, "var": "ui_goods1", "name": "ui_goods1", "runtime": "ui.goods.GoodsItem5UI" }, "compId": 143 }, { "type": "Image", "props": { "y": 120, "x": 399, "skin": "ui/img_uk_text_gxhd2.png" }, "compId": 175 }], "loadList": ["ui/img_uk_ui2_uibg2.jpg", "ui/img_uk_ui_new_ui38.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_ui2_obj2.png", "ui/img_uk_ui2_obj3.png", "ui/img_uk_ui_vseffect.png", "ui/img_uk_text_gxhd2.png"], "loadList3D": [] };
            platform.PlatformFollowRewardUI = PlatformFollowRewardUI;
            REG("ui.platform.PlatformFollowRewardUI", PlatformFollowRewardUI);
            class PlatformFollowReward1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformFollowReward1UI.uiView);
                }
            }
            PlatformFollowReward1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "positionVariance_0": 100, "maxPartices": 100, "height": 720, "centerX": 0 }, "compId": 1, "child": [{ "type": "Image", "props": { "y": 360, "x": 640, "width": 700, "skin": "ui/img_ui_ui_effect.png", "scaleY": 1, "scaleX": 1, "rotation": 360, "pivotY": 350, "pivotX": 350, "height": 700 }, "compId": 97 }, { "type": "Box", "props": { "y": 274, "x": 394 }, "compId": 98, "child": [{ "type": "Image", "props": { "x": 39, "width": 411, "skin": "ui/img_uj_ui_panel.png", "sizeGrid": "20,20,20,20", "height": 242 }, "compId": 100 }, { "type": "Image", "props": { "y": 39, "x": 96, "width": 300, "skin": "ui/img_uj_ui_panel3.png", "sizeGrid": "20,20,20,20", "height": 133 }, "compId": 101 }, { "type": "Button", "props": { "y": 181, "x": 168, "width": 155, "var": "btn_ok", "stateNum": 1, "skin": "ui/btn_uj_btn_gunlvup.png", "sizeGrid": "20,20,20,20", "name": "btn_ok", "height": 72 }, "compId": 102, "child": [{ "type": "Image", "props": { "y": 6, "x": 37.5, "skin": "ui/img_uj_ui_text_lq.png" }, "compId": 103 }] }, { "type": "Image", "props": { "y": 196, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 106 }, { "type": "Image", "props": { "y": 228, "x": 39, "width": 27, "skin": "ui/img_ug_star.png", "height": 28 }, "compId": 107 }, { "type": "Image", "props": { "y": 169, "x": 432, "width": 24, "skin": "ui/img_ug_star.png", "height": 24 }, "compId": 108 }, { "type": "Image", "props": { "y": 217, "x": 413, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 109 }, { "type": "Image", "props": { "y": 238, "x": 385, "width": 22, "skin": "ui/img_ug_star.png", "height": 24 }, "compId": 110 }] }, { "type": "Box", "props": { "y": 173, "x": 353, "width": 596, "height": 195 }, "compId": 99, "child": [{ "type": "Image", "props": { "y": 40, "x": 86, "width": 428, "skin": "ui/img_ug_ribbon1.png", "height": 89 }, "compId": 111 }, { "type": "Box", "props": { "pivotY": 0, "pivotX": 0 }, "compId": 112, "child": [{ "type": "Image", "props": { "y": 27, "x": 442, "width": 77, "skin": "ui/img_ug_star.png", "height": 79 }, "compId": 113 }, { "type": "Image", "props": { "y": 27, "x": 39, "width": 100, "skin": "ui/img_ug_star.png", "rotation": 7, "height": 100 }, "compId": 114 }, { "type": "Image", "props": { "y": 60, "x": 488, "width": 45, "skin": "ui/img_ug_star.png", "height": 46 }, "compId": 115 }, { "type": "Image", "props": { "y": 127, "x": 19, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 116 }, { "type": "Image", "props": { "y": 93, "x": 75, "width": 73, "skin": "ui/img_ug_star.png", "rotation": 20, "height": 75 }, "compId": 117 }, { "type": "Image", "props": { "y": 61, "x": 496, "width": 100, "skin": "ui/img_ug_star.png", "rotation": 33, "height": 100 }, "compId": 118 }, { "type": "Image", "props": { "y": 155, "x": 519, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 119 }, { "type": "Image", "props": { "y": 77, "width": 39, "skin": "ui/img_ug_star.png", "height": 39 }, "compId": 120 }, { "type": "Image", "props": { "x": 394, "width": 100, "skin": "ui/img_ug_star.png", "rotation": 23, "height": 100 }, "compId": 121 }, { "type": "Image", "props": { "x": 99, "width": 117, "skin": "ui/img_ug_star.png", "rotation": 13, "height": 113 }, "compId": 122 }, { "type": "Image", "props": { "y": 43, "x": 148, "width": 68, "skin": "ui/img_ug_star.png", "rotation": -30, "height": 67 }, "compId": 123 }, { "type": "Image", "props": { "y": 44, "x": 344, "width": 50, "skin": "ui/img_ug_star.png", "rotation": -11, "height": 49 }, "compId": 124 }, { "type": "Image", "props": { "y": 41, "x": 406, "width": 92, "skin": "ui/img_uj_ui_box.png", "rotation": 14, "height": 107 }, "compId": 125 }, { "type": "Image", "props": { "y": 68, "x": 66, "width": 99, "skin": "ui/img_uj_fun_7day.png", "rotation": -19, "height": 96 }, "compId": 126 }] }, { "type": "Image", "props": { "y": 45, "x": 182, "width": 220, "skin": "ui/img_uj_text_follow3.png", "height": 87 }, "compId": 127 }] }, { "type": "Image", "props": { "y": 450.5, "x": 597.5, "width": 85, "var": "img_ok", "skin": "ui/img_uj_btn_Check.png", "name": "img_ok", "height": 63 }, "compId": 96 }, { "type": "Button", "props": { "y": 227, "x": 779, "var": "btn_close", "stateNum": 1, "skin": "ui/btn_uj_btn_close.png", "name": "btn_close" }, "compId": 94 }, { "type": "GoodsItem", "props": { "y": 287, "x": 555, "var": "ui_goods", "name": "ui_goods", "runtime": "ui.goods.GoodsItemUI" }, "compId": 85 }], "loadList": ["ui/img_ui_ui_effect.png", "ui/img_uj_ui_panel.png", "ui/img_uj_ui_panel3.png", "ui/btn_uj_btn_gunlvup.png", "ui/img_uj_ui_text_lq.png", "ui/img_ug_star.png", "ui/img_ug_ribbon1.png", "ui/img_uj_ui_box.png", "ui/img_uj_fun_7day.png", "ui/img_uj_text_follow3.png", "ui/img_uj_btn_Check.png", "ui/btn_uj_btn_close.png"], "loadList3D": [] };
            platform.PlatformFollowReward1UI = PlatformFollowReward1UI;
            REG("ui.platform.PlatformFollowReward1UI", PlatformFollowReward1UI);
            class platformIcoItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(platformIcoItemUI.uiView);
                }
            }
            platformIcoItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 59, "x": 65, "width": 73, "skin": "ui/img_uk_icon_fx2.png", "pivotY": 37, "pivotX": 37, "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 28, "wordWrap": true, "width": 74, "valign": "middle", "text": "更多精彩", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 16, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 56, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 59, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx2.png"], "loadList3D": [] };
            platform.platformIcoItemUI = platformIcoItemUI;
            REG("ui.platform.platformIcoItemUI", platformIcoItemUI);
            class PlatformNativeAdUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeAdUI.uiView);
                }
            }
            PlatformNativeAdUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 495, "x": 399, "mouseThrough": true }, "compId": 83, "child": [{ "type": "Image", "props": { "width": 378, "var": "img_ad", "skin": "comp/img_white.png", "name": "img_ad", "height": 190 }, "compId": 71, "child": [{ "type": "Label", "props": { "y": 13, "x": 324, "width": 29, "text": "广告", "stroke": 4, "height": 15, "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 78 }] }, { "type": "Image", "props": { "y": 23, "x": 28, "width": 27, "var": "img_close", "skin": "ui/img_ui_ui_close.png", "name": "img_close", "height": 27 }, "compId": 80 }] }, { "type": "Label", "props": { "y": 644, "x": 866, "width": 122, "var": "txt_ad", "underline": true, "text": "查看广告", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 82 }], "loadList": ["comp/img_white.png", "ui/img_ui_ui_close.png"], "loadList3D": [] };
            platform.PlatformNativeAdUI = PlatformNativeAdUI;
            REG("ui.platform.PlatformNativeAdUI", PlatformNativeAdUI);
            class PlatformNativeAd1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeAd1UI.uiView);
                }
            }
            PlatformNativeAd1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "height": 720, "centerX": 0 }, "compId": 1, "child": [{ "type": "Image", "props": { "y": 590, "x": 360, "width": 559, "var": "img_ad", "skin": "comp/img_white.png", "name": "img_ad", "height": 130 }, "compId": 71, "child": [{ "type": "Label", "props": { "y": 11, "x": 12, "text": "广告", "stroke": 4, "font": "SimHei", "color": "#ffffff" }, "compId": 78 }, { "type": "Image", "props": { "y": 3, "x": 529, "width": 26, "var": "img_close", "skin": "ui/img_ui_ui_close.png", "name": "img_close", "height": 26 }, "compId": 80 }] }], "loadList": ["comp/img_white.png", "ui/img_ui_ui_close.png"], "loadList3D": [] };
            platform.PlatformNativeAd1UI = PlatformNativeAd1UI;
            REG("ui.platform.PlatformNativeAd1UI", PlatformNativeAd1UI);
            class PlatformNativeAd2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeAd2UI.uiView);
                }
            }
            PlatformNativeAd2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "height": 720, "centerX": 0 }, "compId": 1, "child": [{ "type": "Image", "props": { "y": 148, "width": 550, "var": "img_ad", "skin": "comp/img_white.png", "right": 50, "name": "img_ad", "height": 440 }, "compId": 71, "child": [{ "type": "Label", "props": { "y": 11, "x": 12, "text": "广告", "stroke": 4, "font": "SimHei", "color": "#ffffff" }, "compId": 78 }, { "type": "Image", "props": { "y": 5, "x": 121, "width": 20, "var": "img_close", "skin": "ui/img_ui_ui_close.png", "right": 5, "name": "img_close", "height": 20 }, "compId": 80 }] }], "loadList": ["comp/img_white.png", "ui/img_ui_ui_close.png"], "loadList3D": [] };
            platform.PlatformNativeAd2UI = PlatformNativeAd2UI;
            REG("ui.platform.PlatformNativeAd2UI", PlatformNativeAd2UI);
            class PlatformNativeAd3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeAd3UI.uiView);
                }
            }
            PlatformNativeAd3UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 466, "x": 399, "mouseThrough": true }, "compId": 83, "child": [{ "type": "Image", "props": { "width": 378, "var": "img_ad", "skin": "comp/img_white.png", "name": "img_ad", "height": 190 }, "compId": 71, "child": [{ "type": "Label", "props": { "y": 13, "x": 324, "width": 29, "text": "广告", "stroke": 4, "height": 15, "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 78 }] }, { "type": "Image", "props": { "y": 19, "x": 34, "width": 27, "var": "img_close", "skin": "ui/img_ui_ui_close.png", "name": "img_close", "height": 27 }, "compId": 80 }] }, { "type": "Image", "props": { "y": 566, "x": 829, "width": 230, "var": "img_ad1", "skin": "ui/img_UM_btn_OrangeButton_2.png", "name": "img_ad1", "height": 96 }, "compId": 84, "child": [{ "type": "Label", "props": { "y": 30, "x": 54, "width": 122, "var": "txt_ad", "underline": false, "text": "查看广告", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#120201" }, "compId": 82 }] }], "loadList": ["comp/img_white.png", "ui/img_ui_ui_close.png", "ui/img_UM_btn_OrangeButton_2.png"], "loadList3D": [] };
            platform.PlatformNativeAd3UI = PlatformNativeAd3UI;
            REG("ui.platform.PlatformNativeAd3UI", PlatformNativeAd3UI);
            class PlatformNativeAd4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeAd4UI.uiView);
                }
            }
            PlatformNativeAd4UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 504, "x": 399, "mouseThrough": true }, "compId": 83, "child": [{ "type": "Image", "props": { "width": 378, "var": "img_ad", "skin": "comp/img_white.png", "name": "img_ad", "height": 190 }, "compId": 71, "child": [{ "type": "Label", "props": { "y": 13, "x": 324, "width": 29, "text": "广告", "stroke": 4, "height": 15, "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 78 }] }, { "type": "Image", "props": { "y": 17, "x": 33, "width": 27, "var": "img_close", "skin": "ui/img_ui_ui_close.png", "name": "img_close", "height": 27 }, "compId": 80 }] }, { "type": "Image", "props": { "y": 604, "x": 829, "width": 230, "var": "img_ad1", "skin": "ui/img_UM_btn_OrangeButton_2.png", "name": "img_ad1", "height": 96 }, "compId": 84, "child": [{ "type": "Label", "props": { "y": 30, "x": 54, "width": 122, "var": "txt_ad", "underline": false, "text": "查看广告", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#120201" }, "compId": 82 }] }], "loadList": ["comp/img_white.png", "ui/img_ui_ui_close.png", "ui/img_UM_btn_OrangeButton_2.png"], "loadList3D": [] };
            platform.PlatformNativeAd4UI = PlatformNativeAd4UI;
            REG("ui.platform.PlatformNativeAd4UI", PlatformNativeAd4UI);
            class PlatformNativeAd5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeAd5UI.uiView);
                }
            }
            PlatformNativeAd5UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Label", "props": { "y": 662, "wordWrap": false, "width": 171, "visible": true, "var": "txt_skip", "valign": "middle", "text": "继续游戏", "strokeColor": "#000000", "stroke": 3, "name": "txt_skip", "height": 34, "fontSize": 40, "font": "SimHei", "color": "#e9ead6", "centerX": 0, "bottom": 24, "bold": true, "align": "left" }, "compId": 85 }], "loadList": [], "loadList3D": [] };
            platform.PlatformNativeAd5UI = PlatformNativeAd5UI;
            REG("ui.platform.PlatformNativeAd5UI", PlatformNativeAd5UI);
            class PlatformNativeAdPageUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeAdPageUI.uiView);
                }
            }
            PlatformNativeAdPageUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 49, "x": 335, "var": "box_ad", "name": "box_ad" }, "compId": 78, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 619, "skin": "ui/img_UM_rank_jlbg2.png", "sizeGrid": "71,63,89,65", "height": 464 }, "compId": 66 }, { "type": "Label", "props": { "y": 5, "x": 6, "width": 607, "var": "txt_title", "underline": false, "text": "查看广告", "strokeColor": "#a63c3a", "padding": "20", "name": "txt_title", "leading": 80, "height": 142, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 68 }, { "type": "Label", "props": { "y": 362, "x": 8, "width": 602, "var": "txt_content", "text": "广告文本广告文本广告文本广告文本", "strokeColor": "#a63c3a", "name": "txt_content", "leading": 50, "height": 80, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 69 }, { "type": "Image", "props": { "y": 98, "x": 61, "width": 496, "var": "img_ad", "skin": "comp/img_white.png", "name": "img_ad", "height": 248 }, "compId": 71 }, { "type": "Label", "props": { "y": 113, "x": 496, "text": "广告", "stroke": 4, "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 75 }, { "type": "Box", "props": { "y": 458, "x": 201, "var": "btn_shop", "name": "btn_shop" }, "compId": 79, "child": [{ "type": "Image", "props": { "y": 6, "x": 0, "width": 220, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "16,21,29,19", "height": 85 }, "compId": 80 }, { "type": "Label", "props": { "y": 16, "x": 40, "wordWrap": true, "width": 139, "valign": "middle", "text": "点击跳过", "strokeColor": "#c5bdb0", "stroke": 2, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 81 }] }, { "type": "Box", "props": { "y": 458, "x": 199, "var": "btn_look", "name": "btn_look" }, "compId": 83, "child": [{ "type": "Image", "props": { "y": 6, "x": 0, "width": 220, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "16,21,29,19", "height": 85 }, "compId": 84 }, { "type": "Label", "props": { "y": 16, "x": 40, "wordWrap": true, "width": 139, "valign": "middle", "text": "点击查看", "strokeColor": "#c5bdb0", "stroke": 2, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 85 }] }, { "type": "Button", "props": { "y": 125, "x": 106, "width": 50, "var": "btn_close", "stateNum": 1, "skin": "ui/img_ug_close.png", "name": "btn_close", "height": 50 }, "compId": 67 }] }], "loadList": ["ui/img_UM_rank_jlbg2.png", "comp/img_white.png", "ui/img_UM_btn_green.png", "ui/img_ug_close.png"], "loadList3D": [] };
            platform.PlatformNativeAdPageUI = PlatformNativeAdPageUI;
            REG("ui.platform.PlatformNativeAdPageUI", PlatformNativeAdPageUI);
            class PlatformNativeIconUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeIconUI.uiView);
                }
            }
            PlatformNativeIconUI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 218, "width": 99, "var": "box_ad", "rotation": 0, "right": 1057, "pivotY": 51, "pivotX": 50, "name": "box_ad", "height": 101 }, "compId": 79, "child": [{ "type": "Image", "props": { "width": 100, "var": "img_ad", "skin": "comp/img_white.png", "name": "img_ad", "height": 100 }, "compId": 71 }, { "type": "Label", "props": { "y": 3, "x": 66, "width": 38, "text": "广告", "stroke": 4, "height": 22, "fontSize": 15, "font": "SimHei", "color": "#ffffff" }, "compId": 81 }, { "type": "Image", "props": { "y": 3, "x": 0, "width": 20, "var": "img_close", "skin": "ui/img_ui_ui_close.png", "name": "img_close", "height": 21 }, "compId": 82 }] }], "loadList": ["comp/img_white.png", "ui/img_ui_ui_close.png"], "loadList3D": [] };
            platform.PlatformNativeIconUI = PlatformNativeIconUI;
            REG("ui.platform.PlatformNativeIconUI", PlatformNativeIconUI);
            class PlatformNativeIcon1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeIcon1UI.uiView);
                }
            }
            PlatformNativeIcon1UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 397, "width": 477, "height": 92, "centerX": 0 }, "compId": 81, "child": [{ "type": "Image", "props": { "y": 45, "x": 417, "width": 85, "var": "img_ad", "skin": "comp/img_white.png", "rotation": 0, "name": "img_ad", "height": 85, "anchorY": 0.5, "anchorX": 0.5 }, "compId": 83 }] }], "animations": [{ "nodes": [{ "target": 83, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 83, "key": "rotation", "index": 0 }, { "value": -10, "tweenMethod": "linearNone", "tween": true, "target": 83, "key": "rotation", "index": 5 }, { "value": 10, "tweenMethod": "linearNone", "tween": true, "target": 83, "key": "rotation", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 83, "key": "rotation", "index": 25 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["comp/img_white.png"], "loadList3D": [] };
            platform.PlatformNativeIcon1UI = PlatformNativeIcon1UI;
            REG("ui.platform.PlatformNativeIcon1UI", PlatformNativeIcon1UI);
            class PlatformNativeIcon3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformNativeIcon3UI.uiView);
                }
            }
            PlatformNativeIcon3UI.uiView = { "type": "View", "props": { "width": 1280, "top": 0, "right": 0, "positionVariance_0": 100, "mouseThrough": true, "maxPartices": 100, "left": 0, "height": 720, "bottom": 0 }, "compId": 1, "child": [{ "type": "Box", "props": { "y": 339, "var": "box_ad", "rotation": 0, "name": "box_ad", "left": 180, "anchorY": 0.5, "anchorX": 0.5 }, "compId": 79, "child": [{ "type": "Image", "props": { "width": 85, "var": "img_ad", "skin": "comp/img_white.png", "name": "img_ad", "height": 85 }, "compId": 71 }, { "type": "Label", "props": { "y": 5, "x": 4, "text": "广告", "stroke": 4, "font": "SimHei", "color": "#ffffff" }, "compId": 80 }] }], "animations": [{ "nodes": [{ "target": 79, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 79, "key": "rotation", "index": 0 }, { "value": 10, "tweenMethod": "linearNone", "tween": true, "target": 79, "key": "rotation", "index": 5 }, { "value": -10, "tweenMethod": "linearNone", "tween": true, "target": 79, "key": "rotation", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 79, "key": "rotation", "index": 25 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["comp/img_white.png"], "loadList3D": [] };
            platform.PlatformNativeIcon3UI = PlatformNativeIcon3UI;
            REG("ui.platform.PlatformNativeIcon3UI", PlatformNativeIcon3UI);
            class PlatformOppoIcoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformOppoIcoUI.uiView);
                }
            }
            PlatformOppoIcoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "positionVariance_0": 100, "maxPartices": 100, "height": 100 }, "compId": 1, "child": [{ "type": "platformIcoItem", "props": { "y": -15, "x": -15, "var": "box_ico", "name": "box_ico", "runtime": "ui.platform.platformIcoItemUI" }, "compId": 114 }], "loadList": [], "loadList3D": [] };
            platform.PlatformOppoIcoUI = PlatformOppoIcoUI;
            REG("ui.platform.PlatformOppoIcoUI", PlatformOppoIcoUI);
            class PlatformPrivacyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformPrivacyUI.uiView);
                }
            }
            PlatformPrivacyUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 24, "centerX": 0 }, "compId": 38, "child": [{ "type": "Image", "props": { "y": 39, "x": 0, "width": 650, "skin": "ui/img_UM_rank_jlbg2.png", "sizeGrid": "30,30,30,30", "height": 480 }, "compId": 16 }, { "type": "Label", "props": { "y": 100, "x": 55, "width": 540, "var": "txt_content", "valign": "middle", "text": "我们保护您的隐私", "styleSkin": "comp/label.png", "name": "txt_content", "height": 83, "fontSize": 45, "font": "SimHei", "color": "#0d0d0d", "align": "center" }, "compId": 6 }, { "type": "Button", "props": { "y": 540, "x": 51, "width": 246, "var": "btn_no", "stateNum": 1, "skin": "ui/img_UM_rank_jlbg1.png", "sizeGrid": "20,20,20,20", "name": "btn_no", "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 25, "x": 69, "valign": "middle", "text": "不同意", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }, { "type": "Button", "props": { "y": 540, "x": 359, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "20,20,20,20", "name": "btn_ok", "height": 97 }, "compId": 31, "child": [{ "type": "Label", "props": { "y": 25, "x": 87, "valign": "middle", "text": "同意", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 32 }] }, { "type": "Label", "props": { "y": 225, "x": 55, "wordWrap": true, "width": 540, "valign": "middle", "text": "欢迎您使用本游戏,我们将严格遵守相关的法律法则和隐私政策以保护您的个人信息", "styleSkin": "comp/label.png", "name": "txt_content", "leading": 20, "height": 127, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 33 }, { "type": "Label", "props": { "y": 384, "x": 102, "width": 195, "text": "请您阅读并同意", "styleSkin": "comp/label.png", "name": "txt_content", "fontSize": 20, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 34 }, { "type": "Label", "props": { "y": 384, "x": 274, "width": 142, "var": "txt_read1", "text": "<<用户协议>>", "styleSkin": "comp/label.png", "name": "txt_read1", "fontSize": 20, "font": "SimHei", "color": "#37e8b0", "align": "center" }, "compId": 35 }, { "type": "Label", "props": { "y": 384, "x": 431, "width": 155, "var": "txt_read2", "text": "<<服务协议>>", "name": "txt_read2", "fontSize": 20, "font": "SimHei", "color": "#37e8b0", "align": "center" }, "compId": 36 }, { "type": "Label", "props": { "y": 384, "x": 421, "text": "和", "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 37 }] }], "loadList": ["ui/img_UM_rank_jlbg2.png", "comp/label.png", "ui/img_UM_rank_jlbg1.png", "ui/img_UM_rank_jlbg3.png"], "loadList3D": [] };
            platform.PlatformPrivacyUI = PlatformPrivacyUI;
            REG("ui.platform.PlatformPrivacyUI", PlatformPrivacyUI);
            class platformQqIcoItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(platformQqIcoItemUI.uiView);
                }
            }
            platformQqIcoItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 130, "mouseThrough": false, "height": 130 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 9, "width": 111, "skin": "ui/img_uk_icon_bg.png", "height": 111 }, "compId": 785 }, { "type": "Image", "props": { "y": 2, "x": 2, "width": 125, "skin": "ui/img_uk_ui2_obj19.png", "height": 125, "blendMode": "lighter" }, "compId": 786 }, { "type": "Image", "props": { "y": 21, "x": 28, "width": 73, "skin": "ui/img_uk_icon_fx3.png", "height": 73 }, "compId": 787 }, { "type": "Label", "props": { "y": 72, "x": 27, "wordWrap": true, "width": 74, "valign": "middle", "text": "添加桌面", "strokeColor": "#4f1904", "stroke": 4, "height": 35, "fontSize": 16, "font": "SimHei", "color": "#ffed90", "bold": false, "align": "center" }, "compId": 788 }], "animations": [{ "nodes": [{ "target": 786, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 786, "key": "alpha", "index": 15 }] } }, { "target": 787, "keyframes": { "y": [{ "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 0 }, { "value": 18, "tweenMethod": "linearNone", "tween": true, "target": 787, "key": "y", "index": 5 }, { "value": 21, "tweenMethod": "linearNone", "tween": true, "target": 787, "label": null, "key": "y", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_icon_bg.png", "ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_fx3.png"], "loadList3D": [] };
            platform.platformQqIcoItemUI = platformQqIcoItemUI;
            REG("ui.platform.platformQqIcoItemUI", platformQqIcoItemUI);
            class PlatformRecorderBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformRecorderBtnUI.uiView);
                }
            }
            PlatformRecorderBtnUI.uiView = { "type": "View", "props": { "zOrder": 30, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 145, "x": 184, "var": "btn_start", "name": "btn_start", "mouseEnabled": true }, "compId": 10, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 12 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text75.png", "height": 30 }, "compId": 13 }, { "type": "Image", "props": { "y": 23, "x": 11, "width": 78, "skin": "ui/img_UM_icon_lp.png", "height": 78 }, "compId": 14 }, { "type": "PageIco", "props": { "y": 21, "x": 76, "width": 30, "visible": true, "var": "img_tt", "name": "img_tt", "height": 30, "runtime": "ui.page.PageIcoUI" }, "compId": 7 }, { "type": "Label", "props": { "y": 133, "x": -27, "width": 146, "var": "txt_state", "text": " 已录屏：0秒", "strokeColor": "#a63c3a", "stroke": 4, "name": "txt_state", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 8 }] }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text75.png", "ui/img_UM_icon_lp.png"], "loadList3D": [] };
            platform.PlatformRecorderBtnUI = PlatformRecorderBtnUI;
            REG("ui.platform.PlatformRecorderBtnUI", PlatformRecorderBtnUI);
            class PlatformRecorderStateUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformRecorderStateUI.uiView);
                }
            }
            PlatformRecorderStateUI.uiView = { "type": "View", "props": { "zOrder": 30, "width": 1280, "mouseThrough": true, "mouseEnabled": false, "height": 720 }, "compId": 2, "child": [{ "type": "Label", "props": { "y": 169, "x": 63, "var": "txt_state", "text": "录屏中", "strokeColor": "#a63c3a", "stroke": 4, "name": "txt_state", "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true }, "compId": 4 }, { "type": "Image", "props": { "y": 64, "x": 59, "var": "btn_start", "skin": "ui/img_ui_obj16.png", "name": "btn_start" }, "compId": 3 }], "loadList": ["ui/img_ui_obj16.png"], "loadList3D": [] };
            platform.PlatformRecorderStateUI = PlatformRecorderStateUI;
            REG("ui.platform.PlatformRecorderStateUI", PlatformRecorderStateUI);
            class PlatformShareUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformShareUI.uiView);
                }
            }
            PlatformShareUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "positionVariance_0": 100, "maxPartices": 100, "height": 720, "centerX": 0 }, "compId": 1, "child": [{ "type": "Image", "props": { "y": -5, "skin": "ui/img_UM_ui_bg5.jpg", "right": -100, "left": -100 }, "compId": 130 }, { "type": "Box", "props": { "y": 48, "x": 58, "var": "box_close", "name": "box_close" }, "compId": 131, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 145 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 146 }] }, { "type": "Image", "props": { "y": 68, "x": 192, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 543 }, "compId": 132 }, { "type": "Image", "props": { "y": 121, "x": 209, "width": 881, "skin": "ui/img_UM_SponsorWall.png", "height": 471 }, "compId": 133 }, { "type": "Image", "props": { "y": 202, "x": 151, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1 }, "compId": 134 }, { "type": "Image", "props": { "y": 202, "x": 1153, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1, "scaleX": -1 }, "compId": 135 }, { "type": "Box", "props": { "y": 427, "x": 692, "var": "btn_share", "name": "btn_share" }, "compId": 136, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 147 }, { "type": "Image", "props": { "y": 26, "x": 53, "skin": "ui/img_UM_ui_text75.png" }, "compId": 148 }] }, { "type": "Image", "props": { "y": 482, "x": 149, "skin": "ui/img_UM_ui_7day_bianjiao.png" }, "compId": 137 }, { "type": "Image", "props": { "y": 482, "x": 1153, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleX": -1 }, "compId": 138 }, { "type": "Image", "props": { "y": 19, "x": 236, "skin": "ui/img_UM_ui_luping.png" }, "compId": 139 }, { "type": "Box", "props": { "y": 224, "x": 627 }, "compId": 140, "child": [{ "type": "Image", "props": { "width": 123, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 182 }, "compId": 149 }, { "type": "Image", "props": { "y": 34, "x": 5, "width": 113, "skin": "ui/img_UM_goodsCard1.png", "height": 141 }, "compId": 150 }, { "type": "Label", "props": { "y": 5, "x": 21, "wordWrap": true, "width": 81, "text": "金币", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 24, "font": "SimHei", "color": "#d7d7d7", "bold": true, "align": "center" }, "compId": 151 }, { "type": "Image", "props": { "y": 135, "x": 22, "width": 98, "skin": "ui/img_UM_num_2000.png", "height": 43 }, "compId": 152 }] }, { "type": "Image", "props": { "y": 3, "x": 39, "width": 702, "skin": "ui/img_UM_effect_zi.png", "height": 700 }, "compId": 141 }, { "type": "Box", "props": { "y": 226, "x": 755 }, "compId": 142, "child": [{ "type": "Image", "props": { "width": 123, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 182 }, "compId": 153 }, { "type": "Image", "props": { "y": 34, "x": 5, "width": 113, "skin": "ui/img_UM_goodsCard2.png", "height": 141 }, "compId": 154 }, { "type": "Label", "props": { "y": 5, "x": 21, "wordWrap": true, "width": 81, "text": "钻石", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 24, "font": "SimHei", "color": "#d7d7d7", "bold": true, "align": "center" }, "compId": 155 }, { "type": "Image", "props": { "y": 135, "x": 50, "width": 72, "skin": "ui/img_UM_num_100.png", "height": 41 }, "compId": 156 }] }, { "type": "Box", "props": { "y": 226, "x": 883 }, "compId": 143, "child": [{ "type": "Image", "props": { "width": 123, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 182 }, "compId": 157 }, { "type": "Image", "props": { "y": 34, "x": 5, "width": 113, "skin": "ui/img_UM_herohead_card.png", "height": 141 }, "compId": 158 }, { "type": "Label", "props": { "y": 5, "x": 21, "wordWrap": true, "width": 81, "text": "丹", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 24, "font": "SimHei", "color": "#d7d7d7", "bold": true, "align": "center" }, "compId": 159 }, { "type": "Image", "props": { "y": 135, "x": 70, "width": 47, "skin": "ui/img_UM_num_40.png", "height": 40 }, "compId": 160 }] }, { "type": "Image", "props": { "y": -46, "x": 164, "skin": "ui/img_UM_ui_lupingimg2.png" }, "compId": 144 }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk.png", "ui/img_UM_SponsorWall.png", "ui/img_UM_ui_7day_bianjiao.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text75.png", "ui/img_UM_ui_luping.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_goodsCard1.png", "ui/img_UM_num_2000.png", "ui/img_UM_effect_zi.png", "ui/img_UM_goodsCard2.png", "ui/img_UM_num_100.png", "ui/img_UM_herohead_card.png", "ui/img_UM_num_40.png", "ui/img_UM_ui_lupingimg2.png"], "loadList3D": [] };
            platform.PlatformShareUI = PlatformShareUI;
            REG("ui.platform.PlatformShareUI", PlatformShareUI);
            class PlatformVivoIcoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlatformVivoIcoUI.uiView);
                }
            }
            PlatformVivoIcoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "positionVariance_0": 100, "maxPartices": 100, "height": 100 }, "compId": 1, "child": [{ "type": "platformIcoItem", "props": { "y": -15, "x": -15, "var": "box_ico", "name": "box_ico", "runtime": "ui.platform.platformIcoItemUI" }, "compId": 114 }], "loadList": [], "loadList3D": [] };
            platform.PlatformVivoIcoUI = PlatformVivoIcoUI;
            REG("ui.platform.PlatformVivoIcoUI", PlatformVivoIcoUI);
            class VivoContentUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(VivoContentUI.uiView);
                }
            }
            VivoContentUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1280, "skin": "comp/img_white.png", "height": 720 }, "compId": 41 }, { "type": "Panel", "props": { "y": 5, "x": 40, "width": 1200, "vScrollBarSkin": "comp/vscroll.png", "height": 608 }, "compId": 47, "child": [{ "type": "Label", "props": { "wordWrap": true, "width": 1200, "var": "txt_content", "overflow": "visible", "name": "txt_content", "mouseThrough": false, "mouseEnabled": true, "height": 1500, "fontSize": 20, "editable": false, "color": "#030303" }, "compId": 40 }] }, { "type": "Button", "props": { "y": 642, "x": 575, "width": 130, "var": "btn_ok", "stateNum": 1, "skin": "ui/btn_uj_btn_gunlvup5.png", "sizeGrid": "20,19,22,15", "name": "btn_ok", "labelStrokeColor": "#f9f3f3", "labelSize": 35, "labelColors": "#f9f3f3", "label": "同意", "height": 72 }, "compId": 45 }], "loadList": ["comp/img_white.png", "comp/vscroll.png", "ui/btn_uj_btn_gunlvup5.png"], "loadList3D": [] };
            platform.VivoContentUI = VivoContentUI;
            REG("ui.platform.VivoContentUI", VivoContentUI);
            class VivoPrivacyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(VivoPrivacyUI.uiView);
                }
            }
            VivoPrivacyUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 24, "centerX": 0 }, "compId": 38, "child": [{ "type": "Image", "props": { "width": 650, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "30,30,30,30", "height": 480 }, "compId": 16 }, { "type": "Label", "props": { "y": 80, "x": 55, "width": 540, "var": "txt_content", "valign": "middle", "text": "我们保护您的隐私", "styleSkin": "comp/label.png", "name": "txt_content", "height": 83, "fontSize": 45, "font": "SimHei", "color": "#0d0d0d", "align": "center" }, "compId": 6 }, { "type": "Button", "props": { "y": 501, "x": 51, "width": 246, "var": "btn_no", "stateNum": 1, "skin": "ui/img_uk_ui2_btn1.png", "sizeGrid": "20,20,20,20", "name": "btn_no", "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 25, "x": 69, "valign": "middle", "text": "不同意", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }, { "type": "Button", "props": { "y": 501, "x": 359, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/img_uk_ui2_btn1.png", "sizeGrid": "20,20,20,20", "name": "btn_ok", "height": 97 }, "compId": 31, "child": [{ "type": "Label", "props": { "y": 25, "x": 87, "valign": "middle", "text": "同意", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 32 }] }, { "type": "Label", "props": { "y": 186, "x": 55, "wordWrap": true, "width": 540, "valign": "middle", "text": "欢迎您使用本游戏,我们将严格遵守相关的法律法则和隐私政策以保护您的个人信息", "styleSkin": "comp/label.png", "name": "txt_content", "leading": 20, "height": 127, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 33 }, { "type": "Label", "props": { "y": 341, "x": 102, "wordWrap": true, "width": 195, "valign": "middle", "text": "请您阅读并同意", "styleSkin": "comp/label.png", "name": "txt_content", "leading": 20, "height": 24, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 34 }, { "type": "Label", "props": { "y": 342, "x": 274, "wordWrap": true, "width": 156, "var": "txt_read1", "valign": "middle", "text": "<<用户协议>>", "styleSkin": "comp/label.png", "name": "txt_read1", "leading": 20, "height": 27, "fontSize": 20, "font": "SimHei", "color": "#37e8b0", "align": "center" }, "compId": 35 }, { "type": "Label", "props": { "y": 343, "x": 431, "width": 155, "var": "txt_read2", "text": "<<服务协议>>", "name": "txt_read2", "height": 20, "fontSize": 20, "font": "SimHei", "color": "#37e8b0", "align": "center" }, "compId": 36 }, { "type": "Label", "props": { "y": 343, "x": 421, "text": "和", "fontSize": 20, "font": "SimHei", "color": "#ffffff" }, "compId": 37 }] }], "loadList": ["ui/img_uk_ui2_obj5.png", "comp/label.png", "ui/img_uk_ui2_btn1.png"], "loadList3D": [] };
            platform.VivoPrivacyUI = VivoPrivacyUI;
            REG("ui.platform.VivoPrivacyUI", VivoPrivacyUI);
            class WxminiInfoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(WxminiInfoUI.uiView);
                }
            }
            WxminiInfoUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720, "centerY": 0, "centerX": 0, "cacheAs": "none" }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 131, "x": 315, "width": 650, "skin": "ui/img_uj_ui_panel.png", "sizeGrid": "30,30,30,30", "height": 324 }, "compId": 16 }, { "type": "Label", "props": { "y": 204, "x": 370, "width": 540, "var": "txt_content", "valign": "middle", "text": "是否授权使用您的用户名和头像?", "styleSkin": "comp/label.png", "name": "txt_content", "height": 177, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 6 }, { "type": "Button", "props": { "y": 491, "x": 517, "width": 246, "var": "btn_ok", "stateNum": 1, "skin": "ui/btn_uj_btn_gunlvup3.png", "sizeGrid": "20,20,20,20", "name": "btn_ok", "height": 97 }, "compId": 27, "child": [{ "type": "Label", "props": { "y": 25, "x": 87, "valign": "middle", "text": "确定", "strokeColor": "#000000", "height": 40, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 28 }] }, { "type": "Button", "props": { "y": 140, "x": 895, "var": "btn_close", "stateNum": 1, "skin": "ui/btn_uj_btn_close.png", "name": "btn_close" }, "compId": 30 }], "loadList": ["ui/img_uj_ui_panel.png", "comp/label.png", "ui/btn_uj_btn_gunlvup3.png", "ui/btn_uj_btn_close.png"], "loadList3D": [] };
            platform.WxminiInfoUI = WxminiInfoUI;
            REG("ui.platform.WxminiInfoUI", WxminiInfoUI);
        })(platform = ui.platform || (ui.platform = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var player;
        (function (player) {
            class PlayerIcoBgItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlayerIcoBgItemUI.uiView);
                }
            }
            PlayerIcoBgItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 75, "x": 75, "width": 124, "skin": "ui/img_UM_herokill_bg_zi.png", "sizeGrid": "26,37,29,35", "pivotY": 60, "pivotX": 62, "height": 119, "blendMode": "lighter" }, "compId": 1281 }], "animations": [{ "nodes": [{ "target": 1281, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "label": null, "key": "scaleY", "index": 10 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleX", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "label": null, "key": "scaleX", "index": 10 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png"], "loadList3D": [] };
            player.PlayerIcoBgItemUI = PlayerIcoBgItemUI;
            REG("ui.player.PlayerIcoBgItemUI", PlayerIcoBgItemUI);
            class PlayerIcoItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlayerIcoItemUI.uiView);
                }
            }
            PlayerIcoItemUI.uiView = { "type": "View", "props": { "width": 160, "height": 160 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 5, "width": 150, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "15,15,15,15", "height": 150 }, "compId": 3 }, { "type": "PlayerIcoBgItem", "props": { "y": -22, "x": -22, "width": 150, "var": "selectBox", "scaleY": 1.35, "scaleX": 1.35, "name": "selectBox", "height": 150, "runtime": "ui.player.PlayerIcoBgItemUI" }, "compId": 35 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 130, "var": "img_ico", "skin": "ui/img_UM_head.png", "name": "img_ico", "height": 130 }, "compId": 4 }], "loadList": ["ui/img_UM_btn__btn1.png", "ui/img_UM_head.png"], "loadList3D": [] };
            player.PlayerIcoItemUI = PlayerIcoItemUI;
            REG("ui.player.PlayerIcoItemUI", PlayerIcoItemUI);
            class PlayerSetUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlayerSetUI.uiView);
                }
            }
            PlayerSetUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "width": 1480, "skin": "ui/img_UM_ui_bg2.png", "right": -100, "left": -100, "height": 720 }, "compId": 766 }, { "type": "TextInput", "props": { "y": 209, "x": 370, "width": 539, "var": "txt_input", "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "promptColor": "#c5c5c5", "prompt": "请输入角色名", "name": "txt_input", "height": 71, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 762 }, { "type": "Image", "props": { "y": 47, "x": 565, "width": 150, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 150 }, "compId": 958 }, { "type": "Image", "props": { "y": 58, "x": 575, "width": 130, "var": "img_head", "skin": "ui/img_UM_head.png", "name": "img_head", "height": 130 }, "compId": 957 }, { "type": "List", "props": { "y": 286, "x": 239, "width": 805, "var": "list_ioc", "vScrollBarSkin": "comp/vscroll.png", "name": "list_ioc", "height": 314, "elasticEnabled": true }, "compId": 977, "child": [{ "type": "PlayerIcoItem", "props": { "y": 0, "x": 0, "var": "item_ico", "renderType": "render", "name": "item_ico", "runtime": "ui.player.PlayerIcoItemUI" }, "compId": 972 }] }, { "type": "Box", "props": { "y": 24, "x": 41, "var": "img_close", "name": "img_close" }, "compId": 984, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 998 }, { "type": "Image", "props": { "y": 26, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 999 }] }, { "type": "Box", "props": { "y": 607, "x": 530, "var": "img_ok", "name": "img_ok" }, "compId": 988, "child": [{ "type": "Image", "props": { "y": 2, "x": 5, "width": 203, "skin": "ui/img_UM_btn_BlueButton_2.png", "height": 83 }, "compId": 989 }, { "type": "Label", "props": { "y": 11, "x": 60, "wordWrap": true, "width": 139, "valign": "middle", "text": "确认修改", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 990 }, { "type": "Image", "props": { "y": 25, "x": 25, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 992 }] }, { "type": "Box", "props": { "y": 242.5, "x": 983, "width": 122, "var": "box_name", "pivotY": 44, "pivotX": 61, "name": "box_name", "height": 87 }, "compId": 1000, "child": [{ "type": "Image", "props": { "y": 34, "x": 57, "width": 67, "skin": "ui/img_UM_ui_touzi.png", "pivotY": 34, "pivotX": 34, "height": 67 }, "compId": 1001 }, { "type": "Image", "props": { "y": 52, "x": 9, "width": 105, "skin": "ui/img_UM_ui_text22.png", "height": 30 }, "compId": 1002 }] }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_head.png", "comp/vscroll.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_ui_touzi.png", "ui/img_UM_ui_text22.png"], "loadList3D": [] };
            player.PlayerSetUI = PlayerSetUI;
            REG("ui.player.PlayerSetUI", PlayerSetUI);
            class PlayerSet1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlayerSet1UI.uiView);
                }
            }
            PlayerSet1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1480, "skin": "ui/img_UM_ui_bg2.png", "right": -100, "left": -100, "height": 720 }, "compId": 998 }, { "type": "TextInput", "props": { "y": 209, "x": 370, "width": 539, "var": "txt_input", "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "promptColor": "#c5c5c5", "prompt": "请输入角色名", "name": "txt_input", "height": 71, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 999 }, { "type": "Image", "props": { "y": 47, "x": 565, "width": 150, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 150 }, "compId": 1000 }, { "type": "Image", "props": { "y": 58, "x": 575, "width": 130, "var": "img_head", "skin": "ui/img_UM_head.png", "name": "img_head", "height": 130 }, "compId": 1001 }, { "type": "List", "props": { "y": 286, "x": 239, "width": 805, "var": "list_ioc", "vScrollBarSkin": "comp/vscroll.png", "name": "list_ioc", "height": 191, "elasticEnabled": true }, "compId": 1002, "child": [{ "type": "PlayerIcoItem", "props": { "y": 0, "x": 0, "var": "item_ico", "renderType": "render", "name": "item_ico", "runtime": "ui.player.PlayerIcoItemUI" }, "compId": 1006 }] }, { "type": "Box", "props": { "y": 24, "x": 41, "var": "img_close", "name": "img_close" }, "compId": 1003, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1007 }, { "type": "Image", "props": { "y": 26, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1008 }] }, { "type": "Box", "props": { "y": 532, "x": 824, "var": "img_ok", "name": "img_ok" }, "compId": 1004, "child": [{ "type": "Image", "props": { "y": 2, "x": 5, "width": 203, "skin": "ui/img_UM_btn_BlueButton_2.png", "height": 83 }, "compId": 1009 }, { "type": "Label", "props": { "y": 11, "x": 60, "wordWrap": true, "width": 139, "valign": "middle", "text": "确认修改", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1010 }, { "type": "Image", "props": { "y": 25, "x": 25, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1011 }] }, { "type": "Box", "props": { "y": 242, "x": 983, "width": 122, "var": "box_name", "pivotY": 44, "pivotX": 61, "name": "box_name", "height": 87 }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 34, "x": 57, "width": 67, "skin": "ui/img_UM_ui_touzi.png", "pivotY": 34, "pivotX": 34, "height": 67 }, "compId": 1012 }, { "type": "Image", "props": { "y": 52, "x": 9, "width": 105, "skin": "ui/img_UM_ui_text22.png", "height": 30 }, "compId": 1013 }] }, { "type": "Label", "props": { "y": 20, "wordWrap": false, "width": 332, "var": "txt_lv", "valign": "middle", "text": "qq客服：2921065058", "strokeColor": "#000000", "stroke": 4, "right": 20, "name": "txt_lv", "height": 55, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1014 }, { "type": "Label", "props": { "y": 76, "wordWrap": false, "width": 144, "var": "txt_privacy", "valign": "middle", "underline": true, "text": "隐私协议", "strokeColor": "#000000", "stroke": 0, "right": 208, "name": "txt_privacy", "height": 62, "fontSize": 36, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1015 }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_head.png", "comp/vscroll.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_ui_touzi.png", "ui/img_UM_ui_text22.png"], "loadList3D": [] };
            player.PlayerSet1UI = PlayerSet1UI;
            REG("ui.player.PlayerSet1UI", PlayerSet1UI);
            class PlayerSet2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlayerSet2UI.uiView);
                }
            }
            PlayerSet2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1480, "skin": "ui/img_UM_ui_bg2.png", "right": -100, "left": -100, "height": 720 }, "compId": 998 }, { "type": "TextInput", "props": { "y": 181, "x": 395, "width": 539, "var": "txt_input", "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "promptColor": "#c5c5c5", "prompt": "请输入角色名", "name": "txt_input", "height": 71, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 999 }, { "type": "Image", "props": { "y": 21, "x": 590, "width": 150, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 150 }, "compId": 1000 }, { "type": "Image", "props": { "y": 31, "x": 600, "width": 130, "var": "img_head", "skin": "ui/img_UM_head.png", "name": "img_head", "height": 130 }, "compId": 1001 }, { "type": "List", "props": { "y": 258, "x": 264, "width": 805, "var": "list_ioc", "vScrollBarSkin": "comp/vscroll.png", "name": "list_ioc", "height": 191, "elasticEnabled": true }, "compId": 1002, "child": [{ "type": "PlayerIcoItem", "props": { "y": 0, "x": 0, "var": "item_ico", "renderType": "render", "name": "item_ico", "runtime": "ui.player.PlayerIcoItemUI" }, "compId": 1006 }] }, { "type": "Box", "props": { "y": 24, "x": 41, "var": "img_close", "name": "img_close" }, "compId": 1003, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1007 }, { "type": "Image", "props": { "y": 26, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1008 }] }, { "type": "Box", "props": { "y": 568, "x": 1094, "var": "img_ok", "name": "img_ok" }, "compId": 1004, "child": [{ "type": "Image", "props": { "y": 2, "x": 5, "width": 203, "skin": "ui/img_UM_btn_BlueButton_2.png", "height": 83 }, "compId": 1009 }, { "type": "Label", "props": { "y": 11, "x": 60, "wordWrap": true, "width": 139, "valign": "middle", "text": "确认修改", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1010 }, { "type": "Image", "props": { "y": 25, "x": 25, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1011 }] }, { "type": "Box", "props": { "y": 212, "x": 1008, "width": 122, "var": "box_name", "pivotY": 44, "pivotX": 61, "name": "box_name", "height": 87 }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 34, "x": 57, "width": 67, "skin": "ui/img_UM_ui_touzi.png", "pivotY": 34, "pivotX": 34, "height": 67 }, "compId": 1012 }, { "type": "Image", "props": { "y": 52, "x": 9, "width": 105, "skin": "ui/img_UM_ui_text22.png", "height": 30 }, "compId": 1013 }] }, { "type": "Label", "props": { "y": 20, "x": 0, "wordWrap": false, "width": 332, "var": "txt_lv", "valign": "middle", "text": "qq客服：2921065058", "strokeColor": "#000000", "stroke": 4, "right": 20, "name": "txt_lv", "height": 55, "fontSize": 35, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1016 }, { "type": "Label", "props": { "y": 76, "x": 0, "wordWrap": false, "width": 144, "var": "txt_privacy", "valign": "middle", "underline": true, "text": "隐私协议", "strokeColor": "#000000", "stroke": 0, "right": 208, "name": "txt_privacy", "height": 62, "fontSize": 36, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1017 }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_head.png", "comp/vscroll.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_ui_touzi.png", "ui/img_UM_ui_text22.png"], "loadList3D": [] };
            player.PlayerSet2UI = PlayerSet2UI;
            REG("ui.player.PlayerSet2UI", PlayerSet2UI);
            class PlayerSet3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PlayerSet3UI.uiView);
                }
            }
            PlayerSet3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1480, "skin": "ui/img_UM_ui_bg2.png", "right": -100, "left": -100, "height": 720 }, "compId": 998 }, { "type": "TextInput", "props": { "y": 209, "x": 370, "width": 539, "var": "txt_input", "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "promptColor": "#c5c5c5", "prompt": "请输入角色名", "name": "txt_input", "height": 71, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 999 }, { "type": "Image", "props": { "y": 47, "x": 565, "width": 150, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 150 }, "compId": 1000 }, { "type": "Image", "props": { "y": 58, "x": 575, "width": 130, "var": "img_head", "skin": "ui/img_UM_head.png", "name": "img_head", "height": 130 }, "compId": 1001 }, { "type": "List", "props": { "y": 286, "x": 239, "width": 805, "var": "list_ioc", "vScrollBarSkin": "comp/vscroll.png", "name": "list_ioc", "height": 191, "elasticEnabled": true }, "compId": 1002, "child": [{ "type": "PlayerIcoItem", "props": { "y": 0, "x": 0, "var": "item_ico", "renderType": "render", "name": "item_ico", "runtime": "ui.player.PlayerIcoItemUI" }, "compId": 1006 }] }, { "type": "Box", "props": { "y": 24, "x": 41, "var": "img_close", "name": "img_close" }, "compId": 1003, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1007 }, { "type": "Image", "props": { "y": 26, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1008 }] }, { "type": "Box", "props": { "y": 532, "var": "img_ok", "right": 10, "name": "img_ok" }, "compId": 1004, "child": [{ "type": "Image", "props": { "y": 2, "x": 5, "width": 203, "skin": "ui/img_UM_btn_BlueButton_2.png", "height": 83 }, "compId": 1009 }, { "type": "Label", "props": { "y": 11, "x": 60, "wordWrap": true, "width": 139, "valign": "middle", "text": "确认修改", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1010 }, { "type": "Image", "props": { "y": 25, "x": 25, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 1011 }] }, { "type": "Box", "props": { "y": 242, "x": 983, "width": 122, "var": "box_name", "pivotY": 44, "pivotX": 61, "name": "box_name", "height": 87 }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 34, "x": 57, "width": 67, "skin": "ui/img_UM_ui_touzi.png", "pivotY": 34, "pivotX": 34, "height": 67 }, "compId": 1012 }, { "type": "Image", "props": { "y": 52, "x": 9, "width": 105, "skin": "ui/img_UM_ui_text22.png", "height": 30 }, "compId": 1013 }] }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_head.png", "comp/vscroll.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_UM_ui_touzi.png", "ui/img_UM_ui_text22.png"], "loadList3D": [] };
            player.PlayerSet3UI = PlayerSet3UI;
            REG("ui.player.PlayerSet3UI", PlayerSet3UI);
        })(player = ui.player || (ui.player = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var rank;
        (function (rank) {
            class RankUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RankUI.uiView);
                }
            }
            RankUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -72, "skin": "ui/img_uk_ui2_uibg2.jpg", "right": -100, "left": -100 }, "compId": 611 }, { "type": "Box", "props": { "y": 51, "centerX": 0 }, "compId": 625, "child": [{ "type": "Tab", "props": { "x": 208, "var": "tab_2", "selectedIndex": 0, "name": "tab_2", "labelPadding": "0,0,4,0" }, "compId": 595, "child": [{ "type": "Button", "props": { "y": 0, "x": 0, "width": 200, "var": "item0", "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui15.png", "name": "item0", "labelStrokeColor": "#3b3b3b", "labelStroke": 5, "labelSize": 23, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#ffffff,#ffffff", "labelBold": true, "label": "击杀榜", "height": 76 }, "compId": 592 }, { "type": "Button", "props": { "y": 0, "x": 206, "width": 200, "var": "item1", "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui15.png", "name": "item1", "labelStrokeColor": "#3b3b3b", "labelStroke": 5, "labelSize": 23, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#ffffff,#ffffff", "labelBold": true, "label": "胜利榜", "height": 76 }, "compId": 593 }] }, { "type": "Tab", "props": { "y": 132, "var": "tab_1", "selectedIndex": 0, "name": "tab_1" }, "compId": 604, "child": [{ "type": "Button", "props": { "width": 145, "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui2_2.png", "name": "item0", "labelStrokeColor": "#3b3b3b", "labelStroke": 4, "labelSize": 23, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#3b3b3b,#3b3b3b", "labelBold": true, "label": "综合排行" }, "compId": 601 }, { "type": "Button", "props": { "y": 83, "width": 145, "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui2_2.png", "name": "item1", "labelStrokeColor": "#3b3b3b", "labelStroke": 4, "labelSize": 23, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#3b3b3b,#3b3b3b", "labelBold": true, "label": "5V5模式" }, "compId": 602 }, { "type": "Button", "props": { "y": 166, "width": 145, "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui2_2.png", "name": "item2", "labelStrokeColor": "#3b3b3b", "labelStroke": 4, "labelSize": 23, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#3b3b3b,#3b3b3b", "labelBold": true, "label": "自由对战" }, "compId": 603 }, { "type": "Button", "props": { "y": 249, "x": 0, "width": 145, "visible": true, "var": "item3", "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui2_2.png", "name": "item3", "labelStrokeColor": "#3b3b3b", "labelStroke": 4, "labelSize": 23, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#3b3b3b,#3b3b3b", "labelBold": true, "label": "闯关模式" }, "compId": 629 }] }, { "type": "Image", "props": { "y": 76, "x": 151, "width": 1025, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 588, "alpha": 1 }, "compId": 612 }, { "type": "Image", "props": { "y": 551, "x": 166, "width": 994, "skin": "ui/img_uk_ui2_obj13.png", "sizeGrid": "48,112,50,100", "height": 100 }, "compId": 613 }, { "type": "Image", "props": { "y": 103, "x": 181, "width": 964, "skin": "ui/img_uk_ui_new_ui38.png", "sizeGrid": "9,8,10,9", "height": 445, "alpha": 0.4 }, "compId": 614 }, { "type": "Label", "props": { "y": 583, "x": 272, "wordWrap": true, "width": 167, "valign": "middle", "text": "我 的 排 名", "strokeColor": "#3b3b3b", "stroke": 5, "height": 35, "fontSize": 23, "font": "SimHei", "color": "#b4b4b4", "bold": false, "align": "left" }, "compId": 615 }, { "type": "Label", "props": { "y": 582, "x": 420, "wordWrap": true, "width": 159, "var": "txt_rank", "valign": "middle", "text": "1200", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_rank", "height": 37, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 616 }, { "type": "Box", "props": { "y": 569, "x": 187 }, "compId": 617, "child": [{ "type": "Image", "props": { "skin": "ui/img_uk_player_headbg1.png" }, "compId": 622 }, { "type": "Image", "props": { "y": 7, "x": 7, "width": 51, "var": "img_ico", "skin": "ui/img_uk_player_head.png", "name": "img_ico", "height": 51 }, "compId": 623 }] }, { "type": "Label", "props": { "y": 565, "x": 620, "wordWrap": true, "width": 178, "var": "txt_victory", "valign": "middle", "text": "胜利 23", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_victory", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 618 }, { "type": "Label", "props": { "y": 600, "x": 620, "wordWrap": true, "width": 262, "var": "txt_kill", "valign": "middle", "text": "击杀 1200", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_kill", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 619 }, { "type": "Label", "props": { "y": 582, "x": 935, "wordWrap": true, "width": 210, "var": "txt_maxkill", "valign": "middle", "text": "最大击杀 13", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_maxkill", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 620 }, { "type": "List", "props": { "y": 107, "x": 208, "width": 912, "var": "list_1", "vScrollBarSkin": "comp/vscroll.png", "renderType": "render", "name": "list_1", "height": 425, "elasticEnabled": true }, "compId": 621, "child": [{ "type": "RankItem", "props": { "renderType": "render", "runtime": "ui.rank.RankItemUI" }, "compId": 624 }] }, { "type": "Button", "props": { "y": -2, "x": 208, "width": 200, "visible": false, "var": "lev_rank", "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui15.png", "selected": true, "name": "lev_rank", "labelStrokeColor": "#3b3b3b", "labelStroke": 5, "labelSize": 23, "labelFont": "SimHei", "labelColors": "#ffffff,#ffffff,#ffffff,#ffffff", "labelBold": true, "label": "排行榜", "height": 76 }, "compId": 630 }, { "type": "List", "props": { "y": 107, "x": 208, "width": 912, "visible": false, "var": "list_2", "vScrollBarSkin": "comp/vscroll.png", "renderType": "render", "name": "list_2", "height": 425, "elasticEnabled": true }, "compId": 631, "child": [{ "type": "RankLevItem", "props": { "renderType": "render", "runtime": "ui.rank.RankLevItemUI" }, "compId": 633 }] }, { "type": "Label", "props": { "y": 582, "x": 558, "wordWrap": true, "width": 262, "visible": false, "var": "txt_levprog", "valign": "middle", "text": "关卡进度 入门难度", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_levprog", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 634 }] }, { "type": "Box", "props": { "y": 25, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 607, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 608 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 609 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 610 }] }], "loadList": ["ui/img_uk_ui2_uibg2.jpg", "ui/btn_uk_ui_new_ui15.png", "ui/btn_uk_ui_new_ui2_2.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj13.png", "ui/img_uk_ui_new_ui38.png", "ui/img_uk_player_headbg1.png", "ui/img_uk_player_head.png", "comp/vscroll.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png"], "loadList3D": [] };
            rank.RankUI = RankUI;
            REG("ui.rank.RankUI", RankUI);
            class RankItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RankItemUI.uiView);
                }
            }
            RankItemUI.uiView = { "type": "View", "props": { "width": 900, "height": 80 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 4, "x": 71, "skin": "ui/img_uk_player_headbg1.png" }, "compId": 10 }, { "type": "Image", "props": { "y": 11, "x": 78, "width": 51, "var": "img_ico", "skin": "ui/img_uk_player_head.png", "name": "img_ico", "height": 51 }, "compId": 11 }, { "type": "Label", "props": { "y": 22, "x": 18, "wordWrap": true, "width": 45, "var": "txt_num", "valign": "middle", "text": "1", "strokeColor": "#6c6c6c", "stroke": 5, "name": "txt_num", "height": 35, "fontSize": 36, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 4 }, { "type": "Label", "props": { "y": 19, "x": 146, "wordWrap": true, "width": 226, "var": "txt_name", "valign": "middle", "text": "Player Name", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_name", "height": 35, "fontSize": 23, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 5 }, { "type": "Label", "props": { "y": 5, "x": 373, "wordWrap": true, "width": 241, "valign": "middle", "text": "胜利", "strokeColor": "#3b3b3b", "stroke": 5, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 6 }, { "type": "Label", "props": { "y": 37, "x": 373, "wordWrap": true, "width": 287, "valign": "middle", "text": "击杀", "strokeColor": "#3b3b3b", "stroke": 5, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 7 }, { "type": "Label", "props": { "y": 5, "x": 661, "wordWrap": true, "width": 238, "valign": "middle", "text": "最大击杀", "strokeColor": "#3b3b3b", "stroke": 5, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 8 }, { "type": "Image", "props": { "y": 74, "x": -3, "width": 900, "skin": "ui/img_uk_ui_new_ui31.png", "height": 2, "alpha": 0.5 }, "compId": 9 }, { "type": "Label", "props": { "y": 5, "x": 422, "wordWrap": true, "width": 165, "var": "txt_victory", "valign": "middle", "text": "23", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_victory", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 12 }, { "type": "Label", "props": { "y": 37, "x": 422, "wordWrap": true, "width": 242, "var": "txt_kill", "valign": "middle", "text": "200", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_kill", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 13 }, { "type": "Label", "props": { "y": 5, "x": 751, "wordWrap": true, "width": 150, "var": "txt_maxKill", "valign": "middle", "text": "13", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_maxKill", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 14 }], "loadList": ["ui/img_uk_player_headbg1.png", "ui/img_uk_player_head.png", "ui/img_uk_ui_new_ui31.png"], "loadList3D": [] };
            rank.RankItemUI = RankItemUI;
            REG("ui.rank.RankItemUI", RankItemUI);
            class RankLevItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RankLevItemUI.uiView);
                }
            }
            RankLevItemUI.uiView = { "type": "View", "props": { "width": 900, "height": 80 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 4, "x": 71, "skin": "ui/img_uk_player_headbg1.png" }, "compId": 10 }, { "type": "Image", "props": { "y": 11, "x": 78, "width": 51, "var": "img_ico", "skin": "ui/img_uk_player_head.png", "name": "img_ico", "height": 51 }, "compId": 11 }, { "type": "Label", "props": { "y": 22, "x": 18, "wordWrap": true, "width": 45, "var": "txt_num", "valign": "middle", "text": "1", "strokeColor": "#6c6c6c", "stroke": 5, "name": "txt_num", "height": 35, "fontSize": 36, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 4 }, { "type": "Label", "props": { "y": 19, "x": 146, "wordWrap": true, "width": 226, "var": "txt_name", "valign": "middle", "text": "Player Name", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_name", "height": 35, "fontSize": 23, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 5 }, { "type": "Label", "props": { "y": 22, "x": 373, "wordWrap": true, "width": 241, "valign": "middle", "text": "关卡进度", "strokeColor": "#3b3b3b", "stroke": 5, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 6 }, { "type": "Label", "props": { "y": 21, "x": 661, "wordWrap": true, "width": 238, "var": "txt_wave", "valign": "middle", "text": "最大波数", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_wave", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 8 }, { "type": "Image", "props": { "y": 74, "x": -3, "width": 900, "skin": "ui/img_uk_ui_new_ui31.png", "height": 2, "alpha": 0.5 }, "compId": 9 }, { "type": "Label", "props": { "y": 22, "x": 463, "wordWrap": true, "width": 165, "var": "txt_lev", "valign": "middle", "text": "入门难度", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_lev", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 12 }, { "type": "Label", "props": { "y": 21, "x": 751, "wordWrap": true, "width": 150, "var": "txt_maxKill", "valign": "middle", "text": "13", "strokeColor": "#3b3b3b", "stroke": 5, "name": "txt_maxKill", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#c1c1c1", "bold": false, "align": "left" }, "compId": 14 }], "loadList": ["ui/img_uk_player_headbg1.png", "ui/img_uk_player_head.png", "ui/img_uk_ui_new_ui31.png"], "loadList3D": [] };
            rank.RankLevItemUI = RankLevItemUI;
            REG("ui.rank.RankLevItemUI", RankLevItemUI);
            class RankUpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RankUpUI.uiView);
                }
            }
            RankUpUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -2, "x": -1, "width": 1282, "skin": "ui/img_uk_ui_new_ui33.png", "sizeGrid": "6,41,8,43", "height": 742, "alpha": 1 }, "compId": 624 }, { "type": "Box", "props": { "y": 360, "x": 640, "var": "img_coll_4", "name": "img_coll_4", "centerX": 0, "anchorY": 0.5, "anchorX": 0.5 }, "compId": 602, "child": [{ "type": "Image", "props": { "y": 0, "x": 700, "width": 720, "skin": "ui/img_uk_ui_Scope.png", "height": 720 }, "compId": 599 }, { "type": "Image", "props": { "width": 720, "skin": "comp/img_black.png", "height": 720 }, "compId": 600 }, { "type": "Image", "props": { "x": 1401, "width": 720, "skin": "comp/img_black.png", "height": 720 }, "compId": 601 }] }, { "type": "Image", "props": { "var": "img_hurt", "top": 0, "skin": "ui/img_uk_ui2_obj22.png", "rotation": 0, "right": -100, "name": "img_hurt", "mouseThrough": true, "mouseEnabled": false, "left": -100, "bottom": 0, "alpha": 0.9 }, "compId": 520 }, { "type": "Image", "props": { "y": 164, "x": 243, "width": 794, "skin": "ui/img_uk_ui_obj.png", "height": 85 }, "compId": 631 }, { "type": "BattleDir", "props": { "var": "ui_att", "top": 0, "right": 0, "name": "ui_att", "mouseEnabled": true, "left": 0, "bottom": 0, "runtime": "ui.battle.BattleDirUI" }, "compId": 279 }, { "type": "Image", "props": { "y": 166, "x": 352, "skin": "ui/img_uk_text_pmss.png" }, "compId": 621 }, { "type": "Box", "props": { "y": 409, "x": 497, "var": "btn_get", "name": "btn_get" }, "compId": 625, "child": [{ "type": "Image", "props": { "y": 7, "x": -1, "width": 286, "var": "btn_up", "skin": "ui/img_uk_btn_btn1.png", "sizeGrid": "16,18,16,16", "name": "btn_up", "height": 91 }, "compId": 626 }, { "type": "Label", "props": { "y": 38, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "确定", "strokeColor": "#9c7227", "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 627 }] }, { "type": "Label", "props": { "y": 286, "x": 480, "wordWrap": true, "width": 177, "valign": "middle", "text": "历史最高排名：", "strokeColor": "#000000", "stroke": 3, "italic": true, "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 628 }, { "type": "Label", "props": { "y": 326, "x": 480, "wordWrap": true, "width": 160, "valign": "middle", "text": "当前排名：", "strokeColor": "#000000", "stroke": 3, "italic": true, "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffda7f", "bold": true, "align": "left" }, "compId": 629 }, { "type": "Label", "props": { "y": 285, "x": 662, "wordWrap": true, "width": 111, "var": "txt_old", "valign": "middle", "text": "2560", "strokeColor": "#000000", "stroke": 3, "name": "txt_old", "italic": true, "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 630 }, { "type": "Label", "props": { "y": 326, "x": 662, "wordWrap": true, "width": 111, "var": "txt_rank", "valign": "middle", "text": "2560", "strokeColor": "#000000", "stroke": 3, "name": "txt_rank", "italic": true, "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 632 }, { "type": "Box", "props": { "y": 324, "x": 740, "width": 160, "var": "txt_up", "name": "txt_up", "height": 33 }, "compId": 636, "child": [{ "type": "Label", "props": { "y": 1, "x": 2, "wordWrap": true, "width": 30, "valign": "middle", "text": "（", "strokeColor": "#000000", "stroke": 3, "italic": true, "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 633 }, { "type": "Image", "props": { "y": 32, "x": 38, "width": 32, "skin": "ui/img_uk_leadup.png", "rotation": -90, "height": 27 }, "compId": 634 }, { "type": "Label", "props": { "y": 0, "x": 76, "wordWrap": true, "width": 128, "var": "txt_num", "valign": "middle", "text": "239）", "strokeColor": "#000000", "stroke": 3, "name": "txt_num", "italic": true, "height": 30, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 635 }] }], "loadList": ["ui/img_uk_ui_new_ui33.png", "ui/img_uk_ui_Scope.png", "comp/img_black.png", "ui/img_uk_ui2_obj22.png", "ui/img_uk_ui_obj.png", "ui/img_uk_text_pmss.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_leadup.png"], "loadList3D": [] };
            rank.RankUpUI = RankUpUI;
            REG("ui.rank.RankUpUI", RankUpUI);
        })(rank = ui.rank || (ui.rank = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var segment;
        (function (segment) {
            class SegmentUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SegmentUI.uiView);
                }
            }
            SegmentUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "skin": "ui/img_UM_ui_bg7.jpg", "right": -100, "left": -110 }, "compId": 1585 }, { "type": "Box", "props": { "y": 30, "x": -5, "var": "box_close", "name": "box_close" }, "compId": 1682, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1683 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1684 }] }, { "type": "List", "props": { "y": 137, "width": 1280, "var": "list_segment", "spaceX": 0, "name": "list_segment", "height": 585, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true, "centerX": 0 }, "compId": 1813, "child": [{ "type": "SegmentItem", "props": { "renderType": "render", "runtime": "ui.segment.SegmentItemUI" }, "compId": 1812 }] }, { "type": "Box", "props": { "y": 44, "x": 87, "width": 1096, "height": 83, "centerX": 0 }, "compId": 1818, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1096, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 1815 }, { "type": "Image", "props": { "y": 4, "x": 470, "width": 155, "var": "img_test", "skin": "ui/img_UM_ui_text38.png", "name": "img_test", "height": 45, "alpha": 1 }, "compId": 1816 }, { "type": "Image", "props": { "y": 54, "x": 429, "width": 238, "var": "img_test1", "skin": "ui/img_UM_ui_text39.png", "name": "img_test1", "height": 29 }, "compId": 1817 }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "comp/hscroll.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text38.png", "ui/img_UM_ui_text39.png"], "loadList3D": [] };
            segment.SegmentUI = SegmentUI;
            REG("ui.segment.SegmentUI", SegmentUI);
            class SegmentItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SegmentItemUI.uiView);
                }
            }
            SegmentItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 312, "mouseThrough": true, "height": 558 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 111, "x": 0, "width": 312, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "4,4,4,4", "height": 25, "alpha": 0.5 }, "compId": 1797 }, { "type": "Image", "props": { "y": 305, "x": 156, "width": 260, "var": "img_bg", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "name": "img_bg", "height": 260, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": 239, "x": 90, "width": 131, "var": "img_box", "skin": "ui/img_UM_box_rankbox1.png", "name": "img_box", "height": 131 }, "compId": 1784 }, { "type": "Image", "props": { "y": 363, "x": 85, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1785 }, { "type": "GoodsCardFloat", "props": { "y": 187, "x": 96, "width": 200, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "height": 280, "runtime": "ui.goods.GoodsCardFloatUI" }, "compId": 1800 }, { "type": "Label", "props": { "y": 358, "x": 85, "wordWrap": false, "width": 134, "var": "txt_num1", "valign": "middle", "text": "x8000", "strokeColor": "#000000", "stroke": 2, "name": "txt_num1", "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Label", "props": { "y": 199, "x": 50, "wordWrap": true, "width": 213, "var": "txt_name1", "valign": "middle", "text": "青铜宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_name1", "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1804 }, { "type": "Image", "props": { "y": 175, "x": 26, "width": 260, "var": "img_mask", "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "name": "img_mask", "height": 260, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 285, "x": 85, "width": 142, "var": "img_state", "skin": "ui/img_UM_ui_text37.png", "name": "img_state", "height": 40 }, "compId": 1787 }, { "type": "Image", "props": { "y": 194, "x": 239.5, "width": 31, "var": "img_lock", "skin": "ui/img_UM_ui_lock2.png", "name": "img_lock", "height": 33 }, "compId": 1789 }, { "type": "Image", "props": { "y": 113, "x": -1, "width": 315, "var": "img_strip", "skin": "ui/img_UM_ui_Tips1.png", "sizeGrid": "4,4,4,4", "scaleX": 1, "name": "img_strip", "height": 20 }, "compId": 1790 }, { "type": "Image", "props": { "y": 113, "x": 155, "width": 2, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "4,4,4,4", "height": 20, "alpha": 0.9 }, "compId": 1792 }, { "type": "Image", "props": { "y": 89, "x": 135, "width": 42, "var": "img_arrow", "skin": "ui/img_UM_rank_obj1.png", "name": "img_arrow", "height": 42 }, "compId": 1793 }, { "type": "Label", "props": { "y": 136, "x": 124, "wordWrap": false, "width": 64, "var": "txt_num", "valign": "middle", "text": "1200", "strokeColor": "#000000", "stroke": 2, "rotation": 0, "name": "txt_num", "height": 43, "fontSize": 30, "font": "SimHei", "color": "#f3fe00", "bold": true, "align": "center" }, "compId": 1794 }, { "type": "Image", "props": { "y": -10, "x": 116, "width": 80, "var": "img_segment", "skin": "ui/img_UM_ranklv1.png", "name": "img_segment", "height": 80 }, "compId": 1795 }, { "type": "Label", "props": { "y": 52, "x": 81, "wordWrap": true, "width": 149, "var": "txt_name", "valign": "middle", "text": "青铜II", "strokeColor": "#000000", "stroke": 2, "rotation": 0, "name": "txt_name", "height": 43, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1796 }, { "type": "Label", "props": { "y": 101, "x": 93, "wordWrap": false, "width": 40, "var": "txt_num2", "valign": "middle", "text": "40", "strokeColor": "#000000", "name": "txt_num2", "height": 43, "fontSize": 20, "font": "SimHei", "color": "#191919", "bold": true, "align": "right" }, "compId": 1798 }, { "type": "Image", "props": { "y": 142, "x": 190, "width": 30, "skin": "ui/img_UM_icon_lvup_2.png", "height": 30 }, "compId": 1799 }, { "type": "Box", "props": { "y": 451, "x": 32, "var": "box_get", "name": "box_get", "centerX": 1 }, "compId": 1801, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1802 }, { "type": "Image", "props": { "y": 20, "x": 67, "skin": "ui/img_UM_ui_text17.png" }, "compId": 1803 }] }, { "type": "Image", "props": { "y": 227, "x": -7, "var": "img_available", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available" }, "compId": 1805 }], "loadList": ["ui/img_UM_ui_Tips2.png", "ui/img_UM_rank_jlbg3.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_text37.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_Tips1.png", "ui/img_UM_rank_obj1.png", "ui/img_UM_ranklv1.png", "ui/img_UM_icon_lvup_2.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_ui_text47.png"], "loadList3D": [] };
            segment.SegmentItemUI = SegmentItemUI;
            REG("ui.segment.SegmentItemUI", SegmentItemUI);
            class SegmentLuckyBoxUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SegmentLuckyBoxUI.uiView);
                }
            }
            SegmentLuckyBoxUI.uiView = { "type": "View", "props": { "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 62, "x": 154, "width": 971, "skin": "ui/img_UM_SponsorWall.png", "height": 578 }, "compId": 1160 }, { "type": "Image", "props": { "y": 495, "x": 367, "width": 240, "var": "img_get", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,33,33", "name": "img_get", "height": 110 }, "compId": 1162, "child": [{ "type": "Image", "props": { "y": 34, "x": 85, "width": 70, "skin": "ui/img_UM_ui_text17.png", "height": 32 }, "compId": 1165 }] }, { "type": "Image", "props": { "y": 494, "x": 639.5, "width": 240, "var": "img_ad", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,33,33", "name": "img_ad", "height": 110 }, "compId": 1163, "child": [{ "type": "Image", "props": { "y": 31, "x": 77, "width": 137, "skin": "ui/img_UM_ui_text65.png", "height": 39 }, "compId": 1166 }, { "type": "Image", "props": { "y": 32, "x": 25, "width": 50, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 40 }, "compId": 1167 }] }, { "type": "Image", "props": { "y": 459, "x": 233, "width": 814, "var": "img_info", "skin": "ui/img_UM_ui_text64.png", "name": "img_info", "height": 40 }, "compId": 1164 }, { "type": "Box", "props": { "y": -603, "x": 1685, "var": "box_rw1", "name": "box_rw1" }, "compId": 1172 }, { "type": "List", "props": { "y": 91, "x": 215, "width": 881, "var": "list_box", "spaceY": 0, "spaceX": 27, "name": "list_box", "height": 367 }, "compId": 1186, "child": [{ "type": "SegmentLuckyBoxItem", "props": { "y": -9, "x": 10, "width": 259, "renderType": "render", "height": 368, "runtime": "ui.segment.SegmentLuckyBoxItemUI" }, "compId": 1185 }] }, { "type": "Image", "props": { "y": 495, "x": 367, "width": 240, "var": "img_giveUp", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,33,33", "name": "img_giveUp", "height": 110 }, "compId": 1187, "child": [{ "type": "Image", "props": { "y": 31, "x": 51, "width": 137, "skin": "ui/img_UM_ui_text76.png", "height": 39 }, "compId": 1188 }] }, { "type": "Image", "props": { "y": 494, "x": 639, "width": 240, "var": "img_select", "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,33,33", "name": "img_select", "height": 110 }, "compId": 1189, "child": [{ "type": "Image", "props": { "y": 31, "x": 56, "width": 137, "skin": "ui/img_UM_ui_text77.png", "height": 39 }, "compId": 1190 }] }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text65.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text64.png", "ui/img_UM_ui_text76.png", "ui/img_UM_ui_text77.png"], "loadList3D": [] };
            segment.SegmentLuckyBoxUI = SegmentLuckyBoxUI;
            REG("ui.segment.SegmentLuckyBoxUI", SegmentLuckyBoxUI);
            class SegmentLuckyBoxItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SegmentLuckyBoxItemUI.uiView);
                }
            }
            SegmentLuckyBoxItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 259, "scaleY": 1, "scaleX": 1, "mouseThrough": false, "height": 368 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 11, "x": -4, "width": 268, "var": "img_bg", "skin": "ui/img_UM_shop_ui_bg3.png", "sizeGrid": "109,60,161,84", "name": "img_bg", "height": 363 }, "compId": 1165 }, { "type": "Image", "props": { "y": 42, "x": 40, "var": "img_title", "skin": "ui/img_UM_ui_text66.png", "name": "img_title" }, "compId": 1166 }, { "type": "GoodsCardFloat", "props": { "y": 120, "x": 72, "width": 200, "var": "ui_card", "scaleY": 0.6, "scaleX": 0.6, "name": "ui_card", "height": 280, "runtime": "ui.goods.GoodsCardFloatUI" }, "compId": 1170 }, { "type": "Image", "props": { "y": 142, "x": 76, "var": "img_box", "skin": "ui/img_UM_icon_luckybox.png", "name": "img_box" }, "compId": 1167 }, { "type": "Image", "props": { "y": 291, "x": 26, "width": 50, "visible": false, "var": "img_ad", "skin": "ui/img_UM_ui2_guanggao3.png", "name": "img_ad", "height": 40 }, "compId": 1168 }, { "type": "Image", "props": { "y": 258, "x": 152, "width": 136, "visible": false, "var": "img_hand", "skin": "ui/img_UM_icon_hand.png", "name": "img_hand", "height": 116 }, "compId": 1169 }], "loadList": ["ui/img_UM_shop_ui_bg3.png", "ui/img_UM_ui_text66.png", "ui/img_UM_icon_luckybox.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_icon_hand.png"], "loadList3D": [] };
            segment.SegmentLuckyBoxItemUI = SegmentLuckyBoxItemUI;
            REG("ui.segment.SegmentLuckyBoxItemUI", SegmentLuckyBoxItemUI);
            class SegmentLvUpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SegmentLvUpUI.uiView);
                }
            }
            SegmentLvUpUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "skin": "ui/img_UM_ui_bg7.jpg", "right": -100, "left": -100 }, "compId": 1585 }, { "type": "Box", "props": { "y": -808, "centerX": 0 }, "compId": 1648, "child": [{ "type": "Image", "props": { "width": 2353, "skin": "ui/img_UM_effect_zi.png", "height": 1656, "alpha": 0.8 }, "compId": 1586 }, { "type": "Image", "props": { "y": 660, "x": 738, "width": 904, "skin": "ui/img_UM_effect_blue.png", "height": 522, "alpha": 1 }, "compId": 1587 }, { "type": "Box", "props": { "y": 1125, "x": 852 }, "compId": 1605, "child": [{ "type": "Image", "props": { "y": 31, "x": 0, "width": 690, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 211, "alpha": 0.5 }, "compId": 1606 }, { "type": "Image", "props": { "y": -0.5, "x": 29, "width": 64, "skin": "ui/img_UM_fun_rank.png", "height": 64 }, "compId": 1607 }, { "type": "Label", "props": { "y": 15, "x": 103, "wordWrap": true, "width": 529, "text": "即将获得以下奖励：", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1613 }] }, { "type": "Box", "props": { "y": 1378, "x": 1062, "var": "img_goto", "name": "img_goto" }, "compId": 1616, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1617 }, { "type": "Image", "props": { "y": 27, "x": 69, "skin": "ui/img_UM_ui_text34.png" }, "compId": 1647 }] }, { "type": "Image", "props": { "y": 1027, "x": 1161, "width": 60, "skin": "ui/img_UM_ui_jt.png", "height": 40 }, "compId": 1625 }, { "type": "Image", "props": { "y": 952, "x": 1242, "width": 200, "var": "img_segment2", "skin": "ui/img_UM_1_2.png", "name": "img_segment2", "height": 200 }, "compId": 1627 }, { "type": "Image", "props": { "y": 994, "x": 1025, "width": 105, "var": "img_segment1", "skin": "ui/img_UM_1_1.png", "name": "img_segment1", "height": 118 }, "compId": 1628 }, { "type": "Image", "props": { "y": 898, "x": 1066, "width": 261, "skin": "ui/img_UM_ui_text33.png", "height": 62 }, "compId": 1646 }, { "type": "List", "props": { "y": 1182, "x": 869, "width": 661, "var": "list_rw", "spaceY": 0, "spaceX": 10, "name": "list_rw", "height": 173 }, "compId": 1653, "child": [{ "type": "SegmentRwItem", "props": { "y": 0, "x": 0, "width": 123, "renderType": "render", "height": 173, "runtime": "ui.segment.SegmentRwItemUI" }, "compId": 1652 }] }, { "type": "Label", "props": { "y": 1079, "x": 1029, "wordWrap": false, "width": 97, "var": "txt_name1", "text": "青铜Ⅲ", "strokeColor": "#000608", "stroke": 4, "name": "txt_name1", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#eabb75", "bold": true, "align": "left" }, "compId": 1655 }, { "type": "Label", "props": { "y": 1092, "x": 1285, "wordWrap": false, "width": 138, "var": "txt_name2", "text": "青铜Ⅲ", "strokeColor": "#000608", "stroke": 4, "name": "txt_name2", "height": 46, "fontSize": 40, "font": "SimHei", "color": "#eabb75", "bold": true, "align": "left" }, "compId": 1656 }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_effect_zi.png", "ui/img_UM_effect_blue.png", "ui/img_UM_ui_black2.png", "ui/img_UM_fun_rank.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text34.png", "ui/img_UM_ui_jt.png", "ui/img_UM_1_2.png", "ui/img_UM_1_1.png", "ui/img_UM_ui_text33.png"], "loadList3D": [] };
            segment.SegmentLvUpUI = SegmentLvUpUI;
            REG("ui.segment.SegmentLvUpUI", SegmentLvUpUI);
            class SegmentRwItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SegmentRwItemUI.uiView);
                }
            }
            SegmentRwItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 123, "scaleY": 0.6, "scaleX": 0.6, "mouseThrough": false, "height": 173 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "skin": "ui/img_UM_rank_bg1.png", "sizeGrid": "8,8,8,8", "height": 232 }, "compId": 1159 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "青铜宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 48, "x": 0, "var": "img_rw", "skin": "ui/img_UM_box_rankbox1.png", "name": "img_rw" }, "compId": 1158 }, { "type": "Label", "props": { "y": 224, "x": 12, "wordWrap": false, "width": 171, "var": "txt_tong", "valign": "middle", "text": "77", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1162 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_rank_bg1.png", "ui/img_UM_box_rankbox1.png"], "loadList3D": [] };
            segment.SegmentRwItemUI = SegmentRwItemUI;
            REG("ui.segment.SegmentRwItemUI", SegmentRwItemUI);
            class SegmentUpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SegmentUpUI.uiView);
                }
            }
            SegmentUpUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "skin": "ui/img_UM_ui_bg7.jpg", "right": -100, "left": -100 }, "compId": 1585 }, { "type": "GoodsCard1", "props": { "y": 205, "x": 1886, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCard1UI" }, "compId": 1643 }, { "type": "GoodsCard", "props": { "y": 205, "x": 2017, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardUI" }, "compId": 1644 }, { "type": "GoodsCardDiamonds", "props": { "y": 204, "x": 2145, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardDiamondsUI" }, "compId": 1645 }, { "type": "Box", "props": { "y": -808, "centerX": 0 }, "compId": 1648, "child": [{ "type": "Image", "props": { "width": 2353, "skin": "ui/img_UM_effect_zi.png", "height": 1656, "alpha": 0.8 }, "compId": 1586 }, { "type": "Image", "props": { "y": 660, "x": 738, "width": 904, "skin": "ui/img_UM_effect_blue.png", "height": 522, "alpha": 1 }, "compId": 1587 }, { "type": "Box", "props": { "y": 1125, "x": 852 }, "compId": 1605, "child": [{ "type": "Image", "props": { "y": 31, "x": 0, "width": 690, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 211, "alpha": 0.5 }, "compId": 1606 }, { "type": "Image", "props": { "y": -0.5, "x": 29, "width": 64, "skin": "ui/img_UM_fun_rank.png", "height": 64 }, "compId": 1607 }, { "type": "Label", "props": { "y": 15, "x": 103, "wordWrap": true, "width": 529, "text": "即将获得以下奖励：", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1613 }] }, { "type": "Box", "props": { "y": 1378, "x": 1062 }, "compId": 1616, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1617 }, { "type": "Image", "props": { "y": 27, "x": 69, "skin": "ui/img_UM_ui_text34.png" }, "compId": 1647 }] }, { "type": "Image", "props": { "y": 1027, "x": 1161, "width": 60, "skin": "ui/img_UM_ui_jt.png", "height": 40 }, "compId": 1625 }, { "type": "Image", "props": { "y": 970, "x": 1242, "skin": "ui/img_UM_rank_1_3.png" }, "compId": 1627 }, { "type": "Image", "props": { "y": 997, "x": 1025, "width": 105, "skin": "ui/img_UM_rank_1_3.png", "height": 118 }, "compId": 1628 }, { "type": "GoodsRankbox1", "props": { "y": 1187, "x": 879, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox1UI" }, "compId": 1634 }, { "type": "GoodsRankbox2", "props": { "y": 1187, "x": 1005, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox2UI" }, "compId": 1639 }, { "type": "GoodsRankbox3", "props": { "y": 1188, "x": 1132, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox3UI" }, "compId": 1640 }, { "type": "GoodsRankbox4", "props": { "y": 1187, "x": 1258, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox4UI" }, "compId": 1641 }, { "type": "GoodsRankbox5", "props": { "y": 1187, "x": 1384, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox5UI" }, "compId": 1642 }, { "type": "Image", "props": { "y": 898, "x": 1066, "width": 261, "skin": "ui/img_UM_ui_text33.png", "height": 62 }, "compId": 1646 }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_effect_zi.png", "ui/img_UM_effect_blue.png", "ui/img_UM_ui_black2.png", "ui/img_UM_fun_rank.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text34.png", "ui/img_UM_ui_jt.png", "ui/img_UM_rank_1_3.png", "ui/img_UM_ui_text33.png"], "loadList3D": [] };
            segment.SegmentUpUI = SegmentUpUI;
            REG("ui.segment.SegmentUpUI", SegmentUpUI);
        })(segment = ui.segment || (ui.segment = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var shop;
        (function (shop) {
            class ShopBgAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopBgAnimUI.uiView);
                }
            }
            ShopBgAnimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 140 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 70, "x": 90, "width": 168, "skin": "ui/img_uk_ui2_obj19.png", "pivotY": 84, "pivotX": 84, "height": 168, "blendMode": "lighter" }, "compId": 1168 }], "animations": [{ "nodes": [{ "target": 1168, "keyframes": { "alpha": [{ "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 5 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1168, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_uk_ui2_obj19.png"], "loadList3D": [] };
            shop.ShopBgAnimUI = ShopBgAnimUI;
            REG("ui.shop.ShopBgAnimUI", ShopBgAnimUI);
            class ShopBoxOpenUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopBoxOpenUI.uiView);
                }
            }
            ShopBoxOpenUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 297, "x": 579, "width": 349, "skin": "ui/img_uk_ui2_obj19.png", "pivotY": 114, "pivotX": 114, "height": 349 }, "compId": 997 }, { "type": "Image", "props": { "y": 195, "x": 475, "width": 330, "var": "img_cl", "skin": "ui/img_uk_icon_box1.png", "name": "img_cl", "height": 330 }, "compId": 1002 }, { "type": "Image", "props": { "y": 322, "x": 640, "width": 330, "var": "img_op", "skin": "ui/img_uk_icon_boxopen1.png", "pivotY": 165, "pivotX": 165, "name": "img_op", "height": 330 }, "compId": 1001 }, { "type": "Image", "props": { "y": 212, "x": 639, "width": 524, "skin": "ui/img_uk_ui_jlsbox_openEffect.png", "pivotY": 145, "pivotX": 262, "height": 290, "blendMode": "lighter" }, "compId": 1003 }], "animations": [{ "nodes": [{ "target": 1003, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleY", "index": 18 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "scaleX", "index": 18 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 12 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1003, "key": "alpha", "index": 18 }] } }, { "target": 1001, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleY", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleY", "index": 14 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleY", "index": 16 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleX", "index": 14 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "scaleX", "index": 16 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "alpha", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "key": "alpha", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1001, "label": null, "key": "alpha", "index": 16 }] } }, { "target": 1002, "keyframes": { "y": [{ "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "y", "index": 0 }, { "value": 190, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "y", "index": 1 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 2 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 3 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 4 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 5 }, { "value": 190, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 6 }, { "value": 200, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 7 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 8 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 9 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 10 }, { "value": 195, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "y", "index": 12 }], "x": [{ "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "x", "index": 0 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 2 }, { "value": 470, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 3 }, { "value": 480, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 4 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 5 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 7 }, { "value": 470, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 8 }, { "value": 480, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 9 }, { "value": 475, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 10 }, { "value": 480, "tweenMethod": "linearNone", "tween": true, "target": 1002, "label": null, "key": "x", "index": 12 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "alpha", "index": 11 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1002, "key": "alpha", "index": 12 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_uk_ui2_obj19.png", "ui/img_uk_icon_box1.png", "ui/img_uk_icon_boxopen1.png", "ui/img_uk_ui_jlsbox_openEffect.png"], "loadList3D": [] };
            shop.ShopBoxOpenUI = ShopBoxOpenUI;
            REG("ui.shop.ShopBoxOpenUI", ShopBoxOpenUI);
            class ShopBuyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopBuyUI.uiView);
                }
            }
            ShopBuyUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -22, "x": -130, "width": 1539, "visible": true, "var": "box_title", "name": "box_title", "height": 763 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1539, "skin": "ui/img_uk_ui_new_ui38.png", "height": 763, "alpha": 0.5 }, "compId": 785 }, { "type": "Image", "props": { "y": 402, "x": 769, "width": 1300, "skin": "ui/img_uk_ui_new_ui38.png", "sizeGrid": "9,8,10,9", "pivotY": 111, "pivotX": 650, "height": 111, "alpha": 0.6 }, "compId": 786 }, { "type": "Box", "props": { "y": 415, "x": 470, "var": "btn_get", "name": "btn_get" }, "compId": 787, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_ui2_btn2.png", "height": 91 }, "compId": 788 }, { "type": "Label", "props": { "y": 32, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "购 买", "strokeColor": "#000000", "stroke": 5, "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 789 }] }, { "type": "Box", "props": { "y": 415, "x": 771, "var": "btn_cancel", "name": "btn_cancel" }, "compId": 790, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_btn_btn1.png", "height": 91 }, "compId": 791 }, { "type": "Label", "props": { "y": 32, "x": 48, "wordWrap": true, "width": 190, "valign": "middle", "text": "取 消", "strokeColor": "#000000", "stroke": 5, "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 792 }] }, { "type": "Box", "props": { "y": 233, "x": 638 }, "compId": 793, "child": [{ "type": "Image", "props": { "y": 9, "x": 0, "width": 39, "skin": "ui/img_uk_ui_new_ui39.png", "height": 39 }, "compId": 794 }, { "type": "Label", "props": { "y": 14, "x": 43, "wordWrap": true, "width": 209, "valign": "middle", "text": "是否购买以下物品？", "strokeColor": "#6c6c6c", "stroke": 5, "height": 35, "fontSize": 23, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 795 }] }, { "type": "Box", "props": { "y": 309, "x": 620, "width": 422, "height": 72 }, "compId": 796, "child": [{ "type": "Box", "props": { "x": 195.75 }, "compId": 797, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 90, "skin": "ui/img_uk_Icon_jinbi.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 798 }, { "type": "Label", "props": { "y": 18, "x": 78, "wordWrap": true, "width": 118, "var": "txt_priceTong", "text": "2000", "strokeColor": "#000000", "stroke": 4, "name": "txt_priceTong", "height": 35, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 799 }] }, { "type": "Box", "props": { "y": 3, "x": -54, "width": 172, "height": 65 }, "compId": 800, "child": [{ "type": "Image", "props": { "y": -8, "x": 10, "width": 75, "skin": "ui/img_uk_Icon_zs.png", "scaleY": 0.9, "scaleX": 0.9, "height": 75 }, "compId": 801 }, { "type": "Label", "props": { "y": 14, "x": 85, "wordWrap": true, "width": 105, "var": "txt_priceJin", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_priceJin", "height": 35, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 802 }] }, { "type": "Image", "props": { "y": 23, "x": 131, "skin": "ui/img_uk_ui_new_ui30.png" }, "compId": 803 }] }] }], "loadList": ["ui/img_uk_ui_new_ui38.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_ui_new_ui39.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_ui_new_ui30.png"], "loadList3D": [] };
            shop.ShopBuyUI = ShopBuyUI;
            REG("ui.shop.ShopBuyUI", ShopBuyUI);
            class ShopBuy1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopBuy1UI.uiView);
                }
            }
            ShopBuy1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -22, "x": -130, "width": 1539, "visible": true, "var": "box_title", "name": "box_title", "height": 763 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1539, "skin": "ui/img_uk_ui_new_ui38.png", "height": 763, "alpha": 0.5 }, "compId": 785 }, { "type": "Image", "props": { "y": 402, "x": 769, "width": 1300, "skin": "ui/img_uk_ui_new_ui38.png", "sizeGrid": "9,8,10,9", "pivotY": 111, "pivotX": 650, "height": 111, "alpha": 0.6 }, "compId": 786 }, { "type": "Box", "props": { "y": 415, "x": 470, "var": "btn_get", "name": "btn_get" }, "compId": 787, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_ui2_btn2.png", "height": 91 }, "compId": 788 }, { "type": "Label", "props": { "y": 32, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "购 买", "strokeColor": "#000000", "stroke": 5, "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 789 }] }, { "type": "Box", "props": { "y": 415, "x": 771, "var": "btn_cancel", "name": "btn_cancel" }, "compId": 790, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_btn_btn1.png", "height": 91 }, "compId": 791 }, { "type": "Label", "props": { "y": 32, "x": 48, "wordWrap": true, "width": 190, "valign": "middle", "text": "取 消", "strokeColor": "#000000", "stroke": 5, "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 792 }] }, { "type": "Box", "props": { "y": 233, "x": 638 }, "compId": 793, "child": [{ "type": "Image", "props": { "y": 9, "x": 0, "width": 39, "skin": "ui/img_uk_ui_new_ui39.png", "height": 39 }, "compId": 794 }, { "type": "Label", "props": { "y": 14, "x": 43, "wordWrap": true, "width": 209, "valign": "middle", "text": "是否购买以下物品？", "strokeColor": "#6c6c6c", "stroke": 5, "height": 35, "fontSize": 23, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 795 }] }, { "type": "Box", "props": { "y": 309, "x": 620, "width": 422, "height": 72 }, "compId": 796, "child": [{ "type": "Box", "props": { "x": 195.75 }, "compId": 797, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 90, "skin": "ui/img_uk_Icon_jinbi.png", "scaleY": 0.8, "scaleX": 0.8, "height": 90 }, "compId": 798 }, { "type": "Label", "props": { "y": 18, "x": 78, "wordWrap": true, "width": 118, "var": "txt_priceTong", "text": "2000", "strokeColor": "#000000", "stroke": 4, "name": "txt_priceTong", "height": 35, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 799 }] }, { "type": "Box", "props": { "y": 3, "x": -54, "width": 172, "height": 65 }, "compId": 800, "child": [{ "type": "Image", "props": { "y": -8, "x": 10, "width": 75, "skin": "ui/img_uk_Icon_zs.png", "scaleY": 0.9, "scaleX": 0.9, "height": 75 }, "compId": 801 }, { "type": "Label", "props": { "y": 14, "x": 85, "wordWrap": true, "width": 105, "var": "txt_priceJin", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_priceJin", "height": 35, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 802 }] }, { "type": "Image", "props": { "y": 23, "x": 131, "skin": "ui/img_uk_ui_new_ui30.png" }, "compId": 803 }] }] }], "loadList": ["ui/img_uk_ui_new_ui38.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_ui_new_ui39.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_ui_new_ui30.png"], "loadList3D": [] };
            shop.ShopBuy1UI = ShopBuy1UI;
            REG("ui.shop.ShopBuy1UI", ShopBuy1UI);
            class ShopChestUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopChestUI.uiView);
                }
            }
            ShopChestUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "skin": "ui/img_uk_ui2_uibg2.jpg", "right": -100, "left": -100, "height": 720 }, "compId": 796 }, { "type": "Box", "props": { "y": 25, "right": 60 }, "compId": 642, "child": [{ "type": "Image", "props": { "y": 8, "x": 238, "width": 244, "skin": "ui/img_uk_Icon_Tips2.png", "scaleY": 0.9, "scaleX": 0.8, "height": 38 }, "compId": 643 }, { "type": "Image", "props": { "y": 7, "x": 30, "width": 244, "skin": "ui/img_uk_Icon_Tips2.png", "scaleY": 0.9, "scaleX": 0.8, "height": 38 }, "compId": 644 }, { "type": "Image", "props": { "y": -1, "x": 207, "width": 60, "skin": "ui/img_uk_Icon_zs.png", "scaleY": 0.9, "scaleX": 0.9, "height": 60 }, "compId": 645 }, { "type": "Image", "props": { "width": 60, "skin": "ui/img_uk_Icon_jinbi.png", "scaleY": 0.8, "scaleX": 0.8, "height": 60 }, "compId": 646 }, { "type": "Label", "props": { "y": 11, "x": 55, "wordWrap": true, "width": 135, "var": "txt_tong", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 647 }, { "type": "Label", "props": { "y": 10, "x": 266, "wordWrap": true, "width": 144, "var": "txt_jin", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 648 }] }, { "type": "Box", "props": { "y": 25, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 797, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 798 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 799 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 800 }] }, { "type": "Box", "props": { "y": 167, "width": 1176, "height": 496, "centerX": 0 }, "compId": 859, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 1025, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "name": "tab_1", "height": 496, "alpha": 1 }, "compId": 801 }, { "type": "Box", "props": { "y": 57, "x": 9 }, "compId": 860, "child": [{ "type": "Box", "props": { "y": 1, "var": "box_0", "name": "tab_1" }, "compId": 802, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 246, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "51,55,60,59", "height": 379, "alpha": 0.5 }, "compId": 806 }, { "type": "Image", "props": { "y": 80, "x": 35, "skin": "ui/img_uk_icon_gold3.png" }, "compId": 807 }, { "type": "Image", "props": { "y": 301, "x": 17, "width": 217, "skin": "ui/img_uk_ui2_btn2.png", "height": 63, "alpha": 0.7 }, "compId": 808 }, { "type": "Image", "props": { "y": 256, "x": 34.5, "width": 188, "skin": "ui/img_uk_ui2_btn4.png", "height": 42 }, "compId": 809 }, { "type": "Box", "props": { "y": 311, "x": 25, "width": 200 }, "compId": 810, "child": [{ "type": "Label", "props": { "y": 3, "x": 21, "wordWrap": true, "width": 158, "var": "txt_price1", "valign": "middle", "text": "价格：5000", "strokeColor": "#212121", "stroke": 4, "name": "txt_price1", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 811 }, { "type": "Image", "props": { "y": 1, "x": 146, "width": 37, "skin": "ui/img_uk_Icon_zs.png", "height": 37 }, "compId": 812 }] }, { "type": "Label", "props": { "y": 256, "x": 35, "wordWrap": true, "width": 146, "var": "txt_getNum1", "valign": "middle", "text": "2000", "strokeColor": "#212121", "stroke": 4, "name": "txt_getNum1", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 813 }, { "type": "Image", "props": { "y": 259, "x": 135, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 814 }, { "type": "Label", "props": { "y": 30, "x": 51, "wordWrap": true, "width": 143, "valign": "middle", "text": "一堆金币", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 815 }, { "type": "Label", "props": { "y": 381, "x": 51, "wordWrap": true, "width": 143, "var": "txt_num1", "valign": "middle", "text": "剩余次数：1", "strokeColor": "#212121", "stroke": 0, "name": "txt_num1", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 816 }] }, { "type": "Box", "props": { "x": 251, "var": "box_1", "name": "tab_1" }, "compId": 803, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 246, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "51,55,60,59", "height": 379, "alpha": 0.5 }, "compId": 817 }, { "type": "Image", "props": { "y": 79, "x": 35, "skin": "ui/img_uk_icon_gold4.png" }, "compId": 818 }, { "type": "Image", "props": { "y": 300, "x": 17, "width": 217, "skin": "ui/img_uk_ui2_btn2.png", "height": 63, "alpha": 0.7 }, "compId": 819 }, { "type": "Image", "props": { "y": 256, "x": 34.5, "width": 188, "skin": "ui/img_uk_ui2_btn4.png", "height": 42 }, "compId": 820 }, { "type": "Box", "props": { "y": 311, "x": 26, "width": 200, "var": "btn_get2", "name": "btn_get2", "height": 42 }, "compId": 821, "child": [{ "type": "Label", "props": { "y": 3, "x": 21, "wordWrap": true, "width": 158, "valign": "middle", "text": "价格：2000", "strokeColor": "#212121", "stroke": 4, "name": "txt_price1", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 822 }, { "type": "Image", "props": { "y": 0, "x": 149, "width": 37, "skin": "ui/img_uk_Icon_zs.png", "height": 37 }, "compId": 823 }] }, { "type": "Label", "props": { "y": 255, "x": 35, "wordWrap": true, "width": 146, "var": "txt_getNum2", "valign": "middle", "text": "10000", "strokeColor": "#212121", "stroke": 4, "name": "txt_getNum2", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 824 }, { "type": "Image", "props": { "y": 258, "x": 135, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 825 }, { "type": "Label", "props": { "y": 29, "x": 51, "wordWrap": true, "width": 143, "valign": "middle", "text": "金币宝箱", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 826 }, { "type": "Label", "props": { "y": 380, "x": 51, "wordWrap": true, "width": 143, "var": "txt_num2", "valign": "middle", "text": "剩余次数：1", "strokeColor": "#212121", "stroke": 0, "name": "txt_num2", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 827 }] }, { "type": "Box", "props": { "x": 503, "var": "box_2", "name": "tab_1" }, "compId": 804, "child": [{ "type": "Image", "props": { "width": 246, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "51,55,60,59", "height": 379, "alpha": 0.5 }, "compId": 828 }, { "type": "Image", "props": { "y": 79, "x": 35, "skin": "ui/img_uk_icon_gold7.png" }, "compId": 829 }, { "type": "Image", "props": { "y": 300, "x": 17, "width": 217, "skin": "ui/img_uk_ui2_btn2.png", "height": 63, "alpha": 0.7 }, "compId": 830 }, { "type": "Image", "props": { "y": 255, "x": 34.5, "width": 188, "skin": "ui/img_uk_ui2_btn4.png", "height": 42 }, "compId": 831 }, { "type": "Label", "props": { "y": 255, "x": 35, "wordWrap": true, "width": 146, "var": "txt_getNum3", "valign": "middle", "text": "2000", "strokeColor": "#212121", "stroke": 4, "name": "txt_getNum3", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 832 }, { "type": "Image", "props": { "y": 258, "x": 135, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 833 }, { "type": "Label", "props": { "y": 29, "x": 51, "wordWrap": true, "width": 143, "valign": "middle", "text": "金币红包", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 834 }, { "type": "Box", "props": { "y": 308, "x": 41 }, "compId": 835, "child": [{ "type": "Label", "props": { "y": 5, "x": 41, "wordWrap": true, "width": 123, "valign": "middle", "text": "立即领取", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 837 }, { "type": "Image", "props": { "y": 7.5, "x": 7, "width": 40, "var": "img_ad", "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 868 }] }, { "type": "Label", "props": { "y": 380, "x": 51, "wordWrap": true, "width": 143, "var": "txt_num3", "valign": "middle", "text": "剩余次数：1", "strokeColor": "#212121", "stroke": 0, "name": "txt_num3", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 838 }] }, { "type": "Box", "props": { "x": 754, "var": "box_3", "name": "tab_1" }, "compId": 805, "child": [{ "type": "Image", "props": { "width": 246, "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "51,55,60,59", "height": 379, "alpha": 0.5 }, "compId": 839 }, { "type": "Image", "props": { "y": 79, "x": 35, "skin": "ui/img_uk_icon_gold8.png" }, "compId": 840 }, { "type": "Image", "props": { "y": 300, "x": 17, "width": 217, "skin": "ui/img_uk_ui2_btn2.png", "height": 63, "alpha": 0.7 }, "compId": 841 }, { "type": "Image", "props": { "y": 255, "x": 34.5, "width": 188, "skin": "ui/img_uk_ui2_btn4.png", "height": 42 }, "compId": 842 }, { "type": "Label", "props": { "y": 255, "x": 35, "wordWrap": true, "width": 146, "var": "txt_getNum4", "valign": "middle", "text": "5000", "strokeColor": "#212121", "stroke": 4, "name": "txt_getNum4", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 843 }, { "type": "Image", "props": { "y": 258, "x": 135, "width": 30, "skin": "ui/img_uk_Icon_jinbi.png", "height": 30 }, "compId": 844 }, { "type": "Label", "props": { "y": 29, "x": 51, "wordWrap": true, "width": 143, "valign": "middle", "text": "金币福袋", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 845 }, { "type": "Box", "props": { "y": 308.5, "x": 47.5 }, "compId": 846, "child": [{ "type": "Label", "props": { "y": 5, "x": 41, "wordWrap": true, "width": 123, "valign": "middle", "text": "立即领取", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 848 }, { "type": "Image", "props": { "y": 7.5, "x": 7, "width": 40, "skin": "ui/img_uk_ui2_guanggao3.png", "name": "img_ad", "height": 30 }, "compId": 869 }] }, { "type": "Label", "props": { "y": 380, "x": 51, "wordWrap": true, "width": 143, "var": "txt_num4", "valign": "middle", "text": "剩余次数：1", "strokeColor": "#212121", "stroke": 0, "name": "txt_num4", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 849 }] }] }, { "type": "Box", "props": { "y": 12, "x": 1029 }, "compId": 861, "child": [{ "type": "Button", "props": { "y": 0, "x": 0, "width": 145, "var": "item0", "stateNum": 2, "skin": "ui/btn_uk_ui2_btn7.png", "selected": false, "name": "item0", "labelSize": 24, "labelFont": "SimHei", "labelColors": "#fff,#ff0,#fff,#fff,", "labelBold": true, "label": "军备箱", "height": 80 }, "compId": 857 }, { "type": "Button", "props": { "y": 81, "width": 145, "var": "item1", "stateNum": 2, "skin": "ui/btn_uk_ui2_btn7.png", "selected": true, "name": "item1", "labelSize": 24, "labelFont": "SimHei", "labelColors": "#fff,#ff0,#fff,#fff,", "labelBold": true, "label": "限时特惠", "height": 80 }, "compId": 858 }, { "type": "Button", "props": { "y": 162, "x": 0, "width": 145, "visible": true, "var": "item2", "stateNum": 2, "skin": "ui/btn_uk_ui2_btn7.png", "selected": false, "name": "item2", "labelSize": 24, "labelFont": "SimHei", "labelColors": "#fff,#ff0,#fff,#fff,", "labelBold": true, "label": "极品装备", "height": 80 }, "compId": 874 }] }, { "type": "Box", "props": { "y": 265, "x": 1013, "var": "box_free", "name": "box_free" }, "compId": 867, "child": [{ "type": "GoodsFreeBox", "props": { "mouseEnabled": true, "runtime": "ui.goods.GoodsFreeBoxUI" }, "compId": 866 }] }] }], "loadList": ["ui/img_uk_ui2_uibg2.jpg", "ui/img_uk_Icon_Tips2.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_obj17.png", "ui/img_uk_icon_gold3.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_ui2_btn4.png", "ui/img_uk_icon_gold4.png", "ui/img_uk_icon_gold7.png", "ui/img_uk_ui2_guanggao3.png", "ui/img_uk_icon_gold8.png", "ui/btn_uk_ui2_btn7.png"], "loadList3D": [] };
            shop.ShopChestUI = ShopChestUI;
            REG("ui.shop.ShopChestUI", ShopChestUI);
            class ShopItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopItem1UI.uiView);
                }
            }
            ShopItem1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 336, "mouseThrough": false, "height": 500 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": -2, "width": 304, "skin": "ui/img_UM_shop_ui_bg8.png", "sizeGrid": "109,60,161,84", "height": 498 }, "compId": 1406 }, { "type": "Image", "props": { "y": 407, "x": 188, "width": 228, "var": "img_buy", "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 152, "name": "img_buy", "mouseEnabled": true, "height": 110 }, "compId": 1414 }, { "type": "Image", "props": { "y": 231, "x": 150, "width": 366, "skin": "ui/img_UM_effect_blue.png", "pivotY": 183, "pivotX": 183, "height": 366, "blendMode": "lighter" }, "compId": 1424 }, { "type": "Image", "props": { "y": 133, "x": 50, "width": 200, "skin": "ui/img_UM_box_box1.png", "height": 200 }, "compId": 1416 }, { "type": "Image", "props": { "y": 34, "x": 60, "skin": "ui/img_UM_ui_text27.png" }, "compId": 1422 }, { "type": "Box", "props": { "y": 375, "x": 135, "var": "box_price", "name": "box_price" }, "compId": 1428, "child": [{ "type": "Image", "props": { "skin": "ui/img_UM_num_100.png" }, "compId": 1425 }, { "type": "Image", "props": { "y": 7, "x": -65, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1427 }] }, { "type": "Image", "props": { "y": 377, "x": 103, "width": 94, "var": "img_free", "skin": "ui/img_UM_ui_text26.png", "name": "img_free", "height": 48 }, "compId": 1415 }, { "type": "Label", "props": { "y": 106, "x": 23, "wordWrap": false, "width": 255, "visible": true, "valign": "middle", "text": "普通英雄，稀有英雄", "strokeColor": "#000000", "stroke": 3, "height": 27, "fontSize": 23, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "center" }, "compId": 1429 }], "animations": [{ "nodes": [{ "target": 1424, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_shop_ui_bg8.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_effect_blue.png", "ui/img_UM_box_box1.png", "ui/img_UM_ui_text27.png", "ui/img_UM_num_100.png", "ui/img_UM_Diamond.png", "ui/img_UM_ui_text26.png"], "loadList3D": [] };
            shop.ShopItem1UI = ShopItem1UI;
            REG("ui.shop.ShopItem1UI", ShopItem1UI);
            class ShopItem2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopItem2UI.uiView);
                }
            }
            ShopItem2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 336, "mouseThrough": false, "height": 500 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": -2, "width": 304, "skin": "ui/img_UM_shop_ui_bg3.png", "sizeGrid": "109,60,161,84", "height": 498 }, "compId": 1406 }, { "type": "Image", "props": { "y": 407, "x": 150, "width": 228, "var": "img_buy2", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "name": "img_buy2", "mouseEnabled": true, "height": 110 }, "compId": 1414, "child": [{ "type": "Image", "props": { "y": 20, "x": 28, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1428 }, { "type": "Image", "props": { "y": 13, "x": 90, "width": 111, "skin": "ui/img_UM_num_200.png", "height": 64 }, "compId": 1426 }] }, { "type": "Image", "props": { "y": 231, "x": 150, "width": 366, "skin": "ui/img_UM_effect_gold.png", "pivotY": 183, "pivotX": 183, "height": 366, "blendMode": "lighter" }, "compId": 1424 }, { "type": "Image", "props": { "y": 133, "x": 50, "width": 200, "skin": "ui/img_UM_box_box3.png", "height": 200 }, "compId": 1416 }, { "type": "Image", "props": { "y": 34, "x": 60, "skin": "ui/img_UM_ui_text28.png" }, "compId": 1422 }, { "type": "Label", "props": { "y": 106, "x": 23, "wordWrap": false, "width": 255, "visible": true, "valign": "middle", "text": "稀有英雄，史诗英雄", "strokeColor": "#000000", "stroke": 3, "height": 27, "fontSize": 23, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "center" }, "compId": 1429 }], "animations": [{ "nodes": [{ "target": 1424, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_shop_ui_bg3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_Diamond.png", "ui/img_UM_num_200.png", "ui/img_UM_effect_gold.png", "ui/img_UM_box_box3.png", "ui/img_UM_ui_text28.png"], "loadList3D": [] };
            shop.ShopItem2UI = ShopItem2UI;
            REG("ui.shop.ShopItem2UI", ShopItem2UI);
            class ShopItem3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopItem3UI.uiView);
                }
            }
            ShopItem3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 336, "mouseThrough": false, "height": 500 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": -2, "width": 304, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "109,60,161,84", "height": 498 }, "compId": 1406 }, { "type": "Image", "props": { "y": 351, "x": 36, "width": 228, "var": "img_buy1", "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "name": "img_buy1", "mouseEnabled": true, "height": 110 }, "compId": 1414, "child": [{ "type": "Image", "props": { "y": 24, "x": 29, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1433 }, { "type": "Image", "props": { "y": 17, "x": 93, "skin": "ui/img_UM_num_500.png" }, "compId": 1431 }] }, { "type": "Image", "props": { "y": 231, "x": 150, "width": 366, "skin": "ui/img_UM_effect_blue.png", "pivotY": 183, "pivotX": 183, "height": 366, "blendMode": "lighter" }, "compId": 1424 }, { "type": "Image", "props": { "y": 133, "x": 50, "width": 200, "skin": "ui/img_UM_box_box4.png", "height": 200 }, "compId": 1416 }, { "type": "Image", "props": { "y": 34, "x": 60, "skin": "ui/img_UM_ui_text29.png" }, "compId": 1422 }, { "type": "Image", "props": { "y": 150, "x": 73, "width": 100, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 100, "blendMode": "lighter", "alpha": 0 }, "compId": 1426 }, { "type": "Image", "props": { "y": 189, "x": 258, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter" }, "compId": 1427 }, { "type": "Image", "props": { "y": 263, "x": 131, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter" }, "compId": 1428 }, { "type": "Image", "props": { "y": 351, "x": 281, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter", "alpha": 0 }, "compId": 1429 }, { "type": "Image", "props": { "y": 330, "x": 81, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter", "alpha": 0.5 }, "compId": 1430 }, { "type": "Label", "props": { "y": 106, "x": 22.5, "wordWrap": false, "width": 255, "visible": true, "valign": "middle", "text": "大量稀有英雄，史诗英雄", "strokeColor": "#000000", "stroke": 3, "height": 27, "fontSize": 23, "font": "SimHei", "color": "#f6ff2c", "bold": true, "align": "center" }, "compId": 1434 }], "animations": [{ "nodes": [{ "target": 1424, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "label": null, "key": "alpha", "index": 10 }] } }, { "target": 1426, "keyframes": { "y": [{ "value": 150, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "y", "index": 0 }, { "value": 151, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "y", "index": 5 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "alpha", "index": 10 }] } }, { "target": 1429, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 5 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 10 }] } }, { "target": 1427, "keyframes": { "y": [{ "value": 189, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "y", "index": 0 }, { "value": 190, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "y", "index": 5 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "alpha", "index": 10 }] } }, { "target": 1428, "keyframes": { "y": [{ "value": 263, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "y", "index": 0 }, { "value": 263, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "y", "index": 5 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "alpha", "index": 0 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "alpha", "index": 10 }] } }, { "target": 1430, "keyframes": { "alpha": [{ "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1430, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1430, "key": "alpha", "index": 5 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1430, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_shop_ui_bg2.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_Diamond.png", "ui/img_UM_num_500.png", "ui/img_UM_effect_blue.png", "ui/img_UM_box_box4.png", "ui/img_UM_ui_text29.png", "ui/img_UM_effect_star.png"], "loadList3D": [] };
            shop.ShopItem3UI = ShopItem3UI;
            REG("ui.shop.ShopItem3UI", ShopItem3UI);
            class ShopItem4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopItem4UI.uiView);
                }
            }
            ShopItem4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 588, "mouseThrough": false, "height": 500 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 4, "x": -12, "width": 608, "skin": "ui/img_UM_shop_ui_bg4.png", "sizeGrid": "109,60,161,84", "height": 496 }, "compId": 1430 }, { "type": "Box", "props": { "y": 95, "x": 15, "width": 171, "height": 192 }, "compId": 1431, "child": [{ "type": "Image", "props": { "y": 22, "x": 1, "width": 170, "skin": "ui/img_UM_shop_ui_bg5.png", "sizeGrid": "27,48,79,45", "height": 170 }, "compId": 1432 }, { "type": "Image", "props": { "y": -15, "x": 13, "width": 154, "skin": "ui/img_UM_box_gold.png", "height": 154 }, "compId": 1433 }] }, { "type": "Image", "props": { "y": 35, "x": 209, "skin": "ui/img_UM_ui_text30.png" }, "compId": 1434 }, { "type": "Image", "props": { "y": 296, "x": 18, "width": 170, "var": "img_bg3", "skin": "ui/img_UM_shop_ui_bg7.png", "sizeGrid": "27,48,79,45", "name": "img_bg3", "height": 170 }, "compId": 1436 }, { "type": "Image", "props": { "y": 117, "x": 198, "width": 170, "var": "img_bg1", "skin": "ui/img_UM_shop_ui_bg5.png", "sizeGrid": "27,48,79,45", "name": "img_bg1", "height": 170 }, "compId": 1440 }, { "type": "Image", "props": { "y": 296, "x": 198, "width": 170, "var": "img_bg4", "skin": "ui/img_UM_shop_ui_bg7.png", "sizeGrid": "27,48,79,45", "name": "img_bg4", "height": 170 }, "compId": 1444 }, { "type": "Image", "props": { "y": 117, "x": 375, "width": 170, "var": "img_bg2", "skin": "ui/img_UM_shop_ui_bg5.png", "sizeGrid": "27,48,79,45", "name": "img_bg2", "height": 170 }, "compId": 1448 }, { "type": "Image", "props": { "y": 296, "x": 375, "width": 170, "var": "img_bg5", "skin": "ui/img_UM_shop_ui_bg6.png", "sizeGrid": "27,48,79,45", "name": "img_bg5", "height": 170 }, "compId": 1452 }, { "type": "Box", "props": { "y": 392, "x": 35, "width": 224, "var": "box_buy6", "scaleY": 0.6, "scaleX": 0.6, "name": "box_buy6", "mouseEnabled": true, "height": 105 }, "compId": 1458, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1459 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_300.png" }, "compId": 1460 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1462 }] }, { "type": "Box", "props": { "y": 392, "x": 216, "width": 224, "var": "box_buy7", "scaleY": 0.6, "scaleX": 0.6, "name": "box_buy7", "mouseEnabled": true, "height": 105 }, "compId": 1463, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1464 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_300.png" }, "compId": 1465 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1467 }] }, { "type": "Box", "props": { "y": 391, "x": 392, "width": 224, "var": "box_buy8", "scaleY": 0.6, "scaleX": 0.6, "name": "box_buy8", "mouseEnabled": true, "height": 105 }, "compId": 1468, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1469 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_300.png" }, "compId": 1470 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1472 }] }, { "type": "Box", "props": { "y": 212, "x": 216, "width": 224, "var": "box_buy4", "scaleY": 0.6, "scaleX": 0.6, "name": "box_buy4", "mouseEnabled": true, "height": 105 }, "compId": 1473, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1474 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_300.png" }, "compId": 1475 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1477 }] }, { "type": "Box", "props": { "y": 212, "x": 392, "width": 224, "var": "box_buy5", "scaleY": 0.6, "scaleX": 0.6, "name": "box_buy5", "mouseEnabled": true, "height": 105 }, "compId": 1478, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1479 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_300.png" }, "compId": 1480 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1482 }] }, { "type": "Image", "props": { "y": 247, "x": 124, "width": 228, "var": "img_buy3", "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "27,30,40,37", "scaleY": 0.6, "scaleX": 0.6, "pivotY": 55, "pivotX": 152, "name": "img_buy3", "mouseEnabled": true, "height": 110 }, "compId": 1456 }, { "type": "Image", "props": { "y": 229, "x": 73, "width": 94, "var": "img_free", "skin": "ui/img_UM_ui_text26.png", "scaleY": 0.6, "scaleX": 0.6, "name": "img_free", "height": 48 }, "compId": 1457 }, { "type": "Box", "props": { "y": 209, "x": 57, "width": 107, "var": "box_price", "name": "box_price", "height": 64 }, "compId": 1483, "child": [{ "type": "Image", "props": { "y": 14, "x": 29, "width": 111, "skin": "ui/img_UM_num_100.png", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1484 }, { "type": "Image", "props": { "y": 19, "x": -10, "width": 54, "skin": "ui/img_UM_Diamond.png", "scaleY": 0.6, "scaleX": 0.6, "height": 54 }, "compId": 1485 }] }, { "type": "Image", "props": { "y": 290, "x": 52, "var": "img_card3", "skin": "ui/img_UM_playerhead2.png", "name": "img_card3" }, "compId": 1437 }, { "type": "Image", "props": { "y": 112, "x": 232, "var": "img_card1", "skin": "ui/img_UM_playerhead2.png", "name": "img_card1" }, "compId": 1441 }, { "type": "Image", "props": { "y": 291, "x": 232, "var": "img_card4", "skin": "ui/img_UM_playerhead2.png", "name": "img_card4" }, "compId": 1445 }, { "type": "Image", "props": { "y": 112, "x": 409, "var": "img_card2", "skin": "ui/img_UM_playerhead2.png", "name": "img_card2" }, "compId": 1449 }, { "type": "Image", "props": { "y": 290, "x": 409, "var": "img_card5", "skin": "ui/img_UM_playerhead2.png", "name": "img_card5" }, "compId": 1454 }, { "type": "Image", "props": { "y": 349, "x": 496, "width": 40, "var": "img_num5", "skin": "ui/img_UM_num_5.png", "name": "img_num5", "height": 42 }, "compId": 1455 }, { "type": "Image", "props": { "y": 170, "x": 481, "width": 40, "var": "img_num2", "skin": "ui/img_UM_num_40.png", "name": "img_num2", "height": 42 }, "compId": 1450 }, { "type": "Image", "props": { "y": 349, "x": 317, "width": 40, "var": "img_num4", "skin": "ui/img_UM_num_5.png", "name": "img_num4", "height": 42 }, "compId": 1446 }, { "type": "Image", "props": { "y": 170, "x": 319, "width": 40, "var": "img_num1", "skin": "ui/img_UM_num_2.png", "name": "img_num1", "height": 42 }, "compId": 1442 }, { "type": "Image", "props": { "y": 349, "x": 139, "width": 40, "var": "img_num3", "skin": "ui/img_UM_num_5.png", "name": "img_num3", "height": 42 }, "compId": 1438 }], "loadList": ["ui/img_UM_shop_ui_bg4.png", "ui/img_UM_shop_ui_bg5.png", "ui/img_UM_box_gold.png", "ui/img_UM_ui_text30.png", "ui/img_UM_shop_ui_bg7.png", "ui/img_UM_shop_ui_bg6.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_num_300.png", "ui/img_UM_Diamond.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text26.png", "ui/img_UM_num_100.png", "ui/img_UM_playerhead2.png", "ui/img_UM_num_5.png", "ui/img_UM_num_40.png", "ui/img_UM_num_2.png"], "loadList3D": [] };
            shop.ShopItem4UI = ShopItem4UI;
            REG("ui.shop.ShopItem4UI", ShopItem4UI);
            class ShopMallUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopMallUI.uiView);
                }
            }
            ShopMallUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "skin": "ui/img_UM_ui_bg7.jpg", "right": -100, "left": -100 }, "compId": 1579 }, { "type": "Box", "props": { "y": 28, "x": 38, "var": "box_close", "name": "box_close" }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Panel", "props": { "y": 156, "width": 1268, "var": "panel_list", "name": "panel_list", "height": 527, "hScrollBarSkin": "comp/hscroll.png", "elasticEnabled": true, "centerX": 0 }, "compId": 1693, "child": [{ "type": "Box", "props": { "y": 0, "x": 11, "width": 1744, "var": "box_list", "name": "box_list", "height": 500 }, "compId": 1694, "child": [{ "type": "ShopItem1", "props": { "y": 0, "x": 0, "width": 336, "var": "item_tong", "name": "item_tong", "height": 500, "runtime": "ui.shop.ShopItem1UI" }, "compId": 1695 }, { "type": "ShopItem2", "props": { "y": 0, "x": 295, "width": 336, "var": "item_gold", "name": "item_gold", "height": 500, "runtime": "ui.shop.ShopItem2UI" }, "compId": 1696 }, { "type": "ShopItem3", "props": { "y": 0, "x": 595, "width": 336, "var": "item_jin", "name": "item_jin", "height": 500, "runtime": "ui.shop.ShopItem3UI" }, "compId": 1697 }, { "type": "ShopItem4", "props": { "y": 0, "x": 908, "width": 588, "var": "item_preferential", "name": "item_preferential", "height": 500, "runtime": "ui.shop.ShopItem4UI" }, "compId": 1698 }] }] }, { "type": "Box", "props": { "y": 28, "right": 260 }, "compId": 1753, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1755 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 1756 }, { "type": "Image", "props": { "y": 7, "x": 163, "var": "img_tong", "skin": "ui/img_UM_btn__btn_2.png", "name": "img_tong", "mouseThrough": false, "mouseEnabled": true }, "compId": 1757 }, { "type": "Label", "props": { "y": 15, "x": 64, "wordWrap": true, "width": 108, "var": "txt_tong", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1758 }] }, { "type": "Box", "props": { "y": 28, "right": 20 }, "compId": 1754, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1759 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 1760 }, { "type": "Image", "props": { "y": 7, "x": 163, "var": "img_jin", "skin": "ui/img_UM_btn__btn_2.png", "name": "img_jin", "mouseThrough": false, "mouseEnabled": true }, "compId": 1761 }, { "type": "Label", "props": { "y": 15, "x": 65, "wordWrap": true, "width": 108, "var": "txt_jin", "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 48, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1762 }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "comp/hscroll.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_gold.png", "ui/img_UM_btn__btn_2.png", "ui/img_UM_Diamond.png"], "loadList3D": [] };
            shop.ShopMallUI = ShopMallUI;
            REG("ui.shop.ShopMallUI", ShopMallUI);
            class ShopMedalUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopMedalUI.uiView);
                }
            }
            ShopMedalUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -1, "skin": "ui/img_uk_ui2_uibg2.jpg", "right": -100, "left": -100, "height": 720 }, "compId": 796 }, { "type": "Box", "props": { "y": 24, "right": 60 }, "compId": 642, "child": [{ "type": "Image", "props": { "y": 8, "x": 458, "width": 244, "skin": "ui/img_uk_Icon_Tips2.png", "scaleY": 0.9, "scaleX": 0.8, "height": 38 }, "compId": 643 }, { "type": "Image", "props": { "y": 7, "x": 250, "width": 244, "skin": "ui/img_uk_Icon_Tips2.png", "scaleY": 0.9, "scaleX": 0.8, "height": 38 }, "compId": 644 }, { "type": "Image", "props": { "y": -1, "x": 427, "width": 60, "skin": "ui/img_uk_Icon_zs.png", "scaleY": 0.9, "scaleX": 0.9, "height": 60 }, "compId": 645 }, { "type": "Image", "props": { "x": 220, "width": 60, "skin": "ui/img_uk_Icon_jinbi.png", "scaleY": 0.8, "scaleX": 0.8, "height": 60 }, "compId": 646 }, { "type": "Label", "props": { "y": 11, "x": 275, "wordWrap": true, "width": 135, "var": "txt_tong", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 647 }, { "type": "Image", "props": { "y": 7, "x": 22, "width": 244, "visible": true, "skin": "ui/img_uk_Icon_Tips2.png", "scaleY": 0.9, "scaleX": 0.8, "height": 38 }, "compId": 903 }, { "type": "Label", "props": { "y": 10, "x": 486, "wordWrap": true, "width": 144, "var": "txt_jin", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 648 }, { "type": "Image", "props": { "y": -5, "x": 0, "width": 65, "visible": true, "skin": "ui/img_uk_icon_xz.png", "scaleY": 0.9, "scaleX": 0.9, "height": 65 }, "compId": 899 }, { "type": "Label", "props": { "y": 11, "x": 62, "wordWrap": true, "width": 144, "visible": true, "var": "txt_modal", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_modal", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 900 }, { "type": "Image", "props": { "y": 6, "x": 170, "visible": false, "var": "img_jia", "skin": "ui/img_uk_ui2_jiahao.png", "name": "img_jia" }, "compId": 901 }] }, { "type": "Box", "props": { "y": 24, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 797, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 798 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 799 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 800 }] }, { "type": "Box", "props": { "y": 166, "width": 1176, "height": 496, "centerX": 0 }, "compId": 859, "child": [{ "type": "Image", "props": { "y": 0, "x": 1, "width": 1025, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "name": "tab_1", "height": 496, "alpha": 1 }, "compId": 801 }, { "type": "Box", "props": { "y": 12, "x": 1029 }, "compId": 861, "child": [{ "type": "Button", "props": { "y": 0, "x": 0, "width": 145, "var": "item0", "stateNum": 2, "skin": "ui/btn_uk_ui2_btn7.png", "selected": false, "name": "item0", "labelSize": 24, "labelFont": "SimHei", "labelColors": "#fff,#ff0,#fff,#fff,", "labelBold": true, "label": "军备箱", "height": 80 }, "compId": 857 }, { "type": "Button", "props": { "y": 163, "x": 0, "width": 145, "visible": true, "var": "item1", "stateNum": 2, "skin": "ui/btn_uk_ui2_btn7.png", "selected": true, "name": "item1", "labelSize": 24, "labelFont": "SimHei", "labelColors": "#fff,#ff0,#fff,#fff,", "labelBold": true, "label": "极品装备", "height": 80 }, "compId": 858 }, { "type": "Button", "props": { "y": 81, "x": 0, "width": 145, "var": "item2", "stateNum": 2, "skin": "ui/btn_uk_ui2_btn7.png", "selected": false, "name": "item2", "labelSize": 24, "labelFont": "SimHei", "labelColors": "#fff,#ff0,#fff,#fff,", "labelBold": true, "label": "限时特惠", "height": 80 }, "compId": 871 }] }, { "type": "Box", "props": { "y": 265, "x": 1013, "var": "box_free", "name": "box_free" }, "compId": 867, "child": [{ "type": "GoodsFreeBox", "props": { "mouseEnabled": true, "runtime": "ui.goods.GoodsFreeBoxUI" }, "compId": 866 }] }, { "type": "List", "props": { "y": 74, "x": 14, "width": 999, "var": "list_item", "vScrollBarSkin": "comp/vscroll.png", "selectEnable": true, "name": "list_item", "height": 384, "elasticEnabled": true }, "compId": 893, "child": [{ "type": "ShopMedalItem", "props": { "renderType": "render", "runtime": "ui.shop.ShopMedalItemUI" }, "compId": 898 }] }] }], "loadList": ["ui/img_uk_ui2_uibg2.jpg", "ui/img_uk_Icon_Tips2.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_icon_xz.png", "ui/img_uk_ui2_jiahao.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png", "ui/img_uk_ui2_obj5.png", "ui/btn_uk_ui2_btn7.png", "comp/vscroll.png"], "loadList3D": [] };
            shop.ShopMedalUI = ShopMedalUI;
            REG("ui.shop.ShopMedalUI", ShopMedalUI);
            class ShopMedalBuyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopMedalBuyUI.uiView);
                }
            }
            ShopMedalBuyUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": false, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": -22, "x": -130, "width": 1539, "visible": true, "var": "box_title", "name": "box_title", "height": 763 }, "compId": 784, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1539, "skin": "ui/img_uk_ui_new_ui38.png", "height": 763, "alpha": 0.5 }, "compId": 785 }, { "type": "Image", "props": { "y": 326, "x": 1301, "width": 236, "skin": "ui/img_uk_ui_new_ui38.png", "sizeGrid": "9,8,10,9", "pivotY": 111, "pivotX": 650, "height": 190, "alpha": 0.6 }, "compId": 786 }, { "type": "Box", "props": { "y": 415, "x": 470, "var": "btn_get", "name": "btn_get" }, "compId": 787, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_ui2_btn2.png", "height": 91 }, "compId": 788 }, { "type": "Label", "props": { "y": 32, "x": 29, "wordWrap": true, "width": 227, "valign": "middle", "text": "购 买", "strokeColor": "#000000", "stroke": 5, "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 789 }] }, { "type": "Box", "props": { "y": 415, "x": 771, "var": "btn_cancel", "name": "btn_cancel" }, "compId": 790, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 286, "skin": "ui/img_uk_btn_btn1.png", "height": 91 }, "compId": 791 }, { "type": "Label", "props": { "y": 32, "x": 48, "wordWrap": true, "width": 190, "valign": "middle", "text": "取 消", "strokeColor": "#000000", "stroke": 5, "fontSize": 35, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 792 }] }, { "type": "Box", "props": { "y": 147, "x": 638 }, "compId": 793, "child": [{ "type": "Image", "props": { "y": 9, "x": 0, "width": 39, "skin": "ui/img_uk_ui_new_ui39.png", "height": 39 }, "compId": 794 }, { "type": "Label", "props": { "y": 14, "x": 43, "wordWrap": true, "width": 209, "valign": "middle", "text": "是否购买以下物品？", "strokeColor": "#6c6c6c", "stroke": 5, "height": 35, "fontSize": 23, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 795 }, { "type": "Image", "props": { "y": 95, "x": 63, "var": "img_gun", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_gun" }, "compId": 805 }] }] }], "loadList": ["ui/img_uk_ui_new_ui38.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_btn_btn1.png", "ui/img_uk_ui_new_ui39.png", "ui/img_uk_icon_gunicon.png"], "loadList3D": [] };
            shop.ShopMedalBuyUI = ShopMedalBuyUI;
            REG("ui.shop.ShopMedalBuyUI", ShopMedalBuyUI);
            class ShopMedalItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopMedalItemUI.uiView);
                }
            }
            ShopMedalItemUI.uiView = { "type": "View", "props": { "width": 249, "height": 384 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 2, "x": 0, "width": 246, "var": "img_bg", "skin": "ui/img_uk_ui2_obj17.png", "sizeGrid": "51,55,60,59", "name": "img_bg", "height": 379, "alpha": 0.5 }, "compId": 10 }, { "type": "Image", "props": { "y": 302, "x": 17, "width": 217, "var": "img_buttonBg", "skin": "ui/img_uk_ui2_btn2.png", "name": "img_buttonBg", "height": 63, "alpha": 0.7 }, "compId": 11 }, { "type": "Label", "props": { "y": 315, "x": 46, "wordWrap": true, "width": 158, "var": "txt_price", "valign": "middle", "text": "价格：500", "strokeColor": "#212121", "stroke": 4, "name": "txt_price", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 13 }, { "type": "Image", "props": { "y": 313, "x": 171, "width": 40, "skin": "ui/img_uk_icon_xz.png", "height": 40 }, "compId": 14 }, { "type": "Label", "props": { "y": 31, "x": 51, "wordWrap": true, "width": 143, "var": "txt_title", "valign": "middle", "text": "GLOCK", "strokeColor": "#212121", "stroke": 4, "renderType": "render", "name": "txt_title", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 15 }, { "type": "Image", "props": { "y": 148, "x": -1, "width": 247, "skin": "ui/img_uk_ui2_btn5.png", "height": 132 }, "compId": 16 }, { "type": "Image", "props": { "y": 87, "x": 49, "var": "img_ico", "skin": "ui/img_uk_icon_gunicon.png", "name": "img_ico" }, "compId": 17 }], "loadList": ["ui/img_uk_ui2_obj17.png", "ui/img_uk_ui2_btn2.png", "ui/img_uk_icon_xz.png", "ui/img_uk_ui2_btn5.png", "ui/img_uk_icon_gunicon.png"], "loadList3D": [] };
            shop.ShopMedalItemUI = ShopMedalItemUI;
            REG("ui.shop.ShopMedalItemUI", ShopMedalItemUI);
            class ShopRollUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopRollUI.uiView);
                }
            }
            ShopRollUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -72, "skin": "ui/img_uk_ui2_uibg4.jpg", "right": -100, "left": -100 }, "compId": 748 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 0, "var": "box_scene", "name": "box_scene", "height": 0 }, "compId": 742 }, { "type": "Box", "props": { "y": 646, "x": 54, "width": 433.20000000000005, "height": 53 }, "compId": 727, "child": [{ "type": "Image", "props": { "y": 8, "x": 238, "width": 244, "skin": "ui/img_uk_Icon_Tips2.png", "scaleY": 0.9, "scaleX": 0.8, "height": 38 }, "compId": 721 }, { "type": "Image", "props": { "y": 7, "x": 30, "width": 244, "skin": "ui/img_uk_Icon_Tips2.png", "scaleY": 0.9, "scaleX": 0.8, "height": 38 }, "compId": 722 }, { "type": "Image", "props": { "y": -1, "x": 207, "width": 60, "skin": "ui/img_uk_Icon_zs.png", "scaleY": 0.9, "scaleX": 0.9, "height": 60 }, "compId": 723 }, { "type": "Image", "props": { "width": 60, "skin": "ui/img_uk_Icon_jinbi.png", "scaleY": 0.8, "scaleX": 0.8, "height": 60 }, "compId": 724 }, { "type": "Label", "props": { "y": 11, "x": 55, "wordWrap": true, "width": 150, "var": "txt_tong", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 725 }, { "type": "Label", "props": { "y": 10, "x": 266, "wordWrap": true, "width": 166, "var": "txt_jin", "text": "500", "strokeColor": "#000000", "stroke": 4, "name": "txt_jin", "height": 35, "fontSize": 28, "font": "Arial", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 726 }] }, { "type": "Box", "props": { "y": 25, "x": 41, "var": "btn_close", "name": "btn_close" }, "compId": 744, "child": [{ "type": "Image", "props": { "width": 91, "skin": "ui/img_uk_ui2_obj4.png", "height": 95 }, "compId": 745 }, { "type": "Image", "props": { "y": 26, "x": 13, "width": 67, "skin": "ui/img_uk_ui2_back.png", "height": 45 }, "compId": 746 }, { "type": "Label", "props": { "y": 17, "x": 92, "wordWrap": true, "width": 77, "valign": "middle", "text": "返回", "strokeColor": "#252534", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 747 }] }, { "type": "Box", "props": { "y": 3, "right": 0 }, "compId": 756, "child": [{ "type": "Image", "props": { "width": 715, "skin": "ui/img_uk_ui2_obj5.png", "sizeGrid": "92,99,92,94", "height": 718, "alpha": 1 }, "compId": 749 }, { "type": "Image", "props": { "y": 19, "x": 17, "width": 688, "skin": "ui/img_uk_ui2_btn3.png", "sizeGrid": "17,53,14,55", "height": 41, "alpha": 0.7 }, "compId": 750 }, { "type": "Image", "props": { "y": 20, "x": 55, "width": 39, "skin": "ui/img_uk_ui_new_ui39.png", "height": 39 }, "compId": 751 }, { "type": "Label", "props": { "y": 24, "x": 101, "wordWrap": true, "width": 282, "valign": "middle", "text": "开启有几率获得以下物品", "strokeColor": "#586e88", "stroke": 4, "height": 35, "fontSize": 23, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "left" }, "compId": 752 }, { "type": "Label", "props": { "y": 582, "x": 192, "wordWrap": true, "width": 122, "var": "txt_price", "valign": "middle", "text": "700", "strokeColor": "#6c6c6c", "stroke": 5, "name": "txt_price", "height": 35, "fontSize": 30, "font": "Microsoft YaHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 636 }, { "type": "Image", "props": { "y": 80, "x": 3, "width": 552, "skin": "ui/img_uk_ui2_obj13.png", "sizeGrid": "41,65,41,76", "height": 502, "alpha": 0.4 }, "compId": 757 }, { "type": "Image", "props": { "y": 573, "x": 321, "width": 45, "var": "img_ico", "skin": "ui/img_uk_Icon_jinbi.png", "name": "img_ico", "height": 45 }, "compId": 637 }, { "type": "Tab", "props": { "y": 67, "x": 554, "width": 147, "var": "tab_1", "selectedIndex": 0, "name": "tab_1", "height": 253 }, "compId": 734, "child": [{ "type": "Button", "props": { "y": 0, "x": 0, "width": 147, "var": "item0", "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui2_2.png", "selected": true, "name": "item0", "labelStrokeColor": "#ffffff", "labelSize": 23, "labelFont": "SimHei", "labelColors": "#fff,#fff,#fff,#fff,", "labelBold": true, "label": "黄金宝箱", "height": 83 }, "compId": 733 }, { "type": "Button", "props": { "y": 84, "x": 0, "width": 147, "var": "item1", "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui2_2.png", "name": "item1", "labelStrokeColor": "#ffffff", "labelSize": 23, "labelFont": "SimHei", "labelColors": "#fff,#fff,#fff,#fff,", "labelBold": true, "label": "白金宝箱", "height": 83 }, "compId": 732 }, { "type": "Button", "props": { "y": 166, "x": 0, "width": 147, "var": "item2", "stateNum": 2, "skin": "ui/btn_uk_ui_new_ui2_2.png", "name": "item2", "labelStrokeColor": "#ffffff", "labelSize": 23, "labelFont": "SimHei", "labelColors": "#fff,#fff,#fff,#fff,", "labelBold": true, "label": "史诗宝箱", "height": 83 }, "compId": 735 }] }, { "type": "List", "props": { "y": 81, "x": 17, "width": 522, "var": "list_goods", "vScrollBarSkin": "comp/vscroll.png", "name": "list_goods", "height": 495, "elasticEnabled": true }, "compId": 740, "child": [{ "type": "GoodsItem1", "props": { "y": -3, "x": -1, "var": "item_goods", "renderType": "render", "name": "item_goods", "runtime": "ui.goods.GoodsItem1UI" }, "compId": 739 }] }, { "type": "Box", "props": { "y": 599, "x": 179, "var": "btn_roll", "name": "btn_roll" }, "compId": 753, "child": [{ "type": "Image", "props": { "y": 23, "width": 220, "skin": "ui/img_uk_ui2_btn1.png", "height": 78 }, "compId": 754 }, { "type": "Label", "props": { "y": 34, "x": 41, "wordWrap": true, "width": 139, "valign": "middle", "text": "开启一次", "strokeColor": "#275f9c", "stroke": 4, "height": 58, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 755 }] }, { "type": "Box", "props": { "y": 400, "x": 539, "var": "box_free", "name": "box_free" }, "compId": 759, "child": [{ "type": "GoodsFreeBox", "props": { "mouseEnabled": true, "runtime": "ui.goods.GoodsFreeBoxUI" }, "compId": 758 }] }] }], "loadList": ["ui/img_uk_ui2_uibg4.jpg", "ui/img_uk_Icon_Tips2.png", "ui/img_uk_Icon_zs.png", "ui/img_uk_Icon_jinbi.png", "ui/img_uk_ui2_obj4.png", "ui/img_uk_ui2_back.png", "ui/img_uk_ui2_obj5.png", "ui/img_uk_ui2_btn3.png", "ui/img_uk_ui_new_ui39.png", "ui/img_uk_ui2_obj13.png", "ui/btn_uk_ui_new_ui2_2.png", "comp/vscroll.png", "ui/img_uk_ui2_btn1.png"], "loadList3D": [] };
            shop.ShopRollUI = ShopRollUI;
            REG("ui.shop.ShopRollUI", ShopRollUI);
            class ShopRollBoxUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShopRollBoxUI.uiView);
                }
            }
            ShopRollBoxUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "top": 0, "skin": "ui/img_uk_ui2_uibg2.jpg", "right": -100, "left": -100, "bottom": 0 }, "compId": 627 }, { "type": "ShopBoxOpen", "props": { "y": 0, "x": 0, "var": "box_open", "name": "box_open", "runtime": "ui.shop.ShopBoxOpenUI" }, "compId": 695 }], "loadList": ["ui/img_uk_ui2_uibg2.jpg"], "loadList3D": [] };
            shop.ShopRollBoxUI = ShopRollBoxUI;
            REG("ui.shop.ShopRollBoxUI", ShopRollBoxUI);
        })(shop = ui.shop || (ui.shop = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var sign;
        (function (sign) {
            class SignDayUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignDayUI.uiView);
                }
            }
            SignDayUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "centerX": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 48, "x": 58, "var": "btn_close", "name": "btn_close" }, "compId": 600, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 601 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 602 }] }, { "type": "Box", "props": { "y": -1, "centerX": 0 }, "compId": 616, "child": [{ "type": "Image", "props": { "y": 66, "x": 43, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 543 }, "compId": 603 }, { "type": "Image", "props": { "y": 124, "x": 61, "width": 881, "skin": "ui/img_UM_ui_uibk2.png", "sizeGrid": "36,36,36,36", "height": 471 }, "compId": 604 }, { "type": "Box", "props": { "y": 615, "x": 253, "var": "btn_get", "name": "btn_get" }, "compId": 605, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 612 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 613 }] }, { "type": "Image", "props": { "y": 200, "x": 2, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1 }, "compId": 606 }, { "type": "Image", "props": { "y": 200, "x": 1004, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1, "scaleX": -1 }, "compId": 607 }, { "type": "Image", "props": { "x": 87, "skin": "ui/img_UM_ui_7day_tou.png" }, "compId": 608 }, { "type": "Box", "props": { "y": 615, "x": 501, "var": "btn_double", "name": "btn_double" }, "compId": 609, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 614 }, { "type": "Image", "props": { "y": 25, "x": 81, "width": 135, "skin": "ui/img_UM_ui_text46.png", "height": 40 }, "compId": 615 }, { "type": "Image", "props": { "y": 29, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 665 }] }, { "type": "Image", "props": { "y": 480, "skin": "ui/img_UM_ui_7day_bianjiao.png" }, "compId": 610 }, { "type": "Image", "props": { "y": 480, "x": 1004, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleX": -1 }, "compId": 611 }] }, { "type": "Box", "props": { "y": 134, "width": 930, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 453, "centerX": 50 }, "compId": 553, "child": [{ "type": "Box", "props": { "y": -2.5, "x": 5, "width": 167, "var": "box_1", "name": "box_1", "height": 225 }, "compId": 511, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_1", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_1", "height": 221 }, "compId": 525 }, { "type": "Label", "props": { "y": 3, "x": 1, "wordWrap": true, "width": 164, "var": "txt_day", "valign": "middle", "text": "第一天", "strokeColor": "#212121", "stroke": 4, "name": "txt_day", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 526 }, { "type": "Image", "props": { "y": 28, "x": 8, "width": 150, "skin": "ui/img_UM_jin.png", "height": 150 }, "compId": 527 }, { "type": "Box", "props": { "y": 173, "x": 1, "width": 164, "height": 37.2 }, "compId": 627, "child": [{ "type": "Image", "props": { "y": 2, "x": 12, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 618 }, { "type": "Label", "props": { "y": 1, "x": 18, "wordWrap": true, "width": 127, "valign": "middle", "text": "钻石*100", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 528 }] }, { "type": "Box", "props": { "y": 1, "x": 0, "width": 167, "var": "box_get_1", "name": "box_get_1", "height": 222 }, "compId": 557, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 167, "var": "img_mask_1", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_1", "height": 221, "alpha": 0.5 }, "compId": 556 }] }, { "type": "Image", "props": { "y": 92, "x": 12, "var": "img_reach_1", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_1" }, "compId": 617 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_1", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_1", "height": 33 }, "compId": 619 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_1", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_1", "height": 27 }, "compId": 620 }] }, { "type": "Box", "props": { "y": -2, "x": 181, "width": 172, "var": "box_2", "name": "box_2", "height": 223 }, "compId": 512, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_2", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_2", "height": 221 }, "compId": 529 }, { "type": "Image", "props": { "y": 37, "x": 11, "width": 143, "skin": "ui/img_hero1.png", "height": 133 }, "compId": 591 }, { "type": "Label", "props": { "y": 4, "x": 4, "wordWrap": true, "width": 164, "valign": "middle", "text": "第二天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 530 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_2", "name": "box_get_2", "height": 224 }, "compId": 558, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_2", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_2", "height": 221, "alpha": 0.5 }, "compId": 626 }] }, { "type": "Image", "props": { "y": 92, "x": 15, "var": "img_reach_2", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_2" }, "compId": 621 }, { "type": "Image", "props": { "y": 32.5, "x": -22, "width": 95, "var": "img_available_2", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_2", "height": 27 }, "compId": 624 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_2", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_2", "height": 33 }, "compId": 625 }, { "type": "Box", "props": { "y": 174, "x": 15 }, "compId": 664, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 622 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 135, "valign": "middle", "text": "麦卡奈特*100", "strokeColor": "#212121", "stroke": 4, "height": 34, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 593 }] }] }, { "type": "Box", "props": { "y": -2, "x": 360, "width": 172, "var": "box_3", "name": "box_3", "height": 209 }, "compId": 513, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_3", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_3", "height": 221 }, "compId": 533 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第三天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 534 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_jin.png", "height": 138 }, "compId": 535 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_3", "name": "box_get_3", "height": 209 }, "compId": 561, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_3", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_3", "height": 221, "alpha": 0.5 }, "compId": 562 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_3", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_3" }, "compId": 630 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_3", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_3", "height": 33 }, "compId": 628 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_3", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_3", "height": 27 }, "compId": 629 }, { "type": "Box", "props": { "y": 172, "x": 4 }, "compId": 632, "child": [{ "type": "Image", "props": { "y": 0, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 631 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石*300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 536 }] }] }, { "type": "Box", "props": { "y": 225, "x": 5, "width": 172, "var": "box_4", "name": "box_4", "height": 221 }, "compId": 514, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_4", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_4", "height": 221 }, "compId": 537 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第四天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 538 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_hero2.png", "height": 138 }, "compId": 539 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 635, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 634 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "杰比*200", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 540 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_4", "name": "box_get_4", "height": 209 }, "compId": 564, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_4", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_4", "height": 221, "alpha": 0.5 }, "compId": 565 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_4", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_4" }, "compId": 633 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_4", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_4", "height": 33 }, "compId": 636 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_4", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_4", "height": 27 }, "compId": 637 }] }, { "type": "Box", "props": { "y": 225, "x": 183, "width": 172, "var": "box_5", "name": "box_5", "height": 209 }, "compId": 515, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_bg_5", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_5", "height": 221 }, "compId": 640 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_jin.png", "height": 138 }, "compId": 543 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第五天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 542 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 643, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 644 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石*500", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 645 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_5", "name": "box_get_5", "height": 209 }, "compId": 567, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_5", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_5", "height": 221, "alpha": 0.5 }, "compId": 641 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_5", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_5" }, "compId": 642 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_5", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_5", "height": 33 }, "compId": 638 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_5", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_5", "height": 27 }, "compId": 639 }] }, { "type": "Box", "props": { "y": 225, "x": 360, "width": 172, "var": "box_6", "name": "box_6", "height": 209 }, "compId": 516, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_bg_6", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_6", "height": 221 }, "compId": 646 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第六天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 546 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_hero3.png", "height": 138 }, "compId": 547 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 649, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 650 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "丹*300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 651 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_6", "name": "box_get_6", "height": 209 }, "compId": 570, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_6", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_6", "height": 221, "alpha": 0.5 }, "compId": 647 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_6", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_6" }, "compId": 648 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_6", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_6", "height": 33 }, "compId": 652 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_6", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_6", "height": 27 }, "compId": 653 }] }, { "type": "Box", "props": { "y": 0, "x": 519, "width": 337, "var": "box_7", "name": "box_7", "height": 445 }, "compId": 554, "child": [{ "type": "Image", "props": { "x": 16, "width": 328, "var": "img_bg_7", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_7", "height": 444 }, "compId": 510 }, { "type": "Image", "props": { "y": -112, "x": -90, "width": 523, "skin": "ui/img_UM_effect_gold.png", "height": 593, "blendMode": "lighter", "alpha": 0.6 }, "compId": 660 }, { "type": "Image", "props": { "y": 13, "x": 18, "width": 329, "skin": "ui/img_UM_ui_botemama.png", "height": 424 }, "compId": 661 }, { "type": "Image", "props": { "y": 18, "x": 85, "skin": "ui/img_UM_ui_text_sign7.png" }, "compId": 657 }, { "type": "Box", "props": { "y": 0, "x": 19, "width": 321, "var": "box_get_7", "name": "box_get_7", "height": 441 }, "compId": 573, "child": [{ "type": "Image", "props": { "y": -1, "x": -2, "width": 325, "var": "img_mask_7", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_7", "height": 443, "alpha": 0.5 }, "compId": 658 }] }, { "type": "Image", "props": { "y": 200, "x": 108, "var": "img_reach_7", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_7" }, "compId": 659 }, { "type": "Image", "props": { "y": 317, "x": 30, "width": 301, "skin": "ui/img_UM_ui_7day_text1.png", "height": 48 }, "compId": 654 }, { "type": "Image", "props": { "y": 366, "x": 30, "width": 188, "skin": "ui/img_UM_ui_7day_text2.png", "height": 59 }, "compId": 655 }, { "type": "Image", "props": { "y": 357, "x": 216, "width": 103, "skin": "ui/img_UM_ui_7day_text3.png", "height": 66 }, "compId": 656 }, { "type": "Image", "props": { "y": 45, "x": -19, "var": "img_available_7", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_7" }, "compId": 662 }, { "type": "Image", "props": { "y": 11, "x": 303.5, "width": 31, "var": "img_state_7", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_7", "height": 33 }, "compId": 663 }] }] }], "loadList": ["ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk2.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_ui_7day_bianjiao.png", "ui/img_UM_ui_7day_tou.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_rank_jlbg3.png", "ui/img_UM_jin.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_text37.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_text47.png", "ui/img_hero1.png", "ui/img_UM_hero2.png", "ui/img_UM_hero3.png", "ui/img_UM_effect_gold.png", "ui/img_UM_ui_botemama.png", "ui/img_UM_ui_text_sign7.png", "ui/img_UM_ui_7day_text1.png", "ui/img_UM_ui_7day_text2.png", "ui/img_UM_ui_7day_text3.png"], "loadList3D": [] };
            sign.SignDayUI = SignDayUI;
            REG("ui.sign.SignDayUI", SignDayUI);
            class SignDay1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignDay1UI.uiView);
                }
            }
            SignDay1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "centerX": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 48, "x": 58, "var": "btn_close", "name": "btn_close" }, "compId": 600, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 601 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 602 }] }, { "type": "Box", "props": { "y": -1, "centerX": 0 }, "compId": 616, "child": [{ "type": "Image", "props": { "y": 66, "x": 43, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 543 }, "compId": 603 }, { "type": "Image", "props": { "y": 124, "x": 61, "width": 881, "skin": "ui/img_UM_ui_uibk2.png", "sizeGrid": "36,36,36,36", "height": 471 }, "compId": 604 }, { "type": "Box", "props": { "y": 615, "x": 253, "var": "btn_get", "name": "btn_get" }, "compId": 605, "child": [{ "type": "Label", "props": { "y": 30, "x": 43, "width": 67, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 666 }] }, { "type": "Image", "props": { "y": 200, "x": 2, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1 }, "compId": 606 }, { "type": "Image", "props": { "y": 200, "x": 1004, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1, "scaleX": -1 }, "compId": 607 }, { "type": "Image", "props": { "x": 87, "skin": "ui/img_UM_ui_7day_tou.png" }, "compId": 608 }, { "type": "Box", "props": { "y": 615, "x": 379, "var": "btn_double", "name": "btn_double" }, "compId": 609, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 614 }, { "type": "Image", "props": { "y": 25, "x": 81, "width": 135, "skin": "ui/img_UM_ui_text46.png", "height": 40 }, "compId": 615 }, { "type": "Image", "props": { "y": 29, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 665 }] }, { "type": "Image", "props": { "y": 480, "skin": "ui/img_UM_ui_7day_bianjiao.png" }, "compId": 610 }, { "type": "Image", "props": { "y": 480, "x": 1004, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleX": -1 }, "compId": 611 }] }, { "type": "Box", "props": { "y": 134, "width": 930, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 453, "centerX": 50 }, "compId": 553, "child": [{ "type": "Box", "props": { "y": -2.5, "x": 5, "width": 167, "var": "box_1", "name": "box_1", "height": 225 }, "compId": 511, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_1", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_1", "height": 221 }, "compId": 525 }, { "type": "Label", "props": { "y": 3, "x": 1, "wordWrap": true, "width": 164, "var": "txt_day", "valign": "middle", "text": "第一天", "strokeColor": "#212121", "stroke": 4, "name": "txt_day", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 526 }, { "type": "Image", "props": { "y": 28, "x": 8, "width": 150, "skin": "ui/img_UM_jin.png", "height": 150 }, "compId": 527 }, { "type": "Box", "props": { "y": 173, "x": 1, "width": 164, "height": 37.2 }, "compId": 627, "child": [{ "type": "Image", "props": { "y": 2, "x": 12, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 618 }, { "type": "Label", "props": { "y": 1, "x": 18, "wordWrap": true, "width": 127, "valign": "middle", "text": "钻石*100", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 528 }] }, { "type": "Box", "props": { "y": 1, "x": 0, "width": 167, "var": "box_get_1", "name": "box_get_1", "height": 222 }, "compId": 557, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 167, "var": "img_mask_1", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_1", "height": 221, "alpha": 0.5 }, "compId": 556 }] }, { "type": "Image", "props": { "y": 92, "x": 12, "var": "img_reach_1", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_1" }, "compId": 617 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_1", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_1", "height": 33 }, "compId": 619 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_1", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_1", "height": 27 }, "compId": 620 }] }, { "type": "Box", "props": { "y": -2, "x": 181, "width": 172, "var": "box_2", "name": "box_2", "height": 223 }, "compId": 512, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_2", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_2", "height": 221 }, "compId": 529 }, { "type": "Image", "props": { "y": 37, "x": 11, "width": 143, "skin": "ui/img_hero1.png", "height": 133 }, "compId": 591 }, { "type": "Label", "props": { "y": 4, "x": 4, "wordWrap": true, "width": 164, "valign": "middle", "text": "第二天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 530 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_2", "name": "box_get_2", "height": 224 }, "compId": 558, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_2", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_2", "height": 221, "alpha": 0.5 }, "compId": 626 }] }, { "type": "Image", "props": { "y": 92, "x": 15, "var": "img_reach_2", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_2" }, "compId": 621 }, { "type": "Image", "props": { "y": 32.5, "x": -22, "width": 95, "var": "img_available_2", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_2", "height": 27 }, "compId": 624 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_2", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_2", "height": 33 }, "compId": 625 }, { "type": "Box", "props": { "y": 174, "x": 15 }, "compId": 664, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 622 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 135, "valign": "middle", "text": "麦卡奈特*100", "strokeColor": "#212121", "stroke": 4, "height": 34, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 593 }] }] }, { "type": "Box", "props": { "y": -2, "x": 360, "width": 172, "var": "box_3", "name": "box_3", "height": 209 }, "compId": 513, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_3", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_3", "height": 221 }, "compId": 533 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第三天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 534 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_jin.png", "height": 138 }, "compId": 535 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_3", "name": "box_get_3", "height": 209 }, "compId": 561, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_3", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_3", "height": 221, "alpha": 0.5 }, "compId": 562 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_3", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_3" }, "compId": 630 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_3", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_3", "height": 33 }, "compId": 628 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_3", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_3", "height": 27 }, "compId": 629 }, { "type": "Box", "props": { "y": 172, "x": 4 }, "compId": 632, "child": [{ "type": "Image", "props": { "y": 0, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 631 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石*300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 536 }] }] }, { "type": "Box", "props": { "y": 225, "x": 5, "width": 172, "var": "box_4", "name": "box_4", "height": 221 }, "compId": 514, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_4", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_4", "height": 221 }, "compId": 537 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第四天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 538 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_hero2.png", "height": 138 }, "compId": 539 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 635, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 634 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "杰比*200", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 540 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_4", "name": "box_get_4", "height": 209 }, "compId": 564, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_4", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_4", "height": 221, "alpha": 0.5 }, "compId": 565 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_4", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_4" }, "compId": 633 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_4", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_4", "height": 33 }, "compId": 636 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_4", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_4", "height": 27 }, "compId": 637 }] }, { "type": "Box", "props": { "y": 225, "x": 183, "width": 172, "var": "box_5", "name": "box_5", "height": 209 }, "compId": 515, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_bg_5", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_5", "height": 221 }, "compId": 640 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_jin.png", "height": 138 }, "compId": 543 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第五天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 542 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 643, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 644 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石*500", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 645 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_5", "name": "box_get_5", "height": 209 }, "compId": 567, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_5", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_5", "height": 221, "alpha": 0.5 }, "compId": 641 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_5", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_5" }, "compId": 642 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_5", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_5", "height": 33 }, "compId": 638 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_5", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_5", "height": 27 }, "compId": 639 }] }, { "type": "Box", "props": { "y": 225, "x": 360, "width": 172, "var": "box_6", "name": "box_6", "height": 209 }, "compId": 516, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_bg_6", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_6", "height": 221 }, "compId": 646 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第六天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 546 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_hero3.png", "height": 138 }, "compId": 547 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 649, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 650 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "丹*300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 651 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_6", "name": "box_get_6", "height": 209 }, "compId": 570, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_6", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_6", "height": 221, "alpha": 0.5 }, "compId": 647 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_6", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_6" }, "compId": 648 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_6", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_6", "height": 33 }, "compId": 652 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_6", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_6", "height": 27 }, "compId": 653 }] }, { "type": "Box", "props": { "y": 0, "x": 519, "width": 337, "var": "box_7", "name": "box_7", "height": 445 }, "compId": 554, "child": [{ "type": "Image", "props": { "x": 16, "width": 328, "var": "img_bg_7", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_7", "height": 444 }, "compId": 510 }, { "type": "Image", "props": { "y": -112, "x": -90, "width": 523, "skin": "ui/img_UM_effect_gold.png", "height": 593, "blendMode": "lighter", "alpha": 0.6 }, "compId": 660 }, { "type": "Image", "props": { "y": 13, "x": 18, "width": 329, "skin": "ui/img_UM_ui_botemama.png", "height": 424 }, "compId": 661 }, { "type": "Image", "props": { "y": 18, "x": 85, "skin": "ui/img_UM_ui_text_sign7.png" }, "compId": 657 }, { "type": "Box", "props": { "y": 0, "x": 19, "width": 321, "var": "box_get_7", "name": "box_get_7", "height": 441 }, "compId": 573, "child": [{ "type": "Image", "props": { "y": -1, "x": -2, "width": 325, "var": "img_mask_7", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_7", "height": 443, "alpha": 0.5 }, "compId": 658 }] }, { "type": "Image", "props": { "y": 200, "x": 108, "var": "img_reach_7", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_7" }, "compId": 659 }, { "type": "Image", "props": { "y": 317, "x": 30, "width": 301, "skin": "ui/img_UM_ui_7day_text1.png", "height": 48 }, "compId": 654 }, { "type": "Image", "props": { "y": 366, "x": 30, "width": 188, "skin": "ui/img_UM_ui_7day_text2.png", "height": 59 }, "compId": 655 }, { "type": "Image", "props": { "y": 357, "x": 216, "width": 103, "skin": "ui/img_UM_ui_7day_text3.png", "height": 66 }, "compId": 656 }, { "type": "Image", "props": { "y": 45, "x": -19, "var": "img_available_7", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_7" }, "compId": 662 }, { "type": "Image", "props": { "y": 11, "x": 303.5, "width": 31, "var": "img_state_7", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_7", "height": 33 }, "compId": 663 }] }] }], "loadList": ["ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk2.png", "ui/img_UM_ui_7day_bianjiao.png", "ui/img_UM_ui_7day_tou.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_rank_jlbg3.png", "ui/img_UM_jin.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_text37.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_text47.png", "ui/img_hero1.png", "ui/img_UM_hero2.png", "ui/img_UM_hero3.png", "ui/img_UM_effect_gold.png", "ui/img_UM_ui_botemama.png", "ui/img_UM_ui_text_sign7.png", "ui/img_UM_ui_7day_text1.png", "ui/img_UM_ui_7day_text2.png", "ui/img_UM_ui_7day_text3.png"], "loadList3D": [] };
            sign.SignDay1UI = SignDay1UI;
            REG("ui.sign.SignDay1UI", SignDay1UI);
            class SignDay2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignDay2UI.uiView);
                }
            }
            SignDay2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "centerX": 0, "bottom": 0 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 48, "x": 58, "var": "btn_close", "name": "btn_close" }, "compId": 600, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 601 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 602 }] }, { "type": "Box", "props": { "y": -1, "centerX": 0 }, "compId": 616, "child": [{ "type": "Image", "props": { "y": 66, "x": 43, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 543 }, "compId": 603 }, { "type": "Image", "props": { "y": 124, "x": 61, "width": 881, "skin": "ui/img_UM_ui_uibk2.png", "sizeGrid": "36,36,36,36", "height": 471 }, "compId": 604 }, { "type": "Box", "props": { "y": 615, "x": 253, "var": "btn_get", "name": "btn_get" }, "compId": 605, "child": [{ "type": "Label", "props": { "y": 30, "x": 43, "width": 67, "var": "txt_ad", "underline": true, "text": "领取", "stroke": 0, "name": "txt_ad", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff" }, "compId": 666 }] }, { "type": "Image", "props": { "y": 200, "x": 2, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1 }, "compId": 606 }, { "type": "Image", "props": { "y": 200, "x": 1004, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1, "scaleX": -1 }, "compId": 607 }, { "type": "Image", "props": { "x": 87, "skin": "ui/img_UM_ui_7day_tou.png" }, "compId": 608 }, { "type": "Box", "props": { "y": 615, "x": 379, "var": "btn_double", "name": "btn_double" }, "compId": 609, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 614 }, { "type": "Image", "props": { "y": 25, "x": 81, "width": 135, "skin": "ui/img_UM_ui_text46.png", "height": 40 }, "compId": 615 }, { "type": "Image", "props": { "y": 29, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 665 }] }, { "type": "Image", "props": { "y": 480, "skin": "ui/img_UM_ui_7day_bianjiao.png" }, "compId": 610 }, { "type": "Image", "props": { "y": 480, "x": 1004, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleX": -1 }, "compId": 611 }] }, { "type": "Box", "props": { "y": 134, "width": 930, "var": "box_scale", "scaleY": 1, "scaleX": 1, "name": "box_scale", "height": 453, "centerX": 50 }, "compId": 553, "child": [{ "type": "Box", "props": { "y": -2.5, "x": 5, "width": 167, "var": "box_1", "name": "box_1", "height": 225 }, "compId": 511, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_1", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_1", "height": 221 }, "compId": 525 }, { "type": "Label", "props": { "y": 3, "x": 1, "wordWrap": true, "width": 164, "var": "txt_day", "valign": "middle", "text": "第一天", "strokeColor": "#212121", "stroke": 4, "name": "txt_day", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 526 }, { "type": "Image", "props": { "y": 28, "x": 8, "width": 150, "skin": "ui/img_UM_jin.png", "height": 150 }, "compId": 527 }, { "type": "Box", "props": { "y": 173, "x": 1, "width": 164, "height": 37.2 }, "compId": 627, "child": [{ "type": "Image", "props": { "y": 2, "x": 12, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 618 }, { "type": "Label", "props": { "y": 1, "x": 18, "wordWrap": true, "width": 127, "valign": "middle", "text": "钻石*100", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 528 }] }, { "type": "Box", "props": { "y": 1, "x": 0, "width": 167, "var": "box_get_1", "name": "box_get_1", "height": 222 }, "compId": 557, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 167, "var": "img_mask_1", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_1", "height": 221, "alpha": 0.5 }, "compId": 556 }] }, { "type": "Image", "props": { "y": 92, "x": 12, "var": "img_reach_1", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_1" }, "compId": 617 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_1", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_1", "height": 33 }, "compId": 619 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_1", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_1", "height": 27 }, "compId": 620 }] }, { "type": "Box", "props": { "y": -2, "x": 181, "width": 172, "var": "box_2", "name": "box_2", "height": 223 }, "compId": 512, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_2", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_2", "height": 221 }, "compId": 529 }, { "type": "Image", "props": { "y": 37, "x": 11, "width": 143, "skin": "ui/img_hero1.png", "height": 133 }, "compId": 591 }, { "type": "Label", "props": { "y": 4, "x": 4, "wordWrap": true, "width": 164, "valign": "middle", "text": "第二天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 530 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_2", "name": "box_get_2", "height": 224 }, "compId": 558, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_2", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_2", "height": 221, "alpha": 0.5 }, "compId": 626 }] }, { "type": "Image", "props": { "y": 92, "x": 15, "var": "img_reach_2", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_2" }, "compId": 621 }, { "type": "Image", "props": { "y": 32.5, "x": -22, "width": 95, "var": "img_available_2", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_2", "height": 27 }, "compId": 624 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_2", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_2", "height": 33 }, "compId": 625 }, { "type": "Box", "props": { "y": 174, "x": 15 }, "compId": 664, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 622 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 135, "valign": "middle", "text": "麦卡奈特*100", "strokeColor": "#212121", "stroke": 4, "height": 34, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 593 }] }] }, { "type": "Box", "props": { "y": -2, "x": 360, "width": 172, "var": "box_3", "name": "box_3", "height": 209 }, "compId": 513, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_3", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_3", "height": 221 }, "compId": 533 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第三天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 534 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_jin.png", "height": 138 }, "compId": 535 }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_3", "name": "box_get_3", "height": 209 }, "compId": 561, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_3", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_3", "height": 221, "alpha": 0.5 }, "compId": 562 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_3", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_3" }, "compId": 630 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_3", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_3", "height": 33 }, "compId": 628 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_3", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_3", "height": 27 }, "compId": 629 }, { "type": "Box", "props": { "y": 172, "x": 4 }, "compId": 632, "child": [{ "type": "Image", "props": { "y": 0, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 631 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石*300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 536 }] }] }, { "type": "Box", "props": { "y": 225, "x": 5, "width": 172, "var": "box_4", "name": "box_4", "height": 221 }, "compId": 514, "child": [{ "type": "Image", "props": { "width": 167, "var": "img_bg_4", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_4", "height": 221 }, "compId": 537 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第四天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 538 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_hero2.png", "height": 138 }, "compId": 539 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 635, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 634 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "杰比*200", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 540 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_4", "name": "box_get_4", "height": 209 }, "compId": 564, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_4", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_4", "height": 221, "alpha": 0.5 }, "compId": 565 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_4", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_4" }, "compId": 633 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_4", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_4", "height": 33 }, "compId": 636 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_4", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_4", "height": 27 }, "compId": 637 }] }, { "type": "Box", "props": { "y": 225, "x": 183, "width": 172, "var": "box_5", "name": "box_5", "height": 209 }, "compId": 515, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_bg_5", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_5", "height": 221 }, "compId": 640 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_jin.png", "height": 138 }, "compId": 543 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第五天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 542 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 643, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 644 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "钻石*500", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 645 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_5", "name": "box_get_5", "height": 209 }, "compId": 567, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_5", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_5", "height": 221, "alpha": 0.5 }, "compId": 641 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_5", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_5" }, "compId": 642 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_5", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_5", "height": 33 }, "compId": 638 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_5", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_5", "height": 27 }, "compId": 639 }] }, { "type": "Box", "props": { "y": 225, "x": 360, "width": 172, "var": "box_6", "name": "box_6", "height": 209 }, "compId": 516, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_bg_6", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_6", "height": 221 }, "compId": 646 }, { "type": "Label", "props": { "y": 3, "x": 6, "wordWrap": true, "width": 164, "valign": "middle", "text": "第六天", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 26, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 546 }, { "type": "Image", "props": { "y": 35, "x": 17, "width": 138, "skin": "ui/img_UM_hero3.png", "height": 138 }, "compId": 547 }, { "type": "Box", "props": { "y": 176, "x": 4, "width": 164, "height": 35 }, "compId": 649, "child": [{ "type": "Image", "props": { "y": -1, "x": 14, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 650 }, { "type": "Label", "props": { "y": 0, "x": 0, "wordWrap": true, "width": 164, "valign": "middle", "text": "丹*300", "strokeColor": "#212121", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "center" }, "compId": 651 }] }, { "type": "Box", "props": { "y": 0, "x": 0, "width": 172, "var": "box_get_6", "name": "box_get_6", "height": 209 }, "compId": 570, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 167, "var": "img_mask_6", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_6", "height": 221, "alpha": 0.5 }, "compId": 647 }] }, { "type": "Image", "props": { "y": 91, "x": 12, "var": "img_reach_6", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_6" }, "compId": 648 }, { "type": "Image", "props": { "y": 5, "x": 131, "width": 31, "var": "img_state_6", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_6", "height": 33 }, "compId": 652 }, { "type": "Image", "props": { "y": 34, "x": -21, "width": 95, "var": "img_available_6", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_6", "height": 27 }, "compId": 653 }] }, { "type": "Box", "props": { "y": 0, "x": 519, "width": 337, "var": "box_7", "name": "box_7", "height": 445 }, "compId": 554, "child": [{ "type": "Image", "props": { "x": 16, "width": 328, "var": "img_bg_7", "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "name": "img_bg_7", "height": 444 }, "compId": 510 }, { "type": "Image", "props": { "y": -112, "x": -90, "width": 523, "skin": "ui/img_UM_effect_gold.png", "height": 593, "blendMode": "lighter", "alpha": 0.6 }, "compId": 660 }, { "type": "Image", "props": { "y": 13, "x": 18, "width": 329, "skin": "ui/img_UM_ui_botemama.png", "height": 424 }, "compId": 661 }, { "type": "Image", "props": { "y": 18, "x": 85, "skin": "ui/img_UM_ui_text_sign7.png" }, "compId": 657 }, { "type": "Box", "props": { "y": 0, "x": 19, "width": 321, "var": "box_get_7", "name": "box_get_7", "height": 441 }, "compId": 573, "child": [{ "type": "Image", "props": { "y": -1, "x": -2, "width": 325, "var": "img_mask_7", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask_7", "height": 443, "alpha": 0.5 }, "compId": 658 }] }, { "type": "Image", "props": { "y": 200, "x": 108, "var": "img_reach_7", "skin": "ui/img_UM_ui_text37.png", "name": "img_reach_7" }, "compId": 659 }, { "type": "Image", "props": { "y": 317, "x": 30, "width": 301, "skin": "ui/img_UM_ui_7day_text1.png", "height": 48 }, "compId": 654 }, { "type": "Image", "props": { "y": 366, "x": 30, "width": 188, "skin": "ui/img_UM_ui_7day_text2.png", "height": 59 }, "compId": 655 }, { "type": "Image", "props": { "y": 357, "x": 216, "width": 103, "skin": "ui/img_UM_ui_7day_text3.png", "height": 66 }, "compId": 656 }, { "type": "Image", "props": { "y": 45, "x": -19, "var": "img_available_7", "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "name": "img_available_7" }, "compId": 662 }, { "type": "Image", "props": { "y": 11, "x": 303.5, "width": 31, "var": "img_state_7", "skin": "ui/img_UM_ui_lock2.png", "name": "img_state_7", "height": 33 }, "compId": 663 }] }] }], "loadList": ["ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk2.png", "ui/img_UM_ui_7day_bianjiao.png", "ui/img_UM_ui_7day_tou.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_rank_jlbg3.png", "ui/img_UM_jin.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_text37.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_text47.png", "ui/img_hero1.png", "ui/img_UM_hero2.png", "ui/img_UM_hero3.png", "ui/img_UM_effect_gold.png", "ui/img_UM_ui_botemama.png", "ui/img_UM_ui_text_sign7.png", "ui/img_UM_ui_7day_text1.png", "ui/img_UM_ui_7day_text2.png", "ui/img_UM_ui_7day_text3.png"], "loadList3D": [] };
            sign.SignDay2UI = SignDay2UI;
            REG("ui.sign.SignDay2UI", SignDay2UI);
        })(sign = ui.sign || (ui.sign = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var task;
        (function (task) {
            class TaskUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TaskUI.uiView);
                }
            }
            TaskUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -100, "skin": "ui/img_UM_ui_bg7.jpg", "right": -100, "left": -100 }, "compId": 1579 }, { "type": "Box", "props": { "y": 28, "var": "box_close", "name": "box_close", "left": 20 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Box", "props": { "y": 14, "x": 169, "width": 942, "height": 692, "centerX": 0 }, "compId": 1632, "child": [{ "type": "Image", "props": { "x": 19, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 692 }, "compId": 1584 }, { "type": "Image", "props": { "y": 204, "x": 36, "width": 881, "skin": "ui/img_UM_ui_uibk2.png", "sizeGrid": "36,36,36,36", "height": 464 }, "compId": 1600 }, { "type": "Image", "props": { "y": 216, "x": 48, "width": 858, "skin": "ui/img_UM_ui_uibk3.png", "sizeGrid": "10,10,10,10", "height": 144 }, "compId": 1601 }, { "type": "Image", "props": { "y": 11, "x": 0, "var": "img_test", "skin": "ui/img_UM_ui_text40.png", "name": "img_test" }, "compId": 1607 }, { "type": "Image", "props": { "y": 3, "x": 851, "width": 52, "skin": "ui/img_UM_ui_wenhao.png", "height": 52 }, "compId": 1619 }, { "type": "Image", "props": { "y": 20, "x": 859, "skin": "ui/img_UM_ui_paopao.png" }, "compId": 1620 }, { "type": "Label", "props": { "y": 47, "x": 926, "wordWrap": true, "width": 163, "text": "在二天内完成任务获得积分，达标后可开启宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 111, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1621 }, { "type": "List", "props": { "y": 362, "x": 27, "width": 900, "var": "list_task", "vScrollBarSkin": "comp/vscroll.png", "name": "list_task", "height": 298, "elasticEnabled": false }, "compId": 1634, "child": [{ "type": "TaskItem", "props": { "y": -1, "x": 0, "width": 900, "renderType": "render", "height": 100, "runtime": "ui.task.TaskItemUI" }, "compId": 1633 }] }, { "type": "Image", "props": { "y": 9, "x": 637, "width": 347, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,22,25,23", "scaleY": 0.6, "scaleX": 0.6, "height": 72, "alpha": 0.5 }, "compId": 1635 }, { "type": "Label", "props": { "y": 19, "x": 648, "wordWrap": true, "width": 192, "var": "txt_time", "text": "剩余 99:00:00", "strokeColor": "#000000", "stroke": 4, "name": "txt_time", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#c2ccd6", "bold": true, "align": "left" }, "compId": 1636 }, { "type": "List", "props": { "y": 212, "x": 47, "width": 856, "var": "list_box1", "name": "list_box1", "height": 146 }, "compId": 1640, "child": [{ "type": "TaskItem1", "props": { "y": 0, "x": 0, "width": 286, "renderType": "render", "height": 146, "runtime": "ui.task.TaskItem1UI" }, "compId": 1639 }] }, { "type": "List", "props": { "y": 65, "x": 44, "width": 856, "var": "list_box2", "name": "list_box2", "height": 150 }, "compId": 1642, "child": [{ "type": "TaskItem2", "props": { "renderType": "render", "runtime": "ui.task.TaskItem2UI" }, "compId": 1641 }] }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk2.png", "ui/img_UM_ui_uibk3.png", "ui/img_UM_ui_text40.png", "ui/img_UM_ui_wenhao.png", "ui/img_UM_ui_paopao.png", "comp/vscroll.png", "ui/img_UM_ui_black2.png"], "loadList3D": [] };
            task.TaskUI = TaskUI;
            REG("ui.task.TaskUI", TaskUI);
            class TaskItemUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TaskItemUI.uiView);
                }
            }
            TaskItemUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 900, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 3, "x": 21, "width": 858, "skin": "ui/img_UM_ui_uibk3.png", "sizeGrid": "10,10,10,10", "height": 94 }, "compId": 1596 }, { "type": "Image", "props": { "y": 16, "x": 59, "width": 503, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "12,49,11,20", "height": 43, "alpha": 0.4 }, "compId": 1599 }, { "type": "Image", "props": { "y": 6, "x": 24, "width": 68, "skin": "ui/img_UM_fun_rank.png", "height": 68 }, "compId": 1597 }, { "type": "Label", "props": { "y": 71, "x": 25, "wordWrap": false, "width": 47, "var": "txt_num", "text": "+9", "strokeColor": "#000000", "name": "txt_num", "height": 27, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1598 }, { "type": "Label", "props": { "y": 23, "x": 100, "wordWrap": true, "width": 394, "var": "txt_info", "text": "完成需要达成的条件...", "strokeColor": "#000000", "name": "txt_info", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1602 }, { "type": "Image", "props": { "y": 66, "x": 98, "width": 453, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "6,6,6,6", "height": 24 }, "compId": 1606 }, { "type": "Image", "props": { "y": 67, "x": 99, "width": 451, "var": "img_bar", "skin": "ui/img_UM_rank_bar.png", "sizeGrid": "6,11,7,6", "name": "img_bar", "height": 22 }, "compId": 1604 }, { "type": "Image", "props": { "y": 10, "x": 731, "width": 141, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "35,30,36,36", "height": 80, "alpha": 0.5 }, "compId": 1610 }, { "type": "Label", "props": { "y": 65, "x": 772.5, "wordWrap": true, "width": 60, "text": "奖励", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1611 }, { "type": "Image", "props": { "y": 19, "x": 762.5, "width": 36, "var": "img_rw", "skin": "ui/img_UM_Diamond.png", "name": "img_rw", "height": 36 }, "compId": 1612 }, { "type": "Label", "props": { "y": 66, "x": 269, "wordWrap": false, "width": 111, "var": "txt_pro", "text": "1/1", "strokeColor": "#000000", "stroke": 4, "name": "txt_pro", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1615 }, { "type": "Box", "props": { "y": 6, "x": 593, "var": "box_goto", "name": "box_goto", "mouseEnabled": true }, "compId": 1619, "child": [{ "type": "Image", "props": { "width": 136, "skin": "ui/img_UM_btn_BlueButton_2.png", "height": 89 }, "compId": 1608 }, { "type": "Image", "props": { "y": 26, "x": 15, "width": 105, "skin": "ui/img_UM_ui_text42.png", "height": 30 }, "compId": 1614 }] }, { "type": "Box", "props": { "y": 8, "x": 593, "var": "box_available", "name": "box_available", "mouseEnabled": true }, "compId": 1618, "child": [{ "type": "Image", "props": { "width": 136, "skin": "ui/img_UM_btn_YellowButton_1.png", "height": 89 }, "compId": 1616 }] }, { "type": "Label", "props": { "y": 14, "x": 801.5, "width": 66, "var": "txt_tong", "valign": "middle", "text": "39", "strokeColor": "#000000", "stroke": 4, "name": "txt_tong", "fontSize": 45, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1620 }, { "type": "Image", "props": { "y": 35, "x": 607, "width": 105, "var": "img_available", "skin": "ui/img_UM_ui_text43.png", "name": "img_available", "height": 29 }, "compId": 1617 }], "loadList": ["ui/img_UM_ui_uibk3.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_fun_rank.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_rank_bar.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_Diamond.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text42.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text43.png"], "loadList3D": [] };
            task.TaskItemUI = TaskItemUI;
            REG("ui.task.TaskItemUI", TaskItemUI);
            class TaskItem1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TaskItem1UI.uiView);
                }
            }
            TaskItem1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 286, "mouseThrough": false, "height": 146 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 278, "var": "img_bg", "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,57,44,54", "name": "img_bg", "mouseThrough": false, "mouseEnabled": true, "height": 138 }, "compId": 1591 }, { "type": "Image", "props": { "y": 12, "x": 18, "width": 108, "var": "img_box", "skin": "ui/img_UM_box_rankbox2.png", "name": "img_box", "height": 108 }, "compId": 1592 }, { "type": "Label", "props": { "y": 30, "x": 128, "wordWrap": false, "width": 136, "var": "txt_name", "text": "黄金宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1593 }, { "type": "Image", "props": { "y": -2, "x": -4, "width": 292, "var": "img_frame", "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "41,42,42,41", "name": "img_frame", "height": 149 }, "compId": 1598 }, { "type": "Image", "props": { "y": 73, "x": 128, "width": 132, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "12,12,12,12", "height": 32, "alpha": 1 }, "compId": 1600 }, { "type": "Image", "props": { "y": 74, "x": 129, "width": 130, "var": "img_bar", "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "name": "img_bar", "height": 31 }, "compId": 1601 }, { "type": "Image", "props": { "y": 63.5, "x": 227, "width": 55, "skin": "ui/img_UM_fun_rank.png", "height": 55 }, "compId": 1594 }, { "type": "Label", "props": { "y": 76, "x": 121, "wordWrap": false, "width": 139, "var": "txt_pro", "text": "90/90", "strokeColor": "#000000", "stroke": 4, "name": "txt_pro", "height": 28, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1602 }, { "type": "Image", "props": { "y": 11, "x": 9, "width": 267, "var": "img_mask", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask", "height": 129, "alpha": 0.5 }, "compId": 1603 }, { "type": "Image", "props": { "y": 59, "x": -7, "width": 112, "var": "img_available", "skin": "ui/img_UM_ui_text41.png", "rotation": -31, "name": "img_available", "height": 31 }, "compId": 1599 }, { "type": "Image", "props": { "y": 10, "x": 246, "width": 31, "var": "img_state", "skin": "ui/img_UM_ui_tick.png", "name": "img_state", "height": 33 }, "compId": 1604 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_box_rankbox2.png", "ui/img_UM_rank_effectbk.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_fun_rank.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_text41.png", "ui/img_UM_ui_tick.png"], "loadList3D": [] };
            task.TaskItem1UI = TaskItem1UI;
            REG("ui.task.TaskItem1UI", TaskItem1UI);
            class TaskItem2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TaskItem2UI.uiView);
                }
            }
            TaskItem2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 429, "mouseThrough": false, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": 3, "width": 425, "var": "img_bg", "skin": "ui/img_UM_shop_ui_bg9.png", "sizeGrid": "46,53,51,48", "name": "img_bg", "mouseEnabled": true, "height": 140, "gray": true }, "compId": 1583 }, { "type": "Image", "props": { "y": 22, "x": 19, "width": 393, "var": "img_bg2", "skin": "ui/img_UM_rank_obj2.png", "sizeGrid": "8,8,8,8", "name": "img_bg2", "height": 60, "gray": true, "alpha": 1 }, "compId": 1584 }, { "type": "Label", "props": { "y": 34.5, "x": 157, "wordWrap": false, "width": 243, "var": "txt_name", "text": "彩虹宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#edff1e", "bold": true, "align": "left" }, "compId": 1586 }, { "type": "Image", "props": { "y": 86, "x": 29, "width": 373, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "12,12,12,12", "height": 45, "alpha": 1 }, "compId": 1587 }, { "type": "Image", "props": { "y": 85, "x": 29, "width": 372, "var": "img_bar", "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "name": "img_bar", "height": 47 }, "compId": 1588 }, { "type": "Label", "props": { "y": 94, "x": 141, "wordWrap": true, "width": 150, "var": "txt_pro", "text": "99/99", "strokeColor": "#000000", "stroke": 4, "name": "txt_pro", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1589 }, { "type": "Image", "props": { "y": -2, "x": -4, "width": 435, "var": "img_frame", "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "41,42,42,41", "name": "img_frame", "height": 149 }, "compId": 1594 }, { "type": "Image", "props": { "y": 79, "x": 358, "width": 68, "skin": "ui/img_UM_fun_rank.png", "height": 68 }, "compId": 1590 }, { "type": "Image", "props": { "y": -6, "x": 26, "width": 108, "var": "img_box", "skin": "ui/img_UM_box_rankbox5.png", "name": "img_box", "height": 108 }, "compId": 1585 }, { "type": "Image", "props": { "y": 11, "x": 9, "width": 414, "var": "img_mask", "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "name": "img_mask", "height": 128, "alpha": 0.5 }, "compId": 1591 }, { "type": "Image", "props": { "y": 17, "x": 386.5, "width": 31, "var": "img_state", "skin": "ui/img_UM_ui_tick.png", "name": "img_state", "height": 33 }, "compId": 1592 }, { "type": "Image", "props": { "y": 50, "x": -14, "width": 112, "var": "img_available", "skin": "ui/img_UM_ui_text36.png", "rotation": -31, "name": "img_available", "height": 31 }, "compId": 1593 }], "loadList": ["ui/img_UM_shop_ui_bg9.png", "ui/img_UM_rank_obj2.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_rank_effectbk.png", "ui/img_UM_fun_rank.png", "ui/img_UM_box_rankbox5.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_tick.png", "ui/img_UM_ui_text36.png"], "loadList3D": [] };
            task.TaskItem2UI = TaskItem2UI;
            REG("ui.task.TaskItem2UI", TaskItem2UI);
        })(task = ui.task || (ui.task = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var temp;
        (function (temp) {
            class TempUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TempUI.uiView);
                }
            }
            TempUI.uiView = { "type": "View", "props": { "width": 1280, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 63, "x": 28, "skin": "ui/img_uj_kill_1.png" }, "compId": 3 }, { "type": "Image", "props": { "y": 63, "x": 161, "skin": "ui/img_uj_kill_10.png" }, "compId": 4 }, { "type": "Image", "props": { "y": 63, "x": 294, "skin": "ui/img_uj_kill_9.png" }, "compId": 5 }, { "type": "Image", "props": { "y": 63, "x": 428, "skin": "ui/img_uj_kill_8.png" }, "compId": 6 }, { "type": "Image", "props": { "y": 63, "x": 561, "skin": "ui/img_uj_kill_2.png" }, "compId": 7 }, { "type": "Image", "props": { "y": 63, "x": 694, "skin": "ui/img_uj_kill_3.png" }, "compId": 8 }, { "type": "Image", "props": { "y": 63, "x": 827, "skin": "ui/img_uj_kill_4.png" }, "compId": 9 }, { "type": "Image", "props": { "y": 63, "x": 961, "skin": "ui/img_uj_kill_5.png" }, "compId": 10 }, { "type": "Image", "props": { "y": 63, "x": 1094, "skin": "ui/img_uj_kill_6.png" }, "compId": 11 }, { "type": "Image", "props": { "y": 63, "x": 1227, "skin": "ui/img_uj_kill_7.png" }, "compId": 12 }, { "type": "Image", "props": { "y": 272, "x": 28, "skin": "ui/img_uk_rank_icon1.png" }, "compId": 13 }, { "type": "Image", "props": { "y": 272, "x": 171, "skin": "ui/img_uk_rank_icon2.png" }, "compId": 14 }, { "type": "Image", "props": { "y": 272, "x": 310, "skin": "ui/img_uk_rank_icon4.png" }, "compId": 15 }, { "type": "Image", "props": { "y": 272, "x": 450, "skin": "ui/img_uk_rank_icon3.png" }, "compId": 16 }, { "type": "Image", "props": { "y": 272, "x": 589, "skin": "ui/img_uk_rank_icon5.png" }, "compId": 17 }, { "type": "Image", "props": { "y": 272, "x": 729, "skin": "ui/img_uk_rank_icon6.png" }, "compId": 18 }, { "type": "Image", "props": { "y": 272, "x": 868, "skin": "ui/img_uk_rank_icon7.png" }, "compId": 19 }, { "type": "Image", "props": { "y": 272, "x": 1008, "skin": "ui/img_uk_rank_icon8.png" }, "compId": 20 }, { "type": "Image", "props": { "y": 272, "x": 1147, "skin": "ui/img_uk_rank_icon9.png" }, "compId": 21 }, { "type": "Image", "props": { "y": 517, "x": 69, "skin": "ui/img_uk_dian_blue.png" }, "compId": 22 }, { "type": "Image", "props": { "y": 517, "x": 108, "skin": "ui/img_uk_dian_red.png" }, "compId": 23 }, { "type": "Image", "props": { "y": 517, "x": 145, "skin": "ui/img_uk_dian_white.png" }, "compId": 24 }, { "type": "Image", "props": { "y": 824, "x": 11.5, "width": 200, "skin": "ui/img_uk_rank_icon1.png", "height": 200 }, "compId": 27, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 26 }] }, { "type": "Image", "props": { "y": 825, "x": 160, "skin": "ui/img_uk_rank_icon2.png" }, "compId": 28, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 36 }] }, { "type": "Image", "props": { "y": 825, "x": 299, "skin": "ui/img_uk_rank_icon4.png" }, "compId": 29, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 37 }] }, { "type": "Image", "props": { "y": 825, "x": 439, "skin": "ui/img_uk_rank_icon3.png" }, "compId": 30, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 38 }] }, { "type": "Image", "props": { "y": 825, "x": 578, "skin": "ui/img_uk_rank_icon5.png" }, "compId": 31, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 39 }] }, { "type": "Image", "props": { "y": 825, "x": 718, "skin": "ui/img_uk_rank_icon6.png" }, "compId": 32, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 40 }] }, { "type": "Image", "props": { "y": 825, "x": 857, "skin": "ui/img_uk_rank_icon7.png" }, "compId": 33, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 41 }] }, { "type": "Image", "props": { "y": 825, "x": 997, "skin": "ui/img_uk_rank_icon8.png" }, "compId": 34, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 42 }] }, { "type": "Image", "props": { "y": 825, "x": 1136, "skin": "ui/img_uk_rank_icon9.png" }, "compId": 35, "child": [{ "type": "Image", "props": { "y": -9, "x": 82, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 43 }] }, { "type": "Image", "props": { "y": 1077, "x": -1, "skin": "ui/img_uk_rank_icon1.png" }, "compId": 44, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 55, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 53 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 54 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 143, "skin": "ui/img_uk_rank_icon2.png" }, "compId": 45, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 56, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 57 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 58 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 282, "skin": "ui/img_uk_rank_icon4.png" }, "compId": 46, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 59, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 60 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 61 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 422, "skin": "ui/img_uk_rank_icon3.png" }, "compId": 47, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 62, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 63 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 64 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 561, "skin": "ui/img_uk_rank_icon5.png" }, "compId": 48, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 65, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 66 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 67 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 701, "skin": "ui/img_uk_rank_icon6.png" }, "compId": 49, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 68, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 69 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 70 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 840, "skin": "ui/img_uk_rank_icon7.png" }, "compId": 50, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 71, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 72 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 73 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 980, "skin": "ui/img_uk_rank_icon8.png" }, "compId": 51, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 74, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 75 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 76 }] }] }, { "type": "Image", "props": { "y": 1077, "x": 1119, "skin": "ui/img_uk_rank_icon9.png" }, "compId": 52, "child": [{ "type": "Box", "props": { "y": -6, "x": 65 }, "compId": 77, "child": [{ "type": "Image", "props": { "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 78 }, { "type": "Image", "props": { "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 79 }] }] }, { "type": "Image", "props": { "y": 1322, "x": -1, "skin": "ui/img_uk_rank_icon1.png" }, "compId": 80, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 89, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 90 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 91 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 92 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 143, "skin": "ui/img_uk_rank_icon2.png" }, "compId": 81, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 93, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 94 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 95 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 96 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 282, "skin": "ui/img_uk_rank_icon4.png" }, "compId": 82, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 97, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 98 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 99 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 100 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 422, "skin": "ui/img_uk_rank_icon3.png" }, "compId": 83, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 101, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 102 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 103 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 104 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 561, "skin": "ui/img_uk_rank_icon5.png" }, "compId": 84, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 105, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 106 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 107 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 108 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 701, "skin": "ui/img_uk_rank_icon6.png" }, "compId": 85, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 109, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 110 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 111 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 112 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 840, "skin": "ui/img_uk_rank_icon7.png" }, "compId": 86, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 113, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 114 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 115 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 116 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 980, "skin": "ui/img_uk_rank_icon8.png" }, "compId": 87, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 117, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 118 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 119 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 120 }] }] }, { "type": "Image", "props": { "y": 1322, "x": 1119, "skin": "ui/img_uk_rank_icon9.png" }, "compId": 88, "child": [{ "type": "Box", "props": { "y": -6, "x": 48 }, "compId": 121, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 122 }, { "type": "Image", "props": { "y": 0, "x": 35, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 123 }, { "type": "Image", "props": { "y": 0, "x": 69, "width": 35, "skin": "ui/img_uk_star2.png", "height": 33 }, "compId": 124 }] }] }, { "type": "Image", "props": { "y": 567, "x": 364, "skin": "ui/img_UM_hp_p_1.png" }, "compId": 147 }, { "type": "Image", "props": { "y": 567, "x": 471, "skin": "ui/img_UM_hp_p_2.png" }, "compId": 148 }], "loadList": ["ui/img_uj_kill_1.png", "ui/img_uj_kill_10.png", "ui/img_uj_kill_9.png", "ui/img_uj_kill_8.png", "ui/img_uj_kill_2.png", "ui/img_uj_kill_3.png", "ui/img_uj_kill_4.png", "ui/img_uj_kill_5.png", "ui/img_uj_kill_6.png", "ui/img_uj_kill_7.png", "ui/img_uk_rank_icon1.png", "ui/img_uk_rank_icon2.png", "ui/img_uk_rank_icon4.png", "ui/img_uk_rank_icon3.png", "ui/img_uk_rank_icon5.png", "ui/img_uk_rank_icon6.png", "ui/img_uk_rank_icon7.png", "ui/img_uk_rank_icon8.png", "ui/img_uk_rank_icon9.png", "ui/img_uk_dian_blue.png", "ui/img_uk_dian_red.png", "ui/img_uk_dian_white.png", "ui/img_uk_star2.png", "ui/img_UM_hp_p_1.png", "ui/img_UM_hp_p_2.png"], "loadList3D": [] };
            temp.TempUI = TempUI;
            REG("ui.temp.TempUI", TempUI);
        })(temp = ui.temp || (ui.temp = {}));
    })(ui || (ui = {}));
    (function (ui) {
        var test;
        (function (test) {
            class AnimTarget1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(AnimTarget1UI.uiView);
                }
            }
            AnimTarget1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 80 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 40, "x": 640, "width": 730, "pivotY": 25, "pivotX": 365, "height": 50 }, "compId": 1143, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_tipsbg.png", "alpha": 0.6 }, "compId": 1144 }, { "type": "Image", "props": { "y": 9, "x": 158, "skin": "ui/img_UM_ui_text2.png", "scaleY": 0.8, "scaleX": 0.8 }, "compId": 1145 }] }], "animations": [{ "nodes": [{ "target": 1143, "keyframes": { "x": [{ "value": -365, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 0 }, { "value": 608, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 3 }, { "value": 664, "tweenMethod": "linearNone", "tween": true, "target": 1143, "label": null, "key": "x", "index": 40 }, { "value": 1645, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "x", "index": 43 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1143, "key": "alpha", "index": 43 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_ui_tipsbg.png", "ui/img_UM_ui_text2.png"], "loadList3D": [] };
            test.AnimTarget1UI = AnimTarget1UI;
            REG("ui.test.AnimTarget1UI", AnimTarget1UI);
            class AnimTarget2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(AnimTarget2UI.uiView);
                }
            }
            AnimTarget2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 80 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 40, "x": 640, "width": 730, "pivotY": 25, "pivotX": 365, "height": 50 }, "compId": 1149, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_tipsbg.png", "alpha": 0.6 }, "compId": 1150 }, { "type": "Image", "props": { "y": 9, "x": 220, "skin": "ui/img_UM_ui_text3.png", "scaleY": 0.8, "scaleX": 0.8 }, "compId": 1151 }] }], "animations": [{ "nodes": [{ "target": 1149, "keyframes": { "x": [{ "value": -365, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 0 }, { "value": 608, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 3 }, { "value": 664, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 40 }, { "value": 1645, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "x", "index": 43 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 40 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1149, "key": "alpha", "index": 43 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_ui_tipsbg.png", "ui/img_UM_ui_text3.png"], "loadList3D": [] };
            test.AnimTarget2UI = AnimTarget2UI;
            REG("ui.test.AnimTarget2UI", AnimTarget2UI);
            class BattleUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleUI.uiView);
                }
            }
            BattleUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 432, "x": 117, "width": 182, "skin": "ui/img_uk_ui_Steering wheel1.png", "height": 182 }, "compId": 1127 }, { "type": "Image", "props": { "y": 432, "x": 200, "width": 90, "skin": "ui/img_UM_ui_lunpan.png", "height": 90 }, "compId": 1132 }, { "type": "Image", "props": { "y": 9, "x": 587, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 1133 }, { "type": "Image", "props": { "y": 3, "x": 617, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 1134 }, { "type": "Label", "props": { "y": 39, "x": 586, "wordWrap": true, "width": 108, "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 1135 }, { "type": "Box", "props": { "y": 19.1, "x": 365.4, "width": 220.6, "height": 46.8 }, "compId": 1139, "child": [{ "type": "Image", "props": { "y": 0, "x": -2, "width": 371, "skin": "ui/img_UM_progressbar_bluebg.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 78 }, "compId": 1136 }, { "type": "Image", "props": { "y": 4, "x": 3, "width": 354, "skin": "ui/img_UM_progressbar_blue.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1137 }, { "type": "Label", "props": { "y": 5, "x": 56, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1138 }] }, { "type": "Box", "props": { "y": 19.6, "x": 696, "width": 220.6, "height": 46.8 }, "compId": 1140, "child": [{ "type": "Image", "props": { "y": 0, "x": -2, "width": 371, "skin": "ui/img_UM_progressbar_redbg.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 78 }, "compId": 1141 }, { "type": "Image", "props": { "y": 4, "x": 3, "width": 354, "skin": "ui/img_UM_progressbar_red.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1142 }, { "type": "Label", "props": { "y": 5, "x": 56, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1143 }] }, { "type": "HPBlue", "props": { "y": 586, "x": 753, "width": 300, "scaleY": 0.8, "scaleX": 0.8, "height": 100, "runtime": "ui.test.HPBlueUI" }, "compId": 1145 }, { "type": "HPRed", "props": { "y": 230, "x": 532, "width": 270, "scaleY": 0.8, "scaleX": 0.8, "height": 80, "runtime": "ui.test.HPRedUI" }, "compId": 1146 }], "loadList": ["ui/img_uk_ui_Steering wheel1.png", "ui/img_UM_ui_lunpan.png", "ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_progressbar_bluebg.png", "ui/img_UM_progressbar_blue.png", "ui/img_UM_progressbar_redbg.png", "ui/img_UM_progressbar_red.png"], "loadList3D": [] };
            test.BattleUI = BattleUI;
            REG("ui.test.BattleUI", BattleUI);
            class Battle1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Battle1UI.uiView);
                }
            }
            Battle1UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg.jpg" }, "compId": 1150 }, { "type": "Image", "props": { "y": 432, "x": 117, "width": 182, "skin": "ui/img_uk_ui_Steering wheel1.png", "height": 182 }, "compId": 1127 }, { "type": "Image", "props": { "y": 432, "x": 200, "width": 90, "skin": "ui/img_UM_ui_lunpan.png", "height": 90 }, "compId": 1132 }, { "type": "Image", "props": { "y": 9, "x": 587, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 1133 }, { "type": "Image", "props": { "y": 3, "x": 617, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 1134 }, { "type": "Label", "props": { "y": 39, "x": 586, "wordWrap": true, "width": 108, "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 1135 }, { "type": "Box", "props": { "y": 19.1, "x": 365.4 }, "compId": 1139, "child": [{ "type": "Image", "props": { "y": 0, "x": -2, "width": 371, "skin": "ui/img_UM_progressbar_bluebg.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 78 }, "compId": 1136 }, { "type": "Image", "props": { "y": 4, "x": 3, "width": 354, "skin": "ui/img_UM_progressbar_blue.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1137 }, { "type": "Label", "props": { "y": 5, "x": 56, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1138 }] }, { "type": "Box", "props": { "y": 19.6, "x": 696 }, "compId": 1140, "child": [{ "type": "Image", "props": { "y": 0, "x": -2, "width": 371, "skin": "ui/img_UM_progressbar_redbg.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 78 }, "compId": 1141 }, { "type": "Image", "props": { "y": 4, "x": 3, "width": 354, "skin": "ui/img_UM_progressbar_red.png", "sizeGrid": "12,12,12,12", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1142 }, { "type": "Label", "props": { "y": 5, "x": 56, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1143 }] }, { "type": "HPBlue", "props": { "y": 586, "x": 753, "scaleY": 0.8, "scaleX": 0.8, "runtime": "ui.test.HPBlueUI" }, "compId": 1145 }, { "type": "HPRed", "props": { "y": 230, "x": 532, "scaleY": 0.8, "scaleX": 0.8, "runtime": "ui.test.HPRedUI" }, "compId": 1146 }, { "type": "Box", "props": { "y": 159.5, "x": 1158, "scaleY": 0.7, "scaleX": 0.7 }, "compId": 1153, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillbg.png", "alpha": 0.3 }, "compId": 1147 }, { "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillcdWhite.png" }, "compId": 1148 }, { "type": "Label", "props": { "y": 43, "x": 39, "wordWrap": true, "width": 61, "text": "7", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1149 }, { "type": "Image", "props": { "y": 85, "x": 55, "width": 35, "skin": "ui/img_UM_AmmoIcon_white.png", "height": 16 }, "compId": 1151 }] }, { "type": "Box", "props": { "y": 262, "x": 1158, "scaleY": 0.7, "scaleX": 0.7 }, "compId": 1154, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillbg.png", "alpha": 0.3 }, "compId": 1155 }, { "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillcdYellow.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": 45, "x": 45, "width": 50, "skin": "ui/img_UM_skillicon_yellow.png", "height": 50 }, "compId": 1159 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_uk_ui_Steering wheel1.png", "ui/img_UM_ui_lunpan.png", "ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_progressbar_bluebg.png", "ui/img_UM_progressbar_blue.png", "ui/img_UM_progressbar_redbg.png", "ui/img_UM_progressbar_red.png", "ui/img_UM_skillbg.png", "ui/img_UM_skillcdWhite.png", "ui/img_UM_AmmoIcon_white.png", "ui/img_UM_skillcdYellow.png", "ui/img_UM_skillicon_yellow.png"], "loadList3D": [] };
            test.Battle1UI = Battle1UI;
            REG("ui.test.Battle1UI", Battle1UI);
            class Battle2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Battle2UI.uiView);
                }
            }
            Battle2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 587, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 1133 }, { "type": "Image", "props": { "y": 3, "x": 617, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 1134 }, { "type": "Label", "props": { "y": 39, "x": 586, "wordWrap": true, "width": 108, "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 1135 }, { "type": "HPBlue", "props": { "y": 586, "x": 753, "width": 300, "scaleY": 0.8, "scaleX": 0.8, "height": 100, "runtime": "ui.test.HPBlueUI" }, "compId": 1145 }, { "type": "HPRed", "props": { "y": 230, "x": 532, "scaleY": 0.8, "scaleX": 0.8, "runtime": "ui.test.HPRedUI" }, "compId": 1146 }, { "type": "Map", "props": { "y": 10.100000000000001, "x": 8, "scaleY": 0.7, "scaleX": 0.7, "runtime": "ui.test.MapUI" }, "compId": 1147 }, { "type": "Defen", "props": { "y": 330, "x": 1355, "runtime": "ui.test.DefenUI" }, "compId": 1148 }, { "type": "HeroSkill", "props": { "y": 273, "x": 1122, "runtime": "ui.test.HeroSkillUI" }, "compId": 1153 }, { "type": "HeroSkill1", "props": { "y": 297, "x": 980, "runtime": "ui.test.HeroSkill1UI" }, "compId": 1155 }, { "type": "Box", "props": { "y": 159.5, "x": 1144, "scaleY": 0.7, "scaleX": 0.7 }, "compId": 1156, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillbg.png", "alpha": 0.3 }, "compId": 1157 }, { "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillcdWhite.png" }, "compId": 1158 }, { "type": "Label", "props": { "y": 43, "x": 39, "wordWrap": true, "width": 61, "text": "7", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1159 }, { "type": "Image", "props": { "y": 85, "x": 55, "width": 35, "skin": "ui/img_UM_AmmoIcon_white.png", "height": 16 }, "compId": 1160 }] }, { "type": "Image", "props": { "y": 459, "x": 81, "width": 240, "skin": "ui/img_UM_lunpan.png", "height": 240 }, "compId": 1161 }, { "type": "Image", "props": { "y": 509, "x": 131, "skin": "ui/img_UM_lunpan_btn.png" }, "compId": 1163 }, { "type": "Image", "props": { "y": 459, "x": 996, "width": 240, "skin": "ui/img_UM_lunpan.png", "height": 240 }, "compId": 1164 }, { "type": "Image", "props": { "y": 509, "x": 1046, "skin": "ui/img_UM_lunpan_btn3.png" }, "compId": 1165 }, { "type": "HeroKillHead", "props": { "y": 262, "x": 20, "runtime": "ui.test.HeroKillHeadUI" }, "compId": 1167 }, { "type": "Box", "props": { "y": 20.1, "x": 378.20000000000005 }, "compId": 1172, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1171 }, { "type": "Image", "props": { "y": 3, "x": 86, "width": 195, "skin": "ui/img_UM_progressbar_blue2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1170 }, { "type": "Label", "props": { "y": 4, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1176 }] }, { "type": "Box", "props": { "y": 22, "x": 695.1 }, "compId": 1179, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1180 }, { "type": "Image", "props": { "y": 3, "x": 3, "width": 195, "skin": "ui/img_UM_progressbar_red2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1181 }, { "type": "Label", "props": { "y": 5, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1183 }] }], "loadList": ["ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_skillbg.png", "ui/img_UM_skillcdWhite.png", "ui/img_UM_AmmoIcon_white.png", "ui/img_UM_lunpan.png", "ui/img_UM_lunpan_btn.png", "ui/img_UM_lunpan_btn3.png", "ui/img_UM_progressbar_blue2_1.png", "ui/img_UM_progressbar_blue2.png", "ui/img_UM_progressbar_red2.png"], "loadList3D": [] };
            test.Battle2UI = Battle2UI;
            REG("ui.test.Battle2UI", Battle2UI);
            class Battle3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Battle3UI.uiView);
                }
            }
            Battle3UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 587, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 1133 }, { "type": "Image", "props": { "y": 3, "x": 617, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 1134 }, { "type": "BattleEffect", "props": { "y": 3, "x": 361.1, "runtime": "ui.test.BattleEffectUI" }, "compId": 1219 }, { "type": "Label", "props": { "y": 39, "x": 586, "wordWrap": true, "width": 108, "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 1135 }, { "type": "HPBlue", "props": { "y": 623, "x": 530, "scaleY": 0.8, "scaleX": 0.8, "runtime": "ui.test.HPBlueUI" }, "compId": 1145 }, { "type": "HPRed", "props": { "y": 230, "x": 532, "scaleY": 0.8, "scaleX": 0.8, "runtime": "ui.test.HPRedUI" }, "compId": 1146 }, { "type": "Map", "props": { "y": 10.100000000000001, "x": 8, "scaleY": 0.7, "scaleX": 0.7, "runtime": "ui.test.MapUI" }, "compId": 1147 }, { "type": "Defen", "props": { "y": 330, "x": 1355, "runtime": "ui.test.DefenUI" }, "compId": 1148 }, { "type": "HeroSkill", "props": { "y": 273, "x": 1122, "runtime": "ui.test.HeroSkillUI" }, "compId": 1153 }, { "type": "HeroSkill1", "props": { "y": 159.5, "x": 1515, "runtime": "ui.test.HeroSkill1UI" }, "compId": 1155 }, { "type": "Box", "props": { "y": 159.5, "x": 1144, "scaleY": 0.7, "scaleX": 0.7 }, "compId": 1156, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillbg.png", "alpha": 0.3 }, "compId": 1157 }, { "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillcdWhite.png" }, "compId": 1158 }, { "type": "Label", "props": { "y": 43, "x": 39, "wordWrap": true, "width": 61, "text": "7", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1159 }, { "type": "Image", "props": { "y": 85, "x": 55, "width": 35, "skin": "ui/img_UM_AmmoIcon_white.png", "height": 16 }, "compId": 1160 }] }, { "type": "Image", "props": { "y": 334, "x": 89, "width": 240, "skin": "ui/img_UM_lunpan.png", "height": 240 }, "compId": 1161 }, { "type": "Image", "props": { "y": 384, "x": 138, "skin": "ui/img_UM_lunpan_btn.png" }, "compId": 1163 }, { "type": "Image", "props": { "y": 396, "x": 875, "width": 240, "skin": "ui/img_UM_lunpan.png", "height": 240 }, "compId": 1164 }, { "type": "Image", "props": { "y": 446, "x": 925, "skin": "ui/img_UM_lunpan_btn3.png" }, "compId": 1165 }, { "type": "HeroKillHead", "props": { "y": 20.1, "x": 995, "runtime": "ui.test.HeroKillHeadUI" }, "compId": 1167 }, { "type": "Box", "props": { "y": 20.1, "x": 378.20000000000005 }, "compId": 1172, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1171 }, { "type": "Image", "props": { "y": 3, "x": 86, "width": 195, "skin": "ui/img_UM_progressbar_blue2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1170 }, { "type": "Label", "props": { "y": 4, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1176 }] }, { "type": "Box", "props": { "y": 22, "x": 695.1 }, "compId": 1179, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1180 }, { "type": "Image", "props": { "y": 3, "x": 3, "width": 195, "skin": "ui/img_UM_progressbar_red2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1181 }, { "type": "Label", "props": { "y": 5, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1183 }] }, { "type": "AnimTarget1", "props": { "y": 101, "x": 0, "runtime": "ui.test.AnimTarget1UI" }, "compId": 1194 }, { "type": "AnimTarget2", "props": { "y": 147, "x": 0, "runtime": "ui.test.AnimTarget2UI" }, "compId": 1195 }, { "type": "Image", "props": { "y": 8.100000000000001, "x": 410, "width": 466, "skin": "ui/img_UM_ribbon_bg_yellow2.png", "sizeGrid": "0,69,0,67", "scaleY": 0.3, "scaleX": 0.3, "height": 75 }, "compId": 1212 }, { "type": "Image", "props": { "y": 6, "x": 462.6, "width": 37, "skin": "ui/img_UM_ui_text16.png", "height": 20 }, "compId": 1213 }, { "type": "Image", "props": { "y": 16, "x": 138, "width": 205, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "33,37,38,35", "height": 172, "alpha": 0.2 }, "compId": 1214 }, { "type": "Box", "props": { "y": 580, "x": 797 }, "compId": 1217, "child": [{ "type": "Image", "props": { "width": 86, "skin": "ui/img_UM_lunpan_btn4.png", "height": 86 }, "compId": 1215 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 55, "skin": "ui/img_UM_text_qiehuan.png", "height": 54 }, "compId": 1216 }] }, { "type": "BattleShiyong", "props": { "y": 535, "x": 1096, "runtime": "ui.test.BattleShiyongUI" }, "compId": 1232 }, { "type": "Image", "props": { "y": 273, "x": 47, "width": 84, "skin": "ui/img_UM_lunpan_btn3.png", "height": 84 }, "compId": 1233 }, { "type": "BattleTaskBox", "props": { "y": 618, "x": 236, "runtime": "ui.test.BattleTaskBoxUI" }, "compId": 1236 }, { "type": "BattleTaskBox2", "props": { "y": 618, "x": 143, "runtime": "ui.test.BattleTaskBox2UI" }, "compId": 1237 }, { "type": "BattleTaskBox3", "props": { "y": 618, "x": 329, "runtime": "ui.test.BattleTaskBox3UI" }, "compId": 1238 }, { "type": "BattleTaskBox3", "props": { "y": 618, "x": 422, "runtime": "ui.test.BattleTaskBox3UI" }, "compId": 1239 }, { "type": "BtnDaodan", "props": { "y": 109.5, "x": 1015, "runtime": "ui.test.BtnDaodanUI" }, "compId": 1240 }, { "type": "BtnHuixue", "props": { "y": 230, "x": 1015, "runtime": "ui.test.BtnHuixueUI" }, "compId": 1241 }], "loadList": ["ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_skillbg.png", "ui/img_UM_skillcdWhite.png", "ui/img_UM_AmmoIcon_white.png", "ui/img_UM_lunpan.png", "ui/img_UM_lunpan_btn.png", "ui/img_UM_lunpan_btn3.png", "ui/img_UM_progressbar_blue2_1.png", "ui/img_UM_progressbar_blue2.png", "ui/img_UM_progressbar_red2.png", "ui/img_UM_ribbon_bg_yellow2.png", "ui/img_UM_ui_text16.png", "ui/img_UM_ui_yingzi.png", "ui/img_UM_lunpan_btn4.png", "ui/img_UM_text_qiehuan.png"], "loadList3D": [] };
            test.Battle3UI = Battle3UI;
            REG("ui.test.Battle3UI", Battle3UI);
            class Battle4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Battle4UI.uiView);
                }
            }
            Battle4UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg.jpg" }, "compId": 1187 }, { "type": "Image", "props": { "y": 9, "x": 587, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 1133 }, { "type": "Image", "props": { "y": 3, "x": 617, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 1134 }, { "type": "BattleEffect", "props": { "y": 3, "x": 361.1, "runtime": "ui.test.BattleEffectUI" }, "compId": 1219 }, { "type": "Label", "props": { "y": 39, "x": 586, "wordWrap": true, "width": 108, "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 1135 }, { "type": "HPBlue", "props": { "y": 586, "x": 520, "scaleY": 0.8, "scaleX": 0.8, "runtime": "ui.test.HPBlueUI" }, "compId": 1145 }, { "type": "HPRed", "props": { "y": 230, "x": 532, "scaleY": 0.8, "scaleX": 0.8, "runtime": "ui.test.HPRedUI" }, "compId": 1146 }, { "type": "Map", "props": { "y": 10.100000000000001, "x": 8, "scaleY": 0.7, "scaleX": 0.7, "runtime": "ui.test.MapUI" }, "compId": 1147 }, { "type": "Defen", "props": { "y": 330, "x": 1355, "runtime": "ui.test.DefenUI" }, "compId": 1148 }, { "type": "HeroSkill", "props": { "y": 273, "x": 1122, "runtime": "ui.test.HeroSkillUI" }, "compId": 1153 }, { "type": "HeroSkill1", "props": { "y": 310, "x": 996, "runtime": "ui.test.HeroSkill1UI" }, "compId": 1155 }, { "type": "Box", "props": { "y": 159.5, "x": 1144, "scaleY": 0.7, "scaleX": 0.7 }, "compId": 1156, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillbg.png", "alpha": 0.3 }, "compId": 1157 }, { "type": "Image", "props": { "y": 1, "x": 0, "skin": "ui/img_UM_skillcdWhite.png" }, "compId": 1158 }, { "type": "Label", "props": { "y": 43, "x": 39, "wordWrap": true, "width": 61, "text": "7", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1159 }, { "type": "Image", "props": { "y": 85, "x": 55, "width": 35, "skin": "ui/img_UM_AmmoIcon_white.png", "height": 16 }, "compId": 1160 }] }, { "type": "Image", "props": { "y": 459, "x": 81, "width": 240, "skin": "ui/img_UM_lunpan.png", "height": 240 }, "compId": 1161 }, { "type": "Image", "props": { "y": 509, "x": 131, "skin": "ui/img_UM_lunpan_btn.png" }, "compId": 1163 }, { "type": "Image", "props": { "y": 459, "x": 996, "width": 240, "skin": "ui/img_UM_lunpan.png", "height": 240 }, "compId": 1164 }, { "type": "Image", "props": { "y": 509, "x": 1046, "skin": "ui/img_UM_lunpan_btn3.png" }, "compId": 1165 }, { "type": "HeroKillHead", "props": { "y": 262, "x": 20, "runtime": "ui.test.HeroKillHeadUI" }, "compId": 1167 }, { "type": "Box", "props": { "y": 20.1, "x": 378.20000000000005 }, "compId": 1172, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1171 }, { "type": "Image", "props": { "y": 3, "x": 86, "width": 195, "skin": "ui/img_UM_progressbar_blue2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1170 }, { "type": "Label", "props": { "y": 4, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1176 }] }, { "type": "Box", "props": { "y": 22, "x": 695.1 }, "compId": 1179, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1180 }, { "type": "Image", "props": { "y": 3, "x": 3, "width": 195, "skin": "ui/img_UM_progressbar_red2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1181 }, { "type": "Label", "props": { "y": 5, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1183 }] }, { "type": "AnimTarget1", "props": { "y": 101, "x": 0, "runtime": "ui.test.AnimTarget1UI" }, "compId": 1194 }, { "type": "AnimTarget2", "props": { "y": 147, "x": 0, "runtime": "ui.test.AnimTarget2UI" }, "compId": 1195 }, { "type": "Image", "props": { "y": 8.100000000000001, "x": 410, "width": 466, "skin": "ui/img_UM_ribbon_bg_yellow2.png", "sizeGrid": "0,69,0,67", "scaleY": 0.3, "scaleX": 0.3, "height": 75 }, "compId": 1212 }, { "type": "Image", "props": { "y": 6, "x": 462.6, "width": 37, "skin": "ui/img_UM_ui_text16.png", "height": 20 }, "compId": 1213 }, { "type": "Image", "props": { "y": 16, "x": 138, "width": 205, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "33,37,38,35", "height": 172, "alpha": 0.2 }, "compId": 1214 }, { "type": "Box", "props": { "y": 613, "x": 910 }, "compId": 1217, "child": [{ "type": "Image", "props": { "width": 86, "skin": "ui/img_UM_lunpan_btn4.png", "height": 86 }, "compId": 1215 }, { "type": "Image", "props": { "y": 15, "x": 15, "width": 55, "skin": "ui/img_UM_text_qiehuan.png", "height": 54 }, "compId": 1216 }] }, { "type": "Image", "props": { "y": -40, "x": -10, "width": 1300, "skin": "ui/img_UM_black.png", "sizeGrid": "11,11,11,11", "height": 800, "alpha": 0.6 }, "compId": 1224 }, { "type": "guide1", "props": { "y": 378, "x": 1, "runtime": "ui.test.guide1UI" }, "compId": 1220 }, { "type": "guide2", "props": { "y": 381, "x": 916, "runtime": "ui.test.guide2UI" }, "compId": 1221 }, { "type": "guide3", "props": { "y": 66.8, "x": 1677, "runtime": "ui.test.guide3UI" }, "compId": 1222 }, { "type": "guide4", "props": { "y": 43, "x": 1452, "runtime": "ui.test.guide4UI" }, "compId": 1223 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_skillbg.png", "ui/img_UM_skillcdWhite.png", "ui/img_UM_AmmoIcon_white.png", "ui/img_UM_lunpan.png", "ui/img_UM_lunpan_btn.png", "ui/img_UM_lunpan_btn3.png", "ui/img_UM_progressbar_blue2_1.png", "ui/img_UM_progressbar_blue2.png", "ui/img_UM_progressbar_red2.png", "ui/img_UM_ribbon_bg_yellow2.png", "ui/img_UM_ui_text16.png", "ui/img_UM_ui_yingzi.png", "ui/img_UM_lunpan_btn4.png", "ui/img_UM_text_qiehuan.png", "ui/img_UM_black.png"], "loadList3D": [] };
            test.Battle4UI = Battle4UI;
            REG("ui.test.Battle4UI", Battle4UI);
            class BattleEffectUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleEffectUI.uiView);
                }
            }
            BattleEffectUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 240, "mouseThrough": true, "height": 80 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 120, "width": 238, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "29,40,31,46", "pivotY": 36, "pivotX": 119, "height": 72 }, "compId": 1151 }], "animations": [{ "nodes": [{ "target": 1151, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "label": null, "key": "scaleY", "index": 10 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "label": null, "key": "scaleX", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_yellow.png"], "loadList3D": [] };
            test.BattleEffectUI = BattleEffectUI;
            REG("ui.test.BattleEffectUI", BattleEffectUI);
            class BattleShiyongUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleShiyongUI.uiView);
                }
            }
            BattleShiyongUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": false, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 29, "x": 31, "width": 138, "skin": "ui/img_UM_btn__Gold.png", "sizeGrid": "22,22,22,22", "height": 141 }, "compId": 1146 }, { "type": "Image", "props": { "y": 19, "x": 21, "width": 146, "skin": "ui/img_UM_img_shiyong.png", "height": 91 }, "compId": 1147 }, { "type": "Image", "props": { "y": 110, "x": 22, "width": 156, "skin": "ui/img_UM_btn_green.png", "height": 63 }, "compId": 1148, "child": [{ "type": "Image", "props": { "y": 18, "x": 53, "width": 89, "skin": "ui/img_UM_ui_text62.png", "height": 26 }, "compId": 1150 }, { "type": "Image", "props": { "y": 18, "x": 15, "width": 32, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 26 }, "compId": 1152 }] }, { "type": "Image", "props": { "y": 140, "x": 99, "width": 168, "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "33,33,33,33", "pivotY": 39, "pivotX": 84, "height": 77 }, "compId": 1151 }], "animations": [{ "nodes": [{ "target": 1151, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1151, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1151, "label": null, "key": "alpha", "index": 25 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_btn__Gold.png", "ui/img_UM_img_shiyong.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text62.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_rank_effectbk.png"], "loadList3D": [] };
            test.BattleShiyongUI = BattleShiyongUI;
            REG("ui.test.BattleShiyongUI", BattleShiyongUI);
            class BattleTaskBoxUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTaskBoxUI.uiView);
                }
            }
            BattleTaskBoxUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_UM_battle_taskbox.png", "height": 100 }, "compId": 1152 }, { "type": "Image", "props": { "y": 40, "x": 6, "width": 87, "skin": "ui/img_UM_ui_text37.png", "height": 25 }, "compId": 1153 }], "loadList": ["ui/img_UM_battle_taskbox.png", "ui/img_UM_ui_text37.png"], "loadList3D": [] };
            test.BattleTaskBoxUI = BattleTaskBoxUI;
            REG("ui.test.BattleTaskBoxUI", BattleTaskBoxUI);
            class BattleTaskBox2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTaskBox2UI.uiView);
                }
            }
            BattleTaskBox2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 82, "scaleY": 0.8, "scaleX": 0.8, "mouseThrough": false, "height": 75 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 50, "x": 50, "width": 106, "var": "img_frame", "skin": "ui/img_UM_battle_taskbox2.png", "pivotY": 53, "pivotX": 53, "name": "img_frame", "height": 106, "gray": false }, "compId": 1154 }, { "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "var": "img_box", "skin": "ui/img_UM_battle_taskbox.png", "name": "img_box", "height": 100, "gray": false }, "compId": 1152 }, { "type": "Image", "props": { "y": 37, "x": 6, "width": 87, "var": "img_receive", "skin": "ui/img_UM_ui_text37.png", "name": "img_receive", "height": 25 }, "compId": 1157 }, { "type": "BattleTaskBoxPao", "props": { "y": -18, "x": 51, "width": 100, "var": "ui_bubble", "pivotY": 17, "pivotX": 50, "name": "ui_bubble", "height": 50, "runtime": "ui.test.BattleTaskBoxPaoUI" }, "compId": 1158 }], "animations": [{ "nodes": [{ "target": 1154, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "label": null, "key": "alpha", "index": 20 }] } }, { "target": 1158, "keyframes": { "y": [{ "value": -18, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "y", "index": 0 }, { "value": -27, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "y", "index": 5 }, { "value": -14, "tweenMethod": "linearNone", "tween": true, "target": 1158, "label": null, "key": "y", "index": 15 }, { "value": -18, "tweenMethod": "linearNone", "tween": true, "target": 1158, "label": null, "key": "y", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_battle_taskbox2.png", "ui/img_UM_battle_taskbox.png", "ui/img_UM_ui_text37.png"], "loadList3D": [] };
            test.BattleTaskBox2UI = BattleTaskBox2UI;
            REG("ui.test.BattleTaskBox2UI", BattleTaskBox2UI);
            class BattleTaskBox3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTaskBox3UI.uiView);
                }
            }
            BattleTaskBox3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_UM_battle_taskbox.png", "height": 100, "gray": true }, "compId": 1152 }, { "type": "Image", "props": { "y": 40, "x": 4, "width": 92, "skin": "ui/img_UM_ui_text36.png", "height": 26 }, "compId": 1157 }], "loadList": ["ui/img_UM_battle_taskbox.png", "ui/img_UM_ui_text36.png"], "loadList3D": [] };
            test.BattleTaskBox3UI = BattleTaskBox3UI;
            REG("ui.test.BattleTaskBox3UI", BattleTaskBox3UI);
            class BattleTaskBoxPaoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BattleTaskBoxPaoUI.uiView);
                }
            }
            BattleTaskBoxPaoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 50 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 26, "x": 50, "width": 98, "skin": "ui/img_UM_ui_red2.png", "sizeGrid": "17,17,31,40", "pivotY": 27, "pivotX": 49, "height": 54 }, "compId": 1160 }, { "type": "Image", "props": { "y": 27, "x": 50, "width": 126, "var": "img_get", "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "scaleY": 0.7, "scaleX": 0.7, "pivotY": 31, "pivotX": 63, "name": "img_get", "height": 62 }, "compId": 1158 }, { "type": "Image", "props": { "y": 13, "x": 20, "width": 58, "var": "img_txt", "skin": "ui/img_UM_ui_text63.png", "name": "img_txt", "height": 17 }, "compId": 1159 }], "animations": [{ "nodes": [{ "target": 1160, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1160, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1160, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1160, "label": null, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red2.png", "ui/img_UM_ui_red.png", "ui/img_UM_ui_text63.png"], "loadList3D": [] };
            test.BattleTaskBoxPaoUI = BattleTaskBoxPaoUI;
            REG("ui.test.BattleTaskBoxPaoUI", BattleTaskBoxPaoUI);
            class BtnDaodanUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnDaodanUI.uiView);
                }
            }
            BtnDaodanUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 51, "width": 120, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,22,22,22", "pivotY": 49, "pivotX": 60, "height": 120, "blendMode": "lighter" }, "compId": 1657 }, { "type": "Image", "props": { "y": 50, "x": 50, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "pivotY": 50, "pivotX": 50, "height": 100 }, "compId": 1652 }, { "type": "Image", "props": { "y": 77, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text78.png", "height": 30 }, "compId": 1653 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 104, "skin": "ui/img_UM_icon_daodan.png", "height": 82 }, "compId": 1655 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 38, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 30 }, "compId": 1656 }], "animations": [{ "nodes": [{ "target": 1657, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 20 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 30 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 40 }] } }, { "target": 1652, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 7 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 11 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleY", "index": 19 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 7 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 11 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleX", "index": 19 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text78.png", "ui/img_UM_icon_daodan.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            test.BtnDaodanUI = BtnDaodanUI;
            REG("ui.test.BtnDaodanUI", BtnDaodanUI);
            class BtnEffectUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnEffectUI.uiView);
                }
            }
            BtnEffectUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 160 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 200, "width": 343, "skin": "ui/img_UM_btn_effect5.png", "sizeGrid": "49,65,49,58", "pivotY": 63, "pivotX": 172, "height": 126, "blendMode": "lighter" }, "compId": 1161 }, { "type": "Box", "props": { "y": 19, "x": 31, "width": 338, "height": 121 }, "compId": 1147, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 338, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "55,50,40,50", "height": 121 }, "compId": 1149 }] }, { "type": "Image", "props": { "y": 25, "x": 38, "width": 323, "skin": "ui/img_UM_btn_effect3.png", "height": 97, "blendMode": "lighter", "alpha": 0.1 }, "compId": 1158 }, { "type": "Box", "props": { "y": 25, "x": 38 }, "compId": 1156, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 323, "skin": "ui/img_UM_btn_effect3.png", "renderType": "mask", "height": 97, "blendMode": "lighter", "alpha": 0.3 }, "compId": 1155 }, { "type": "Image", "props": { "y": -25, "x": -429, "skin": "ui/img_UM_btn_effect4.png", "blendMode": "lighter" }, "compId": 1157 }] }, { "type": "Image", "props": { "y": 73, "x": 200, "width": 217, "skin": "ui/img_UM_text_ksyx.png", "pivotY": 26, "pivotX": 109, "height": 51 }, "compId": 1150 }], "animations": [{ "nodes": [{ "target": 1157, "keyframes": { "x": [{ "value": -429, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "x", "index": 0 }, { "value": 450, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "x", "index": 10 }, { "value": 450, "tweenMethod": "linearNone", "tween": true, "target": 1157, "label": null, "key": "x", "index": 15 }] } }, { "target": 1155, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 15 }] } }, { "target": 1158, "keyframes": { "alpha": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "alpha", "index": 5 }, { "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "alpha", "index": 15 }] } }, { "target": 1161, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "scaleY", "index": 0 }, { "value": 1.8, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "scaleY", "index": 5 }, { "value": 2, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "scaleY", "index": 15 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "scaleX", "index": 5 }, { "value": 1.4, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "scaleX", "index": 15 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1161, "key": "alpha", "index": 15 }] } }, { "target": 1150, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "label": null, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "key": "scaleY", "index": 5 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1150, "label": null, "key": "scaleY", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "label": null, "key": "scaleY", "index": 9 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "label": null, "key": "scaleX", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "key": "scaleX", "index": 5 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1150, "label": null, "key": "scaleX", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1150, "label": null, "key": "scaleX", "index": 9 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_effect5.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_btn_effect3.png", "ui/img_UM_btn_effect4.png", "ui/img_UM_text_ksyx.png"], "loadList3D": [] };
            test.BtnEffectUI = BtnEffectUI;
            REG("ui.test.BtnEffectUI", BtnEffectUI);
            class BtnEffect1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnEffect1UI.uiView);
                }
            }
            BtnEffect1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 160 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 19, "x": 31, "width": 338, "height": 121 }, "compId": 1147, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 338, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "55,50,40,50", "height": 121 }, "compId": 1149 }] }, { "type": "Image", "props": { "y": 25, "x": 38, "width": 323, "skin": "ui/img_UM_btn_effect3.png", "height": 97, "blendMode": "lighter", "alpha": 0.1 }, "compId": 1158 }, { "type": "Box", "props": { "y": 25, "x": 38 }, "compId": 1156, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 323, "skin": "ui/img_UM_btn_effect3.png", "renderType": "mask", "height": 97, "blendMode": "lighter", "alpha": 0.3 }, "compId": 1155 }, { "type": "Image", "props": { "y": -25, "x": -429, "skin": "ui/img_UM_btn_effect4.png", "blendMode": "lighter" }, "compId": 1157 }] }, { "type": "Image", "props": { "y": 102, "x": -835, "width": 217, "skin": "ui/img_UM_text_ksyx.png", "height": 51 }, "compId": 1150 }, { "type": "Image", "props": { "y": 72, "x": -906, "skin": "ui/img_UM_clan35.png" }, "compId": 1151 }, { "type": "Label", "props": { "y": 43, "x": 101, "wordWrap": true, "width": 197, "valign": "middle", "text": "开始战斗", "strokeColor": "#000000", "name": "txt_phy", "height": 59, "fontSize": 46, "font": "SimHei", "color": "#2a1509", "bold": true, "align": "center" }, "compId": 1160 }], "animations": [{ "nodes": [{ "target": 1157, "keyframes": { "x": [{ "value": -429, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "x", "index": 0 }, { "value": 450, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "x", "index": 10 }, { "value": 450, "tweenMethod": "linearNone", "tween": true, "target": 1157, "label": null, "key": "x", "index": 15 }] } }, { "target": 1155, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 15 }] } }, { "target": 1158, "keyframes": { "alpha": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "alpha", "index": 5 }, { "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 1158, "key": "alpha", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_btn_effect3.png", "ui/img_UM_btn_effect4.png", "ui/img_UM_text_ksyx.png", "ui/img_UM_clan35.png"], "loadList3D": [] };
            test.BtnEffect1UI = BtnEffect1UI;
            REG("ui.test.BtnEffect1UI", BtnEffect1UI);
            class BtnHeadUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnHeadUI.uiView);
                }
            }
            BtnHeadUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 50, "x": 50, "width": 110, "pivotY": 55, "pivotX": 55, "height": 110 }, "compId": 1154, "child": [{ "type": "Image", "props": { "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1155 }, { "type": "Image", "props": { "y": 3, "x": 4, "var": "img_head", "skin": "ui/img_UM_head.png", "renderType": "render", "name": "img_head" }, "compId": 1156 }] }], "animations": [{ "nodes": [{ "target": 1154, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleY", "index": 17 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1154, "key": "scaleX", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn__btn1.png", "ui/img_UM_head.png"], "loadList3D": [] };
            test.BtnHeadUI = BtnHeadUI;
            REG("ui.test.BtnHeadUI", BtnHeadUI);
            class BtnHuixueUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnHuixueUI.uiView);
                }
            }
            BtnHuixueUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 51, "width": 120, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,22,22,22", "pivotY": 49, "pivotX": 60, "height": 120, "blendMode": "lighter" }, "compId": 1657 }, { "type": "Image", "props": { "y": 50, "x": 50, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "pivotY": 50, "pivotX": 50, "height": 100 }, "compId": 1652 }, { "type": "Image", "props": { "y": 77, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text79.png", "height": 30 }, "compId": 1653 }, { "type": "Image", "props": { "y": 6, "x": 14, "width": 73, "skin": "ui/img_UM_icon_jiaxue.png", "height": 71 }, "compId": 1659 }, { "type": "Image", "props": { "y": -1, "x": -2, "width": 38, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 30 }, "compId": 1656 }], "animations": [{ "nodes": [{ "target": 1657, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "key": "alpha", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 20 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 30 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1657, "label": null, "key": "alpha", "index": 40 }] } }, { "target": 1652, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 7 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 11 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleY", "index": 19 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 7 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 11 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1652, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1652, "label": null, "key": "scaleX", "index": 19 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text79.png", "ui/img_UM_icon_jiaxue.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            test.BtnHuixueUI = BtnHuixueUI;
            REG("ui.test.BtnHuixueUI", BtnHuixueUI);
            class BtnLjsyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnLjsyUI.uiView);
                }
            }
            BtnLjsyUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 250, "mouseThrough": false, "height": 80 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 40, "x": 125, "width": 243, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 36, "pivotX": 122, "height": 72 }, "compId": 1144 }, { "type": "Image", "props": { "y": 21, "x": 101, "width": 103, "skin": "ui/img_UM_Card_text3.png", "height": 30 }, "compId": 1145 }, { "type": "Image", "props": { "y": 20.5, "x": 44, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1146 }], "animations": [{ "nodes": [{ "target": 1144, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleY", "index": 0 }, { "value": 1.04, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleY", "index": 15 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "key": "scaleX", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1144, "label": null, "key": "scaleX", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_Card_text3.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            test.BtnLjsyUI = BtnLjsyUI;
            REG("ui.test.BtnLjsyUI", BtnLjsyUI);
            class BtnShiyongUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnShiyongUI.uiView);
                }
            }
            BtnShiyongUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 135 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1144 }, { "type": "Image", "props": { "y": 7, "x": 7, "width": 85, "var": "img_hero", "skin": "ui/img_UM_hero2.png", "name": "img_hero", "height": 85 }, "compId": 1147 }, { "type": "Box", "props": { "y": 111, "x": 52, "width": 125, "scaleX": 1, "pivotY": 30, "pivotX": 63, "height": 59 }, "compId": 1152, "child": [{ "type": "Image", "props": { "width": 122, "skin": "ui/img_UM_herokill_bg_yellow.png", "height": 57 }, "compId": 1151 }, { "type": "Image", "props": { "y": 23, "x": 61, "width": 219, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,24,33,23", "scaleY": 0.5, "scaleX": 0.5, "pivotY": 37, "pivotX": 110, "height": 96 }, "compId": 1148 }] }, { "type": "Image", "props": { "y": 99, "x": 6, "width": 21, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 17 }, "compId": 1149 }, { "type": "Image", "props": { "y": 97, "x": 27, "width": 66, "skin": "ui/img_UM_ui_text73_2.png", "height": 20 }, "compId": 1150 }, { "type": "Label", "props": { "y": 65, "x": -3, "wordWrap": false, "width": 93, "var": "txt_num", "text": "x28", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_num", "height": 21, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1153 }], "animations": [{ "nodes": [{ "target": 1152, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 10 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 17 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 10 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_hero2.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text73_2.png"], "loadList3D": [] };
            test.BtnShiyongUI = BtnShiyongUI;
            REG("ui.test.BtnShiyongUI", BtnShiyongUI);
            class BtnStarGameUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnStarGameUI.uiView);
                }
            }
            BtnStarGameUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 460, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 99, "x": 229, "width": 458, "skin": "ui/img_UM_game_star.png", "scaleY": 0.9, "scaleX": 0.9, "pivotY": 89, "pivotX": 229, "height": 178 }, "compId": 1147 }], "animations": [{ "nodes": [{ "target": 1147, "keyframes": { "scaleY": [{ "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 2 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 4 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 8 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 10 }, { "value": 0.93, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 12 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 14 }, { "value": 0.91, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 16 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleY", "index": 18 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "label": null, "key": "scaleY", "index": 40 }], "scaleX": [{ "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 2 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 4 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 6 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 8 }, { "value": 0.93, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 10 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 12 }, { "value": 0.91, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 14 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1147, "key": "scaleX", "index": 16 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_game_star.png"], "loadList3D": [] };
            test.BtnStarGameUI = BtnStarGameUI;
            REG("ui.test.BtnStarGameUI", BtnStarGameUI);
            class BtnTianjiangUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(BtnTianjiangUI.uiView);
                }
            }
            BtnTianjiangUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1144 }, { "type": "Box", "props": { "y": 111, "x": 52, "width": 125, "scaleX": 1, "pivotY": 30, "pivotX": 63, "height": 59 }, "compId": 1152, "child": [{ "type": "Image", "props": { "width": 122, "skin": "ui/img_UM_herokill_bg_yellow.png", "height": 57 }, "compId": 1151 }, { "type": "Image", "props": { "y": 23, "x": 61, "width": 219, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "19,24,33,23", "scaleY": 0.5, "scaleX": 0.5, "pivotY": 37, "pivotX": 110, "height": 96 }, "compId": 1148 }] }, { "type": "Image", "props": { "y": 99, "x": 6, "width": 21, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 17 }, "compId": 1149 }, { "type": "Image", "props": { "y": 97, "x": 27, "width": 66, "skin": "ui/img_UM_ui_text74.png", "height": 20 }, "compId": 1150 }, { "type": "Image", "props": { "y": 46, "x": 51, "width": 95, "var": "img_box", "skin": "ui/img_UM_box_rankbox3.png", "pivotY": 48, "pivotX": 48, "name": "img_box", "height": 95 }, "compId": 1153 }], "animations": [{ "nodes": [{ "target": 1152, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 10 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleY", "index": 17 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 10 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1152, "key": "scaleX", "index": 17 }] } }, { "target": 1153, "keyframes": { "y": [{ "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "y", "index": 0 }, { "value": 51, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "y", "index": 3 }, { "value": 34, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "y", "index": 6 }, { "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 10 }, { "value": 49, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 13 }, { "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 15 }, { "value": 46, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "y", "index": 17 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 6 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 10 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleY", "index": 13 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "label": null, "key": "scaleY", "index": 15 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 6 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 10 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1153, "key": "scaleX", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_Yellow.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text74.png", "ui/img_UM_box_rankbox3.png"], "loadList3D": [] };
            test.BtnTianjiangUI = BtnTianjiangUI;
            REG("ui.test.BtnTianjiangUI", BtnTianjiangUI);
            class Collimation1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Collimation1UI.uiView);
                }
            }
            Collimation1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_Collimation_1.png" }, "compId": 1078 }, { "type": "Image", "props": { "y": 43, "x": 43, "skin": "ui/img_UM_Collimation_3.png" }, "compId": 1079 }], "loadList": ["ui/img_UM_Collimation_1.png", "ui/img_UM_Collimation_3.png"], "loadList3D": [] };
            test.Collimation1UI = Collimation1UI;
            REG("ui.test.Collimation1UI", Collimation1UI);
            class Collimation2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Collimation2UI.uiView);
                }
            }
            Collimation2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_UM_Collimation_2.png" }, "compId": 1079 }, { "type": "Image", "props": { "y": 43, "x": 43, "skin": "ui/img_UM_Collimation_3.png" }, "compId": 1080 }], "loadList": ["ui/img_UM_Collimation_2.png", "ui/img_UM_Collimation_3.png"], "loadList3D": [] };
            test.Collimation2UI = Collimation2UI;
            REG("ui.test.Collimation2UI", Collimation2UI);
            class Collimation3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Collimation3UI.uiView);
                }
            }
            Collimation3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_UM_Collimation_2.png" }, "compId": 1079 }, { "type": "Image", "props": { "y": 32, "x": 32, "skin": "ui/img_UM_Collimation_4.png" }, "compId": 1081 }], "loadList": ["ui/img_UM_Collimation_2.png", "ui/img_UM_Collimation_4.png"], "loadList3D": [] };
            test.Collimation3UI = Collimation3UI;
            REG("ui.test.Collimation3UI", Collimation3UI);
            class Collimation4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Collimation4UI.uiView);
                }
            }
            Collimation4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": false, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_UM_Collimation_2.png" }, "compId": 1079 }, { "type": "Image", "props": { "y": 50, "x": 50, "width": 36, "skin": "ui/img_UM_Collimation_5.png", "pivotY": 18, "pivotX": 18, "height": 36 }, "compId": 1082 }], "animations": [{ "nodes": [{ "target": 1082, "keyframes": { "scaleY": [{ "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleY", "index": 2 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "label": null, "key": "scaleY", "index": 4 }], "scaleX": [{ "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1082, "key": "scaleX", "index": 2 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1082, "label": null, "key": "scaleX", "index": 4 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_Collimation_2.png", "ui/img_UM_Collimation_5.png"], "loadList3D": [] };
            test.Collimation4UI = Collimation4UI;
            REG("ui.test.Collimation4UI", Collimation4UI);
            class DefenUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(DefenUI.uiView);
                }
            }
            DefenUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 160, "mouseThrough": true, "height": 160 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 70, "x": 19, "width": 121, "skin": "ui/img_UM_ui_defen_red.png", "sizeGrid": "23,23,23,23", "height": 61, "alpha": 0.5 }, "compId": 1171 }, { "type": "Image", "props": { "y": 43, "x": 80, "width": 56, "skin": "ui/img_UM_CrownMVP.png", "pivotY": 28, "pivotX": 28, "height": 56 }, "compId": 1170 }], "loadList": ["ui/img_UM_ui_defen_red.png", "ui/img_UM_CrownMVP.png"], "loadList3D": [] };
            test.DefenUI = DefenUI;
            REG("ui.test.DefenUI", DefenUI);
            class gamemode1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(gamemode1UI.uiView);
                }
            }
            gamemode1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 600, "mouseThrough": false, "height": 360 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 35, "width": 530, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 341, "alpha": 0.6 }, "compId": 1076 }, { "type": "Image", "props": { "y": 85, "x": 44, "skin": "ui/img_UM_ui_img1.png" }, "compId": 1075 }, { "type": "Image", "props": { "y": 16, "x": 146, "skin": "ui/img_UM_text_zd.png" }, "compId": 1077 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_ui_img1.png", "ui/img_UM_text_zd.png"], "loadList3D": [] };
            test.gamemode1UI = gamemode1UI;
            REG("ui.test.gamemode1UI", gamemode1UI);
            class gamemode2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(gamemode2UI.uiView);
                }
            }
            gamemode2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 600, "mouseThrough": false, "height": 360 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 35, "width": 530, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 341, "alpha": 0.6 }, "compId": 1076 }, { "type": "Image", "props": { "y": 85, "x": 44, "skin": "ui/img_UM_ui_img4.png" }, "compId": 1075 }, { "type": "Image", "props": { "y": 16, "x": 146, "skin": "ui/img_UM_text_jdbw.png" }, "compId": 1077 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_ui_img4.png", "ui/img_UM_text_jdbw.png"], "loadList3D": [] };
            test.gamemode2UI = gamemode2UI;
            REG("ui.test.gamemode2UI", gamemode2UI);
            class gamemode3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(gamemode3UI.uiView);
                }
            }
            gamemode3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 600, "mouseThrough": true, "height": 360 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 9, "x": 35, "width": 530, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 341, "alpha": 0.6 }, "compId": 1076 }, { "type": "Image", "props": { "y": 85, "x": 44, "skin": "ui/img_UM_ui_img3.png" }, "compId": 1075 }, { "type": "Image", "props": { "y": 16, "x": 146, "skin": "ui/img_UM_text_5v5.png" }, "compId": 1077 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_ui_img3.png", "ui/img_UM_text_5v5.png"], "loadList3D": [] };
            test.gamemode3UI = gamemode3UI;
            REG("ui.test.gamemode3UI", gamemode3UI);
            class GoodsCardUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsCardUI.uiView);
                }
            }
            GoodsCardUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_goodsCard1.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "金币", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 210, "x": 109, "wordWrap": false, "width": 80, "var": "txt_num", "text": "77", "strokeColor": "#0a0101", "stroke": 5, "name": "txt_num", "height": 61, "fontSize": 65, "font": "SimHei", "color": "#fdfdfd", "bold": true, "align": "right" }, "compId": 1158 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_goodsCard1.png"], "loadList3D": [] };
            test.GoodsCardUI = GoodsCardUI;
            REG("ui.test.GoodsCardUI", GoodsCardUI);
            class GoodsCard1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsCard1UI.uiView);
                }
            }
            GoodsCard1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "名称", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 212, "x": 109, "wordWrap": false, "width": 80, "var": "txt_num", "text": "77", "strokeColor": "#0a0101", "stroke": 5, "name": "txt_num", "height": 61, "fontSize": 65, "font": "SimHei", "color": "#fdfdfd", "bold": true, "align": "right" }, "compId": 1158 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png"], "loadList3D": [] };
            test.GoodsCard1UI = GoodsCard1UI;
            REG("ui.test.GoodsCard1UI", GoodsCard1UI);
            class goodsCardboxUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(goodsCardboxUI.uiView);
                }
            }
            goodsCardboxUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "var": "txt_lv", "skin": "ui/img_ui_num_7.png", "name": "txt_lv" }, "compId": 1151 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.goodsCardboxUI = goodsCardboxUI;
            REG("ui.test.goodsCardboxUI", goodsCardboxUI);
            class GoodsCardDiamondsUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsCardDiamondsUI.uiView);
                }
            }
            GoodsCardDiamondsUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "钻石", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_goodsCard2.png", "name": "img_ico" }, "compId": 1158 }, { "type": "Image", "props": { "y": 204, "x": 149, "skin": "ui/img_ui_num_7.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": 204, "x": 110, "skin": "ui/img_ui_num_7.png" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_goodsCard2.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.GoodsCardDiamondsUI = GoodsCardDiamondsUI;
            REG("ui.test.GoodsCardDiamondsUI", GoodsCardDiamondsUI);
            class GoodsRankbox1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsRankbox1UI.uiView);
                }
            }
            GoodsRankbox1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "skin": "ui/img_UM_rank_bg1.png", "sizeGrid": "8,8,8,8", "height": 232 }, "compId": 1159 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "青铜宝箱", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 48, "x": 1, "skin": "ui/img_UM_box_rankbox1.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 204, "x": 149, "skin": "ui/img_ui_num_7.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": 204, "x": 110, "skin": "ui/img_ui_num_7.png" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_rank_bg1.png", "ui/img_UM_box_rankbox1.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.GoodsRankbox1UI = GoodsRankbox1UI;
            REG("ui.test.GoodsRankbox1UI", GoodsRankbox1UI);
            class GoodsRankbox2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsRankbox2UI.uiView);
                }
            }
            GoodsRankbox2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "skin": "ui/img_UM_rank_bg1.png", "sizeGrid": "8,8,8,8", "height": 232 }, "compId": 1159 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "黄金宝箱", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 48, "x": 1, "skin": "ui/img_UM_box_rankbox2.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 204, "x": 149, "skin": "ui/img_ui_num_7.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": 204, "x": 110, "skin": "ui/img_ui_num_7.png" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_rank_bg1.png", "ui/img_UM_box_rankbox2.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.GoodsRankbox2UI = GoodsRankbox2UI;
            REG("ui.test.GoodsRankbox2UI", GoodsRankbox2UI);
            class GoodsRankbox3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsRankbox3UI.uiView);
                }
            }
            GoodsRankbox3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "skin": "ui/img_UM_rank_bg1.png", "sizeGrid": "8,8,8,8", "height": 232 }, "compId": 1159 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "钻石宝箱", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 48, "x": 1, "skin": "ui/img_UM_box_rankbox3.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 204, "x": 149, "skin": "ui/img_ui_num_7.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": 204, "x": 110, "skin": "ui/img_ui_num_7.png" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_rank_bg1.png", "ui/img_UM_box_rankbox3.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.GoodsRankbox3UI = GoodsRankbox3UI;
            REG("ui.test.GoodsRankbox3UI", GoodsRankbox3UI);
            class GoodsRankbox4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsRankbox4UI.uiView);
                }
            }
            GoodsRankbox4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "skin": "ui/img_UM_rank_bg1.png", "sizeGrid": "8,8,8,8", "height": 232 }, "compId": 1159 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "传说宝箱", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 48, "x": 1, "skin": "ui/img_UM_box_rankbox4.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 204, "x": 149, "skin": "ui/img_ui_num_7.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": 204, "x": 110, "skin": "ui/img_ui_num_7.png" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_rank_bg1.png", "ui/img_UM_box_rankbox4.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.GoodsRankbox4UI = GoodsRankbox4UI;
            REG("ui.test.GoodsRankbox4UI", GoodsRankbox4UI);
            class GoodsRankbox5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(GoodsRankbox5UI.uiView);
                }
            }
            GoodsRankbox5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "width": 185, "skin": "ui/img_UM_rank_bg1.png", "sizeGrid": "8,8,8,8", "height": 232 }, "compId": 1159 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "valign": "middle", "text": "彩虹宝箱", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": 48, "x": 1, "skin": "ui/img_UM_box_rankbox5.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 204, "x": 149, "skin": "ui/img_ui_num_7.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": 204, "x": 110, "skin": "ui/img_ui_num_7.png" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_rank_bg1.png", "ui/img_UM_box_rankbox5.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.GoodsRankbox5UI = GoodsRankbox5UI;
            REG("ui.test.GoodsRankbox5UI", GoodsRankbox5UI);
            class guideUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(guideUI.uiView);
                }
            }
            guideUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 500, "mouseThrough": true, "height": 600 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -1, "x": 51, "skin": "ui/img_UM_ui_hero.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": -70, "x": 377, "width": 653, "skin": "ui/img_UM_paopao.png", "sizeGrid": "20,38,45,105", "height": 261 }, "compId": 1147 }, { "type": "Image", "props": { "y": 188, "x": 532, "skin": "ui/img_UM_ui_text58.png" }, "compId": 1150 }, { "type": "Image", "props": { "y": -39.5, "x": 410, "var": "img_info", "skin": "ui/img_UM_ui_guide_1.png", "name": "img_info" }, "compId": 1151 }, { "type": "Image", "props": { "y": 763, "x": 131, "skin": "ui/img_UM_guide_Hand.png" }, "compId": 1154 }], "loadList": ["ui/img_UM_ui_hero.png", "ui/img_UM_paopao.png", "ui/img_UM_ui_text58.png", "ui/img_UM_ui_guide_1.png", "ui/img_UM_guide_Hand.png"], "loadList3D": [] };
            test.guideUI = guideUI;
            REG("ui.test.guideUI", guideUI);
            class guide1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(guide1UI.uiView);
                }
            }
            guide1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 200, "x": 200, "width": 280, "skin": "ui/img_UM_guide_obj1.png", "pivotY": 140, "pivotX": 140, "height": 280 }, "compId": 1155 }, { "type": "Image", "props": { "y": -44, "x": 115, "skin": "ui/img_UM_guide_obj2.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": -67, "x": 71, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1158 }], "animations": [{ "nodes": [{ "target": 1155, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj1.png", "ui/img_UM_guide_obj2.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            test.guide1UI = guide1UI;
            REG("ui.test.guide1UI", guide1UI);
            class guide2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(guide2UI.uiView);
                }
            }
            guide2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 200, "x": 200, "width": 280, "skin": "ui/img_UM_guide_obj1.png", "pivotY": 140, "pivotX": 140, "height": 280 }, "compId": 1155 }, { "type": "Image", "props": { "y": -44, "x": 115, "skin": "ui/img_UM_guide_obj3.png" }, "compId": 1156 }, { "type": "Image", "props": { "y": -69, "x": 71, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1158 }], "animations": [{ "nodes": [{ "target": 1155, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1155, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1155, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj1.png", "ui/img_UM_guide_obj3.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            test.guide2UI = guide2UI;
            REG("ui.test.guide2UI", guide2UI);
            class guide3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(guide3UI.uiView);
                }
            }
            guide3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 179, "x": 179, "width": 161, "skin": "ui/img_UM_guide_obj6.png", "pivotY": 60, "pivotX": 60, "height": 161 }, "compId": 1157 }, { "type": "Image", "props": { "y": 28, "x": 115, "skin": "ui/img_UM_guide_obj4.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 4, "x": 71, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1160 }], "animations": [{ "nodes": [{ "target": 1157, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj6.png", "ui/img_UM_guide_obj4.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            test.guide3UI = guide3UI;
            REG("ui.test.guide3UI", guide3UI);
            class guide4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(guide4UI.uiView);
                }
            }
            guide4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 400, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 200, "x": 200, "width": 148, "skin": "ui/img_UM_guide_obj7.png", "pivotY": 74, "pivotX": 74, "height": 148 }, "compId": 1157 }, { "type": "Image", "props": { "y": 39, "x": 115, "skin": "ui/img_UM_guide_obj5.png" }, "compId": 1158 }, { "type": "Image", "props": { "y": 17, "x": 24, "width": 257, "skin": "ui/img_UM_ui_text58.png", "height": 29 }, "compId": 1159 }], "animations": [{ "nodes": [{ "target": 1157, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 0 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1157, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1157, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_guide_obj7.png", "ui/img_UM_guide_obj5.png", "ui/img_UM_ui_text58.png"], "loadList3D": [] };
            test.guide4UI = guide4UI;
            REG("ui.test.guide4UI", guide4UI);
            class HeadBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeadBtnUI.uiView);
                }
            }
            HeadBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 120 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 60, "x": 150, "width": 303, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 152, "height": 110 }, "compId": 1173 }, { "type": "Image", "props": { "y": 26, "x": 24, "width": 60, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 49 }, "compId": 1174 }, { "type": "Image", "props": { "y": 28, "x": 87, "skin": "ui/img_UM_ui_text23.png" }, "compId": 1175 }], "animations": [{ "nodes": [{ "target": 1173, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text23.png"], "loadList3D": [] };
            test.HeadBtnUI = HeadBtnUI;
            REG("ui.test.HeadBtnUI", HeadBtnUI);
            class heroCardUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCardUI.uiView);
                }
            }
            heroCardUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 260 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_UM_card_card1.png" }, "compId": 1136 }, { "type": "Image", "props": { "y": 60, "x": 20, "width": 140, "skin": "ui/img_UM_playerhead.png", "height": 140 }, "compId": 1133 }, { "type": "Label", "props": { "y": 26, "x": 26, "wordWrap": true, "width": 64, "text": "万能", "strokeColor": "#390f3e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#d32cff", "bold": true, "align": "left" }, "compId": 1134 }, { "type": "Label", "props": { "y": 23, "x": 119, "wordWrap": true, "width": 40, "text": "7", "strokeColor": "#390f3e", "stroke": 4, "name": "txt_phy", "height": 53, "fontSize": 50, "font": "SimHei", "color": "#d32cff", "bold": true, "align": "center" }, "compId": 1137 }, { "type": "Image", "props": { "y": 7, "x": 6, "width": 167, "skin": "ui/img_UM_ui_heroPZ.png", "sizeGrid": "40,40,40,40", "height": 247 }, "compId": 1135 }, { "type": "Box", "props": { "y": 203, "x": 20 }, "compId": 1138, "child": [{ "type": "Image", "props": { "y": -6, "x": -2, "width": 145, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,37,41,41", "scaleY": 1, "scaleX": 1, "height": 73 }, "compId": 1139 }, { "type": "Image", "props": { "y": 5, "x": 31, "skin": "ui/img_UM_Card_text4.png" }, "compId": 1141 }] }], "loadList": ["ui/img_UM_card_card1.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_heroPZ.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_Card_text4.png"], "loadList3D": [] };
            test.heroCardUI = heroCardUI;
            REG("ui.test.heroCardUI", heroCardUI);
            class heroCard1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard1UI.uiView);
                }
            }
            heroCard1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 160, "mouseThrough": true, "height": 230 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 15, "x": 5, "width": 150, "skin": "ui/img_UM_card_card1.png", "sizeGrid": "38,38,44,38", "height": 204 }, "compId": 1136 }, { "type": "Image", "props": { "y": 60, "x": 10, "width": 140, "skin": "ui/img_UM_playerhead.png", "height": 140 }, "compId": 1133 }, { "type": "Label", "props": { "y": 26, "x": 16, "wordWrap": true, "width": 64, "text": "万能", "strokeColor": "#390f3e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#d32cff", "bold": true, "align": "left" }, "compId": 1134 }, { "type": "Label", "props": { "y": 23, "x": 109, "wordWrap": true, "width": 40, "text": "7", "strokeColor": "#390f3e", "stroke": 4, "name": "txt_phy", "height": 53, "fontSize": 50, "font": "SimHei", "color": "#d32cff", "bold": true, "align": "center" }, "compId": 1137 }, { "type": "Image", "props": { "y": 7, "x": -3, "width": 167, "skin": "ui/img_UM_ui_heroPZ.png", "sizeGrid": "40,40,40,40", "height": 222 }, "compId": 1135 }], "loadList": ["ui/img_UM_card_card1.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_heroPZ.png"], "loadList3D": [] };
            test.heroCard1UI = heroCard1UI;
            REG("ui.test.heroCard1UI", heroCard1UI);
            class heroCard2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard2UI.uiView);
                }
            }
            heroCard2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 160, "mouseThrough": true, "height": 230 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 4, "x": 4, "width": 151, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 214 }, "compId": 1138 }, { "type": "Image", "props": { "y": 6, "x": 7, "width": 162, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 225, "alpha": 0.5 }, "compId": 1144 }, { "type": "Image", "props": { "y": 9, "x": 9, "width": 142, "skin": "ui/img_UM_card_pz_0.png", "sizeGrid": "13,13,13,13", "height": 204 }, "compId": 1140 }, { "type": "Image", "props": { "y": 38, "x": 9.5, "width": 140, "skin": "ui/img_UM_playerhead.png", "height": 140 }, "compId": 1133 }, { "type": "Label", "props": { "y": 10, "x": 13, "wordWrap": true, "width": 64, "text": "万能", "strokeColor": "#390f3e", "name": "txt_phy", "height": 28, "fontSize": 24, "font": "SimHei", "color": "#bcbcbc", "bold": true, "align": "left" }, "compId": 1134 }, { "type": "Label", "props": { "y": 10, "x": 107, "wordWrap": true, "width": 40, "text": "7", "strokeColor": "#212121", "stroke": 4, "name": "txt_phy", "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1137 }, { "type": "Image", "props": { "y": 179, "x": 6, "width": 148, "skin": "ui/img_UM_card_barbg.png", "sizeGrid": "10,12,13,13", "height": 36 }, "compId": 1141 }, { "type": "Image", "props": { "y": 178, "x": 6, "width": 149, "skin": "ui/img_UM_card_bar.png", "sizeGrid": "10,12,18,13", "height": 36 }, "compId": 1142 }, { "type": "Label", "props": { "y": 179, "x": 5, "wordWrap": true, "width": 149, "text": "300/300", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#d4f7ff", "bold": true, "align": "center" }, "compId": 1143 }], "loadList": ["ui/img_UM_roundedEmboss.png", "ui/img_UM_ui_yingzi.png", "ui/img_UM_card_pz_0.png", "ui/img_UM_playerhead.png", "ui/img_UM_card_barbg.png", "ui/img_UM_card_bar.png"], "loadList3D": [] };
            test.heroCard2UI = heroCard2UI;
            REG("ui.test.heroCard2UI", heroCard2UI);
            class heroCard21UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard21UI.uiView);
                }
            }
            heroCard21UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 160, "mouseThrough": true, "height": 230 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 7, "width": 162, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 198, "alpha": 0.5 }, "compId": 1144 }, { "type": "Image", "props": { "y": 4, "x": 4, "width": 151, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 188 }, "compId": 1138 }, { "type": "Image", "props": { "y": 9, "x": 9, "width": 142, "skin": "ui/img_UM_card_pz_0.png", "sizeGrid": "13,13,13,13", "height": 177 }, "compId": 1140 }, { "type": "Image", "props": { "y": 38, "x": 9.5, "width": 140, "skin": "ui/img_UM_playerhead.png", "height": 140 }, "compId": 1133 }, { "type": "Label", "props": { "y": 10, "x": 13, "wordWrap": true, "width": 64, "text": "万能", "strokeColor": "#390f3e", "name": "txt_phy", "height": 28, "fontSize": 24, "font": "SimHei", "color": "#bcbcbc", "bold": true, "align": "left" }, "compId": 1134 }, { "type": "Label", "props": { "y": 10, "x": 107, "wordWrap": true, "width": 40, "text": "7", "strokeColor": "#212121", "stroke": 4, "name": "txt_phy", "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1137 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_card_pz_0.png", "ui/img_UM_playerhead.png"], "loadList3D": [] };
            test.heroCard21UI = heroCard21UI;
            REG("ui.test.heroCard21UI", heroCard21UI);
            class heroCard3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard3UI.uiView);
                }
            }
            heroCard3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 0, "x": 162, "wordWrap": false, "width": 27, "visible": true, "var": "txt_lv", "text": "7", "strokeColor": "#272727", "stroke": 4, "name": "txt_lv", "height": 50, "fontSize": 60, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1155 }, { "type": "Label", "props": { "y": 246, "x": 11, "wordWrap": true, "width": 178, "var": "txt_airdrop", "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_airdrop", "height": 25, "fontSize": 25, "font": "SimHei", "color": "#ffffff", "bold": false, "align": "right" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png"], "loadList3D": [] };
            test.heroCard3UI = heroCard3UI;
            REG("ui.test.heroCard3UI", heroCard3UI);
            class heroCard31UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard31UI.uiView);
                }
            }
            heroCard31UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 313, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 306 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "skin": "ui/img_UM_herohead_card.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "skin": "ui/img_ui_num_7.png" }, "compId": 1151 }, { "type": "Image", "props": { "y": 6, "x": 7, "skin": "ui/img_UM_ui_text9.png" }, "compId": 1152 }, { "type": "Box", "props": { "y": 274, "x": 4 }, "compId": 1153, "child": [{ "type": "Image", "props": { "y": -6, "x": -2, "width": 194, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,37,41,41", "scaleY": 1, "scaleX": 1, "height": 73 }, "compId": 1154 }, { "type": "Image", "props": { "y": 5, "x": 58, "skin": "ui/img_UM_ui_text7.png" }, "compId": 1155 }] }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_ui_text9.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text7.png"], "loadList3D": [] };
            test.heroCard31UI = heroCard31UI;
            REG("ui.test.heroCard31UI", heroCard31UI);
            class heroCard32UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard32UI.uiView);
                }
            }
            heroCard32UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 313, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 306 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "skin": "ui/img_UM_herohead_card.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "skin": "ui/img_ui_num_7.png" }, "compId": 1151 }, { "type": "Image", "props": { "y": 6, "x": 7, "skin": "ui/img_UM_ui_text9.png" }, "compId": 1152 }, { "type": "Image", "props": { "y": 271, "x": 4, "width": 191, "skin": "ui/img_UM_card_barbg.png", "sizeGrid": "10,12,13,13", "height": 36 }, "compId": 1153 }, { "type": "Image", "props": { "y": 271, "x": 4, "width": 191, "skin": "ui/img_UM_card_bar.png", "sizeGrid": "10,12,18,13", "height": 36 }, "compId": 1154 }, { "type": "Label", "props": { "y": 273, "x": 25, "wordWrap": true, "width": 149, "text": "300/300", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#d4f7ff", "bold": true, "align": "center" }, "compId": 1155 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_ui_text9.png", "ui/img_UM_card_barbg.png", "ui/img_UM_card_bar.png"], "loadList3D": [] };
            test.heroCard32UI = heroCard32UI;
            REG("ui.test.heroCard32UI", heroCard32UI);
            class heroCard33UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard33UI.uiView);
                }
            }
            heroCard33UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 313, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 306 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "skin": "ui/img_UM_herohead_card.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 0, "x": 153, "skin": "ui/img_ui_num_7.png" }, "compId": 1151 }, { "type": "Image", "props": { "y": 6, "x": 7, "skin": "ui/img_UM_ui_text9.png" }, "compId": 1152 }, { "type": "Box", "props": { "y": 274, "x": 4 }, "compId": 1153, "child": [{ "type": "Image", "props": { "y": -6, "x": -2, "width": 194, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,37,41,41", "scaleY": 1, "scaleX": 1, "height": 73 }, "compId": 1154 }, { "type": "Image", "props": { "y": 5, "x": 45, "skin": "ui/img_UM_ui_text15.png" }, "compId": 1156 }] }, { "type": "Label", "props": { "y": 13, "x": 21, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1157 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_ui_num_7.png", "ui/img_UM_ui_text9.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text15.png"], "loadList3D": [] };
            test.heroCard33UI = heroCard33UI;
            REG("ui.test.heroCard33UI", heroCard33UI);
            class heroCard34UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard34UI.uiView);
                }
            }
            heroCard34UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 310 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 4, "width": 210, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 287, "alpha": 0.5 }, "compId": 1150 }, { "type": "Image", "props": { "y": 2, "x": 1, "width": 198, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 277 }, "compId": 1145 }, { "type": "Image", "props": { "y": 39, "x": 7, "var": "img_ico", "skin": "ui/img_UM_herohead_card.png", "name": "img_ico" }, "compId": 1146 }, { "type": "Image", "props": { "y": -10, "x": 134.5, "width": 76, "skin": "ui/img_UM_levelUpArrow.png", "height": 76 }, "compId": 1155 }, { "type": "Label", "props": { "y": 3, "x": 11, "wordWrap": false, "width": 122, "var": "txt_name", "valign": "middle", "text": "狂点", "strokeColor": "#000000", "stroke": 4, "overflow": "hidden", "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Label", "props": { "y": 7, "x": 149, "wordWrap": false, "width": 47, "var": "txt_lv", "text": "30", "strokeColor": "#272727", "stroke": 4, "name": "txt_lv", "height": 53, "fontSize": 36, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1156 }], "loadList": ["ui/img_UM_ui_yingzi.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_herohead_card.png", "ui/img_UM_levelUpArrow.png"], "loadList3D": [] };
            test.heroCard34UI = heroCard34UI;
            REG("ui.test.heroCard34UI", heroCard34UI);
            class heroCard35UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard35UI.uiView);
                }
            }
            heroCard35UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 140, "mouseThrough": true, "height": 140 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -9, "x": -1, "width": 142, "skin": "ui/img_UM_btn_textBubble.png", "sizeGrid": "33,33,33,33", "height": 157 }, "compId": 1157 }, { "type": "Image", "props": { "y": -3, "x": 7, "width": 126, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 134 }, "compId": 1145 }, { "type": "Image", "props": { "y": 12, "x": 12, "width": 115, "skin": "ui/img_UM_hero3.png", "height": 115 }, "compId": 1156 }, { "type": "Image", "props": { "y": -9, "x": 105, "width": 22, "var": "txt_lv", "skin": "ui/img_ui_num_7.png", "name": "txt_lv", "height": 36 }, "compId": 1151 }, { "type": "Label", "props": { "y": -17, "x": 14, "wordWrap": true, "width": 87, "var": "txt_name", "valign": "middle", "text": "英雄名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 20, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }], "loadList": ["ui/img_UM_btn_textBubble.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_hero3.png", "ui/img_ui_num_7.png"], "loadList3D": [] };
            test.heroCard35UI = heroCard35UI;
            REG("ui.test.heroCard35UI", heroCard35UI);
            class heroCard351UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCard351UI.uiView);
                }
            }
            heroCard351UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 140, "mouseThrough": true, "height": 140 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -9, "x": -1, "width": 142, "skin": "ui/img_UM_btn_textBubble.png", "sizeGrid": "33,33,33,33", "height": 157 }, "compId": 1157 }, { "type": "Image", "props": { "y": -2, "x": 7, "width": 126, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 134 }, "compId": 1145 }, { "type": "Image", "props": { "y": 12, "x": 12, "width": 115, "skin": "ui/img_UM_hero3.png", "height": 115 }, "compId": 1156 }, { "type": "Image", "props": { "y": -9, "x": 105, "width": 22, "var": "txt_lv", "skin": "ui/img_ui_num_7.png", "name": "txt_lv", "height": 36 }, "compId": 1151 }, { "type": "Label", "props": { "y": -17, "x": 14, "wordWrap": true, "width": 87, "var": "txt_name", "valign": "middle", "text": "英雄名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 20, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1154 }, { "type": "Image", "props": { "y": -7, "x": 2, "width": 135, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 152, "alpha": 0.5 }, "compId": 1158 }, { "type": "Image", "props": { "y": 50, "x": -1, "skin": "ui/img_UM_ui_text52.png" }, "compId": 1159 }], "loadList": ["ui/img_UM_btn_textBubble.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_hero3.png", "ui/img_ui_num_7.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_text52.png"], "loadList3D": [] };
            test.heroCard351UI = heroCard351UI;
            REG("ui.test.heroCard351UI", heroCard351UI);
            class heroCardAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCardAnimUI.uiView);
                }
            }
            heroCardAnimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 37, "x": 50, "width": 79, "skin": "ui/img_UM_jt.png", "rotation": 180, "pivotY": 39, "pivotX": 40, "height": 78 }, "compId": 1138 }], "animations": [{ "nodes": [{ "target": 1138, "keyframes": { "y": [{ "value": 34, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 0 }, { "value": 44, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 5 }, { "value": 61.5, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 10 }, { "value": 72, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "y", "index": 15 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 10 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1138, "key": "alpha", "index": 15 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_jt.png"], "loadList3D": [] };
            test.heroCardAnimUI = heroCardAnimUI;
            REG("ui.test.heroCardAnimUI", heroCardAnimUI);
            class heroCardUseUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(heroCardUseUI.uiView);
                }
            }
            heroCardUseUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 160, "mouseThrough": true, "height": 230 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 4, "x": 4, "width": 151, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 214 }, "compId": 1138 }, { "type": "Image", "props": { "y": 6, "x": 7, "width": 162, "skin": "ui/img_UM_ui_yingzi.png", "sizeGrid": "23,30,30,29", "height": 225, "alpha": 0.5 }, "compId": 1144 }, { "type": "Image", "props": { "y": 9, "x": 9, "width": 142, "skin": "ui/img_UM_card_pz_0.png", "sizeGrid": "13,13,13,13", "height": 204 }, "compId": 1140 }, { "type": "Image", "props": { "y": 38, "x": 9.5, "width": 140, "skin": "ui/img_UM_playerhead.png", "height": 140 }, "compId": 1133 }, { "type": "Label", "props": { "y": 10, "x": 13, "wordWrap": true, "width": 64, "text": "万能", "strokeColor": "#390f3e", "name": "txt_phy", "height": 28, "fontSize": 24, "font": "SimHei", "color": "#bcbcbc", "bold": true, "align": "left" }, "compId": 1134 }, { "type": "Label", "props": { "y": 10, "x": 107, "wordWrap": true, "width": 40, "text": "7", "strokeColor": "#212121", "stroke": 4, "name": "txt_phy", "height": 40, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1137 }, { "type": "Box", "props": { "y": 180.95, "x": 11 }, "compId": 1145, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 461, "skin": "ui/img_UM_btn_OrangeButton.png", "sizeGrid": "19,19,29,19", "scaleY": 0.3, "scaleX": 0.3, "height": 187 }, "compId": 1146 }, { "type": "Label", "props": { "y": 7, "x": 23, "wordWrap": true, "width": 92, "valign": "middle", "text": "使 用", "strokeColor": "#8e3409", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1147 }] }], "loadList": ["ui/img_UM_roundedEmboss.png", "ui/img_UM_ui_yingzi.png", "ui/img_UM_card_pz_0.png", "ui/img_UM_playerhead.png", "ui/img_UM_btn_OrangeButton.png"], "loadList3D": [] };
            test.heroCardUseUI = heroCardUseUI;
            REG("ui.test.heroCardUseUI", heroCardUseUI);
            class HeroInfoBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroInfoBtnUI.uiView);
                }
            }
            HeroInfoBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 160, "mouseThrough": false, "height": 120 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 60, "x": 80, "width": 160, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 80, "height": 110 }, "compId": 1173 }, { "type": "Image", "props": { "y": 17, "x": 45, "width": 74, "skin": "ui/img_UM_ui_text24.png", "height": 29 }, "compId": 1176 }, { "type": "Image", "props": { "y": 52, "x": 84, "width": 33, "skin": "ui/img_UM_gold.png", "height": 33 }, "compId": 1177 }, { "type": "Label", "props": { "y": 53, "x": 10, "wordWrap": false, "width": 63, "var": "txt_tong", "text": "5", "strokeColor": "#272727", "stroke": 4, "name": "txt_tong", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1179 }], "animations": [{ "nodes": [{ "target": 1173, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text24.png", "ui/img_UM_gold.png"], "loadList3D": [] };
            test.HeroInfoBtnUI = HeroInfoBtnUI;
            REG("ui.test.HeroInfoBtnUI", HeroInfoBtnUI);
            class HeroInfoBtn1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroInfoBtn1UI.uiView);
                }
            }
            HeroInfoBtn1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": false, "height": 120 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 60, "x": 150, "width": 303, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 152, "height": 110 }, "compId": 1173 }, { "type": "Label", "props": { "y": 53, "x": 78, "wordWrap": false, "width": 63, "var": "txt_tong", "text": "5", "strokeColor": "#272727", "stroke": 4, "name": "txt_tong", "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "right" }, "compId": 1179 }, { "type": "Image", "props": { "y": 53, "x": 152, "width": 32, "skin": "ui/img_UM_xpicon.png", "height": 32 }, "compId": 1181 }, { "type": "Label", "props": { "y": 18, "x": 82, "wordWrap": false, "width": 135, "underlineColor": "#f1f1e7", "text": "申请出战", "stroke": 5, "name": "txt_tong", "height": 32, "fontSize": 32, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1182 }], "animations": [{ "nodes": [{ "target": 1173, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1173, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1173, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_btn_green.png", "ui/img_UM_xpicon.png"], "loadList3D": [] };
            test.HeroInfoBtn1UI = HeroInfoBtn1UI;
            REG("ui.test.HeroInfoBtn1UI", HeroInfoBtn1UI);
            class HeroKillHeadUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroKillHeadUI.uiView);
                }
            }
            HeroKillHeadUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 260, "mouseThrough": true, "height": 70 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -2, "x": 151, "skin": "ui/img_UM_herokill_bg_red.png" }, "compId": 1150 }, { "type": "Image", "props": { "y": -2, "x": -9, "skin": "ui/img_UM_herokill_bg_blue.png" }, "compId": 1149 }, { "type": "Image", "props": { "y": 5, "x": 0, "skin": "ui/img_UM_herohead_mini.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 5, "x": 160, "skin": "ui/img_UM_herohead_mini.png" }, "compId": 1147 }, { "type": "Image", "props": { "y": 4, "x": 104, "width": 51, "skin": "ui/img_UM_herokillicon.png", "height": 51 }, "compId": 1148 }, { "type": "Label", "props": { "y": 55, "x": -2, "wordWrap": true, "width": 108, "valign": "middle", "text": "英雄名称", "strokeColor": "#093d4e", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1151 }, { "type": "Label", "props": { "y": 55, "x": 156, "wordWrap": true, "width": 108, "valign": "middle", "text": "英雄名称", "strokeColor": "#4e091c", "stroke": 4, "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1152 }], "loadList": ["ui/img_UM_herokill_bg_red.png", "ui/img_UM_herokill_bg_blue.png", "ui/img_UM_herohead_mini.png", "ui/img_UM_herokillicon.png"], "loadList3D": [] };
            test.HeroKillHeadUI = HeroKillHeadUI;
            REG("ui.test.HeroKillHeadUI", HeroKillHeadUI);
            class HeroLvUpAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroLvUpAnimUI.uiView);
                }
            }
            HeroLvUpAnimUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg9.jpg" }, "compId": 1395 }, { "type": "Image", "props": { "y": 456, "x": 495, "width": 289, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "height": 70, "alpha": 1 }, "compId": 1245 }, { "type": "Image", "props": { "y": 457, "x": 494, "width": 292, "skin": "ui/img_UM_bar_green.png", "sizeGrid": "15,53,22,21", "height": 69, "alpha": 1 }, "compId": 1374 }, { "type": "Box", "props": { "y": 472, "x": 602, "alpha": 1 }, "compId": 1384, "child": [{ "type": "Image", "props": { "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1380 }, { "type": "Label", "props": { "y": 3, "x": 21, "wordWrap": true, "width": 21, "text": "/", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1381 }, { "type": "Image", "props": { "x": 39, "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1382 }, { "type": "Image", "props": { "x": 57, "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1383 }] }, { "type": "heroCard34", "props": { "y": 291, "x": 648, "width": 200, "scaleY": 1, "scaleX": 1, "pivotY": 143, "pivotX": 108, "height": 310, "runtime": "ui.test.heroCard34UI" }, "compId": 1405 }, { "type": "Image", "props": { "y": 467, "x": 772, "width": 80, "skin": "ui/img_UM_lvupeffect.png", "rotation": 0, "pivotY": 40, "pivotX": 40, "height": 80, "alpha": 1 }, "compId": 1406 }, { "type": "Image", "props": { "y": 506, "x": 773, "width": 80, "skin": "ui/img_UM_lvupeffect.png", "rotation": 0, "pivotY": 40, "pivotX": 40, "height": 80, "alpha": 1 }, "compId": 1407 }, { "type": "Image", "props": { "y": 286, "x": 640, "width": 256, "skin": "ui/img_UM_levelUpArrow.png", "scaleY": 1, "scaleX": 1, "pivotY": 128, "pivotX": 128, "height": 256, "alpha": 0 }, "compId": 1408 }, { "type": "Image", "props": { "y": 340, "x": 946, "width": 358, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "31,31,31,28", "pivotY": 78, "pivotX": 179, "height": 156, "alpha": 0 }, "compId": 1409 }, { "type": "Box", "props": { "y": 315, "x": 953, "width": 337, "pivotY": 29, "pivotX": 169, "height": 57, "alpha": 0 }, "compId": 1420, "child": [{ "type": "Box", "props": {}, "compId": 1413, "child": [{ "type": "Image", "props": { "y": 2, "width": 50, "skin": "ui/img_UM_rank_jlbg2.png", "height": 50 }, "compId": 1411 }, { "type": "Image", "props": { "width": 50, "skin": "ui/img_UM_icon_heroInfo3.png", "height": 50 }, "compId": 1412 }] }, { "type": "Label", "props": { "y": 0, "x": 55, "wordWrap": true, "width": 90, "text": "生命值", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#45d9ff", "bold": true, "align": "left" }, "compId": 1417 }, { "type": "Label", "props": { "y": 28, "x": 56, "wordWrap": true, "width": 90, "text": "2988", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1418 }, { "type": "Label", "props": { "y": 14, "x": 228, "wordWrap": true, "width": 109, "text": "+288", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 41, "fontSize": 40, "font": "SimHei", "color": "#47fd0d", "bold": true, "align": "left" }, "compId": 1419 }] }, { "type": "Box", "props": { "y": 372, "x": 953, "width": 338, "pivotY": 29, "pivotX": 169, "height": 57, "alpha": 0 }, "compId": 1421, "child": [{ "type": "Box", "props": {}, "compId": 1422, "child": [{ "type": "Image", "props": { "y": 2, "width": 50, "skin": "ui/img_UM_rank_jlbg2.png", "height": 50 }, "compId": 1423 }, { "type": "Image", "props": { "width": 50, "skin": "ui/img_UM_icon_heroInfo2.png", "height": 50 }, "compId": 1424 }] }, { "type": "Label", "props": { "y": 0, "x": 55, "wordWrap": true, "width": 158, "text": "最大每秒伤害", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#45d9ff", "bold": true, "align": "left" }, "compId": 1425 }, { "type": "Label", "props": { "y": 28, "x": 56, "wordWrap": true, "width": 90, "text": "2988", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1426 }, { "type": "Label", "props": { "y": 14, "x": 229, "wordWrap": true, "width": 109, "text": "+288", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 41, "fontSize": 40, "font": "SimHei", "color": "#47fd0d", "bold": true, "align": "left" }, "compId": 1427 }] }, { "type": "Label", "props": { "y": 231, "x": 921, "wordWrap": true, "width": 249, "text": "等级7", "strokeColor": "#920b00", "stroke": 8, "pivotY": 37, "pivotX": 125, "name": "txt_phy", "height": 73, "fontSize": 50, "font": "SimHei", "color": "#f1da33", "bold": false, "alpha": 0, "align": "center" }, "compId": 1429 }, { "type": "Box", "props": { "y": 451, "x": 490, "alpha": 0 }, "compId": 1431, "child": [{ "type": "HeroInfoBtn1", "props": { "runtime": "ui.test.HeroInfoBtn1UI" }, "compId": 1430 }] }], "animations": [{ "nodes": [{ "target": 1408, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleY", "index": 15 }, { "value": 3, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleY", "index": 25 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleX", "index": 15 }, { "value": 3, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "scaleX", "index": 25 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 15 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1408, "key": "alpha", "index": 25 }] } }, { "target": 1374, "keyframes": { "width": [{ "value": 292, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "width", "index": 0 }, { "value": 10, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "width", "index": 15 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1374, "key": "alpha", "index": 20 }] } }, { "target": 1406, "keyframes": { "x": [{ "value": 772, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "x", "index": 0 }, { "value": 503, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "x", "index": 15 }], "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "rotation", "index": 15 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1406, "key": "alpha", "index": 20 }] } }, { "target": 1407, "keyframes": { "x": [{ "value": 773, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "x", "index": 0 }, { "value": 503, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "x", "index": 15 }], "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "rotation", "index": 15 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1407, "key": "alpha", "index": 20 }] } }, { "target": 1405, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleY", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleY", "index": 15 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleY", "index": 18 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleY", "index": 20 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleY", "index": 22 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleY", "index": 24 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleX", "index": 0 }, { "value": 0.8, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleX", "index": 15 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleX", "index": 18 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleX", "index": 20 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleX", "index": 22 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1405, "key": "scaleX", "index": 24 }] } }, { "target": 1245, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1245, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1245, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1245, "key": "alpha", "index": 20 }] } }, { "target": 1384, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1384, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1384, "key": "alpha", "index": 15 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1384, "key": "alpha", "index": 20 }] } }, { "target": 1429, "keyframes": { "y": [{ "value": 231, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 0 }, { "value": 273, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 15 }, { "value": 238, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 25 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 25 }] } }, { "target": 1409, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1409, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1409, "key": "alpha", "index": 30 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1409, "key": "alpha", "index": 40 }] } }, { "target": 1420, "keyframes": { "y": [{ "value": 315, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "y", "index": 0 }, { "value": 292, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "y", "index": 25 }, { "value": 315, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "y", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "alpha", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1420, "key": "alpha", "index": 35 }] } }, { "target": 1421, "keyframes": { "y": [{ "value": 372, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "y", "index": 0 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "y", "index": 35 }, { "value": 372, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "y", "index": 45 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "alpha", "index": 35 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1421, "key": "alpha", "index": 45 }] } }, { "target": 1431, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1431, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1431, "key": "alpha", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1431, "key": "alpha", "index": 35 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_bar_green.png", "ui/img_UM_num_5.png", "ui/img_UM_lvupeffect.png", "ui/img_UM_levelUpArrow.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_rank_jlbg2.png", "ui/img_UM_icon_heroInfo3.png", "ui/img_UM_icon_heroInfo2.png"], "loadList3D": [] };
            test.HeroLvUpAnimUI = HeroLvUpAnimUI;
            REG("ui.test.HeroLvUpAnimUI", HeroLvUpAnimUI);
            class HeroSkillUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroSkillUI.uiView);
                }
            }
            HeroSkillUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_btn_Skill3.png" }, "compId": 1174 }, { "type": "Image", "props": { "y": 25, "x": 25, "skin": "ui/img_UM_btn_Skill2.png" }, "compId": 1172 }, { "type": "Image", "props": { "y": 40, "x": 40, "skin": "ui/img_UM_ui_skill icon1_2.png" }, "compId": 1173 }, { "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_btn_Skill3_1.png" }, "compId": 1175 }], "loadList": ["ui/img_UM_btn_Skill3.png", "ui/img_UM_btn_Skill2.png", "ui/img_UM_ui_skill icon1_2.png", "ui/img_UM_btn_Skill3_1.png"], "loadList3D": [] };
            test.HeroSkillUI = HeroSkillUI;
            REG("ui.test.HeroSkillUI", HeroSkillUI);
            class HeroSkill1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HeroSkill1UI.uiView);
                }
            }
            HeroSkill1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_btn_Skill.png" }, "compId": 1172 }, { "type": "Image", "props": { "y": 15, "x": 15, "skin": "ui/img_UM_ui_skill icon1_1.png" }, "compId": 1173 }], "loadList": ["ui/img_UM_btn_Skill.png", "ui/img_UM_ui_skill icon1_1.png"], "loadList3D": [] };
            test.HeroSkill1UI = HeroSkill1UI;
            REG("ui.test.HeroSkill1UI", HeroSkill1UI);
            class HPbarBlueUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HPbarBlueUI.uiView);
                }
            }
            HPbarBlueUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 30 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_hpbarbg.png" }, "compId": 1141 }, { "type": "Image", "props": { "y": 4, "x": 4, "skin": "ui/img_UM_hp_1.png" }, "compId": 1138 }], "loadList": ["ui/img_UM_ui_hpbarbg.png", "ui/img_UM_hp_1.png"], "loadList3D": [] };
            test.HPbarBlueUI = HPbarBlueUI;
            REG("ui.test.HPbarBlueUI", HPbarBlueUI);
            class HPbarRedUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HPbarRedUI.uiView);
                }
            }
            HPbarRedUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 30 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_hpbarbg.png" }, "compId": 1141 }, { "type": "Image", "props": { "y": 4, "x": 5, "skin": "ui/img_UM_hp_2.png" }, "compId": 1138 }], "loadList": ["ui/img_UM_ui_hpbarbg.png", "ui/img_UM_hp_2.png"], "loadList3D": [] };
            test.HPbarRedUI = HPbarRedUI;
            REG("ui.test.HPbarRedUI", HPbarRedUI);
            class HPBlueUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HPBlueUI.uiView);
                }
            }
            HPBlueUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -4, "x": -4, "width": 108, "skin": "ui/img_UM_herohead_bg.png", "height": 108 }, "compId": 1149 }, { "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_playerhead2.png" }, "compId": 1148 }, { "type": "Image", "props": { "y": 56, "x": 67, "width": 45, "skin": "ui/img_UM_Payload_HP_blue.png", "height": 45 }, "compId": 1143 }, { "type": "Label", "props": { "y": 61, "x": 75, "wordWrap": true, "width": 30, "valign": "middle", "text": "9", "strokeColor": "#006a9c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1144 }, { "type": "HPbarBlue", "props": { "y": 70, "x": 103, "runtime": "ui.test.HPbarBlueUI" }, "compId": 1145 }], "animations": [{ "nodes": [{ "target": 1139, "keyframes": { "width": [{ "value": 3, "tweenMethod": "linearNone", "tween": true, "target": 1139, "key": "width", "index": 0 }, { "value": 193, "tweenMethod": "linearNone", "tween": true, "target": 1139, "key": "width", "index": 100 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herohead_bg.png", "ui/img_UM_playerhead2.png", "ui/img_UM_Payload_HP_blue.png"], "loadList3D": [] };
            test.HPBlueUI = HPBlueUI;
            REG("ui.test.HPBlueUI", HPBlueUI);
            class HPRedUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(HPRedUI.uiView);
                }
            }
            HPRedUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 270, "mouseThrough": true, "height": 80 }, "compId": 2, "child": [{ "type": "HPbarRed", "props": { "y": 40, "x": 63, "runtime": "ui.test.HPbarRedUI" }, "compId": 1142 }, { "type": "Image", "props": { "y": 8, "x": 13, "width": 62, "skin": "ui/img_UM_Payload_HP_red.png", "height": 62 }, "compId": 1143 }, { "type": "Label", "props": { "y": 20, "x": 29, "wordWrap": true, "width": 30, "valign": "middle", "text": "9", "strokeColor": "#9c0200", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 40, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1144 }], "animations": [{ "nodes": [{ "target": 1139, "keyframes": { "width": [{ "value": 3, "tweenMethod": "linearNone", "tween": true, "target": 1139, "key": "width", "index": 0 }, { "value": 193, "tweenMethod": "linearNone", "tween": true, "target": 1139, "key": "width", "index": 100 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_Payload_HP_red.png"], "loadList3D": [] };
            test.HPRedUI = HPRedUI;
            REG("ui.test.HPRedUI", HPRedUI);
            class huxiAnimUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(huxiAnimUI.uiView);
                }
            }
            huxiAnimUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 106, "x": 100, "width": 141, "skin": "ui/img_UM_herokill_bg_zi.png", "sizeGrid": "22,29,30,34", "pivotY": 103, "pivotX": 71, "height": 192, "blendMode": "lighter" }, "compId": 1249 }], "animations": [{ "nodes": [{ "target": 1249, "keyframes": { "alpha": [{ "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1249, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1249, "key": "alpha", "index": 5 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1249, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png"], "loadList3D": [] };
            test.huxiAnimUI = huxiAnimUI;
            REG("ui.test.huxiAnimUI", huxiAnimUI);
            class JinruZhandouUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(JinruZhandouUI.uiView);
                }
            }
            JinruZhandouUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -18, "x": -32, "width": 1344, "skin": "ui/img_UM_ui_bg.jpg", "height": 756 }, "compId": 984 }, { "type": "Label", "props": { "y": 59, "x": 471, "wordWrap": true, "width": 338, "text": "09", "strokeColor": "#390f3e", "name": "txt_phy", "height": 57, "fontSize": 60, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1132 }, { "type": "Box", "props": { "y": 38, "x": 1111 }, "compId": 1138, "child": [{ "type": "Image", "props": { "width": 169, "skin": "ui/img_UM_btn_red.png", "height": 89 }, "compId": 1136 }, { "type": "Image", "props": { "y": 20, "x": 47, "skin": "ui/img_UM_ui_text1.png" }, "compId": 1137 }] }, { "type": "Image", "props": { "y": 405, "x": 640, "width": 876, "skin": "ui/img_UM_SponsorWall2.png", "pivotY": 262, "pivotX": 438, "height": 505 }, "compId": 1139 }, { "type": "Image", "props": { "y": 13, "x": 518, "skin": "ui/img_UM_ui_text13.png" }, "compId": 1140 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_btn_red.png", "ui/img_UM_ui_text1.png", "ui/img_UM_SponsorWall2.png", "ui/img_UM_ui_text13.png"], "loadList3D": [] };
            test.JinruZhandouUI = JinruZhandouUI;
            REG("ui.test.JinruZhandouUI", JinruZhandouUI);
            class KillUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(KillUI.uiView);
                }
            }
            KillUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 400 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 314, "x": 100, "width": 116, "skin": "ui/img_UM_killConfirmed.png", "pivotY": 57, "pivotX": 58, "height": 113 }, "compId": 1142 }], "animations": [{ "nodes": [{ "target": 1142, "keyframes": { "y": [{ "value": 314, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "y", "index": 0 }, { "value": 314, "tweenMethod": "linearNone", "tween": true, "target": 1142, "label": null, "key": "y", "index": 9 }, { "value": 80, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "y", "index": 20 }], "scaleX": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 0 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 2 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 5 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "scaleX", "index": 9 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "label": null, "key": "scaleX", "index": 15 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 2 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 9 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1142, "label": null, "key": "alpha", "index": 11 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1142, "key": "alpha", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_killConfirmed.png"], "loadList3D": [] };
            test.KillUI = KillUI;
            REG("ui.test.KillUI", KillUI);
            class loading2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(loading2UI.uiView);
                }
            }
            loading2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_loading.jpg" }, "compId": 1128 }, { "type": "Box", "props": { "y": 367, "x": 453, "width": 374, "height": 280, "centerX": 0, "bottom": 73 }, "compId": 1149, "child": [{ "type": "Image", "props": { "y": 169, "x": -331, "width": 1036, "skin": "ui/img_UM_loadingBarbg.png", "sizeGrid": "13,32,17,32", "height": 40 }, "compId": 1160 }, { "type": "Image", "props": { "y": 169, "x": -331, "width": 510, "skin": "ui/img_UM_loadingBar.png", "sizeGrid": "13,42,15,37", "height": 40 }, "compId": 1161 }, { "type": "Label", "props": { "y": 178, "x": 170, "text": "60%", "strokeColor": "#404040", "stroke": 2, "fontSize": 22, "font": "SimHei", "color": "#ffffff" }, "compId": 1162 }, { "type": "Image", "props": { "y": 263, "x": -441, "skin": "ui/img_UM_loading_text3.png", "alpha": 1 }, "compId": 1164 }, { "type": "Box", "props": { "y": 218, "x": -255 }, "compId": 1167, "child": [{ "type": "Image", "props": { "skin": "ui/img_UM_loading_text1.png" }, "compId": 1163 }, { "type": "Image", "props": { "x": 582, "skin": "ui/img_UM_loading_text2.png" }, "compId": 1166 }] }] }], "loadList": ["ui/img_UM_loading.jpg", "ui/img_UM_loadingBarbg.png", "ui/img_UM_loadingBar.png", "ui/img_UM_loading_text3.png", "ui/img_UM_loading_text1.png", "ui/img_UM_loading_text2.png"], "loadList3D": [] };
            test.loading2UI = loading2UI;
            REG("ui.test.loading2UI", loading2UI);
            class loadingTipsUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(loadingTipsUI.uiView);
                }
            }
            loadingTipsUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_loading.jpg" }, "compId": 1128 }, { "type": "Box", "props": { "y": 367, "x": 453, "width": 374, "height": 280, "centerX": 0, "bottom": 73 }, "compId": 1149, "child": [{ "type": "Image", "props": { "y": 169, "x": -331, "width": 1036, "skin": "ui/img_UM_loadingBarbg.png", "sizeGrid": "13,32,17,32", "height": 40 }, "compId": 1160 }, { "type": "Image", "props": { "y": 169, "x": -331, "width": 510, "skin": "ui/img_UM_loadingBar.png", "sizeGrid": "13,42,15,37", "height": 40 }, "compId": 1161 }, { "type": "Label", "props": { "y": 178, "x": 170, "text": "60%", "strokeColor": "#404040", "stroke": 2, "fontSize": 22, "font": "SimHei", "color": "#ffffff" }, "compId": 1162 }, { "type": "Image", "props": { "y": 273, "x": -441, "skin": "ui/img_UM_loading_text3.png", "alpha": 1 }, "compId": 1164 }, { "type": "Box", "props": { "y": 239, "x": -255 }, "compId": 1167, "child": [{ "type": "Image", "props": { "skin": "ui/img_UM_loading_text1.png" }, "compId": 1163 }, { "type": "Image", "props": { "x": 582, "skin": "ui/img_UM_loading_text2.png" }, "compId": 1166 }] }, { "type": "Image", "props": { "y": 206, "x": 90, "skin": "ui/img_UM_loading_text4.png" }, "compId": 1168 }] }], "loadList": ["ui/img_UM_loading.jpg", "ui/img_UM_loadingBarbg.png", "ui/img_UM_loadingBar.png", "ui/img_UM_loading_text3.png", "ui/img_UM_loading_text1.png", "ui/img_UM_loading_text2.png", "ui/img_UM_loading_text4.png"], "loadList3D": [] };
            test.loadingTipsUI = loadingTipsUI;
            REG("ui.test.loadingTipsUI", loadingTipsUI);
            class LuckyBoxUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LuckyBoxUI.uiView);
                }
            }
            LuckyBoxUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "skin": "ui/img_UM_SponsorWall.png" }, "compId": 1160 }, { "type": "Image", "props": { "y": 495, "x": 367, "width": 240, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,33,33", "height": 110 }, "compId": 1162, "child": [{ "type": "Image", "props": { "y": 34, "x": 85, "width": 70, "skin": "ui/img_UM_ui_text17.png", "height": 32 }, "compId": 1165 }] }, { "type": "Image", "props": { "y": 494, "x": 639.5, "width": 240, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,33,33", "height": 110 }, "compId": 1163, "child": [{ "type": "Image", "props": { "y": 31, "x": 77, "width": 137, "skin": "ui/img_UM_ui_text65.png", "height": 39 }, "compId": 1166 }, { "type": "Image", "props": { "y": 32, "x": 25, "width": 50, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 40 }, "compId": 1167 }] }, { "type": "Image", "props": { "y": 459, "x": 233, "width": 814, "skin": "ui/img_UM_ui_text64.png", "height": 40 }, "compId": 1164 }, { "type": "Box", "props": { "y": 101, "x": 217 }, "compId": 1172, "child": [{ "type": "Image", "props": { "width": 268, "skin": "ui/img_UM_shop_ui_bg3.png", "sizeGrid": "109,60,161,84", "height": 363 }, "compId": 1161 }, { "type": "Image", "props": { "y": 31, "x": 44, "skin": "ui/img_UM_ui_text66.png" }, "compId": 1168 }, { "type": "Image", "props": { "y": 131, "x": 80, "skin": "ui/img_UM_icon_luckybox.png" }, "compId": 1169 }, { "type": "Image", "props": { "y": 280, "x": 30, "width": 50, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 40 }, "compId": 1170 }, { "type": "Image", "props": { "y": 247, "x": 156, "width": 136, "skin": "ui/img_UM_icon_hand.png", "height": 116 }, "compId": 1171 }] }, { "type": "Box", "props": { "y": 101, "x": 505 }, "compId": 1173, "child": [{ "type": "Image", "props": { "width": 268, "skin": "ui/img_UM_shop_ui_bg3.png", "sizeGrid": "109,60,161,84", "height": 363 }, "compId": 1174 }, { "type": "Image", "props": { "y": 31, "x": 44, "skin": "ui/img_UM_ui_text67.png" }, "compId": 1175 }, { "type": "Image", "props": { "y": 131, "x": 80, "skin": "ui/img_UM_icon_luckybox.png" }, "compId": 1176 }, { "type": "Image", "props": { "y": 280, "x": 30, "width": 50, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 40 }, "compId": 1177 }, { "type": "Image", "props": { "y": 247, "x": 156, "width": 136, "skin": "ui/img_UM_icon_hand.png", "height": 116 }, "compId": 1178 }] }, { "type": "Box", "props": { "y": 100, "x": 792 }, "compId": 1179, "child": [{ "type": "Image", "props": { "width": 268, "skin": "ui/img_UM_shop_ui_bg3.png", "sizeGrid": "109,60,161,84", "height": 363 }, "compId": 1180 }, { "type": "Image", "props": { "y": 31, "x": 44, "skin": "ui/img_UM_ui_text68.png" }, "compId": 1181 }, { "type": "Image", "props": { "y": 131, "x": 80, "skin": "ui/img_UM_icon_luckybox.png" }, "compId": 1182 }, { "type": "Image", "props": { "y": 280, "x": 30, "width": 50, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 40 }, "compId": 1183 }, { "type": "Image", "props": { "y": 247, "x": 156, "width": 136, "skin": "ui/img_UM_icon_hand.png", "height": 116 }, "compId": 1184 }] }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text65.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_text64.png", "ui/img_UM_shop_ui_bg3.png", "ui/img_UM_ui_text66.png", "ui/img_UM_icon_luckybox.png", "ui/img_UM_icon_hand.png", "ui/img_UM_ui_text67.png", "ui/img_UM_ui_text68.png"], "loadList3D": [] };
            test.LuckyBoxUI = LuckyBoxUI;
            REG("ui.test.LuckyBoxUI", LuckyBoxUI);
            class LupingUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(LupingUI.uiView);
                }
            }
            LupingUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -27, "skin": "ui/img_UM_ui_bg5.jpg" }, "compId": 600 }, { "type": "Box", "props": { "y": 38, "x": 48 }, "compId": 601, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 602 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 603 }] }, { "type": "Image", "props": { "y": 58, "x": 182, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 543 }, "compId": 604 }, { "type": "Image", "props": { "y": 111, "x": 199, "width": 881, "skin": "ui/img_UM_SponsorWall.png", "height": 471 }, "compId": 605 }, { "type": "Image", "props": { "y": 192, "x": 141.5, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1 }, "compId": 624 }, { "type": "Image", "props": { "y": 192, "x": 1143, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1, "scaleX": -1 }, "compId": 625 }, { "type": "Box", "props": { "y": 417, "x": 682 }, "compId": 618, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 619 }, { "type": "Image", "props": { "y": 26, "x": 53, "skin": "ui/img_UM_ui_text75.png" }, "compId": 637 }] }, { "type": "Image", "props": { "y": 472, "x": 139, "skin": "ui/img_UM_ui_7day_bianjiao.png" }, "compId": 622 }, { "type": "Image", "props": { "y": 472, "x": 1143, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleX": -1 }, "compId": 623 }, { "type": "Image", "props": { "y": 9, "x": 226, "skin": "ui/img_UM_ui_luping.png" }, "compId": 634 }, { "type": "Image", "props": { "y": 45.5, "x": -708, "width": 500, "skin": "ui/img_UM_ui_lupingimg.png", "height": 568 }, "compId": 635 }, { "type": "Box", "props": { "y": 214, "x": 617 }, "compId": 648, "child": [{ "type": "Image", "props": { "width": 123, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 182 }, "compId": 647 }, { "type": "Image", "props": { "y": 34, "x": 5, "width": 113, "skin": "ui/img_UM_goodsCard1.png", "height": 141 }, "compId": 640 }, { "type": "Label", "props": { "y": 5, "x": 21, "wordWrap": true, "width": 81, "text": "金币", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 24, "font": "SimHei", "color": "#d7d7d7", "bold": true, "align": "center" }, "compId": 650 }, { "type": "Image", "props": { "y": 135, "x": 22, "width": 98, "skin": "ui/img_UM_num_2000.png", "height": 43 }, "compId": 663 }] }, { "type": "Image", "props": { "y": -7, "x": 29, "width": 702, "skin": "ui/img_UM_effect_zi.png", "height": 700 }, "compId": 668 }, { "type": "Box", "props": { "y": 216, "x": 745 }, "compId": 651, "child": [{ "type": "Image", "props": { "width": 123, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 182 }, "compId": 652 }, { "type": "Image", "props": { "y": 34, "x": 5, "width": 113, "skin": "ui/img_UM_goodsCard2.png", "height": 141 }, "compId": 653 }, { "type": "Label", "props": { "y": 5, "x": 21, "wordWrap": true, "width": 81, "text": "钻石", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 24, "font": "SimHei", "color": "#d7d7d7", "bold": true, "align": "center" }, "compId": 655 }, { "type": "Image", "props": { "y": 135, "x": 50, "width": 72, "skin": "ui/img_UM_num_100.png", "height": 41 }, "compId": 664 }] }, { "type": "Box", "props": { "y": 216, "x": 873 }, "compId": 657, "child": [{ "type": "Image", "props": { "width": 123, "skin": "ui/img_UM_roundedEmboss.png", "sizeGrid": "12,13,14,12", "height": 182 }, "compId": 658 }, { "type": "Image", "props": { "y": 34, "x": 5, "width": 113, "skin": "ui/img_UM_herohead_card.png", "height": 141 }, "compId": 659 }, { "type": "Label", "props": { "y": 5, "x": 21, "wordWrap": true, "width": 81, "text": "丹", "strokeColor": "#212121", "name": "txt_phy", "height": 40, "fontSize": 24, "font": "SimHei", "color": "#d7d7d7", "bold": true, "align": "center" }, "compId": 660 }, { "type": "Image", "props": { "y": 135, "x": 70, "width": 47, "skin": "ui/img_UM_num_40.png", "height": 40 }, "compId": 662 }] }, { "type": "Image", "props": { "y": -56, "x": 154, "skin": "ui/img_UM_ui_lupingimg2.png" }, "compId": 667 }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk.png", "ui/img_UM_SponsorWall.png", "ui/img_UM_ui_7day_bianjiao.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text75.png", "ui/img_UM_ui_luping.png", "ui/img_UM_ui_lupingimg.png", "ui/img_UM_roundedEmboss.png", "ui/img_UM_goodsCard1.png", "ui/img_UM_num_2000.png", "ui/img_UM_effect_zi.png", "ui/img_UM_goodsCard2.png", "ui/img_UM_num_100.png", "ui/img_UM_herohead_card.png", "ui/img_UM_num_40.png", "ui/img_UM_ui_lupingimg2.png"], "loadList3D": [] };
            test.LupingUI = LupingUI;
            REG("ui.test.LupingUI", LupingUI);
            class MapUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(MapUI.uiView);
                }
            }
            MapUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 350 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 10, "x": 12, "skin": "ui/img_UM_map_bg.png", "alpha": 0.4 }, "compId": 1147 }, { "type": "Image", "props": { "y": 154, "x": 20, "skin": "ui/img_UM_map_obj1.png" }, "compId": 1148 }, { "type": "Box", "props": { "y": 275, "x": 75, "alpha": 0.6 }, "compId": 1151, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_blue.png" }, "compId": 1149 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_blue_hp.png" }, "compId": 1150 }] }, { "type": "Box", "props": { "y": 225, "x": 25, "alpha": 0.6 }, "compId": 1152, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_blue.png" }, "compId": 1153 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_blue_hp.png" }, "compId": 1154 }] }, { "type": "Box", "props": { "y": 225, "x": 125, "alpha": 0.6 }, "compId": 1155, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_blue.png" }, "compId": 1156 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_blue_hp.png" }, "compId": 1157 }] }, { "type": "Box", "props": { "y": 77, "x": 25, "alpha": 0.6 }, "compId": 1158, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_red.png" }, "compId": 1159 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_red_hp.png" }, "compId": 1160 }] }, { "type": "Box", "props": { "y": 77, "x": 125, "alpha": 0.6 }, "compId": 1161, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_red.png" }, "compId": 1162 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_red_hp.png" }, "compId": 1163 }] }, { "type": "Box", "props": { "y": 27, "x": 75, "alpha": 0.6 }, "compId": 1164, "child": [{ "type": "Image", "props": { "y": 12, "x": 12, "skin": "ui/img_UM_map_tower_red.png" }, "compId": 1165 }, { "type": "Image", "props": { "skin": "ui/img_UM_map_tower_red_hp.png" }, "compId": 1166 }] }, { "type": "Image", "props": { "y": 241.5, "x": 91.5, "skin": "ui/img_UM_map_player_blue.png" }, "compId": 1167 }, { "type": "Image", "props": { "y": 118.5, "x": 91.5, "skin": "ui/img_UM_map_player_red.png" }, "compId": 1169 }], "loadList": ["ui/img_UM_map_bg.png", "ui/img_UM_map_obj1.png", "ui/img_UM_map_tower_blue.png", "ui/img_UM_map_tower_blue_hp.png", "ui/img_UM_map_tower_red.png", "ui/img_UM_map_tower_red_hp.png", "ui/img_UM_map_player_blue.png", "ui/img_UM_map_player_red.png"], "loadList3D": [] };
            test.MapUI = MapUI;
            REG("ui.test.MapUI", MapUI);
            class mubiaoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(mubiaoUI.uiView);
                }
            }
            mubiaoUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 147, "x": 100, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1168 }, { "type": "Image", "props": { "y": 94, "x": 133, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "rotation": 60, "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1169 }, { "type": "Image", "props": { "y": 94, "x": 70, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "rotation": -60, "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1170 }], "animations": [{ "nodes": [{ "target": 1168, "keyframes": { "y": [{ "value": 1064, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "y", "index": 0 }, { "value": 147, "tweenMethod": "linearNone", "tween": true, "target": 1168, "label": null, "key": "y", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "width", "index": 17 }], "rotation": [{ "value": 90, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "rotation", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 17 }] } }, { "target": 1169, "keyframes": { "y": [{ "value": -452, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "y", "index": 0 }, { "value": 94, "tweenMethod": "linearNone", "tween": true, "target": 1169, "label": null, "key": "y", "index": 17 }], "x": [{ "value": 999, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "x", "index": 0 }, { "value": 133, "tweenMethod": "linearNone", "tween": true, "target": 1169, "label": null, "key": "x", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "width", "index": 17 }], "rotation": [{ "value": -30, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "rotation", "index": 0 }, { "value": 60, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "alpha", "index": 17 }] } }, { "target": 1170, "keyframes": { "y": [{ "value": -460, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "y", "index": 0 }, { "value": 94, "tweenMethod": "linearNone", "tween": true, "target": 1170, "label": null, "key": "y", "index": 17 }], "x": [{ "value": -880, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "x", "index": 0 }, { "value": 70, "tweenMethod": "linearNone", "tween": true, "target": 1170, "label": null, "key": "x", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "width", "index": 17 }], "rotation": [{ "value": 30, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 0 }, { "value": -60, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "alpha", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_ui_mubiao.png"], "loadList3D": [] };
            test.mubiaoUI = mubiaoUI;
            REG("ui.test.mubiaoUI", mubiaoUI);
            class mubiao1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(mubiao1UI.uiView);
                }
            }
            mubiao1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 360, "x": 640, "width": 200, "pivotY": 100, "pivotX": 100, "height": 200 }, "compId": 1172, "child": [{ "type": "mubiao", "props": { "y": 0, "x": 0, "runtime": "ui.test.mubiaoUI" }, "compId": 1171 }] }], "animations": [{ "nodes": [{ "target": 1172, "keyframes": { "y": [{ "value": -46, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "y", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "y", "index": 5 }], "x": [{ "value": 1370, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "x", "index": 0 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1172, "key": "x", "index": 5 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": [], "loadList3D": [] };
            test.mubiao1UI = mubiao1UI;
            REG("ui.test.mubiao1UI", mubiao1UI);
            class mubiao2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(mubiao2UI.uiView);
                }
            }
            mubiao2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 200, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 147, "x": 100, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1168 }, { "type": "Image", "props": { "y": 94, "x": 133, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "rotation": 60, "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1169 }, { "type": "Image", "props": { "y": 94, "x": 70, "width": 126, "skin": "ui/img_UM_ui_mubiao.png", "rotation": -60, "pivotY": 8, "pivotX": 63, "height": 16 }, "compId": 1170 }], "animations": [{ "nodes": [{ "target": 1168, "keyframes": { "y": [{ "value": 1064, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "y", "index": 0 }, { "value": 147, "tweenMethod": "linearNone", "tween": true, "target": 1168, "label": null, "key": "y", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "width", "index": 17 }], "rotation": [{ "value": 90, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "rotation", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1168, "key": "alpha", "index": 17 }] } }, { "target": 1169, "keyframes": { "y": [{ "value": -452, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "y", "index": 0 }, { "value": 94, "tweenMethod": "linearNone", "tween": true, "target": 1169, "label": null, "key": "y", "index": 17 }], "x": [{ "value": 999, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "x", "index": 0 }, { "value": 133, "tweenMethod": "linearNone", "tween": true, "target": 1169, "label": null, "key": "x", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "width", "index": 17 }], "rotation": [{ "value": -30, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "rotation", "index": 0 }, { "value": 60, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1169, "key": "alpha", "index": 17 }] } }, { "target": 1170, "keyframes": { "y": [{ "value": -460, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "y", "index": 0 }, { "value": 94, "tweenMethod": "linearNone", "tween": true, "target": 1170, "label": null, "key": "y", "index": 17 }], "x": [{ "value": -880, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "x", "index": 0 }, { "value": 70, "tweenMethod": "linearNone", "tween": true, "target": 1170, "label": null, "key": "x", "index": 17 }], "width": [{ "value": 400, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "width", "index": 0 }, { "value": 123, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "width", "index": 17 }], "rotation": [{ "value": 30, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 0 }, { "value": -60, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 17 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "alpha", "index": 17 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 0 }], "loadList": ["ui/img_UM_ui_mubiao.png"], "loadList3D": [] };
            test.mubiao2UI = mubiao2UI;
            REG("ui.test.mubiao2UI", mubiao2UI);
            class NewHeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(NewHeroUI.uiView);
                }
            }
            NewHeroUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 62, "x": 154, "skin": "ui/img_UM_SponsorWall.png" }, "compId": 1152 }, { "type": "Image", "props": { "y": 533, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": -1, "x": 130, "skin": "ui/img_UM_ui_text80.png" }, "compId": 1143 }, { "type": "TrialHeroAnim1", "props": { "y": -26, "x": 544.5, "runtime": "ui.test.TrialHeroAnim1UI" }, "compId": 1178 }, { "type": "TrialHeroAnim2", "props": { "y": 196, "x": 185.5, "runtime": "ui.test.TrialHeroAnim2UI" }, "compId": 1179 }, { "type": "TrialHeroAnim3", "props": { "y": 205, "x": 345, "runtime": "ui.test.TrialHeroAnim3UI" }, "compId": 1180 }, { "type": "TrialHeroAnim3", "props": { "y": 337, "x": 345, "runtime": "ui.test.TrialHeroAnim3UI" }, "compId": 1181 }, { "type": "Label", "props": { "y": 487, "x": 185.5, "wordWrap": true, "width": 226, "valign": "middle", "text": "英雄解锁进度：", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1187 }, { "type": "Box", "props": { "y": 520, "x": 199 }, "compId": 1188, "child": [{ "type": "Image", "props": { "y": 6, "x": 23, "width": 445, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "33,33,33,33", "height": 52 }, "compId": 1184 }, { "type": "Image", "props": { "y": 9, "x": 26, "width": 624, "skin": "ui/img_UM_btn__Gold.png", "sizeGrid": "33,33,33,33", "scaleY": 0.7, "scaleX": 0.7, "height": 66 }, "compId": 1185 }, { "type": "Image", "props": { "width": 57, "skin": "ui/img_UM_icon_cup.png", "height": 62 }, "compId": 1183 }, { "type": "Label", "props": { "y": 17, "x": 114, "wordWrap": true, "width": 226, "var": "txt_info", "valign": "middle", "text": "100%", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1186 }] }, { "type": "Image", "props": { "y": 610, "x": 199, "width": 227, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,48,33", "height": 99 }, "compId": 1189, "child": [{ "type": "Label", "props": { "y": 25, "x": 0, "wordWrap": true, "width": 226, "valign": "middle", "text": "确定", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1192 }] }, { "type": "Image", "props": { "y": 610, "x": 419, "width": 227, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "height": 98 }, "compId": 1190, "child": [{ "type": "Label", "props": { "y": 23, "x": 60, "wordWrap": true, "width": 150, "valign": "middle", "text": "直接解锁", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1193 }, { "type": "Image", "props": { "y": 27.5, "x": 22, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1194 }] }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text80.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_btn__Gold.png", "ui/img_UM_icon_cup.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            test.NewHeroUI = NewHeroUI;
            REG("ui.test.NewHeroUI", NewHeroUI);
            class NothanksBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(NothanksBtnUI.uiView);
                }
            }
            NothanksBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": false, "height": 120 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 16, "x": 14, "width": 271, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 88 }, "compId": 1183 }, { "type": "Image", "props": { "y": 34, "x": 58, "skin": "ui/img_UM_ui_text49.png" }, "compId": 1185 }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text49.png"], "loadList3D": [] };
            test.NothanksBtnUI = NothanksBtnUI;
            REG("ui.test.NothanksBtnUI", NothanksBtnUI);
            class Online1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Online1UI.uiView);
                }
            }
            Online1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": false, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -27, "skin": "ui/img_UM_ui_bg5.jpg" }, "compId": 585 }, { "type": "Box", "props": { "y": 46, "x": 52 }, "compId": 558, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 559 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 560 }] }, { "type": "PageRankRewardobj1", "props": { "y": 168, "x": 213, "runtime": "ui.test.PageRankRewardobj1UI" }, "compId": 563 }, { "type": "PageRankRewardobj2", "props": { "y": 169, "x": 772, "runtime": "ui.test.PageRankRewardobj2UI" }, "compId": 564 }, { "type": "PageRankRewardobj3", "props": { "y": 169, "x": 493, "runtime": "ui.test.PageRankRewardobj3UI" }, "compId": 565 }, { "type": "Box", "props": { "y": 876, "x": 493 }, "compId": 566, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 568 }, { "type": "Image", "props": { "y": 28, "x": 105, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 569 }, { "type": "Image", "props": { "y": 29, "x": 61, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 572 }] }, { "type": "Label", "props": { "y": 449, "x": -12, "wordWrap": true, "width": 183, "valign": "middle", "text": "5分钟", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 574 }, { "type": "Label", "props": { "y": 449, "x": 263, "wordWrap": true, "width": 183, "valign": "middle", "text": "10分钟", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 575 }, { "type": "Label", "props": { "y": 449, "x": 538, "wordWrap": true, "width": 183, "valign": "middle", "text": "15分钟", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 576 }, { "type": "Label", "props": { "y": 617, "x": 458, "wordWrap": true, "width": 363, "valign": "middle", "text": "已累计在线时长：15分钟", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 577 }, { "type": "Image", "props": { "y": 63, "x": 158, "width": 964, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 579 }, { "type": "Image", "props": { "y": 63, "x": 550, "skin": "ui/img_UM_ui_text48.png" }, "compId": 580 }, { "type": "PageRankRewardobj1", "props": { "y": 169, "x": -61, "runtime": "ui.test.PageRankRewardobj1UI" }, "compId": 581 }, { "type": "PageRankRewardobj2", "props": { "y": 168, "x": 1040, "runtime": "ui.test.PageRankRewardobj2UI" }, "compId": 582 }, { "type": "Label", "props": { "y": 449, "x": 813, "wordWrap": true, "width": 183, "valign": "middle", "text": "20分钟", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 583 }, { "type": "Label", "props": { "y": 449, "x": 1089, "wordWrap": true, "width": 183, "valign": "middle", "text": "25分钟", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 584 }, { "type": "Box", "props": { "y": 509, "x": 392 }, "compId": 586, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 588 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 589 }] }, { "type": "Box", "props": { "y": 510, "x": 641 }, "compId": 587, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 590 }, { "type": "Image", "props": { "y": 25, "x": 79, "skin": "ui/img_UM_ui_text46.png" }, "compId": 591 }, { "type": "Image", "props": { "y": 28.5, "x": 33, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 592 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text48.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png"], "loadList3D": [] };
            test.Online1UI = Online1UI;
            REG("ui.test.Online1UI", Online1UI);
            class Page1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Page1UI.uiView);
                }
            }
            Page1UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -18, "x": -32, "width": 1344, "skin": "ui/img_UM_ui_bg.jpg", "height": 756 }, "compId": 984 }, { "type": "Image", "props": { "y": 63, "x": 222, "width": 467, "skin": "ui/img_UM_ui_hero.png", "height": 678 }, "compId": 1108 }, { "type": "Box", "props": { "y": 3, "x": 443 }, "compId": 1003, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1002 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_tl.png", "height": 64 }, "compId": 985 }, { "type": "Image", "props": { "y": 2, "x": 163, "skin": "ui/img_UM_btn__btn1.png" }, "compId": 996, "child": [{ "type": "Image", "props": { "y": 22, "x": 22, "width": 29, "skin": "ui/img_UM_jiahao.png", "height": 29 }, "compId": 995 }] }, { "type": "Label", "props": { "y": 22, "x": 63, "wordWrap": true, "width": 108, "valign": "middle", "text": "45/50", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1004 }, { "type": "Label", "props": { "y": 59, "x": 57, "wordWrap": true, "width": 89, "valign": "middle", "text": "01:58 +1", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1017 }, { "type": "Image", "props": { "y": 62, "x": 142, "width": 30, "skin": "ui/img_UM_tl.png", "height": 30 }, "compId": 1018 }] }, { "type": "Box", "props": { "y": 3, "x": 688 }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 1007 }, { "type": "Image", "props": { "y": 2, "x": 163, "skin": "ui/img_UM_btn__btn1.png" }, "compId": 1008, "child": [{ "type": "Image", "props": { "y": 22, "x": 22, "width": 29, "skin": "ui/img_UM_jiahao.png", "height": 29 }, "compId": 1009 }] }, { "type": "Label", "props": { "y": 22, "x": 63, "wordWrap": true, "width": 108, "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1010 }] }, { "type": "Box", "props": { "y": 3, "x": 932 }, "compId": 1011, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1012 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 1013 }, { "type": "Image", "props": { "y": 2, "x": 163, "skin": "ui/img_UM_btn__btn1.png" }, "compId": 1014, "child": [{ "type": "Image", "props": { "y": 22, "x": 22, "width": 29, "skin": "ui/img_UM_jiahao.png", "height": 29 }, "compId": 1015 }] }, { "type": "Label", "props": { "y": 22, "x": 63, "wordWrap": true, "width": 108, "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1016 }] }, { "type": "Box", "props": { "y": 618, "x": 6 }, "compId": 1022, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 402, "skin": "ui/img_UM_btn_BlueButton.png", "sizeGrid": "50,50,70,50", "scaleY": 0.4, "scaleX": 0.4, "height": 201 }, "compId": 992 }, { "type": "Image", "props": { "y": 11.25, "x": 5, "width": 64, "skin": "ui/img_UM_fun_shop.png", "height": 64 }, "compId": 1019 }, { "type": "Image", "props": { "y": 31.6, "x": 68, "width": 82, "skin": "ui/img_UM_text_shop.png", "height": 42 }, "compId": 1020 }] }, { "type": "gamemode1", "props": { "y": 169, "x": 685, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.test.gamemode1UI" }, "compId": 1075 }, { "type": "gamemode2", "props": { "y": 170, "x": 987, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.test.gamemode2UI" }, "compId": 1076 }, { "type": "Box", "props": { "y": 357.4, "x": 701 }, "compId": 1093, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 567, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 359, "alpha": 0.6 }, "compId": 1090 }, { "type": "Image", "props": { "y": 76, "x": 8, "width": 551, "skin": "ui/img_UM_ui_img3.png", "height": 275 }, "compId": 1091 }, { "type": "Image", "props": { "y": 7, "x": 130, "skin": "ui/img_UM_text_5v5.png" }, "compId": 1092 }] }, { "type": "Box", "props": { "y": -1.5, "x": 1344 }, "compId": 1094, "child": [{ "type": "Image", "props": { "y": 1, "x": 3, "width": 240, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 196, "alpha": 0.6 }, "compId": 1095 }, { "type": "Image", "props": { "y": 76, "x": 9, "width": 228, "skin": "ui/img_UM_ui_img1.png", "height": 114 }, "compId": 1096 }, { "type": "Image", "props": { "y": 14, "x": 22.5, "width": 201, "skin": "ui/img_UM_text_pk.png", "height": 48 }, "compId": 1097 }] }, { "type": "Box", "props": { "y": 0, "x": 1587 }, "compId": 1102, "child": [{ "type": "Image", "props": { "y": 1, "x": 3, "width": 240, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 196, "alpha": 0.6 }, "compId": 1103 }, { "type": "Image", "props": { "y": 76, "x": 9, "width": 228, "skin": "ui/img_UM_ui_img4.png", "height": 114 }, "compId": 1104 }, { "type": "Image", "props": { "y": 14, "x": 22.5, "width": 201, "skin": "ui/img_UM_text_jdbw.png", "height": 48 }, "compId": 1105 }] }, { "type": "Box", "props": { "y": 618, "x": 176.8 }, "compId": 1109, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 402, "skin": "ui/img_UM_btn_BlueButton.png", "sizeGrid": "50,50,70,50", "scaleY": 0.4, "scaleX": 0.4, "height": 201 }, "compId": 1110 }, { "type": "Image", "props": { "y": 11.25, "x": 5, "width": 64, "skin": "ui/img_UM_fun_task.png", "height": 64 }, "compId": 1111 }, { "type": "Image", "props": { "y": 31.6, "x": 68, "width": 82, "skin": "ui/img_UM_text_task.png", "height": 42 }, "compId": 1112 }] }, { "type": "Box", "props": { "y": 618, "x": 348.6 }, "compId": 1113, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 402, "skin": "ui/img_UM_btn_BlueButton.png", "sizeGrid": "50,50,70,50", "scaleY": 0.4, "scaleX": 0.4, "height": 201 }, "compId": 1114 }, { "type": "Image", "props": { "y": 11.25, "x": 5, "width": 64, "skin": "ui/img_UM_fun_rank.png", "height": 64 }, "compId": 1115 }, { "type": "Image", "props": { "y": 31.6, "x": 68, "width": 82, "skin": "ui/img_UM_text_rank.png", "height": 42 }, "compId": 1116 }] }, { "type": "Box", "props": { "y": 618, "x": 519.5 }, "compId": 1117, "child": [{ "type": "Image", "props": { "y": 18, "x": 0, "width": 402, "skin": "ui/img_UM_btn_BlueButton.png", "sizeGrid": "50,50,70,50", "scaleY": 0.4, "scaleX": 0.4, "height": 201 }, "compId": 1118 }, { "type": "Image", "props": { "y": 11.25, "x": 5, "width": 64, "skin": "ui/img_UM_fun_hero.png", "height": 64 }, "compId": 1119 }, { "type": "Image", "props": { "y": 31.6, "x": 68, "width": 82, "skin": "ui/img_UM_text_hero.png", "height": 42 }, "compId": 1120 }] }, { "type": "Box", "props": { "y": 5, "x": 6 }, "compId": 1123, "child": [{ "type": "Image", "props": { "y": 3, "x": 79, "width": 293, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "13,27,13,12", "height": 48, "alpha": 0.7 }, "compId": 1126 }, { "type": "Image", "props": { "y": -2, "x": -5, "width": 110, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 110, "alpha": 0.6 }, "compId": 1124 }, { "type": "Image", "props": { "y": 0, "x": 314, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 987 }, { "type": "Image", "props": { "y": 3, "width": 100, "skin": "ui/img_UM_playerhead.png", "height": 100 }, "compId": 989 }, { "type": "Label", "props": { "y": 13, "x": 317, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 990 }, { "type": "Label", "props": { "y": 11, "x": 114, "wordWrap": true, "width": 173, "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 991 }, { "type": "Image", "props": { "y": 54, "x": 109, "width": 199, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "7,7,7,7", "height": 45 }, "compId": 1121 }, { "type": "Image", "props": { "y": 56, "x": 111, "width": 100, "skin": "ui/img_UM_ui_bar.png", "sizeGrid": "7,7,7,7", "height": 40 }, "compId": 1122 }, { "type": "Label", "props": { "y": 49, "x": 104, "wordWrap": true, "width": 210, "valign": "middle", "text": "355/400", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1125 }] }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_hero.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_tl.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_jiahao.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png", "ui/img_UM_btn_BlueButton.png", "ui/img_UM_fun_shop.png", "ui/img_UM_text_shop.png", "ui/img_UM_black.png", "ui/img_UM_ui_img3.png", "ui/img_UM_text_5v5.png", "ui/img_UM_ui_img1.png", "ui/img_UM_text_pk.png", "ui/img_UM_ui_img4.png", "ui/img_UM_text_jdbw.png", "ui/img_UM_fun_task.png", "ui/img_UM_text_task.png", "ui/img_UM_fun_rank.png", "ui/img_UM_text_rank.png", "ui/img_UM_fun_hero.png", "ui/img_UM_text_hero.png", "ui/img_UM_xpicon.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_ui_bar.png"], "loadList3D": [] };
            test.Page1UI = Page1UI;
            REG("ui.test.Page1UI", Page1UI);
            class Page2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Page2UI.uiView);
                }
            }
            Page2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg4.jpg" }, "compId": 1237 }, { "type": "Image", "props": { "y": 96, "x": 249.79999999999995, "skin": "ui/img_UM_ui_hero.png" }, "compId": 1191 }, { "type": "Box", "props": { "y": 3, "x": 443 }, "compId": 1003, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1002 }, { "type": "Image", "props": { "y": 5, "x": 0, "width": 64, "skin": "ui/img_UM_tl.png", "height": 64 }, "compId": 985 }, { "type": "Image", "props": { "y": 2, "x": 163, "skin": "ui/img_UM_btn__btn_2.png" }, "compId": 996 }, { "type": "Label", "props": { "y": 22, "x": 63, "wordWrap": true, "width": 108, "valign": "middle", "text": "45/50", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1004 }, { "type": "Label", "props": { "y": 59, "x": 57, "wordWrap": true, "width": 89, "valign": "middle", "text": "01:58 +1", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1017 }, { "type": "Image", "props": { "y": 62, "x": 142, "width": 30, "skin": "ui/img_UM_tl.png", "height": 30 }, "compId": 1018 }] }, { "type": "Box", "props": { "y": 3, "x": 688 }, "compId": 1005, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1006 }, { "type": "Image", "props": { "y": 5, "x": 0, "width": 64, "skin": "ui/img_UM_gold.png", "height": 64 }, "compId": 1007 }, { "type": "Image", "props": { "y": 2, "x": 163, "skin": "ui/img_UM_btn__btn_2.png" }, "compId": 1008 }, { "type": "Label", "props": { "y": 22, "x": 63, "wordWrap": true, "width": 108, "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1010 }] }, { "type": "Box", "props": { "y": 3, "x": 932 }, "compId": 1011, "child": [{ "type": "Image", "props": { "y": 15, "x": 28, "width": 191, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.7 }, "compId": 1012 }, { "type": "Image", "props": { "y": 7, "x": 0, "width": 64, "skin": "ui/img_UM_Diamond.png", "height": 64 }, "compId": 1013 }, { "type": "Image", "props": { "y": 2, "x": 163, "skin": "ui/img_UM_btn__btn_2.png" }, "compId": 1014 }, { "type": "Label", "props": { "y": 22, "x": 63, "wordWrap": true, "width": 108, "valign": "middle", "text": "3999", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1016 }] }, { "type": "Box", "props": { "y": 617, "x": 9 }, "compId": 1022, "child": [{ "type": "Image", "props": { "y": 5, "x": -3, "width": 184, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "57,50,43,50", "scaleY": 1, "scaleX": 1, "height": 92 }, "compId": 992 }, { "type": "Image", "props": { "y": 5, "x": 12, "width": 64, "skin": "ui/img_UM_fun_shop.png", "height": 64 }, "compId": 1019 }, { "type": "Image", "props": { "y": 23, "x": 72, "width": 82, "skin": "ui/img_UM_text_shop.png", "height": 42 }, "compId": 1020 }] }, { "type": "Box", "props": { "y": 11, "x": 16 }, "compId": 1123, "child": [{ "type": "Image", "props": { "y": 3, "x": 79, "width": 293, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "13,27,13,12", "height": 48, "alpha": 0.7 }, "compId": 1126 }, { "type": "Image", "props": { "y": -2, "x": -5, "width": 110, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 110, "alpha": 0.6 }, "compId": 1124 }, { "type": "Image", "props": { "y": 0, "x": 314, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 987 }, { "type": "Image", "props": { "y": 3, "width": 100, "skin": "ui/img_UM_playerhead.png", "height": 100 }, "compId": 989 }, { "type": "Label", "props": { "y": 13, "x": 317, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 990 }, { "type": "Label", "props": { "y": 11, "x": 114, "wordWrap": true, "width": 173, "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 991 }, { "type": "Image", "props": { "y": 54, "x": 109, "width": 199, "skin": "ui/img_UM_card_barbg.png", "sizeGrid": "7,7,7,7", "height": 45 }, "compId": 1121 }, { "type": "Image", "props": { "y": 56, "x": 111, "width": 100, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "7,7,7,7", "height": 40 }, "compId": 1122 }, { "type": "Label", "props": { "y": 49, "x": 104, "wordWrap": true, "width": 210, "valign": "middle", "text": "355/400", "strokeColor": "#232323", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1125 }] }, { "type": "Box", "props": { "y": 92, "x": 783 }, "compId": 1147, "child": [{ "type": "Image", "props": { "width": 237, "skin": "ui/img_UM_btn_textBubble.png", "sizeGrid": "35,30,48,34", "height": 203 }, "compId": 1133 }, { "type": "Image", "props": { "y": 47, "x": 9, "skin": "ui/img_UM_ui_sw2.png" }, "compId": 1146 }, { "type": "Image", "props": { "y": 8, "x": 10, "width": 218, "skin": "ui/img_UM_ui_obj5.png", "sizeGrid": "13,27,18,26", "height": 62 }, "compId": 1217 }, { "type": "Image", "props": { "y": 15, "x": 37, "width": 163, "skin": "ui/img_UM_text_JDBW_2.png", "height": 38 }, "compId": 1141 }] }, { "type": "Box", "props": { "y": 276, "x": 783 }, "compId": 1165, "child": [{ "type": "Image", "props": { "y": 22, "x": 0, "width": 482, "skin": "ui/img_UM_btn_textBubble.png", "sizeGrid": "35,30,48,34", "height": 274 }, "compId": 1127 }, { "type": "Image", "props": { "y": 93, "x": 9.5, "skin": "ui/img_UM_img_5v5_4.png" }, "compId": 1236 }, { "type": "Image", "props": { "y": 31, "x": 9, "width": 464, "skin": "ui/img_UM_ui_obj5.png", "sizeGrid": "13,27,18,26", "height": 70 }, "compId": 1179 }, { "type": "Image", "props": { "y": 37, "x": 128, "skin": "ui/img_UM_text_5v5_2.png" }, "compId": 1138 }] }, { "type": "Image", "props": { "y": 597, "x": 1369, "width": 339, "skin": "ui/img_UM_btn_textBubble.png", "sizeGrid": "35,30,48,34", "height": 86 }, "compId": 1250 }, { "type": "Box", "props": { "y": 91, "x": 1028 }, "compId": 1182, "child": [{ "type": "Image", "props": { "width": 237, "skin": "ui/img_UM_btn_textBubble.png", "sizeGrid": "35,30,48,34", "height": 203 }, "compId": 1183 }, { "type": "Image", "props": { "y": 47, "x": 9, "skin": "ui/img_UM_ui_zd_2.png" }, "compId": 1184 }, { "type": "Image", "props": { "y": 8, "x": 8, "width": 221, "skin": "ui/img_UM_ui_obj5.png", "sizeGrid": "13,27,18,26", "height": 62 }, "compId": 1185 }, { "type": "Image", "props": { "y": 18, "x": 37, "width": 163, "skin": "ui/img_UM_text_zdpk.png", "height": 38 }, "compId": 1186 }] }, { "type": "Box", "props": { "y": 473, "x": 1369, "width": 338, "height": 121 }, "compId": 1189, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 338, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "55,50,40,50", "height": 121 }, "compId": 1187 }, { "type": "Image", "props": { "y": 29, "x": 97, "width": 217, "skin": "ui/img_UM_text_ksyx.png", "height": 51 }, "compId": 1188 }, { "type": "Image", "props": { "y": 25, "x": 31, "skin": "ui/img_UM_clan35.png" }, "compId": 1246 }] }, { "type": "Box", "props": { "y": 617, "x": 191 }, "compId": 1222, "child": [{ "type": "Image", "props": { "y": 5, "x": -3, "width": 184, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "57,50,43,50", "scaleY": 1, "scaleX": 1, "height": 92 }, "compId": 1223 }, { "type": "Image", "props": { "y": 5, "x": 12, "width": 64, "skin": "ui/img_UM_fun_rank.png", "height": 64 }, "compId": 1224 }, { "type": "Image", "props": { "y": 23, "x": 72, "width": 82, "skin": "ui/img_UM_text_rank.png", "height": 42 }, "compId": 1225 }] }, { "type": "Box", "props": { "y": 617, "x": 372 }, "compId": 1226, "child": [{ "type": "Image", "props": { "y": 5, "x": -3, "width": 184, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "57,50,43,50", "scaleY": 1, "scaleX": 1, "height": 92 }, "compId": 1227 }, { "type": "Image", "props": { "y": 5, "x": 12, "width": 64, "skin": "ui/img_UM_fun_task.png", "height": 64 }, "compId": 1228 }, { "type": "Image", "props": { "y": 23, "x": 72, "width": 82, "skin": "ui/img_UM_text_task.png", "height": 42 }, "compId": 1229 }] }, { "type": "Box", "props": { "y": 617, "x": 553 }, "compId": 1230, "child": [{ "type": "Image", "props": { "y": 5, "x": -3, "width": 184, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "57,50,43,50", "scaleY": 1, "scaleX": 1, "height": 92 }, "compId": 1231 }, { "type": "Image", "props": { "y": 5, "x": 12, "width": 64, "skin": "ui/img_UM_fun_hero.png", "height": 64 }, "compId": 1232 }, { "type": "Image", "props": { "y": 23, "x": 72, "width": 82, "skin": "ui/img_UM_text_hero.png", "height": 42 }, "compId": 1233 }] }, { "type": "BtnEffect", "props": { "y": 560, "x": 820, "runtime": "ui.test.BtnEffectUI" }, "compId": 1251 }], "loadList": ["ui/img_UM_ui_bg4.jpg", "ui/img_UM_ui_hero.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_tl.png", "ui/img_UM_btn__btn_2.png", "ui/img_UM_gold.png", "ui/img_UM_Diamond.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_fun_shop.png", "ui/img_UM_text_shop.png", "ui/img_UM_black.png", "ui/img_UM_xpicon.png", "ui/img_UM_playerhead.png", "ui/img_UM_card_barbg.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_btn_textBubble.png", "ui/img_UM_ui_sw2.png", "ui/img_UM_ui_obj5.png", "ui/img_UM_text_JDBW_2.png", "ui/img_UM_img_5v5_4.png", "ui/img_UM_text_5v5_2.png", "ui/img_UM_ui_zd_2.png", "ui/img_UM_text_zdpk.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_text_ksyx.png", "ui/img_UM_clan35.png", "ui/img_UM_fun_rank.png", "ui/img_UM_text_rank.png", "ui/img_UM_fun_task.png", "ui/img_UM_text_task.png", "ui/img_UM_fun_hero.png", "ui/img_UM_text_hero.png"], "loadList3D": [] };
            test.Page2UI = Page2UI;
            REG("ui.test.Page2UI", Page2UI);
            class Page3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Page3UI.uiView);
                }
            }
            Page3UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -27, "skin": "ui/img_UM_ui_bg5.jpg" }, "compId": 1252 }, { "type": "Image", "props": { "y": 23, "x": 901, "skin": "ui/img_UM_top1.png" }, "compId": 1253 }, { "type": "Image", "props": { "y": 23, "x": 433, "skin": "ui/img_UM_top3.png" }, "compId": 1254 }, { "type": "Image", "props": { "y": 521, "x": 207, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1267 }, { "type": "Image", "props": { "y": 23, "x": 667, "skin": "ui/img_UM_top2.png" }, "compId": 1255 }, { "type": "Image", "props": { "y": 294, "x": 786, "skin": "ui/img_UM_gameMode_5v5.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1257 }, { "type": "Image", "props": { "y": 117, "x": 1020, "skin": "ui/img_UM_gameMode_2v2.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1258 }, { "type": "Image", "props": { "y": 117, "x": 785, "skin": "ui/img_UM_gameMode_dibao.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1260 }, { "type": "Image", "props": { "y": 590, "x": 3, "skin": "ui/img_UM_fun_btn_1.png" }, "compId": 1261 }, { "type": "Image", "props": { "y": 590, "x": 197, "skin": "ui/img_UM_fun_btn_2.png" }, "compId": 1262 }, { "type": "Image", "props": { "y": 590, "x": 392, "skin": "ui/img_UM_fun_btn_3.png" }, "compId": 1263 }, { "type": "Image", "props": { "y": 590, "x": 586, "skin": "ui/img_UM_fun_btn_4.png" }, "compId": 1264 }, { "type": "Image", "props": { "y": -7, "x": -6, "skin": "ui/img_UM_playerinfo.png" }, "compId": 1268 }, { "type": "Box", "props": { "y": 304, "x": 147 }, "compId": 1269, "child": [{ "type": "Image", "props": { "skin": "ui/img_UM_ui_xuanzhuan1.png" }, "compId": 1265 }, { "type": "Image", "props": { "y": 0, "x": 395, "skin": "ui/img_UM_ui_xuanzhuan2.png" }, "compId": 1266 }] }, { "type": "Image", "props": { "y": 68, "x": 122, "width": 193, "skin": "ui/img_UM_playerEXPbar.png", "sizeGrid": "15,19,22,21", "height": 46 }, "compId": 1270 }, { "type": "Label", "props": { "y": 35, "x": 132, "wordWrap": true, "width": 173, "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1271 }, { "type": "Label", "props": { "y": 43.5, "x": 326.5, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1272 }, { "type": "Image", "props": { "y": 12, "x": 15, "width": 95, "skin": "ui/img_UM_playerhead.png", "height": 95 }, "compId": 1273 }, { "type": "BtnStarGame", "props": { "y": 535, "x": 801, "runtime": "ui.test.BtnStarGameUI" }, "compId": 1274 }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_top1.png", "ui/img_UM_top3.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_top2.png", "ui/img_UM_gameMode_5v5.png", "ui/img_UM_gameMode_2v2.png", "ui/img_UM_gameMode_dibao.png", "ui/img_UM_fun_btn_1.png", "ui/img_UM_fun_btn_2.png", "ui/img_UM_fun_btn_3.png", "ui/img_UM_fun_btn_4.png", "ui/img_UM_playerinfo.png", "ui/img_UM_ui_xuanzhuan1.png", "ui/img_UM_ui_xuanzhuan2.png", "ui/img_UM_playerEXPbar.png", "ui/img_UM_playerhead.png"], "loadList3D": [] };
            test.Page3UI = Page3UI;
            REG("ui.test.Page3UI", Page3UI);
            class Page4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Page4UI.uiView);
                }
            }
            Page4UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -27, "skin": "ui/img_UM_ui_bg5.jpg" }, "compId": 1252 }, { "type": "Image", "props": { "y": 23, "x": 901, "skin": "ui/img_UM_top1.png" }, "compId": 1253 }, { "type": "Image", "props": { "y": 23, "x": 433, "skin": "ui/img_UM_top3.png" }, "compId": 1254 }, { "type": "Image", "props": { "y": 521, "x": 207, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1267 }, { "type": "Image", "props": { "y": 23, "x": 667, "skin": "ui/img_UM_top2.png" }, "compId": 1255 }, { "type": "Image", "props": { "y": 294, "x": 786, "skin": "ui/img_UM_gameMode_5v5.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1257 }, { "type": "Image", "props": { "y": 117, "x": 1020, "skin": "ui/img_UM_gameMode_2v2.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1258 }, { "type": "Image", "props": { "y": 117, "x": 785, "skin": "ui/img_UM_gameMode_dibao.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1260 }, { "type": "Image", "props": { "y": 590, "x": 3, "skin": "ui/img_UM_fun_btn_1.png" }, "compId": 1261 }, { "type": "Image", "props": { "y": 590, "x": 197, "skin": "ui/img_UM_fun_btn_2.png" }, "compId": 1262 }, { "type": "Image", "props": { "y": 590, "x": 392, "skin": "ui/img_UM_fun_btn_3.png" }, "compId": 1263 }, { "type": "Image", "props": { "y": 590, "x": 586, "skin": "ui/img_UM_fun_btn_4.png" }, "compId": 1264 }, { "type": "Image", "props": { "y": -7, "x": -6, "skin": "ui/img_UM_playerinfo.png" }, "compId": 1268 }, { "type": "Image", "props": { "y": 68, "x": 122, "width": 193, "skin": "ui/img_UM_playerEXPbar.png", "sizeGrid": "15,19,22,21", "height": 46 }, "compId": 1270 }, { "type": "Label", "props": { "y": 35, "x": 132, "wordWrap": true, "width": 173, "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1271 }, { "type": "Label", "props": { "y": 43.5, "x": 326.5, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1272 }, { "type": "BtnStarGame", "props": { "y": 535, "x": 801, "runtime": "ui.test.BtnStarGameUI" }, "compId": 1274 }, { "type": "Image", "props": { "y": 310, "x": 148, "skin": "ui/img_UM_btn_jiantou.png" }, "compId": 1275 }, { "type": "Image", "props": { "y": 310, "x": 545, "skin": "ui/img_UM_btn_jiantou2.png" }, "compId": 1276 }, { "type": "Image", "props": { "y": 290, "x": 330, "skin": "ui/img_UM_ui_lock.png" }, "compId": 1277 }, { "type": "Box", "props": { "y": 492, "x": 303 }, "compId": 1290, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 176, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 83 }, "compId": 1291 }, { "type": "Image", "props": { "y": 15, "x": 21, "width": 133, "skin": "ui/img_UM_ui_text20.png", "height": 38 }, "compId": 1293 }] }, { "type": "Box", "props": { "y": 493, "x": 115.5 }, "compId": 1294, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 176, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 83, "gray": true }, "compId": 1295 }, { "type": "Image", "props": { "y": 14, "x": 37, "skin": "ui/img_UM_ui_text15.png" }, "compId": 1297 }] }, { "type": "RedAnim1", "props": { "y": 575, "x": 104, "runtime": "ui.test.RedAnim1UI" }, "compId": 1298 }, { "type": "RedAnim2", "props": { "y": 575, "x": 684, "runtime": "ui.test.RedAnim2UI" }, "compId": 1299 }, { "type": "RedAnim1", "props": { "y": 575, "x": 297, "runtime": "ui.test.RedAnim1UI" }, "compId": 1300 }, { "type": "RedAnim1", "props": { "y": 575, "x": 491, "runtime": "ui.test.RedAnim1UI" }, "compId": 1301 }, { "type": "Label", "props": { "y": 441.5, "x": 44.5, "wordWrap": true, "width": 681, "text": "解锁条件：XXXXXXXXXXXXXXXXXXXXXXXXX", "strokeColor": "#000000", "stroke": 4, "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1302 }, { "type": "Box", "props": { "y": 3, "x": 7 }, "compId": 1308, "child": [{ "type": "Image", "props": { "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1306 }, { "type": "Image", "props": { "y": 3, "x": 4, "skin": "ui/img_UM_head.png", "renderType": "render" }, "compId": 1307 }] }, { "type": "RedAnim3", "props": { "y": 261, "x": 574, "runtime": "ui.test.RedAnim3UI" }, "compId": 1311 }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_top1.png", "ui/img_UM_top3.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_top2.png", "ui/img_UM_gameMode_5v5.png", "ui/img_UM_gameMode_2v2.png", "ui/img_UM_gameMode_dibao.png", "ui/img_UM_fun_btn_1.png", "ui/img_UM_fun_btn_2.png", "ui/img_UM_fun_btn_3.png", "ui/img_UM_fun_btn_4.png", "ui/img_UM_playerinfo.png", "ui/img_UM_playerEXPbar.png", "ui/img_UM_btn_jiantou.png", "ui/img_UM_btn_jiantou2.png", "ui/img_UM_ui_lock.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text20.png", "ui/img_UM_ui_text15.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_head.png"], "loadList3D": [] };
            test.Page4UI = Page4UI;
            REG("ui.test.Page4UI", Page4UI);
            class Page5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(Page5UI.uiView);
                }
            }
            Page5UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -27, "skin": "ui/img_UM_ui_bg5.jpg" }, "compId": 1252 }, { "type": "Image", "props": { "y": 23, "x": 901, "skin": "ui/img_UM_top1.png" }, "compId": 1253 }, { "type": "Image", "props": { "y": 23, "x": 433, "skin": "ui/img_UM_top3.png" }, "compId": 1254 }, { "type": "Image", "props": { "y": 521, "x": 207, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1267 }, { "type": "Image", "props": { "y": 23, "x": 667, "skin": "ui/img_UM_top2.png" }, "compId": 1255 }, { "type": "Image", "props": { "y": 294, "x": 786, "skin": "ui/img_UM_gameMode_5v5.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1257 }, { "type": "Image", "props": { "y": 117, "x": 1020, "skin": "ui/img_UM_gameMode_2v2.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1258 }, { "type": "Image", "props": { "y": 117, "x": 785, "skin": "ui/img_UM_gameMode_dibao.png", "scaleY": 0.9, "scaleX": 0.9 }, "compId": 1260 }, { "type": "Image", "props": { "y": 590, "x": 3, "skin": "ui/img_UM_fun_btn_1.png" }, "compId": 1261 }, { "type": "Image", "props": { "y": 590, "x": 197, "skin": "ui/img_UM_fun_btn_2.png" }, "compId": 1262 }, { "type": "Image", "props": { "y": 590, "x": 392, "skin": "ui/img_UM_fun_btn_3.png" }, "compId": 1263 }, { "type": "Image", "props": { "y": 590, "x": 586, "skin": "ui/img_UM_fun_btn_4.png" }, "compId": 1264 }, { "type": "Image", "props": { "y": -7, "x": -6, "skin": "ui/img_UM_playerinfo.png" }, "compId": 1268 }, { "type": "Image", "props": { "y": 68, "x": 122, "width": 193, "skin": "ui/img_UM_playerEXPbar.png", "sizeGrid": "15,19,22,21", "height": 46 }, "compId": 1270 }, { "type": "Label", "props": { "y": 35, "x": 132, "wordWrap": true, "width": 173, "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1271 }, { "type": "Label", "props": { "y": 43.5, "x": 326.5, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1272 }, { "type": "BtnStarGame", "props": { "y": 535, "x": 801, "runtime": "ui.test.BtnStarGameUI" }, "compId": 1274 }, { "type": "Image", "props": { "y": 310, "x": 148, "skin": "ui/img_UM_btn_jiantou.png" }, "compId": 1275 }, { "type": "Image", "props": { "y": 310, "x": 545, "skin": "ui/img_UM_btn_jiantou2.png" }, "compId": 1276 }, { "type": "Image", "props": { "y": 290, "x": 330, "skin": "ui/img_UM_ui_lock.png" }, "compId": 1277 }, { "type": "Box", "props": { "y": 492, "x": 303 }, "compId": 1290, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 176, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 83 }, "compId": 1291 }, { "type": "Image", "props": { "y": 15, "x": 21, "width": 133, "skin": "ui/img_UM_ui_text20.png", "height": 38 }, "compId": 1293 }] }, { "type": "Box", "props": { "y": 808, "x": 392 }, "compId": 1294, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 176, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 83, "gray": true }, "compId": 1295 }, { "type": "Image", "props": { "y": 14, "x": 37, "skin": "ui/img_UM_ui_text15.png" }, "compId": 1297 }] }, { "type": "RedAnim1", "props": { "y": 575, "x": 104, "runtime": "ui.test.RedAnim1UI" }, "compId": 1298 }, { "type": "RedAnim2", "props": { "y": 575, "x": 684, "runtime": "ui.test.RedAnim2UI" }, "compId": 1299 }, { "type": "RedAnim1", "props": { "y": 575, "x": 297, "runtime": "ui.test.RedAnim1UI" }, "compId": 1300 }, { "type": "RedAnim1", "props": { "y": 575, "x": 491, "runtime": "ui.test.RedAnim1UI" }, "compId": 1301 }, { "type": "Label", "props": { "y": 441.5, "x": 44.5, "wordWrap": true, "width": 681, "text": "解锁条件：XXXXXXXXXXXXXXXXXXXXXXXXX", "strokeColor": "#000000", "stroke": 4, "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1302 }, { "type": "RedAnim3", "props": { "y": 261, "x": 574, "runtime": "ui.test.RedAnim3UI" }, "compId": 1311 }, { "type": "Box", "props": { "y": 94, "x": 7 }, "compId": 1317, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1314 }, { "type": "Image", "props": { "y": 107, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text45.png", "height": 30 }, "compId": 1316 }, { "type": "Image", "props": { "y": 36.5, "x": 12, "width": 77, "skin": "ui/img_UM_icon_qiandao.png", "height": 76 }, "compId": 1328 }] }, { "type": "Box", "props": { "y": 199, "x": 7 }, "compId": 1329, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1330 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text44.png", "height": 30 }, "compId": 1331 }, { "type": "Image", "props": { "y": 30.5, "x": 10, "width": 78, "skin": "ui/img_UM_icon_zaixian2.png", "height": 77 }, "compId": 1333 }] }, { "type": "RedAnim1", "props": { "y": 112, "x": 59.5, "runtime": "ui.test.RedAnim1UI" }, "compId": 1334 }, { "type": "RedAnim1", "props": { "y": 216, "x": 59.5, "runtime": "ui.test.RedAnim1UI" }, "compId": 1335 }, { "type": "Image", "props": { "y": 164.5, "x": 786, "skin": "ui/img_UM_biaoqian.png" }, "compId": 1336 }, { "type": "Image", "props": { "y": 167, "x": 1031, "skin": "ui/img_UM_biaoqian.png" }, "compId": 1337 }, { "type": "Image", "props": { "y": 76.5, "x": -1493, "width": 1358, "skin": "ui/img_UM_black.png", "sizeGrid": "11,11,11,11", "height": 800, "alpha": 0.6 }, "compId": 1340 }, { "type": "guide", "props": { "y": 105, "x": 1280, "runtime": "ui.test.guideUI" }, "compId": 1339 }, { "type": "BtnShiyong", "props": { "y": 433, "x": 4, "runtime": "ui.test.BtnShiyongUI" }, "compId": 1343 }, { "type": "BtnTianjiang", "props": { "y": 437, "x": 684, "runtime": "ui.test.BtnTianjiangUI" }, "compId": 1344 }, { "type": "BtnHead", "props": { "y": 8, "x": 12, "runtime": "ui.test.BtnHeadUI" }, "compId": 1345 }, { "type": "Box", "props": { "y": 87, "x": 681.5 }, "compId": 1346, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1347 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text75.png", "height": 30 }, "compId": 1348 }, { "type": "Image", "props": { "y": 23, "x": 11, "width": 78, "skin": "ui/img_UM_icon_lp.png", "height": 78 }, "compId": 1350 }] }, { "type": "Box", "props": { "y": 196, "x": 683 }, "compId": 1351, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1352 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text81.png", "height": 30 }, "compId": 1353 }, { "type": "Image", "props": { "y": 23, "x": 11, "width": 78, "skin": "ui/img_UM_img_moregame.png", "height": 78 }, "compId": 1354 }] }, { "type": "Box", "props": { "y": 302, "x": 684, "width": 105, "rotation": 0, "height": 134 }, "compId": 1356, "child": [{ "type": "Image", "props": { "y": 27, "x": 0, "width": 100, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "36,43,46,43", "height": 100 }, "compId": 1357 }, { "type": "Image", "props": { "y": 104, "x": -2, "width": 107, "skin": "ui/img_UM_ui_text82.png", "height": 30 }, "compId": 1358 }, { "type": "Image", "props": { "y": 23, "x": 11, "width": 78, "skin": "ui/img_UM_img_desktop.png", "height": 78 }, "compId": 1359 }] }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_top1.png", "ui/img_UM_top3.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_top2.png", "ui/img_UM_gameMode_5v5.png", "ui/img_UM_gameMode_2v2.png", "ui/img_UM_gameMode_dibao.png", "ui/img_UM_fun_btn_1.png", "ui/img_UM_fun_btn_2.png", "ui/img_UM_fun_btn_3.png", "ui/img_UM_fun_btn_4.png", "ui/img_UM_playerinfo.png", "ui/img_UM_playerEXPbar.png", "ui/img_UM_btn_jiantou.png", "ui/img_UM_btn_jiantou2.png", "ui/img_UM_ui_lock.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text20.png", "ui/img_UM_ui_text15.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text45.png", "ui/img_UM_icon_qiandao.png", "ui/img_UM_ui_text44.png", "ui/img_UM_icon_zaixian2.png", "ui/img_UM_biaoqian.png", "ui/img_UM_black.png", "ui/img_UM_ui_text75.png", "ui/img_UM_icon_lp.png", "ui/img_UM_ui_text81.png", "ui/img_UM_img_moregame.png", "ui/img_UM_ui_text82.png", "ui/img_UM_img_desktop.png"], "loadList3D": [] };
            test.Page5UI = Page5UI;
            REG("ui.test.Page5UI", Page5UI);
            class PageBuyUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageBuyUI.uiView);
                }
            }
            PageBuyUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 90, "x": 327, "width": 625, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 504 }, "compId": 1584 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 100, "x": 550, "var": "img_test", "skin": "ui/img_UM_ui_text55.png", "name": "img_test" }, "compId": 1607 }, { "type": "Image", "props": { "y": 155, "x": 336, "width": 608, "skin": "ui/img_UM_ui_uibk4.png", "sizeGrid": "8,8,8,8", "height": 279 }, "compId": 1638 }, { "type": "Image", "props": { "y": 434, "x": 336, "width": 608, "skin": "ui/img_UM_ui_uibk5.png", "sizeGrid": "8,8,8,8", "height": 144 }, "compId": 1639 }, { "type": "Image", "props": { "y": 175, "x": 550, "width": 300, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "117,76,67,69", "scaleY": 0.6, "scaleX": 0.6, "height": 390 }, "compId": 1640 }, { "type": "Box", "props": { "y": 454, "x": 505 }, "compId": 1641, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1642 }, { "type": "Image", "props": { "y": 23, "x": 89, "width": 153, "skin": "ui/img_UM_ui_text56.png", "height": 44 }, "compId": 1644 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 57, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 46 }, "compId": 1645 }] }, { "type": "Image", "props": { "y": 241, "x": 571.5, "width": 137, "skin": "ui/img_UM_box_gold.png", "height": 137 }, "compId": 1646 }, { "type": "Image", "props": { "y": 190, "x": 671.5, "width": 36, "skin": "ui/img_UM_gold.png", "height": 36 }, "compId": 1647 }, { "type": "Image", "props": { "y": 186.5, "x": 572.5, "width": 95, "skin": "ui/img_UM_num_1000.png", "height": 41 }, "compId": 1649 }, { "type": "Label", "props": { "y": 609, "x": 521, "wordWrap": true, "width": 237, "text": "不了，谢谢", "strokeColor": "#272727", "stroke": 4, "height": 57, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1650 }], "loadList": ["ui/img_UM_ui_uibk.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_text55.png", "ui/img_UM_ui_uibk4.png", "ui/img_UM_ui_uibk5.png", "ui/img_UM_shop_ui_bg2.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui_text56.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_box_gold.png", "ui/img_UM_gold.png", "ui/img_UM_num_1000.png"], "loadList3D": [] };
            test.PageBuyUI = PageBuyUI;
            REG("ui.test.PageBuyUI", PageBuyUI);
            class PageCardUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageCardUI.uiView);
                }
            }
            PageCardUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1280, "skin": "ui/img_UM_cardbg.png", "sizeGrid": "11,15,9,16", "height": 720 }, "compId": 1240 }, { "type": "Image", "props": { "y": 33, "x": 192, "width": 750, "skin": "ui/img_UM_btn_BlueButton_1.png", "sizeGrid": "41,22,32,32", "height": 289 }, "compId": 1239 }, { "type": "Box", "props": { "y": 329, "x": 194, "width": 737, "height": 51 }, "compId": 1249, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 742, "skin": "ui/img_UM_ui_obj3.png", "sizeGrid": "8,15,8,6", "height": 50, "alpha": 0.5 }, "compId": 1246 }, { "type": "Label", "props": { "y": 11, "x": 27, "wordWrap": true, "width": 268, "text": "已拥有卡牌", "strokeColor": "#212121", "name": "txt_phy", "height": 30, "fontSize": 30, "font": "SimHei", "color": "#e8e8e8", "bold": true, "align": "left" }, "compId": 1248 }] }, { "type": "Image", "props": { "y": 48, "x": 222, "width": 700, "skin": "ui/img_UM_ui_obj4.png", "sizeGrid": "7,12,8,8", "height": 50 }, "compId": 1250 }, { "type": "Label", "props": { "y": 60, "x": 236, "wordWrap": true, "width": 268, "text": "战斗卡组", "strokeColor": "#212121", "name": "txt_phy", "height": 30, "fontSize": 30, "font": "SimHei", "color": "#e8e8e8", "bold": true, "align": "left" }, "compId": 1251 }, { "type": "List", "props": { "y": 104, "x": 218, "width": 711, "spaceX": -20, "repeatY": 1, "repeatX": 5, "height": 230 }, "compId": 1253, "child": [{ "type": "heroCard21", "props": { "y": 0, "x": 0, "scaleY": 0.8, "scaleX": 0.8, "renderType": "render", "runtime": "ui.test.heroCard21UI" }, "compId": 1268 }] }, { "type": "List", "props": { "y": 390, "x": 214, "width": 690, "spaceY": -40, "spaceX": -20, "repeatY": 2, "repeatX": 5, "height": 448 }, "compId": 1254, "child": [{ "type": "heroCardUse", "props": { "y": 0, "x": 0, "scaleY": 0.8, "scaleX": 0.8, "renderType": "render", "runtime": "ui.test.heroCardUseUI" }, "compId": 1262 }] }, { "type": "Box", "props": { "y": 38, "x": 48 }, "compId": 1256, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1257 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1258 }] }, { "type": "heroCardAnim", "props": { "y": 256, "x": 232, "runtime": "ui.test.heroCardAnimUI" }, "compId": 1263 }, { "type": "heroCardAnim", "props": { "y": 256, "x": 373, "runtime": "ui.test.heroCardAnimUI" }, "compId": 1264 }, { "type": "heroCardAnim", "props": { "y": 256, "x": 514, "runtime": "ui.test.heroCardAnimUI" }, "compId": 1265 }, { "type": "heroCardAnim", "props": { "y": 256, "x": 654, "runtime": "ui.test.heroCardAnimUI" }, "compId": 1266 }, { "type": "heroCardAnim", "props": { "y": 256, "x": 795, "runtime": "ui.test.heroCardAnimUI" }, "compId": 1267 }, { "type": "Box", "props": { "y": 581, "x": 984 }, "compId": 1269, "child": [{ "type": "Image", "props": { "y": -10, "x": 2, "width": 496, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "43,56,69,55", "scaleY": 0.5, "scaleX": 0.5, "height": 226 }, "compId": 1270 }, { "type": "Image", "props": { "y": 20, "x": 17, "width": 216, "skin": "ui/img_UM_text_ksyx.png", "height": 51 }, "compId": 1271 }] }], "loadList": ["ui/img_UM_cardbg.png", "ui/img_UM_btn_BlueButton_1.png", "ui/img_UM_ui_obj3.png", "ui/img_UM_ui_obj4.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_text_ksyx.png"], "loadList3D": [] };
            test.PageCardUI = PageCardUI;
            REG("ui.test.PageCardUI", PageCardUI);
            class PageCZUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageCZUI.uiView);
                }
            }
            PageCZUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg2.png" }, "compId": 1127 }, { "type": "Image", "props": { "y": -1, "x": 169, "width": 751, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 721, "alpha": 0.6 }, "compId": 1137 }, { "type": "Image", "props": { "y": 326, "x": 180, "width": 723, "skin": "ui/img_UM_cardbg.png", "sizeGrid": "4,5,3,5", "height": 386 }, "compId": 1214 }, { "type": "Image", "props": { "y": -6, "x": 180, "width": 728, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 70 }, "compId": 1206 }, { "type": "Image", "props": { "y": 60, "x": 178, "width": 730, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "50,50,70,50", "scaleY": 1, "scaleX": 1, "height": 280 }, "compId": 1128 }, { "type": "Box", "props": { "y": 593, "x": 961 }, "compId": 1163, "child": [{ "type": "Image", "props": { "y": -5, "x": 0, "width": 269, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 114 }, "compId": 1164 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 216, "skin": "ui/img_UM_text_ksyx.png", "height": 51 }, "compId": 1205 }] }, { "type": "List", "props": { "y": 393, "x": 180, "width": 735, "vScrollBarSkin": "comp/vscroll.png", "spaceY": -40, "spaceX": -35, "repeatY": 2, "repeatX": 5, "renderType": "render", "height": 311 }, "compId": 1192, "child": [{ "type": "heroCard", "props": { "y": 0, "x": 0, "scaleY": 0.8, "scaleX": 0.8, "renderType": "render", "runtime": "ui.test.heroCardUI" }, "compId": 1196 }] }, { "type": "List", "props": { "y": 118, "x": 193, "width": 693, "spaceX": -20, "repeatY": 1, "repeatX": 5, "height": 208 }, "compId": 1195, "child": [{ "type": "heroCard1", "props": { "scaleY": 0.8, "scaleX": 0.8, "renderType": "render", "runtime": "ui.test.heroCard1UI" }, "compId": 1194 }] }, { "type": "Image", "props": { "y": 71, "x": 193, "skin": "ui/img_UM_card_bg.png" }, "compId": 1213 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 80, "x": 203.5, "width": 111, "skin": "ui/img_UM_Card_text2.png", "height": 32 }, "compId": 1207 }, { "type": "Image", "props": { "y": 11, "x": 466.5, "skin": "ui/img_UM_Card_text1.png" }, "compId": 1208 }, { "type": "Box", "props": { "y": 49, "x": 943.5 }, "compId": 1233, "child": [{ "type": "Image", "props": { "x": 11, "skin": "ui/img_UM_gameMode_hero.png" }, "compId": 1218 }, { "type": "Image", "props": { "y": 2, "x": 0, "width": 304, "skin": "ui/img_UM_tu.png", "height": 304 }, "compId": 1225 }, { "type": "Skillicon", "props": { "y": 220, "x": 34, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.test.SkilliconUI" }, "compId": 1228 }, { "type": "Skillicon", "props": { "y": 220, "x": 194, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.test.SkilliconUI" }, "compId": 1229 }, { "type": "Image", "props": { "y": 17, "x": 41, "skin": "ui/img_UM_hero_text1.png" }, "compId": 1231 }, { "type": "BtnLjsy", "props": { "y": 332, "x": 25, "runtime": "ui.test.BtnLjsyUI" }, "compId": 1236 }] }, { "type": "Image", "props": { "y": 344, "x": 190, "skin": "ui/img_UM_card_bg.png", "alpha": 0.2 }, "compId": 1234 }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_black.png", "ui/img_UM_cardbg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_text_ksyx.png", "comp/vscroll.png", "ui/img_UM_card_bg.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_Card_text2.png", "ui/img_UM_Card_text1.png", "ui/img_UM_gameMode_hero.png", "ui/img_UM_tu.png", "ui/img_UM_hero_text1.png"], "loadList3D": [] };
            test.PageCZUI = PageCZUI;
            REG("ui.test.PageCZUI", PageCZUI);
            class PageCZ2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageCZ2UI.uiView);
                }
            }
            PageCZ2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg2.png" }, "compId": 1127 }, { "type": "Image", "props": { "y": -1, "x": 169, "width": 751, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 721, "alpha": 0.6 }, "compId": 1137 }, { "type": "Image", "props": { "y": 326, "x": 180, "width": 723, "skin": "ui/img_UM_cardbg.png", "sizeGrid": "4,5,3,5", "height": 386 }, "compId": 1214 }, { "type": "Image", "props": { "y": -6, "x": 180, "width": 728, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 70 }, "compId": 1206 }, { "type": "Image", "props": { "y": 60, "x": 178, "width": 730, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "50,50,70,50", "scaleY": 1, "scaleX": 1, "height": 280 }, "compId": 1128 }, { "type": "Box", "props": { "y": 593, "x": 961 }, "compId": 1163, "child": [{ "type": "Image", "props": { "y": -5, "x": 0, "width": 269, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 114 }, "compId": 1164 }, { "type": "Image", "props": { "y": 23, "x": 26, "width": 216, "skin": "ui/img_UM_text_ksyx.png", "height": 51 }, "compId": 1205 }] }, { "type": "List", "props": { "y": 396, "x": 193, "width": 703, "vScrollBarSkin": "comp/vscroll.png", "spaceY": -100, "spaceX": -60, "repeatY": 2, "repeatX": 5, "renderType": "render", "height": 311 }, "compId": 1192, "child": [{ "type": "heroCard31", "props": { "y": 0, "x": 0, "scaleY": 0.6, "scaleX": 0.6, "renderType": "render", "runtime": "ui.test.heroCard31UI" }, "compId": 1239 }] }, { "type": "List", "props": { "y": 128, "x": 203, "width": 693, "spaceX": -60, "repeatY": 1, "repeatX": 5, "height": 177 }, "compId": 1195, "child": [{ "type": "heroCard3", "props": { "y": 0, "x": 0, "scaleY": 0.6, "scaleX": 0.6, "renderType": "render", "runtime": "ui.test.heroCard3UI" }, "compId": 1237 }] }, { "type": "Image", "props": { "y": 71, "x": 193, "skin": "ui/img_UM_card_bg.png" }, "compId": 1213 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 80, "x": 203.5, "width": 111, "skin": "ui/img_UM_Card_text2.png", "height": 32 }, "compId": 1207 }, { "type": "Image", "props": { "y": 11, "x": 466.5, "skin": "ui/img_UM_Card_text1.png" }, "compId": 1208 }, { "type": "Box", "props": { "y": 49, "x": 943.5 }, "compId": 1233, "child": [{ "type": "Image", "props": { "x": 11, "skin": "ui/img_UM_gameMode_hero.png" }, "compId": 1218 }, { "type": "Image", "props": { "y": 2, "x": 0, "width": 304, "skin": "ui/img_UM_tu.png", "height": 304 }, "compId": 1225 }, { "type": "Skillicon", "props": { "y": 220, "x": 34, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.test.SkilliconUI" }, "compId": 1228 }, { "type": "Skillicon", "props": { "y": 220, "x": 194, "scaleY": 0.5, "scaleX": 0.5, "runtime": "ui.test.SkilliconUI" }, "compId": 1229 }, { "type": "Image", "props": { "y": 17, "x": 41, "skin": "ui/img_UM_hero_text1.png" }, "compId": 1231 }, { "type": "BtnLjsy", "props": { "y": 332, "x": 25, "runtime": "ui.test.BtnLjsyUI" }, "compId": 1236 }] }, { "type": "Image", "props": { "y": 344, "x": 190, "skin": "ui/img_UM_card_bg.png", "alpha": 0.2 }, "compId": 1234 }, { "type": "heroCard31", "props": { "y": 239, "x": -239, "runtime": "ui.test.heroCard31UI" }, "compId": 1241 }, { "type": "heroCard33", "props": { "y": 580, "x": -239, "runtime": "ui.test.heroCard33UI" }, "compId": 1242 }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_black.png", "ui/img_UM_cardbg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_text_ksyx.png", "comp/vscroll.png", "ui/img_UM_card_bg.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_Card_text2.png", "ui/img_UM_Card_text1.png", "ui/img_UM_gameMode_hero.png", "ui/img_UM_tu.png", "ui/img_UM_hero_text1.png"], "loadList3D": [] };
            test.PageCZ2UI = PageCZ2UI;
            REG("ui.test.PageCZ2UI", PageCZ2UI);
            class PageDefeatUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageDefeatUI.uiView);
                }
            }
            PageDefeatUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 70, "x": 193, "width": 838, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1130 }, { "type": "Label", "props": { "y": 79.5, "x": 210, "wordWrap": true, "width": 173, "text": "战斗卡组", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1131 }, { "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg.jpg" }, "compId": 1217 }, { "type": "Image", "props": { "y": 183, "x": 0, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Box", "props": { "y": 213, "x": 360 }, "compId": 1225, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1207 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1218 }, { "type": "List", "props": { "y": 88, "x": 23, "width": 407, "spaceX": -80, "repeatY": 1, "repeatX": 5, "height": 123 }, "compId": 1210, "child": [{ "type": "heroCard1", "props": { "scaleY": 0.5, "scaleX": 0.5, "renderType": "render", "runtime": "ui.test.heroCard1UI" }, "compId": 1211 }] }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1216 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": true, "width": 63, "text": "+90", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1219 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1220 }, { "type": "Label", "props": { "y": 32, "x": 41, "wordWrap": true, "width": 327, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1221 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1222 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1223 }] }, { "type": "Image", "props": { "y": 114, "x": 447, "width": 643, "skin": "ui/img_UM_ribbon_bg_red.png", "sizeGrid": "43,158,53,158", "scaleY": 0.6, "scaleX": 0.6, "height": 152 }, "compId": 1237 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }], "loadList": ["ui/img_UM_ui_obj1.png", "ui/img_UM_ui_bg.jpg", "ui/img_UM_black.png", "ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png", "ui/img_UM_xpicon.png", "ui/img_UM_ribbon_bg_red.png", "ui/img_UM_text_fail.png"], "loadList3D": [] };
            test.PageDefeatUI = PageDefeatUI;
            REG("ui.test.PageDefeatUI", PageDefeatUI);
            class PageDefeat2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageDefeat2UI.uiView);
                }
            }
            PageDefeat2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 70, "x": 193, "width": 838, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1130 }, { "type": "Label", "props": { "y": 79.5, "x": 210, "wordWrap": true, "width": 173, "text": "战斗卡组", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1131 }, { "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg.jpg" }, "compId": 1217 }, { "type": "Image", "props": { "y": 337, "x": 640, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "pivotY": 154, "pivotX": 640, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_defeatbg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_fail.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "PageTeamBlue", "props": { "y": 100, "x": 250, "width": 500, "pivotY": 100, "pivotX": 250, "height": 200, "runtime": "ui.test.PageTeamBlueUI" }, "compId": 1281 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "PageTeamRed", "props": { "y": 100, "x": 250, "width": 500, "pivotY": 100, "pivotX": 250, "height": 200, "runtime": "ui.test.PageTeamRedUI" }, "compId": 1282 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -0.5, "x": 301, "width": 269, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": -0.5, "width": 269, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 23 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 23 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 27 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 36 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 41 }, { "value": 324, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 51 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }, { "value": 935, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 23 }, { "value": 630, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 32 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 41 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 46 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleY", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 29 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "scaleX", "index": 46 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "scaleX", "index": 51 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 41 }, { "value": 323, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 46 }, { "value": 333, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "y", "index": 51 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleY", "index": 51 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 41 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 46 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "scaleX", "index": 51 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 41 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 46 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 51 }] } }, { "target": 1296, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 51 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 56 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_ui_obj1.png", "ui/img_UM_ui_bg.jpg", "ui/img_UM_black.png", "ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            test.PageDefeat2UI = PageDefeat2UI;
            REG("ui.test.PageDefeat2UI", PageDefeat2UI);
            class PageDefeatQianUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageDefeatQianUI.uiView);
                }
            }
            PageDefeatQianUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "VictoryEffect", "props": { "y": 150, "x": 640, "width": 520, "scaleY": 0.7, "scaleX": 2, "pivotY": 274, "pivotX": 260, "height": 520, "runtime": "ui.test.VictoryEffectUI" }, "compId": 1241 }, { "type": "Image", "props": { "y": 140, "x": 633, "width": 500, "skin": "ui/img_UM_end_victorybg.png", "pivotY": 52, "pivotX": 250, "height": 130 }, "compId": 1242 }, { "type": "Image", "props": { "y": 121, "x": 640, "width": 256, "skin": "ui/img_UM_text_victory.png", "pivotY": 60, "pivotX": 128, "height": 119 }, "compId": 1239 }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "scaleY": 1, "scaleX": 1, "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter", "alpha": 0 }, "compId": 1285 }, { "type": "Image", "props": { "y": 512, "x": 293, "width": 693, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 124, "alpha": 0.4 }, "compId": 1297 }, { "type": "Box", "props": { "y": 518, "x": 299 }, "compId": 1309, "child": [{ "type": "Image", "props": { "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1311 }, { "type": "Label", "props": { "y": 41, "x": 39, "wordWrap": true, "width": 202, "text": "最大Frag连击", "strokeColor": "#000000", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1312 }, { "type": "Label", "props": { "y": 21, "x": 253, "wordWrap": true, "width": 66, "text": "8", "strokeColor": "#000000", "height": 69, "fontSize": 70, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1313 }] }, { "type": "Box", "props": { "y": 473, "x": 639 }, "compId": 1310, "child": [{ "type": "Image", "props": { "y": 45, "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1314 }, { "type": "Label", "props": { "y": 82, "x": 13, "wordWrap": true, "width": 202, "text": "MVP", "strokeColor": "#000000", "height": 35, "fontSize": 40, "font": "SimHei", "color": "#141414", "bold": true, "align": "center" }, "compId": 1315 }, { "type": "heroCard3", "props": { "x": 205, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.heroCard3UI" }, "compId": 1316 }] }], "animations": [{ "nodes": [{ "target": 1241, "keyframes": { "y": [{ "value": 243, "tweenMethod": "linearNone", "tween": true, "target": 1241, "label": null, "key": "y", "index": 0 }, { "value": 150, "tweenMethod": "linearNone", "tween": true, "target": 1241, "label": null, "key": "y", "index": 20 }] } }, { "target": 1242, "keyframes": { "y": [{ "value": 233, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 0 }, { "value": 140, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 20 }], "scaleX": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 20 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 30 }] } }, { "target": 1239, "keyframes": { "y": [{ "value": 214, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 0 }, { "value": 121, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_ui_obj9.png"], "loadList3D": [] };
            test.PageDefeatQianUI = PageDefeatQianUI;
            REG("ui.test.PageDefeatQianUI", PageDefeatQianUI);
            class PageGoodsUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageGoodsUI.uiView);
                }
            }
            PageGoodsUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg2.png" }, "compId": 1127 }, { "type": "Image", "props": { "y": -1, "x": 169, "width": 751, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 721, "alpha": 0.6 }, "compId": 1137 }, { "type": "Image", "props": { "y": 326, "x": 180, "width": 723, "skin": "ui/img_UM_cardbg.png", "sizeGrid": "4,5,3,5", "height": 386 }, "compId": 1214 }, { "type": "Image", "props": { "y": -6, "x": 180, "width": 728, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 70 }, "compId": 1206 }, { "type": "Image", "props": { "y": 60, "x": 178, "width": 730, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "50,50,70,50", "scaleY": 1, "scaleX": 1, "height": 280 }, "compId": 1128 }, { "type": "List", "props": { "y": 396, "x": 193, "width": 703, "vScrollBarSkin": "comp/vscroll.png", "spaceY": -100, "spaceX": -60, "repeatY": 2, "repeatX": 5, "renderType": "render", "height": 311 }, "compId": 1192, "child": [{ "type": "heroCard31", "props": { "y": 0, "x": 0, "scaleY": 0.6, "scaleX": 0.6, "renderType": "render", "runtime": "ui.test.heroCard31UI" }, "compId": 1239 }] }, { "type": "List", "props": { "y": 128, "x": 203, "width": 693, "spaceX": -60, "repeatY": 1, "repeatX": 5, "height": 177 }, "compId": 1195, "child": [{ "type": "heroCard3", "props": { "y": 0, "x": 0, "scaleY": 0.6, "scaleX": 0.6, "renderType": "render", "runtime": "ui.test.heroCard3UI" }, "compId": 1237 }] }, { "type": "Image", "props": { "y": 71, "x": 193, "skin": "ui/img_UM_card_bg.png" }, "compId": 1213 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 80, "x": 203.5, "width": 111, "skin": "ui/img_UM_Card_text2.png", "height": 32 }, "compId": 1207 }, { "type": "Image", "props": { "y": 11, "x": 466.5, "skin": "ui/img_UM_Card_text1.png" }, "compId": 1208 }, { "type": "Image", "props": { "y": 344, "x": 190, "skin": "ui/img_UM_card_bg.png", "alpha": 0.2 }, "compId": 1234 }, { "type": "heroCard31", "props": { "y": 239, "x": -239, "runtime": "ui.test.heroCard31UI" }, "compId": 1241 }, { "type": "heroCard33", "props": { "y": 580, "x": -239, "runtime": "ui.test.heroCard33UI" }, "compId": 1242 }, { "type": "Image", "props": { "y": 128, "x": 991, "skin": "ui/img_UM_top1.png" }, "compId": 1243 }, { "type": "Image", "props": { "y": 49, "x": 991, "skin": "ui/img_UM_top2.png" }, "compId": 1244 }], "loadList": ["ui/img_UM_ui_bg2.png", "ui/img_UM_black.png", "ui/img_UM_cardbg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_btn_BlueButton_2.png", "comp/vscroll.png", "ui/img_UM_card_bg.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_Card_text2.png", "ui/img_UM_Card_text1.png", "ui/img_UM_top1.png", "ui/img_UM_top2.png"], "loadList3D": [] };
            test.PageGoodsUI = PageGoodsUI;
            REG("ui.test.PageGoodsUI", PageGoodsUI);
            class PageHeadUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageHeadUI.uiView);
                }
            }
            PageHeadUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -10, "width": 1300, "skin": "ui/img_UM_cardbg.png", "sizeGrid": "4,5,3,5", "height": 750 }, "compId": 1214 }, { "type": "Image", "props": { "y": 59, "x": 585, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1206 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 184, "x": 442, "width": 395, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "height": 57 }, "compId": 1245 }, { "type": "Label", "props": { "y": 198, "x": 497, "wordWrap": true, "width": 285, "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1246 }, { "type": "Box", "props": { "y": 280, "x": 343 }, "compId": 1255, "child": [{ "type": "Image", "props": { "y": 2, "x": 0, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1250 }, { "type": "Image", "props": { "y": 2, "x": 121, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1262 }, { "type": "Image", "props": { "y": 2, "x": 242, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1263 }, { "type": "Image", "props": { "y": 2, "x": 362, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1264 }, { "type": "Image", "props": { "y": 2, "x": 483, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1265 }] }, { "type": "PageHeadEffect", "props": { "y": 263, "x": 324, "width": 150, "height": 150, "runtime": "ui.test.PageHeadEffectUI" }, "compId": 1282 }, { "type": "Box", "props": { "y": 396, "x": 343.5 }, "compId": 1266, "child": [{ "type": "Image", "props": { "y": 2, "x": 0, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1267 }, { "type": "Image", "props": { "y": 2, "x": 121, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1268 }, { "type": "Image", "props": { "y": 2, "x": 242, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1269 }, { "type": "Image", "props": { "y": 2, "x": 362, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1270 }, { "type": "Image", "props": { "y": 2, "x": 483, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1271 }] }, { "type": "List", "props": { "y": 285.5, "x": 349.5, "width": 579, "spaceY": 14, "spaceX": 20, "repeatY": 2, "repeatX": 5, "height": 202 }, "compId": 1249, "child": [{ "type": "Image", "props": { "skin": "ui/img_UM_head.png", "renderType": "render" }, "compId": 1243 }] }, { "type": "Image", "props": { "y": 62, "x": 589, "skin": "ui/img_UM_head.png", "renderType": "render" }, "compId": 1272 }, { "type": "Box", "props": { "y": 215, "x": 890, "width": 122, "pivotY": 44, "pivotX": 61, "height": 87 }, "compId": 1275, "child": [{ "type": "Image", "props": { "y": 34, "x": 57, "width": 67, "skin": "ui/img_UM_ui_touzi.png", "pivotY": 34, "pivotX": 34, "height": 67 }, "compId": 1273 }, { "type": "Image", "props": { "y": 52, "x": 9, "width": 105, "skin": "ui/img_UM_ui_text22.png", "height": 30 }, "compId": 1274 }] }, { "type": "HeadBtn", "props": { "y": 554, "x": 490, "runtime": "ui.test.HeadBtnUI" }, "compId": 1280 }], "loadList": ["ui/img_UM_cardbg.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_head.png", "ui/img_UM_ui_touzi.png", "ui/img_UM_ui_text22.png"], "loadList3D": [] };
            test.PageHeadUI = PageHeadUI;
            REG("ui.test.PageHeadUI", PageHeadUI);
            class PageHeadEffectUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageHeadEffectUI.uiView);
                }
            }
            PageHeadEffectUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 75, "x": 75, "width": 124, "skin": "ui/img_UM_herokill_bg_zi.png", "sizeGrid": "26,37,29,35", "pivotY": 60, "pivotX": 62, "height": 119, "blendMode": "lighter" }, "compId": 1281 }], "animations": [{ "nodes": [{ "target": 1281, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "label": null, "key": "scaleY", "index": 10 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleX", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "scaleX", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "label": null, "key": "scaleX", "index": 10 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "alpha", "index": 0 }, { "value": 0.7, "tweenMethod": "linearNone", "tween": true, "target": 1281, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1281, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png"], "loadList3D": [] };
            test.PageHeadEffectUI = PageHeadEffectUI;
            REG("ui.test.PageHeadEffectUI", PageHeadEffectUI);
            class PageHeroInfoUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageHeroInfoUI.uiView);
                }
            }
            PageHeroInfoUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -10, "width": 1300, "skin": "ui/img_UM_cardbg3.png", "sizeGrid": "4,5,3,5", "height": 750 }, "compId": 1214 }, { "type": "Image", "props": { "y": 26.5, "x": 1511, "width": 110, "skin": "ui/img_UM_btn__btn1.png", "sizeGrid": "25,30,32,27", "height": 110 }, "compId": 1206 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Label", "props": { "y": 168, "x": 1423, "wordWrap": true, "width": 285, "text": "玩家昵称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1246 }, { "type": "Image", "props": { "y": 32, "x": 1515, "skin": "ui/img_UM_head.png", "renderType": "render" }, "compId": 1272 }, { "type": "Box", "props": { "y": 185, "x": 1816, "width": 122, "pivotY": 44, "pivotX": 61, "height": 87 }, "compId": 1275, "child": [{ "type": "Image", "props": { "y": 34, "x": 57, "width": 67, "skin": "ui/img_UM_ui_touzi.png", "pivotY": 34, "pivotX": 34, "height": 67 }, "compId": 1273 }, { "type": "Image", "props": { "y": 52, "x": 9, "width": 105, "skin": "ui/img_UM_ui_text22.png", "height": 30 }, "compId": 1274 }] }, { "type": "Image", "props": { "y": -165, "x": 171, "width": 916, "skin": "ui/img_UM_effect_blue.png", "height": 914, "blendMode": "lighter", "alpha": 0.5 }, "compId": 1289 }, { "type": "Image", "props": { "y": 501, "x": 432, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1283 }, { "type": "Image", "props": { "y": -37, "x": 312.5, "width": 616, "skin": "ui/img_UM_tu.png", "height": 616 }, "compId": 1284 }, { "type": "Image", "props": { "y": 11, "x": 1023, "skin": "ui/img_UM_top1.png" }, "compId": 1297 }, { "type": "Image", "props": { "y": 11.5, "x": 789, "skin": "ui/img_UM_top2.png" }, "compId": 1298 }, { "type": "Box", "props": { "y": 84, "x": 947 }, "compId": 1352, "child": [{ "type": "Image", "props": { "y": 17, "width": 217, "skin": "ui/img_UM_loading_barbg.png", "sizeGrid": "8,36,6,30", "scaleY": 1.3, "scaleX": 1.3, "height": 30 }, "compId": 1299 }, { "type": "Label", "props": { "y": 18, "x": 59, "wordWrap": true, "width": 104, "text": "英雄等级", "strokeColor": "#09192c", "stroke": 4, "height": 32, "fontSize": 24, "font": "SimHei", "color": "#b7b7b7", "bold": true, "align": "left" }, "compId": 1300 }, { "type": "Label", "props": { "x": 172, "wordWrap": true, "width": 92, "text": "5", "strokeColor": "#09192c", "stroke": 4, "height": 50, "fontSize": 50, "font": "SimHei", "color": "#b7b7b7", "bold": true, "align": "left" }, "compId": 1301 }] }, { "type": "Image", "props": { "y": 250.5, "x": 392.5, "skin": "ui/img_UM_btn_jiantou.png" }, "compId": 1386 }, { "type": "Image", "props": { "y": 252, "x": 789, "skin": "ui/img_UM_btn_jiantou2.png" }, "compId": 1387 }, { "type": "Image", "props": { "y": 237, "x": 574, "skin": "ui/img_UM_ui_lock.png" }, "compId": 1388 }, { "type": "Label", "props": { "y": 388, "x": 288, "wordWrap": true, "width": 681, "text": "解锁条件：XXXXXXXXXXXXXXXXXXXXXXXXX", "strokeColor": "#000000", "stroke": 4, "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1389 }, { "type": "RedAnim3", "props": { "y": 196, "x": 789, "runtime": "ui.test.RedAnim3UI" }, "compId": 1393 }, { "type": "Box", "props": { "y": 135, "x": 927 }, "compId": 1396, "child": [{ "type": "Image", "props": { "y": 271, "x": 18, "width": 289, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "height": 41 }, "compId": 1245 }, { "type": "Box", "props": { "y": -1, "x": 0 }, "compId": 1312, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao2.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1302 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1303 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo3.png", "height": 50 }, "compId": 1304 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": true, "width": 104, "text": "233", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1305 }, { "type": "Label", "props": { "y": 11.5, "x": 65, "wordWrap": true, "width": 104, "text": "生命值", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1306 }, { "type": "Image", "props": { "y": 32.5, "x": 169, "width": 32, "skin": "ui/img_UM_heroinfo_ArrowBack.png", "height": 32 }, "compId": 1376 }, { "type": "Label", "props": { "y": 32.5, "x": 223, "wordWrap": true, "width": 104, "text": "233", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffe73b", "bold": true, "align": "left" }, "compId": 1377 }] }, { "type": "HeroInfoBtn", "props": { "y": 303, "x": 159, "runtime": "ui.test.HeroInfoBtnUI" }, "compId": 1331 }, { "type": "Box", "props": { "y": 66, "x": 0 }, "compId": 1353, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao2.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1354 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1355 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo2.png", "height": 50 }, "compId": 1356 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": true, "width": 104, "text": "43-55", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1357 }, { "type": "Label", "props": { "y": 11.5, "x": 65, "wordWrap": true, "width": 104, "text": "每秒伤害", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1358 }, { "type": "Image", "props": { "y": 30, "x": 169, "width": 32, "skin": "ui/img_UM_heroinfo_ArrowBack.png", "height": 32 }, "compId": 1378 }, { "type": "Label", "props": { "y": 30, "x": 223, "wordWrap": true, "width": 104, "text": "44-58", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffe73b", "bold": true, "align": "left" }, "compId": 1379 }] }, { "type": "Box", "props": { "y": 132, "x": 1 }, "compId": 1359, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1360 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1361 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo4.png", "height": 50 }, "compId": 1362 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": true, "width": 104, "text": "30m", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1363 }, { "type": "Label", "props": { "y": 11.5, "x": 65, "wordWrap": true, "width": 104, "text": "武器射程", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1364 }] }, { "type": "Box", "props": { "y": 199, "x": 1 }, "compId": 1365, "child": [{ "type": "Image", "props": { "y": 1, "x": 0, "width": 325, "skin": "ui/img_UM_heroinfo_tiao.png", "sizeGrid": "42,20,47,16", "height": 71 }, "compId": 1366 }, { "type": "Image", "props": { "y": 13, "x": 13, "width": 47, "skin": "ui/img_UM_herohead_bg.png", "height": 47, "alpha": 0.4 }, "compId": 1367 }, { "type": "Image", "props": { "y": 11.5, "x": 11, "width": 50, "skin": "ui/img_UM_icon_heroInfo1.png", "height": 50 }, "compId": 1368 }, { "type": "Label", "props": { "y": 32.5, "x": 66, "wordWrap": true, "width": 104, "text": "15.00s", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1369 }, { "type": "Label", "props": { "y": 12, "x": 65, "wordWrap": true, "width": 245, "text": "技能冷却时间", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#383838", "bold": true, "align": "left" }, "compId": 1370 }] }, { "type": "Image", "props": { "y": 269, "x": 15, "width": 193, "skin": "ui/img_UM_bar_green.png", "sizeGrid": "15,53,22,21", "height": 46 }, "compId": 1374 }, { "type": "Box", "props": { "y": 276, "x": 125 }, "compId": 1384, "child": [{ "type": "Image", "props": { "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1380 }, { "type": "Label", "props": { "y": 3, "x": 21, "wordWrap": true, "width": 21, "text": "/", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1381 }, { "type": "Image", "props": { "x": 39, "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1382 }, { "type": "Image", "props": { "x": 57, "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1383 }] }, { "type": "Box", "props": { "y": 312, "x": 1.5 }, "compId": 1397, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 160, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1398 }, { "type": "Image", "props": { "y": 30, "x": 21, "width": 117, "skin": "ui/img_UM_ui_text20.png", "height": 33 }, "compId": 1399 }] }] }, { "type": "Box", "props": { "y": 566, "x": -19 }, "compId": 1411, "child": [{ "type": "heroCard35", "props": { "runtime": "ui.test.heroCard35UI" }, "compId": 1402 }, { "type": "heroCard35", "props": { "x": 146, "runtime": "ui.test.heroCard35UI" }, "compId": 1403 }, { "type": "heroCard35", "props": { "x": 293, "runtime": "ui.test.heroCard35UI" }, "compId": 1404 }, { "type": "heroCard35", "props": { "x": 439, "runtime": "ui.test.heroCard35UI" }, "compId": 1405 }, { "type": "heroCard351", "props": { "x": 586, "runtime": "ui.test.heroCard351UI" }, "compId": 1406 }, { "type": "heroCard351", "props": { "x": 732, "runtime": "ui.test.heroCard351UI" }, "compId": 1407 }, { "type": "heroCard351", "props": { "x": 878, "runtime": "ui.test.heroCard351UI" }, "compId": 1408 }, { "type": "heroCard351", "props": { "x": 1025, "runtime": "ui.test.heroCard351UI" }, "compId": 1409 }, { "type": "heroCard351", "props": { "x": 1171, "runtime": "ui.test.heroCard351UI" }, "compId": 1410 }] }, { "type": "Box", "props": { "y": 129.00766505591625, "x": -14 }, "compId": 1412, "child": [{ "type": "Image", "props": { "y": 28.99233494408375, "x": 2, "skin": "ui/img_UM_heronamebg.png" }, "compId": 1288 }, { "type": "Label", "props": { "y": 151.99233494408375, "x": 37, "wordWrap": true, "width": 276, "text": "丹是国际参赛选手中最知名的一位：他的粉丝群体有20亿！过去的3届锦标赛冠军都被他收入囊中", "strokeColor": "#09192c", "stroke": 4, "height": 100, "fontSize": 24, "font": "SimHei", "color": "#6197ca", "bold": true, "align": "left" }, "compId": 1291 }, { "type": "Image", "props": { "y": 84.99233494408375, "x": 158, "width": 68, "skin": "ui/img_UM_heroname_text_1.png", "rotation": -3, "height": 36 }, "compId": 1294 }, { "type": "Image", "props": { "y": 121.99233494408375, "x": 244, "width": 111, "skin": "ui/img_UM_heropz_text_1.png", "rotation": -2, "height": 33 }, "compId": 1295 }, { "type": "Image", "props": { "y": 19.99233494408375, "width": 382, "skin": "ui/img_UM_hero_text_1.png", "rotation": -3, "height": 80 }, "compId": 1296 }, { "type": "Box", "props": { "y": 253.99233494408375, "x": 35 }, "compId": 1395, "child": [{ "type": "Image", "props": { "width": 118, "skin": "ui/img_UM_btn_purple2.png", "sizeGrid": "45,40,45,43", "height": 140 }, "compId": 1371 }, { "type": "Image", "props": { "x": 141, "width": 118, "skin": "ui/img_UM_btn_purple2.png", "sizeGrid": "27,32,45,36", "height": 140 }, "compId": 1372 }, { "type": "Label", "props": { "y": 91, "x": 4, "wordWrap": true, "width": 110, "text": "技能名称", "strokeColor": "#5d330c", "stroke": 3, "height": 24, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1373 }, { "type": "Label", "props": { "y": 91, "x": 146, "wordWrap": true, "width": 110, "text": "技能名称", "strokeColor": "#5d330c", "stroke": 3, "height": 24, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1394 }] }] }, { "type": "Image", "props": { "y": 686, "x": 423, "width": 132, "skin": "ui/img_UM_ribbon_bg_red2.png", "sizeGrid": "13,34,18,34", "height": 40 }, "compId": 1413, "child": [{ "type": "Image", "props": { "y": 3, "x": 30, "width": 71, "skin": "ui/img_UM_ui_text69.png", "height": 24 }, "compId": 1415 }] }, { "type": "Image", "props": { "y": 685, "x": 278, "width": 132, "skin": "ui/img_UM_ribbon_bg_red2.png", "sizeGrid": "13,34,18,34", "height": 40 }, "compId": 1416, "child": [{ "type": "Image", "props": { "y": 3, "x": 30, "width": 71, "skin": "ui/img_UM_ui_text69.png", "height": 24 }, "compId": 1417 }] }], "loadList": ["ui/img_UM_cardbg3.png", "ui/img_UM_btn__btn1.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_head.png", "ui/img_UM_ui_touzi.png", "ui/img_UM_ui_text22.png", "ui/img_UM_effect_blue.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_tu.png", "ui/img_UM_top1.png", "ui/img_UM_top2.png", "ui/img_UM_loading_barbg.png", "ui/img_UM_btn_jiantou.png", "ui/img_UM_btn_jiantou2.png", "ui/img_UM_ui_lock.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_heroinfo_tiao2.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_icon_heroInfo3.png", "ui/img_UM_heroinfo_ArrowBack.png", "ui/img_UM_icon_heroInfo2.png", "ui/img_UM_heroinfo_tiao.png", "ui/img_UM_icon_heroInfo4.png", "ui/img_UM_icon_heroInfo1.png", "ui/img_UM_bar_green.png", "ui/img_UM_num_5.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text20.png", "ui/img_UM_heronamebg.png", "ui/img_UM_heroname_text_1.png", "ui/img_UM_heropz_text_1.png", "ui/img_UM_hero_text_1.png", "ui/img_UM_btn_purple2.png", "ui/img_UM_ribbon_bg_red2.png", "ui/img_UM_ui_text69.png"], "loadList3D": [] };
            test.PageHeroInfoUI = PageHeroInfoUI;
            REG("ui.test.PageHeroInfoUI", PageHeroInfoUI);
            class PageLingquUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageLingquUI.uiView);
                }
            }
            PageLingquUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg9.jpg" }, "compId": 1579 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 139, "x": 630, "width": 140, "skin": "ui/img_UM_box_rankbox2.png", "pivotY": 70, "pivotX": 70, "height": 140 }, "compId": 1638 }, { "type": "Label", "props": { "y": 209, "x": 558, "wordWrap": true, "width": 163, "text": "你已获得：", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 26, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1648 }, { "type": "Box", "props": { "y": 279, "x": 245 }, "compId": 1652, "child": [{ "type": "GoodsCard1", "props": { "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCard1UI" }, "compId": 1645 }, { "type": "GoodsCard", "props": { "x": 134, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardUI" }, "compId": 1646 }, { "type": "GoodsCardDiamonds", "props": { "x": 268, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardDiamondsUI" }, "compId": 1647 }, { "type": "GoodsCardDiamonds", "props": { "x": 401, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardDiamondsUI" }, "compId": 1649 }, { "type": "GoodsCardDiamonds", "props": { "x": 535, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardDiamondsUI" }, "compId": 1650 }, { "type": "GoodsCardDiamonds", "props": { "x": 669, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardDiamondsUI" }, "compId": 1651 }] }, { "type": "Box", "props": { "y": 494, "x": 350 }, "compId": 1653, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1654 }, { "type": "Image", "props": { "y": 22, "x": 57, "width": 156, "skin": "ui/img_UM_ui_text53.png", "height": 45 }, "compId": 1659 }] }, { "type": "Box", "props": { "y": 494, "x": 630 }, "compId": 1656, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1657 }, { "type": "Image", "props": { "y": 23, "x": 81.5, "width": 156, "skin": "ui/img_UM_ui_text54.png", "height": 45 }, "compId": 1660 }, { "type": "Image", "props": { "y": 26, "x": 26.5, "width": 49, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 39 }, "compId": 1661 }] }], "loadList": ["ui/img_UM_ui_bg9.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_box_rankbox2.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text53.png", "ui/img_UM_ui_text54.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            test.PageLingquUI = PageLingquUI;
            REG("ui.test.PageLingquUI", PageLingquUI);
            class PageLvupUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageLvupUI.uiView);
                }
            }
            PageLvupUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg7.jpg" }, "compId": 1585 }, { "type": "Image", "props": { "y": -808, "x": -557, "width": 2353, "skin": "ui/img_UM_effect_zi.png", "height": 1656, "alpha": 0.8 }, "compId": 1586 }, { "type": "Image", "props": { "y": -148, "x": 181.5, "width": 904, "skin": "ui/img_UM_effect_blue.png", "height": 522, "alpha": 1 }, "compId": 1587 }, { "type": "Box", "props": { "y": 341, "x": 112 }, "compId": 1595, "child": [{ "type": "Image", "props": { "y": 30.5, "width": 327, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 166, "alpha": 0.5 }, "compId": 1582 }, { "type": "Image", "props": { "y": 0, "x": 29, "width": 64, "skin": "ui/img_UM_icon_lvup_1.png", "height": 64 }, "compId": 1588 }, { "type": "Image", "props": { "y": 96.5, "x": 19, "skin": "ui/img_UM_heroinfo_tiao.png", "alpha": 0.5 }, "compId": 1589 }, { "type": "Image", "props": { "y": 105.5, "x": 29, "width": 42, "skin": "ui/img_UM_icon_heroInfo3.png", "height": 42 }, "compId": 1590 }, { "type": "Label", "props": { "y": 121.5, "x": 84, "wordWrap": true, "width": 104, "text": "233", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1591 }, { "type": "Label", "props": { "y": 100.5, "x": 82, "wordWrap": true, "width": 104, "text": "生命值", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#4598ad", "bold": true, "align": "left" }, "compId": 1592 }, { "type": "Label", "props": { "y": 108.5, "x": 213, "wordWrap": true, "width": 104, "text": "+65", "strokeColor": "#272727", "stroke": 4, "height": 57, "fontSize": 50, "font": "SimHei", "color": "#00ff5b", "bold": true, "align": "left" }, "compId": 1593 }, { "type": "Label", "props": { "y": 14.5, "x": 103, "wordWrap": true, "width": 147, "text": "我的高塔", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1594 }] }, { "type": "Box", "props": { "y": 341, "x": 478 }, "compId": 1596, "child": [{ "type": "Image", "props": { "y": 30.5, "width": 327, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 166, "alpha": 0.5 }, "compId": 1597 }, { "type": "Image", "props": { "y": -0.5, "x": 29, "width": 64, "skin": "ui/img_UM_icon_lvup_3.png", "height": 64 }, "compId": 1598 }, { "type": "Image", "props": { "y": 96.5, "x": 19, "skin": "ui/img_UM_heroinfo_tiao.png", "alpha": 0.5 }, "compId": 1599 }, { "type": "Image", "props": { "y": 105.5, "x": 29, "width": 42, "skin": "ui/img_UM_icon_heroInfo2.png", "height": 42 }, "compId": 1600 }, { "type": "Label", "props": { "y": 121.5, "x": 84, "wordWrap": true, "width": 104, "text": "233", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1601 }, { "type": "Label", "props": { "y": 100.5, "x": 82, "wordWrap": true, "width": 104, "text": "积分", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#4598ad", "bold": true, "align": "left" }, "compId": 1602 }, { "type": "Label", "props": { "y": 108.5, "x": 213, "wordWrap": true, "width": 104, "text": "+65", "strokeColor": "#272727", "stroke": 4, "height": 57, "fontSize": 50, "font": "SimHei", "color": "#00ff5b", "bold": true, "align": "left" }, "compId": 1603 }, { "type": "Label", "props": { "y": 15, "x": 103, "wordWrap": true, "width": 196, "text": "每击杀积分", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1604 }] }, { "type": "Box", "props": { "y": 341, "x": 844 }, "compId": 1605, "child": [{ "type": "Image", "props": { "y": 30.5, "width": 327, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 166, "alpha": 0.5 }, "compId": 1606 }, { "type": "Image", "props": { "y": -0.5, "x": 29, "width": 64, "skin": "ui/img_UM_icon_lvup_2.png", "height": 64 }, "compId": 1607 }, { "type": "Image", "props": { "y": 96.5, "x": 19, "skin": "ui/img_UM_heroinfo_tiao.png", "alpha": 0.5 }, "compId": 1608 }, { "type": "Image", "props": { "y": 105.5, "x": 29, "width": 42, "skin": "ui/img_UM_icon_heroInfo4.png", "height": 42 }, "compId": 1609 }, { "type": "Label", "props": { "y": 121.5, "x": 84, "wordWrap": true, "width": 104, "text": "233", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1610 }, { "type": "Label", "props": { "y": 100.5, "x": 82, "wordWrap": true, "width": 104, "text": "奖杯", "strokeColor": "#272727", "height": 24, "fontSize": 20, "font": "SimHei", "color": "#4598ad", "bold": true, "align": "left" }, "compId": 1611 }, { "type": "Label", "props": { "y": 108.5, "x": 213, "wordWrap": true, "width": 104, "text": "+65", "strokeColor": "#272727", "stroke": 4, "height": 57, "fontSize": 50, "font": "SimHei", "color": "#00ff5b", "bold": true, "align": "left" }, "compId": 1612 }, { "type": "Label", "props": { "y": 15, "x": 103, "wordWrap": true, "width": 201, "text": "胜利获得奖杯", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1613 }] }, { "type": "Image", "props": { "y": 180, "x": 667, "skin": "ui/img_UM_xpicon.png" }, "compId": 1614 }, { "type": "Image", "props": { "y": 204, "x": 707, "width": 46, "skin": "ui/img_UM_num_5.png", "height": 76 }, "compId": 1615 }, { "type": "Box", "props": { "y": 570, "x": 505 }, "compId": 1616, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1617 }, { "type": "Image", "props": { "y": 25, "x": 84, "skin": "ui/img_UM_ui_text32.png" }, "compId": 1619 }] }, { "type": "Image", "props": { "y": 204, "x": 505, "width": 85, "skin": "ui/img_UM_xpicon.png", "height": 87 }, "compId": 1620 }, { "type": "Image", "props": { "y": 219.5, "x": 532.5, "width": 30, "skin": "ui/img_UM_num_5.png", "height": 49 }, "compId": 1621 }, { "type": "Image", "props": { "y": 221.5, "x": 600.5, "width": 60, "skin": "ui/img_UM_ui_jt.png", "height": 40 }, "compId": 1625 }, { "type": "Image", "props": { "y": 77, "x": 552, "skin": "ui/img_UM_ui_text35.png" }, "compId": 1626 }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_effect_zi.png", "ui/img_UM_effect_blue.png", "ui/img_UM_ui_black2.png", "ui/img_UM_icon_lvup_1.png", "ui/img_UM_heroinfo_tiao.png", "ui/img_UM_icon_heroInfo3.png", "ui/img_UM_icon_lvup_3.png", "ui/img_UM_icon_heroInfo2.png", "ui/img_UM_icon_lvup_2.png", "ui/img_UM_icon_heroInfo4.png", "ui/img_UM_xpicon.png", "ui/img_UM_num_5.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text32.png", "ui/img_UM_ui_jt.png", "ui/img_UM_ui_text35.png"], "loadList3D": [] };
            test.PageLvupUI = PageLvupUI;
            REG("ui.test.PageLvupUI", PageLvupUI);
            class PagePPUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PagePPUI.uiView);
                }
            }
            PagePPUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg.jpg" }, "compId": 1217 }, { "type": "Image", "props": { "y": 70, "x": 193, "width": 838, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1130 }, { "type": "Label", "props": { "y": 79, "x": 210, "wordWrap": true, "width": 173, "text": "战斗卡组", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#cdb9b9", "bold": true, "align": "left" }, "compId": 1131 }, { "type": "Image", "props": { "y": 183, "x": 0, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Box", "props": { "y": 213, "x": 43 }, "compId": 1225, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1207 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1218 }, { "type": "List", "props": { "y": 88, "x": 23, "width": 407, "spaceX": -80, "repeatY": 1, "repeatX": 5, "height": 123 }, "compId": 1210, "child": [{ "type": "heroCard1", "props": { "scaleY": 0.5, "scaleX": 0.5, "renderType": "render", "runtime": "ui.test.heroCard1UI" }, "compId": 1211 }] }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1216 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": true, "width": 63, "text": "80", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1219 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1220 }, { "type": "Label", "props": { "y": 32, "x": 41, "wordWrap": true, "width": 327, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1221 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1222 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1223 }] }, { "type": "Box", "props": { "y": 213.5, "x": 680 }, "compId": 1226, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_red.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1227 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1228 }, { "type": "List", "props": { "y": 88, "x": 23, "width": 407, "spaceX": -80, "repeatY": 1, "repeatX": 5, "height": 123 }, "compId": 1229, "child": [{ "type": "heroCard1", "props": { "scaleY": 0.5, "scaleX": 0.5, "renderType": "render", "runtime": "ui.test.heroCard1UI" }, "compId": 1230 }] }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1231 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": true, "width": 63, "text": "80", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1232 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1233 }, { "type": "Label", "props": { "y": 32, "x": 41, "wordWrap": true, "width": 327, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1234 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1235 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1236 }] }, { "type": "Image", "props": { "y": 283, "x": 585, "width": 109, "skin": "ui/img_UM_vs.png", "height": 82 }, "compId": 1224 }], "loadList": ["ui/img_UM_ui_bg.jpg", "ui/img_UM_ui_obj1.png", "ui/img_UM_black.png", "ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png", "ui/img_UM_xpicon.png", "ui/img_UM_ui_team_red.png", "ui/img_UM_vs.png"], "loadList3D": [] };
            test.PagePPUI = PagePPUI;
            REG("ui.test.PagePPUI", PagePPUI);
            class PagePP1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PagePP1UI.uiView);
                }
            }
            PagePP1UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 360, "x": 640, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "pivotY": 154, "pivotX": 640, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Box", "props": { "y": 360, "x": 323, "width": 559, "pivotY": 116, "pivotX": 280, "height": 231 }, "compId": 1225, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1207 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1218 }, { "type": "List", "props": { "y": 102, "x": 29, "width": 407, "spaceX": -80, "repeatY": 1, "repeatX": 5, "height": 123 }, "compId": 1210, "child": [{ "type": "heroCard21", "props": { "y": 0, "x": 0, "scaleY": 0.5, "scaleX": 0.5, "renderType": "render", "runtime": "ui.test.heroCard21UI" }, "compId": 1239 }] }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1216 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": true, "width": 63, "text": "80", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1219 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1220 }, { "type": "Label", "props": { "y": 33, "x": 92, "wordWrap": true, "width": 202, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1221 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1222 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1223 }, { "type": "Image", "props": { "y": 21, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1244 }, { "type": "Image", "props": { "y": 23, "x": 29, "width": 50, "skin": "ui/img_UM_playerhead.png", "height": 50 }, "compId": 1242 }] }, { "type": "Box", "props": { "y": 351, "x": 960, "width": 559, "pivotY": 107, "pivotX": 280, "height": 231 }, "compId": 1226, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_red.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1227 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1228 }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1231 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": true, "width": 63, "text": "80", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1232 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1233 }, { "type": "Label", "props": { "y": 32, "x": 91, "wordWrap": true, "width": 199, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1234 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1235 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1236 }, { "type": "List", "props": { "y": 106, "x": 29, "width": 407, "spaceX": -80, "repeatY": 1, "repeatX": 5, "height": 123 }, "compId": 1240, "child": [{ "type": "heroCard21", "props": { "y": 0, "x": 0, "scaleY": 0.5, "scaleX": 0.5, "renderType": "render", "runtime": "ui.test.heroCard21UI" }, "compId": 1241 }] }, { "type": "Image", "props": { "y": 20, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1245 }, { "type": "Image", "props": { "y": 22, "x": 29, "width": 50, "skin": "ui/img_UM_playerhead.png", "height": 50 }, "compId": 1243 }] }, { "type": "Image", "props": { "y": 360, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1224 }, { "type": "Image", "props": { "y": 162, "x": 640, "width": 238, "skin": "ui/img_UM_Logo.png", "scaleX": 1, "pivotY": 93, "pivotX": 119, "height": 186 }, "compId": 1246 }], "animations": [{ "nodes": [{ "target": 1225, "keyframes": { "x": [{ "value": -300, "tweenMethod": "circOut", "tween": true, "target": 1225, "key": "x", "index": 0 }, { "value": 300, "tweenMethod": "linearNone", "tween": true, "target": 1225, "key": "x", "index": 7 }, { "value": 300, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "x", "index": 30 }, { "value": -300, "tweenMethod": "circOut", "tween": true, "target": 1225, "label": null, "key": "x", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1225, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1225, "key": "alpha", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1225, "label": null, "key": "alpha", "index": 35 }] } }, { "target": 1226, "keyframes": { "x": [{ "value": 1580, "tweenMethod": "circOut", "tween": true, "target": 1226, "key": "x", "index": 0 }, { "value": 978, "tweenMethod": "linearNone", "tween": true, "target": 1226, "key": "x", "index": 7 }, { "value": 978, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "x", "index": 30 }, { "value": 1580, "tweenMethod": "circOut", "tween": true, "target": 1226, "label": null, "key": "x", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1226, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1226, "key": "alpha", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1226, "label": null, "key": "alpha", "index": 35 }] } }, { "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "cubicOut", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 4 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "scaleY", "index": 30 }], "alpha": [{ "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "alpha", "index": 0 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "alpha", "index": 35 }] } }, { "target": 1246, "keyframes": { "y": [{ "value": 162, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "y", "index": 0 }, { "value": 162, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "y", "index": 30 }, { "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "y", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 35 }] } }, { "target": 1224, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 35 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_xpicon.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_team_red.png", "ui/img_UM_vs.png", "ui/img_UM_Logo.png"], "loadList3D": [] };
            test.PagePP1UI = PagePP1UI;
            REG("ui.test.PagePP1UI", PagePP1UI);
            class PagePP2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PagePP2UI.uiView);
                }
            }
            PagePP2UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 360, "x": 640, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "pivotY": 154, "pivotX": 640, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Image", "props": { "y": 360, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1224 }, { "type": "Image", "props": { "y": 162, "x": 640, "width": 238, "skin": "ui/img_UM_Logo.png", "scaleX": 1, "pivotY": 93, "pivotX": 119, "height": 186 }, "compId": 1246 }, { "type": "PageTeamBlue1", "props": { "y": 343, "x": 312, "width": 500, "scaleY": 1.2, "scaleX": 1.2, "pivotY": 87, "pivotX": 250, "height": 200, "runtime": "ui.test.PageTeamBlue1UI" }, "compId": 1249 }, { "type": "PageTeamRed1", "props": { "y": 358, "x": 968, "width": 500, "scaleY": 1.2, "scaleX": 1.2, "pivotY": 100, "pivotX": 250, "height": 200, "runtime": "ui.test.PageTeamRed1UI" }, "compId": 1250 }], "animations": [{ "nodes": [{ "target": 1249, "keyframes": { "x": [{ "value": -300, "tweenMethod": "circOut", "tween": true, "target": 1249, "key": "x", "index": 0 }, { "value": 300, "tweenMethod": "linearNone", "tween": true, "target": 1249, "key": "x", "index": 7 }, { "value": 300, "tweenMethod": "linearNone", "tween": true, "target": 1249, "label": null, "key": "x", "index": 30 }, { "value": -300, "tweenMethod": "circOut", "tween": true, "target": 1249, "label": null, "key": "x", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1249, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1249, "key": "alpha", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1249, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1249, "label": null, "key": "alpha", "index": 35 }] } }, { "target": 1250, "keyframes": { "x": [{ "value": 1580, "tweenMethod": "circOut", "tween": true, "target": 1250, "key": "x", "index": 0 }, { "value": 978, "tweenMethod": "linearNone", "tween": true, "target": 1250, "key": "x", "index": 7 }, { "value": 978, "tweenMethod": "linearNone", "tween": true, "target": 1250, "label": null, "key": "x", "index": 30 }, { "value": 1580, "tweenMethod": "circOut", "tween": true, "target": 1250, "label": null, "key": "x", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1250, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1250, "key": "alpha", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1250, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1250, "label": null, "key": "alpha", "index": 35 }] } }, { "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "cubicOut", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 4 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "scaleY", "index": 30 }], "alpha": [{ "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "alpha", "index": 0 }, { "value": 0.6, "tweenMethod": "linearNone", "tween": true, "target": 1205, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "alpha", "index": 35 }] } }, { "target": 1246, "keyframes": { "y": [{ "value": 162, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "y", "index": 0 }, { "value": 162, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "y", "index": 30 }, { "value": -200, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "y", "index": 35 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 7 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1246, "label": null, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1246, "key": "alpha", "index": 35 }] } }, { "target": 1224, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 30 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1224, "key": "alpha", "index": 35 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_black.png", "ui/img_UM_vs.png", "ui/img_UM_Logo.png"], "loadList3D": [] };
            test.PagePP2UI = PagePP2UI;
            REG("ui.test.PagePP2UI", PagePP2UI);
            class PageRankRewardUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRankRewardUI.uiView);
                }
            }
            PageRankRewardUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg7.jpg" }, "compId": 1585 }, { "type": "Box", "props": { "y": 590, "x": 516 }, "compId": 1616, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1617 }, { "type": "Image", "props": { "y": 20, "x": 67, "skin": "ui/img_UM_ui_text17.png" }, "compId": 1681 }] }, { "type": "Box", "props": { "y": 240, "x": 0 }, "compId": 1664, "child": [{ "type": "Image", "props": { "width": 1280, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "4,4,4,4", "height": 20, "alpha": 0.5 }, "compId": 1663 }, { "type": "Image", "props": { "y": 0, "x": 0, "width": 635, "skin": "ui/img_UM_ui_Tips1.png", "sizeGrid": "4,4,4,4", "height": 20 }, "compId": 1662 }, { "type": "Image", "props": { "y": 0, "x": 78, "width": 2, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "4,4,4,4", "height": 20, "alpha": 0.9 }, "compId": 1669 }, { "type": "Image", "props": { "y": 0, "x": 363, "width": 2, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "4,4,4,4", "height": 20, "alpha": 0.9 }, "compId": 1671 }, { "type": "Image", "props": { "y": 0, "x": 640, "width": 2, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "4,4,4,4", "height": 20, "alpha": 0.9 }, "compId": 1672 }, { "type": "Image", "props": { "y": 0, "x": 917, "width": 2, "skin": "ui/img_UM_rank_bar.png", "sizeGrid": "4,4,4,4", "height": 20 }, "compId": 1695 }, { "type": "Image", "props": { "y": 0, "x": 1195, "width": 2, "skin": "ui/img_UM_rank_bar.png", "sizeGrid": "4,4,4,4", "height": 20 }, "compId": 1696 }] }, { "type": "Image", "props": { "y": 228, "x": 619, "width": 42, "skin": "ui/img_UM_rank_obj1.png", "height": 42 }, "compId": 1667 }, { "type": "Label", "props": { "y": 266, "x": 51.5, "wordWrap": true, "width": 57, "valign": "middle", "text": "0", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#f3fe00", "bold": true, "align": "center" }, "compId": 1668 }, { "type": "Label", "props": { "y": 266, "x": 329.5, "wordWrap": true, "width": 57, "valign": "middle", "text": "20", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#f3fe00", "bold": true, "align": "center" }, "compId": 1677 }, { "type": "Label", "props": { "y": 265, "x": 611, "wordWrap": true, "width": 57, "valign": "middle", "text": "40", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#f3fe00", "bold": true, "align": "center" }, "compId": 1678 }, { "type": "Label", "props": { "y": 260, "x": 888.5, "wordWrap": true, "width": 57, "valign": "middle", "text": "60", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#f3fe00", "bold": true, "align": "center" }, "compId": 1679 }, { "type": "Label", "props": { "y": 260, "x": 1166.5, "wordWrap": true, "width": 57, "valign": "middle", "text": "80", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#f3fe00", "bold": true, "align": "center" }, "compId": 1680 }, { "type": "Box", "props": { "y": 38, "x": 48 }, "compId": 1682, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1683 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1684 }] }, { "type": "Label", "props": { "y": 227, "x": 578, "wordWrap": true, "width": 57, "valign": "middle", "text": "40", "strokeColor": "#000000", "height": 43, "fontSize": 20, "font": "SimHei", "color": "#191919", "bold": true, "align": "center" }, "compId": 1697 }, { "type": "Image", "props": { "y": 138, "x": 40, "width": 80, "skin": "ui/img_UM_ranklv1.png", "height": 80 }, "compId": 1712 }, { "type": "Image", "props": { "y": 138, "x": 1156, "width": 80, "skin": "ui/img_UM_ranklv1.png", "height": 80 }, "compId": 1713 }, { "type": "Label", "props": { "y": 199, "x": 7.5, "wordWrap": true, "width": 149, "valign": "middle", "text": "青铜I", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1780 }, { "type": "Label", "props": { "y": 199, "x": 1120.5, "wordWrap": true, "width": 149, "valign": "middle", "text": "青铜II", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1782 }, { "type": "PageRankRewardobj1", "props": { "y": 306, "x": -62, "runtime": "ui.test.PageRankRewardobj1UI" }, "compId": 1807 }, { "type": "PageRankRewardobj1", "props": { "y": 306, "x": 218, "runtime": "ui.test.PageRankRewardobj1UI" }, "compId": 1808 }, { "type": "Image", "props": { "y": 53, "x": 156, "width": 1096, "skin": "ui/img_UM_ui_obj10.png", "sizeGrid": "9,41,13,40", "height": 48, "alpha": 0.7 }, "compId": 1818 }, { "type": "PageRankRewardobj2", "props": { "y": 307, "x": 777, "runtime": "ui.test.PageRankRewardobj2UI" }, "compId": 1809 }, { "type": "PageRankRewardobj2", "props": { "y": 307, "x": 1057, "runtime": "ui.test.PageRankRewardobj2UI" }, "compId": 1810 }, { "type": "PageRankRewardobj3", "props": { "y": 307, "x": 498, "runtime": "ui.test.PageRankRewardobj3UI" }, "compId": 1811 }, { "type": "Image", "props": { "y": 57, "x": 562, "width": 155, "skin": "ui/img_UM_ui_text38.png", "height": 45, "alpha": 1 }, "compId": 1812 }, { "type": "Image", "props": { "y": 270.5, "x": 661, "width": 30, "skin": "ui/img_UM_icon_lvup_2.png", "height": 30 }, "compId": 1813 }, { "type": "Image", "props": { "y": 273, "x": 373.5, "width": 30, "skin": "ui/img_UM_icon_lvup_2.png", "height": 30 }, "compId": 1814 }, { "type": "Image", "props": { "y": 273, "x": 90, "width": 30, "skin": "ui/img_UM_icon_lvup_2.png", "height": 30 }, "compId": 1815 }, { "type": "Image", "props": { "y": 268, "x": 932.5, "width": 30, "skin": "ui/img_UM_icon_lvup_2.png", "height": 30 }, "compId": 1816 }, { "type": "Image", "props": { "y": 266, "x": 1210.5, "width": 30, "skin": "ui/img_UM_icon_lvup_2.png", "height": 30 }, "compId": 1817 }, { "type": "Image", "props": { "y": 107, "x": 521, "width": 238, "skin": "ui/img_UM_ui_text39.png", "height": 29 }, "compId": 1819 }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_ui_Tips1.png", "ui/img_UM_rank_bar.png", "ui/img_UM_rank_obj1.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ranklv1.png", "ui/img_UM_ui_obj10.png", "ui/img_UM_ui_text38.png", "ui/img_UM_icon_lvup_2.png", "ui/img_UM_ui_text39.png"], "loadList3D": [] };
            test.PageRankRewardUI = PageRankRewardUI;
            REG("ui.test.PageRankRewardUI", PageRankRewardUI);
            class PageRankRewardobj1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRankRewardobj1UI.uiView);
                }
            }
            PageRankRewardobj1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 280, "mouseThrough": true, "height": 280 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 140, "x": 140, "width": 260, "skin": "ui/img_UM_rank_jlbg2.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 260, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": 74, "x": 74, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1784 }, { "type": "Image", "props": { "y": 198, "x": 72, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1785 }, { "type": "Label", "props": { "y": 193, "x": 111, "wordWrap": true, "width": 57, "valign": "middle", "text": "x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Image", "props": { "y": 10, "x": 10, "width": 260, "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "height": 260, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 120, "x": 69, "skin": "ui/img_UM_ui_text36.png" }, "compId": 1787 }, { "type": "Image", "props": { "y": 29, "x": 220.5, "width": 31, "skin": "ui/img_UM_ui_tick.png", "height": 33 }, "compId": 1789 }, { "type": "Image", "props": { "y": 65, "x": -18, "skin": "ui/img_UM_ui_text47.png", "rotation": -31 }, "compId": 1790 }], "loadList": ["ui/img_UM_rank_jlbg2.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_text36.png", "ui/img_UM_ui_tick.png", "ui/img_UM_ui_text47.png"], "loadList3D": [] };
            test.PageRankRewardobj1UI = PageRankRewardobj1UI;
            REG("ui.test.PageRankRewardobj1UI", PageRankRewardobj1UI);
            class PageRankRewardobj2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRankRewardobj2UI.uiView);
                }
            }
            PageRankRewardobj2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 280, "mouseThrough": true, "height": 280 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 140, "x": 140, "width": 260, "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 260, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": 74, "x": 74, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1784 }, { "type": "Image", "props": { "y": 198, "x": 72, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1785 }, { "type": "Label", "props": { "y": 193, "x": 111, "wordWrap": true, "width": 57, "valign": "middle", "text": "x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Image", "props": { "y": 10, "x": 10, "width": 260, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 260, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 120, "x": 69, "skin": "ui/img_UM_ui_text37.png" }, "compId": 1787 }, { "type": "Image", "props": { "y": 29, "x": 220.5, "width": 31, "skin": "ui/img_UM_ui_lock2.png", "height": 33 }, "compId": 1789 }], "loadList": ["ui/img_UM_rank_jlbg3.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_text37.png", "ui/img_UM_ui_lock2.png"], "loadList3D": [] };
            test.PageRankRewardobj2UI = PageRankRewardobj2UI;
            REG("ui.test.PageRankRewardobj2UI", PageRankRewardobj2UI);
            class PageRankRewardobj21UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRankRewardobj21UI.uiView);
                }
            }
            PageRankRewardobj21UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 280, "mouseThrough": true, "height": 280 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 140, "x": 140, "width": 260, "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 260, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": 74, "x": 74, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1784 }, { "type": "Image", "props": { "y": 198, "x": 72, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1785 }, { "type": "Label", "props": { "y": 193, "x": 111, "wordWrap": true, "width": 57, "valign": "middle", "text": "x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Image", "props": { "y": 10, "x": 10, "width": 260, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 260, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 120, "x": 69, "skin": "ui/img_UM_ui_text37.png" }, "compId": 1787 }, { "type": "Image", "props": { "y": 29, "x": 220.5, "width": 31, "skin": "ui/img_UM_ui_lock2.png", "height": 33 }, "compId": 1789 }], "loadList": ["ui/img_UM_rank_jlbg3.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_text37.png", "ui/img_UM_ui_lock2.png"], "loadList3D": [] };
            test.PageRankRewardobj21UI = PageRankRewardobj21UI;
            REG("ui.test.PageRankRewardobj21UI", PageRankRewardobj21UI);
            class PageRankRewardobj3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRankRewardobj3UI.uiView);
                }
            }
            PageRankRewardobj3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 280, "mouseThrough": true, "height": 280 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 135, "x": 135, "width": 270, "skin": "ui/img_UM_rank_jlbg1.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 270, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": -20, "x": -21, "width": 321, "skin": "ui/img_UM_effect_gold.png", "height": 320, "blendMode": "lighter" }, "compId": 1790 }, { "type": "Image", "props": { "y": 74, "x": 74, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1791 }, { "type": "Image", "props": { "y": 214, "x": 72, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1792 }, { "type": "Label", "props": { "y": 205, "x": 111, "wordWrap": true, "width": 57, "valign": "middle", "text": "x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1793 }, { "type": "Label", "props": { "y": 22, "x": 33, "wordWrap": true, "width": 213, "valign": "middle", "text": "青铜宝箱", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1794 }, { "type": "Image", "props": { "y": 55, "x": -28, "skin": "ui/img_UM_ui_text47.png", "rotation": -31 }, "compId": 1795 }], "loadList": ["ui/img_UM_rank_jlbg1.png", "ui/img_UM_effect_gold.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_ui_text47.png"], "loadList3D": [] };
            test.PageRankRewardobj3UI = PageRankRewardobj3UI;
            REG("ui.test.PageRankRewardobj3UI", PageRankRewardobj3UI);
            class PageRankRewardobj31UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRankRewardobj31UI.uiView);
                }
            }
            PageRankRewardobj31UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 280, "mouseThrough": true, "height": 280 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 135, "x": 135, "width": 270, "skin": "ui/img_UM_rank_jlbg1.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 270, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": -20, "x": -21, "width": 321, "skin": "ui/img_UM_effect_gold.png", "height": 320, "blendMode": "lighter" }, "compId": 1790 }, { "type": "Image", "props": { "y": 74, "x": 74, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1791 }, { "type": "Image", "props": { "y": 214, "x": 72, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1792 }, { "type": "Label", "props": { "y": 205, "x": 111, "wordWrap": true, "width": 57, "valign": "middle", "text": "x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1793 }, { "type": "Label", "props": { "y": 22, "x": 33, "wordWrap": true, "width": 213, "valign": "middle", "text": "青铜宝箱", "strokeColor": "#000000", "stroke": 4, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1794 }], "loadList": ["ui/img_UM_rank_jlbg1.png", "ui/img_UM_effect_gold.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png"], "loadList3D": [] };
            test.PageRankRewardobj31UI = PageRankRewardobj31UI;
            REG("ui.test.PageRankRewardobj31UI", PageRankRewardobj31UI);
            class PageRankUpUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageRankUpUI.uiView);
                }
            }
            PageRankUpUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg7.jpg" }, "compId": 1585 }, { "type": "Image", "props": { "y": -808, "x": -557, "width": 2353, "skin": "ui/img_UM_effect_zi.png", "height": 1656, "alpha": 0.8 }, "compId": 1586 }, { "type": "Image", "props": { "y": -148, "x": 181.5, "width": 904, "skin": "ui/img_UM_effect_blue.png", "height": 522, "alpha": 1 }, "compId": 1587 }, { "type": "Box", "props": { "y": 317, "x": 295 }, "compId": 1605, "child": [{ "type": "Image", "props": { "y": 31, "x": 0, "width": 690, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,26,31,26", "height": 211, "alpha": 0.5 }, "compId": 1606 }, { "type": "Image", "props": { "y": -0.5, "x": 29, "width": 64, "skin": "ui/img_UM_fun_rank.png", "height": 64 }, "compId": 1607 }, { "type": "Label", "props": { "y": 15, "x": 103, "wordWrap": true, "width": 529, "text": "即将获得以下奖励：", "strokeColor": "#004769", "stroke": 4, "height": 32, "fontSize": 30, "font": "SimHei", "color": "#00f4ff", "bold": true, "align": "left" }, "compId": 1613 }] }, { "type": "Box", "props": { "y": 570, "x": 505 }, "compId": 1616, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1617 }, { "type": "Image", "props": { "y": 27, "x": 69, "skin": "ui/img_UM_ui_text34.png" }, "compId": 1647 }] }, { "type": "Image", "props": { "y": 219, "x": 604, "width": 60, "skin": "ui/img_UM_ui_jt.png", "height": 40 }, "compId": 1625 }, { "type": "Image", "props": { "y": 162, "x": 685, "skin": "ui/img_UM_rank_1_3.png" }, "compId": 1627 }, { "type": "Image", "props": { "y": 189, "x": 468.5, "width": 105, "skin": "ui/img_UM_rank_1_3.png", "height": 118 }, "compId": 1628 }, { "type": "GoodsRankbox1", "props": { "y": 379, "x": 322, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox1UI" }, "compId": 1634 }, { "type": "GoodsRankbox2", "props": { "y": 379, "x": 448, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox2UI" }, "compId": 1639 }, { "type": "GoodsRankbox3", "props": { "y": 380, "x": 575, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox3UI" }, "compId": 1640 }, { "type": "GoodsRankbox4", "props": { "y": 379, "x": 701, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox4UI" }, "compId": 1641 }, { "type": "GoodsRankbox5", "props": { "y": 379, "x": 827, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsRankbox5UI" }, "compId": 1642 }, { "type": "GoodsCard1", "props": { "y": 219, "x": 1307, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCard1UI" }, "compId": 1643 }, { "type": "GoodsCard", "props": { "y": 219, "x": 1438, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardUI" }, "compId": 1644 }, { "type": "GoodsCardDiamonds", "props": { "y": 218, "x": 1566, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardDiamondsUI" }, "compId": 1645 }, { "type": "Image", "props": { "y": 90, "x": 509, "width": 261, "skin": "ui/img_UM_ui_text33.png", "height": 62 }, "compId": 1646 }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_effect_zi.png", "ui/img_UM_effect_blue.png", "ui/img_UM_ui_black2.png", "ui/img_UM_fun_rank.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text34.png", "ui/img_UM_ui_jt.png", "ui/img_UM_rank_1_3.png", "ui/img_UM_ui_text33.png"], "loadList3D": [] };
            test.PageRankUpUI = PageRankUpUI;
            REG("ui.test.PageRankUpUI", PageRankUpUI);
            class PageShopUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageShopUI.uiView);
                }
            }
            PageShopUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg7.jpg" }, "compId": 1579 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 11, "x": 1023, "skin": "ui/img_UM_top1.png" }, "compId": 1297 }, { "type": "Image", "props": { "y": 11.5, "x": 789, "skin": "ui/img_UM_top2.png" }, "compId": 1298 }, { "type": "PageShopCard1", "props": { "y": 155, "x": 18, "runtime": "ui.test.PageShopCard1UI" }, "compId": 1424 }, { "type": "PageShopCard2", "props": { "y": 155, "x": 305, "runtime": "ui.test.PageShopCard2UI" }, "compId": 1425 }, { "type": "PageShopCard3", "props": { "y": 155, "x": 589, "runtime": "ui.test.PageShopCard3UI" }, "compId": 1426 }, { "type": "Image", "props": { "y": 157, "x": 877, "width": 608, "skin": "ui/img_UM_shop_ui_bg4.png", "sizeGrid": "109,60,161,84", "height": 496 }, "compId": 1429 }, { "type": "Box", "props": { "y": 248, "x": 904, "width": 171, "height": 192 }, "compId": 1435, "child": [{ "type": "Image", "props": { "y": 22, "x": 1, "width": 170, "skin": "ui/img_UM_shop_ui_bg5.png", "sizeGrid": "27,48,79,45", "height": 170 }, "compId": 1430 }, { "type": "Image", "props": { "y": -15, "x": 13, "width": 154, "skin": "ui/img_UM_box_gold.png", "height": 154 }, "compId": 1432 }] }, { "type": "Image", "props": { "y": 188, "x": 1098, "skin": "ui/img_UM_ui_text30.png" }, "compId": 1476 }, { "type": "Box", "props": { "y": 427, "x": 906, "width": 171, "height": 192 }, "compId": 1495, "child": [{ "type": "Image", "props": { "y": 22, "x": 1, "width": 170, "skin": "ui/img_UM_shop_ui_bg7.png", "sizeGrid": "27,48,79,45", "height": 170 }, "compId": 1496 }, { "type": "Image", "props": { "y": 16, "x": 35, "skin": "ui/img_UM_playerhead2.png" }, "compId": 1512 }, { "type": "Image", "props": { "y": 75, "x": 122.5, "width": 25, "skin": "ui/img_UM_num_5.png", "height": 42 }, "compId": 1520 }] }, { "type": "Box", "props": { "y": 248, "x": 1086, "width": 171, "height": 192 }, "compId": 1506, "child": [{ "type": "Image", "props": { "y": 22, "x": 1, "width": 170, "skin": "ui/img_UM_shop_ui_bg5.png", "sizeGrid": "27,48,79,45", "height": 170 }, "compId": 1507 }, { "type": "Image", "props": { "y": 17, "x": 35, "skin": "ui/img_UM_playerhead2.png" }, "compId": 1513 }, { "type": "Image", "props": { "y": 75, "x": 122.5, "width": 25, "skin": "ui/img_UM_num_5.png", "height": 42 }, "compId": 1522 }] }, { "type": "Box", "props": { "y": 427, "x": 1086, "width": 171, "height": 192 }, "compId": 1514, "child": [{ "type": "Image", "props": { "y": 22, "x": 1, "width": 170, "skin": "ui/img_UM_shop_ui_bg7.png", "sizeGrid": "27,48,79,45", "height": 170 }, "compId": 1515 }, { "type": "Image", "props": { "y": 17, "x": 35, "skin": "ui/img_UM_playerhead2.png" }, "compId": 1519 }, { "type": "Image", "props": { "y": 75, "x": 120.5, "width": 25, "skin": "ui/img_UM_num_5.png", "height": 42 }, "compId": 1521 }] }, { "type": "Box", "props": { "y": 248, "x": 1263, "width": 171, "height": 192 }, "compId": 1523, "child": [{ "type": "Image", "props": { "y": 22, "x": 1, "width": 170, "skin": "ui/img_UM_shop_ui_bg5.png", "sizeGrid": "27,48,79,45", "height": 170 }, "compId": 1524 }, { "type": "Image", "props": { "y": 17, "x": 35, "skin": "ui/img_UM_playerhead2.png" }, "compId": 1528 }, { "type": "Image", "props": { "y": 75, "x": 122.5, "width": 25, "skin": "ui/img_UM_num_5.png", "height": 42 }, "compId": 1529 }] }, { "type": "Box", "props": { "y": 427, "x": 1263, "width": 171, "height": 192 }, "compId": 1530, "child": [{ "type": "Image", "props": { "y": 22, "x": 1, "width": 170, "skin": "ui/img_UM_shop_ui_bg6.png", "sizeGrid": "27,48,79,45", "height": 170 }, "compId": 1531 }, { "type": "Image", "props": { "y": 75, "x": 85, "width": 240, "skin": "ui/img_UM_effect_gold.png", "pivotY": 129, "pivotX": 120, "height": 240, "blendMode": "lighter" }, "compId": 1578 }, { "type": "Image", "props": { "y": 16, "x": 35, "skin": "ui/img_UM_playerhead2.png" }, "compId": 1535 }, { "type": "Image", "props": { "y": 75, "x": 122.5, "width": 25, "skin": "ui/img_UM_num_5.png", "height": 42 }, "compId": 1536 }] }, { "type": "Image", "props": { "y": 400, "x": 1013, "width": 228, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "27,30,40,37", "scaleY": 0.6, "scaleX": 0.6, "pivotY": 55, "pivotX": 152, "height": 110 }, "compId": 1549, "child": [{ "type": "Image", "props": { "y": 25, "x": 67, "width": 94, "skin": "ui/img_UM_ui_text26.png", "height": 48 }, "compId": 1550 }] }, { "type": "Box", "props": { "y": 545, "x": 924, "width": 224, "scaleY": 0.6, "scaleX": 0.6, "height": 105 }, "compId": 1551, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1552 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_5.png" }, "compId": 1553 }, { "type": "Image", "props": { "y": 17, "x": 137, "skin": "ui/img_UM_num_5.png" }, "compId": 1554 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1555 }] }, { "type": "Box", "props": { "y": 545, "x": 1105, "width": 224, "scaleY": 0.6, "scaleX": 0.6, "height": 105 }, "compId": 1556, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1557 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_5.png" }, "compId": 1558 }, { "type": "Image", "props": { "y": 17, "x": 137, "skin": "ui/img_UM_num_5.png" }, "compId": 1559 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1560 }] }, { "type": "Box", "props": { "y": 544, "x": 1281, "width": 224, "scaleY": 0.6, "scaleX": 0.6, "height": 105 }, "compId": 1561, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1562 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_5.png" }, "compId": 1563 }, { "type": "Image", "props": { "y": 17, "x": 137, "skin": "ui/img_UM_num_5.png" }, "compId": 1564 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1565 }] }, { "type": "Box", "props": { "y": 365, "x": 1105, "width": 224, "scaleY": 0.6, "scaleX": 0.6, "height": 105 }, "compId": 1566, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1567 }, { "type": "Image", "props": { "y": 22, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1570 }, { "type": "Image", "props": { "y": 16, "x": 89, "skin": "ui/img_UM_num_300.png" }, "compId": 1582 }] }, { "type": "Box", "props": { "y": 365, "x": 1281, "width": 224, "scaleY": 0.6, "scaleX": 0.6, "height": 105 }, "compId": 1571, "child": [{ "type": "Image", "props": { "y": 55, "x": 114, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1572 }, { "type": "Image", "props": { "y": 17, "x": 98, "skin": "ui/img_UM_num_5.png" }, "compId": 1573 }, { "type": "Image", "props": { "y": 17, "x": 137, "skin": "ui/img_UM_num_5.png" }, "compId": 1574 }, { "type": "Image", "props": { "y": 24, "x": 33, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1575 }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_top1.png", "ui/img_UM_top2.png", "ui/img_UM_shop_ui_bg4.png", "ui/img_UM_shop_ui_bg5.png", "ui/img_UM_box_gold.png", "ui/img_UM_ui_text30.png", "ui/img_UM_shop_ui_bg7.png", "ui/img_UM_playerhead2.png", "ui/img_UM_num_5.png", "ui/img_UM_shop_ui_bg6.png", "ui/img_UM_effect_gold.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text26.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_Diamond.png", "ui/img_UM_num_300.png"], "loadList3D": [] };
            test.PageShopUI = PageShopUI;
            REG("ui.test.PageShopUI", PageShopUI);
            class PageShopCard1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageShopCard1UI.uiView);
                }
            }
            PageShopCard1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 500 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": -2, "width": 304, "skin": "ui/img_UM_shop_ui_bg8.png", "sizeGrid": "109,60,161,84", "height": 498 }, "compId": 1406 }, { "type": "Image", "props": { "y": 407, "x": 188, "width": 228, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 152, "height": 110 }, "compId": 1414, "child": [{ "type": "Image", "props": { "y": 25, "x": 67, "width": 94, "skin": "ui/img_UM_ui_text26.png", "height": 48 }, "compId": 1415 }] }, { "type": "Image", "props": { "y": 231, "x": 150, "width": 366, "skin": "ui/img_UM_effect_blue.png", "pivotY": 183, "pivotX": 183, "height": 366, "blendMode": "lighter" }, "compId": 1424 }, { "type": "Image", "props": { "y": 133, "x": 50, "width": 200, "skin": "ui/img_UM_box_box1.png", "height": 200 }, "compId": 1416 }, { "type": "Image", "props": { "y": 34, "x": 60, "skin": "ui/img_UM_ui_text27.png" }, "compId": 1422 }, { "type": "Image", "props": { "y": 113, "x": 21, "width": 257, "skin": "ui/img_UM_ui_text59.png", "height": 26 }, "compId": 1425 }], "animations": [{ "nodes": [{ "target": 1424, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_shop_ui_bg8.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text26.png", "ui/img_UM_effect_blue.png", "ui/img_UM_box_box1.png", "ui/img_UM_ui_text27.png", "ui/img_UM_ui_text59.png"], "loadList3D": [] };
            test.PageShopCard1UI = PageShopCard1UI;
            REG("ui.test.PageShopCard1UI", PageShopCard1UI);
            class PageShopCard2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageShopCard2UI.uiView);
                }
            }
            PageShopCard2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 500 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": -2, "width": 304, "skin": "ui/img_UM_shop_ui_bg3.png", "sizeGrid": "109,60,161,84", "height": 498 }, "compId": 1406 }, { "type": "Image", "props": { "y": 407, "x": 150, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1414 }, { "type": "Image", "props": { "y": 231, "x": 150, "width": 366, "skin": "ui/img_UM_effect_gold.png", "pivotY": 183, "pivotX": 183, "height": 366, "blendMode": "lighter" }, "compId": 1424 }, { "type": "Image", "props": { "y": 133, "x": 50, "width": 200, "skin": "ui/img_UM_box_box3.png", "height": 200 }, "compId": 1416 }, { "type": "Image", "props": { "y": 34, "x": 60, "skin": "ui/img_UM_ui_text28.png" }, "compId": 1422 }, { "type": "Image", "props": { "y": 375, "x": 60, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1428 }, { "type": "Image", "props": { "y": 368, "x": 114, "skin": "ui/img_UM_num_200.png" }, "compId": 1429 }, { "type": "Image", "props": { "y": 115, "x": 21, "width": 257, "skin": "ui/img_UM_ui_text60.png", "height": 26 }, "compId": 1430 }], "animations": [{ "nodes": [{ "target": 1424, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "label": null, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_shop_ui_bg3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_effect_gold.png", "ui/img_UM_box_box3.png", "ui/img_UM_ui_text28.png", "ui/img_UM_Diamond.png", "ui/img_UM_num_200.png", "ui/img_UM_ui_text60.png"], "loadList3D": [] };
            test.PageShopCard2UI = PageShopCard2UI;
            REG("ui.test.PageShopCard2UI", PageShopCard2UI);
            class PageShopCard3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageShopCard3UI.uiView);
                }
            }
            PageShopCard3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 500 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 1, "x": -2, "width": 304, "skin": "ui/img_UM_shop_ui_bg2.png", "sizeGrid": "109,60,161,84", "height": 498 }, "compId": 1406 }, { "type": "Image", "props": { "y": 407, "x": 150, "width": 228, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 114, "height": 110 }, "compId": 1414 }, { "type": "Image", "props": { "y": 231, "x": 150, "width": 366, "skin": "ui/img_UM_effect_blue.png", "pivotY": 183, "pivotX": 183, "height": 366, "blendMode": "lighter" }, "compId": 1424 }, { "type": "Image", "props": { "y": 133, "x": 50, "width": 200, "skin": "ui/img_UM_box_box4.png", "height": 200 }, "compId": 1416 }, { "type": "Image", "props": { "y": 34, "x": 60, "skin": "ui/img_UM_ui_text29.png" }, "compId": 1422 }, { "type": "Image", "props": { "y": 150, "x": 73, "width": 100, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 100, "blendMode": "lighter", "alpha": 0 }, "compId": 1426 }, { "type": "Image", "props": { "y": 189, "x": 258, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter" }, "compId": 1427 }, { "type": "Image", "props": { "y": 263, "x": 131, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter" }, "compId": 1428 }, { "type": "Image", "props": { "y": 351, "x": 281, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter", "alpha": 0 }, "compId": 1429 }, { "type": "Image", "props": { "y": 330, "x": 81, "width": 42, "skin": "ui/img_UM_effect_star.png", "pivotY": 50, "pivotX": 50, "height": 42, "blendMode": "lighter", "alpha": 0.5 }, "compId": 1430 }, { "type": "Image", "props": { "y": 375, "x": 69, "width": 54, "skin": "ui/img_UM_Diamond.png", "height": 54 }, "compId": 1433 }, { "type": "Image", "props": { "y": 368, "x": 126, "skin": "ui/img_UM_num_500.png" }, "compId": 1434 }, { "type": "Image", "props": { "y": 114, "x": 21, "width": 257, "skin": "ui/img_UM_ui_text61.png", "height": 26 }, "compId": 1435 }], "animations": [{ "nodes": [{ "target": 1424, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1424, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1424, "label": null, "key": "alpha", "index": 10 }] } }, { "target": 1426, "keyframes": { "y": [{ "value": 150, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "y", "index": 0 }, { "value": 151, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "y", "index": 5 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1426, "key": "alpha", "index": 10 }] } }, { "target": 1429, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 0 }, { "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "y", "index": 5 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 5 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1429, "key": "alpha", "index": 10 }] } }, { "target": 1427, "keyframes": { "y": [{ "value": 189, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "y", "index": 0 }, { "value": 190, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "y", "index": 5 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "alpha", "index": 0 }, { "value": 0.4, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1427, "key": "alpha", "index": 10 }] } }, { "target": 1428, "keyframes": { "y": [{ "value": 263, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "y", "index": 0 }, { "value": 263, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "y", "index": 5 }], "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "alpha", "index": 0 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "alpha", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1428, "key": "alpha", "index": 10 }] } }, { "target": 1430, "keyframes": { "alpha": [{ "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1430, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1430, "key": "alpha", "index": 5 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1430, "key": "alpha", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_shop_ui_bg2.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_effect_blue.png", "ui/img_UM_box_box4.png", "ui/img_UM_ui_text29.png", "ui/img_UM_effect_star.png", "ui/img_UM_Diamond.png", "ui/img_UM_num_500.png", "ui/img_UM_ui_text61.png"], "loadList3D": [] };
            test.PageShopCard3UI = PageShopCard3UI;
            REG("ui.test.PageShopCard3UI", PageShopCard3UI);
            class PageTaskUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskUI.uiView);
                }
            }
            PageTaskUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg7.jpg" }, "compId": 1579 }, { "type": "Image", "props": { "y": 21, "x": 182, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 692 }, "compId": 1584 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "PageTaskObj1", "props": { "y": 85, "x": 214, "runtime": "ui.test.PageTaskObj1UI" }, "compId": 1596 }, { "type": "PageTaskObj11", "props": { "y": 84, "x": 638, "runtime": "ui.test.PageTaskObj11UI" }, "compId": 1598 }, { "type": "Image", "props": { "y": 226, "x": 199, "width": 881, "skin": "ui/img_UM_ui_uibk2.png", "sizeGrid": "36,36,36,36", "height": 464 }, "compId": 1600 }, { "type": "Image", "props": { "y": 238, "x": 211, "width": 858, "skin": "ui/img_UM_ui_uibk3.png", "sizeGrid": "10,10,10,10", "height": 144 }, "compId": 1601 }, { "type": "Image", "props": { "y": 33, "x": 163, "var": "img_test", "skin": "ui/img_UM_ui_text40.png", "name": "img_test" }, "compId": 1607 }, { "type": "PageTaskObj3", "props": { "y": 384, "x": 190, "width": 900, "height": 100, "runtime": "ui.test.PageTaskObj3UI" }, "compId": 1608 }, { "type": "PageTaskObj31", "props": { "y": 484, "x": 191, "runtime": "ui.test.PageTaskObj31UI" }, "compId": 1616 }, { "type": "Image", "props": { "y": 34, "x": 1028, "width": 52, "skin": "ui/img_UM_ui_wenhao.png", "height": 52 }, "compId": 1619 }, { "type": "Image", "props": { "y": 44, "x": 1040, "width": 250, "skin": "ui/img_UM_ui_paopao.png", "height": 132 }, "compId": 1620 }, { "type": "Label", "props": { "y": 69, "x": 1106, "wordWrap": true, "width": 163, "text": "在三天内完成任务获得积分，达标后可开启宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "leading": 4, "height": 111, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1621 }, { "type": "PageTaskObj2", "props": { "y": 233, "x": 202, "width": 300, "height": 150, "runtime": "ui.test.PageTaskObj2UI" }, "compId": 1624 }, { "type": "PageTaskObj21", "props": { "y": 233, "x": 491, "width": 300, "height": 150, "runtime": "ui.test.PageTaskObj21UI" }, "compId": 1625 }, { "type": "PageTaskObj22", "props": { "y": 233, "x": 780, "width": 300, "height": 150, "runtime": "ui.test.PageTaskObj22UI" }, "compId": 1626 }, { "type": "PageTaskObj31", "props": { "y": 581, "x": 189.5, "runtime": "ui.test.PageTaskObj31UI" }, "compId": 1627 }, { "type": "PageTaskObj111", "props": { "y": 86, "x": -454, "runtime": "ui.test.PageTaskObj111UI" }, "compId": 1631 }, { "type": "Image", "props": { "y": 38, "x": 818, "width": 347, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "22,22,25,23", "scaleY": 0.6, "scaleX": 0.6, "height": 72, "alpha": 0.5 }, "compId": 1632 }, { "type": "Label", "props": { "y": 47, "x": 829, "wordWrap": true, "width": 192, "text": "剩余 99:00:00", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#c2ccd6", "bold": true, "align": "left" }, "compId": 1637 }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_ui_uibk.png", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk2.png", "ui/img_UM_ui_uibk3.png", "ui/img_UM_ui_text40.png", "ui/img_UM_ui_wenhao.png", "ui/img_UM_ui_paopao.png", "ui/img_UM_ui_black2.png"], "loadList3D": [] };
            test.PageTaskUI = PageTaskUI;
            REG("ui.test.PageTaskUI", PageTaskUI);
            class PageTaskObj1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj1UI.uiView);
                }
            }
            PageTaskObj1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 420, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": -3, "width": 425, "skin": "ui/img_UM_shop_ui_bg9.png", "sizeGrid": "46,53,51,48", "height": 140, "gray": true }, "compId": 1583 }, { "type": "Image", "props": { "y": 22, "x": 13, "width": 393, "skin": "ui/img_UM_rank_obj2.png", "sizeGrid": "8,8,8,8", "height": 60, "gray": true, "alpha": 1 }, "compId": 1584 }, { "type": "Label", "props": { "y": 34.5, "x": 151, "wordWrap": true, "width": 243, "text": "彩虹宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#edff1e", "bold": true, "align": "left" }, "compId": 1586 }, { "type": "Image", "props": { "y": 86, "x": 23, "width": 373, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "12,12,12,12", "height": 45, "alpha": 1 }, "compId": 1587 }, { "type": "Image", "props": { "y": 85, "x": 23, "width": 227, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "height": 47 }, "compId": 1588 }, { "type": "Label", "props": { "y": 94, "x": 135, "wordWrap": true, "width": 150, "text": "99/99", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1589 }, { "type": "Image", "props": { "y": 79, "x": 352, "width": 68, "skin": "ui/img_UM_fun_rank.png", "height": 68 }, "compId": 1590 }, { "type": "Image", "props": { "y": -6, "x": 20, "width": 108, "skin": "ui/img_UM_box_rankbox5.png", "height": 108 }, "compId": 1585 }, { "type": "Image", "props": { "y": 11, "x": 3, "width": 414, "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "height": 128, "alpha": 0.5 }, "compId": 1591 }, { "type": "Image", "props": { "y": 17, "x": 380.5, "width": 31, "skin": "ui/img_UM_ui_tick.png", "height": 33 }, "compId": 1592 }, { "type": "Image", "props": { "y": 50, "x": -20, "width": 112, "skin": "ui/img_UM_ui_text36.png", "rotation": -31, "height": 31 }, "compId": 1593 }], "loadList": ["ui/img_UM_shop_ui_bg9.png", "ui/img_UM_rank_obj2.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_fun_rank.png", "ui/img_UM_box_rankbox5.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_tick.png", "ui/img_UM_ui_text36.png"], "loadList3D": [] };
            test.PageTaskObj1UI = PageTaskObj1UI;
            REG("ui.test.PageTaskObj1UI", PageTaskObj1UI);
            class PageTaskObj11UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj11UI.uiView);
                }
            }
            PageTaskObj11UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 420, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": -3, "width": 425, "skin": "ui/img_UM_shop_ui_bg9.png", "sizeGrid": "46,53,51,48", "height": 140 }, "compId": 1583 }, { "type": "Image", "props": { "y": 22, "x": 13, "width": 393, "skin": "ui/img_UM_rank_obj2.png", "sizeGrid": "8,8,8,8", "height": 60, "alpha": 1 }, "compId": 1584 }, { "type": "Label", "props": { "y": 34.5, "x": 151, "wordWrap": true, "width": 243, "text": "传说宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#edff1e", "bold": true, "align": "left" }, "compId": 1586 }, { "type": "Image", "props": { "y": 86, "x": 23, "width": 373, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "12,12,12,12", "height": 45, "alpha": 1 }, "compId": 1587 }, { "type": "Image", "props": { "y": 85, "x": 23, "width": 227, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "height": 47 }, "compId": 1588 }, { "type": "Label", "props": { "y": 94, "x": 135, "wordWrap": true, "width": 150, "text": "99/99", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1589 }, { "type": "Image", "props": { "y": 79, "x": 352, "width": 68, "skin": "ui/img_UM_fun_rank.png", "height": 68 }, "compId": 1590 }, { "type": "Image", "props": { "y": -7, "x": 20, "width": 108, "skin": "ui/img_UM_box_rankbox4.png", "height": 108 }, "compId": 1585 }, { "type": "Image", "props": { "y": -2, "x": -10, "width": 435, "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "41,42,42,41", "height": 149 }, "compId": 1591 }, { "type": "Image", "props": { "y": 65, "x": -13, "width": 112, "skin": "ui/img_UM_ui_text41.png", "rotation": -31, "height": 31 }, "compId": 1592 }], "loadList": ["ui/img_UM_shop_ui_bg9.png", "ui/img_UM_rank_obj2.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_fun_rank.png", "ui/img_UM_box_rankbox4.png", "ui/img_UM_rank_effectbk.png", "ui/img_UM_ui_text41.png"], "loadList3D": [] };
            test.PageTaskObj11UI = PageTaskObj11UI;
            REG("ui.test.PageTaskObj11UI", PageTaskObj11UI);
            class PageTaskObj111UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj111UI.uiView);
                }
            }
            PageTaskObj111UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 420, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 5, "x": -3, "width": 425, "skin": "ui/img_UM_shop_ui_bg11.png", "sizeGrid": "46,53,51,48", "height": 140 }, "compId": 1583 }, { "type": "Image", "props": { "y": 22, "x": 13, "width": 393, "skin": "ui/img_UM_ui_uibk3.png", "sizeGrid": "8,8,8,8", "height": 60, "alpha": 1 }, "compId": 1584 }, { "type": "Label", "props": { "y": 34.5, "x": 151, "wordWrap": true, "width": 243, "text": "传说宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#edff1e", "bold": true, "align": "left" }, "compId": 1586 }, { "type": "Image", "props": { "y": 86, "x": 23, "width": 373, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "12,12,12,12", "height": 45, "alpha": 1 }, "compId": 1587 }, { "type": "Image", "props": { "y": 85, "x": 23, "width": 227, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "height": 47 }, "compId": 1588 }, { "type": "Label", "props": { "y": 94, "x": 135, "wordWrap": true, "width": 150, "text": "99/99", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1589 }, { "type": "Image", "props": { "y": 79, "x": 352, "width": 68, "skin": "ui/img_UM_fun_rank.png", "height": 68 }, "compId": 1590 }, { "type": "Image", "props": { "y": -7, "x": 20, "width": 108, "skin": "ui/img_UM_box_rankbox4.png", "height": 108 }, "compId": 1585 }, { "type": "Image", "props": { "y": 10, "x": 2, "width": 415, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 134, "alpha": 0.5 }, "compId": 1591 }, { "type": "Image", "props": { "y": 45, "x": -26, "width": 112, "skin": "ui/img_UM_ui_text37.png", "rotation": -31, "height": 31 }, "compId": 1592 }], "loadList": ["ui/img_UM_shop_ui_bg11.png", "ui/img_UM_ui_uibk3.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_fun_rank.png", "ui/img_UM_box_rankbox4.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_text37.png"], "loadList3D": [] };
            test.PageTaskObj111UI = PageTaskObj111UI;
            REG("ui.test.PageTaskObj111UI", PageTaskObj111UI);
            class PageTaskObj2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj2UI.uiView);
                }
            }
            PageTaskObj2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 11, "width": 278, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,57,44,54", "height": 138, "gray": true }, "compId": 1591 }, { "type": "Image", "props": { "y": 12, "x": 25, "width": 108, "skin": "ui/img_UM_box_rankbox1.png", "height": 108 }, "compId": 1592 }, { "type": "Label", "props": { "y": 30, "x": 135, "wordWrap": true, "width": 136, "text": "青铜宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1593 }, { "type": "Image", "props": { "y": 73, "x": 139, "width": 132, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "12,12,12,12", "height": 32, "alpha": 1 }, "compId": 1601 }, { "type": "Image", "props": { "y": 64, "x": 236, "width": 55, "skin": "ui/img_UM_fun_rank.png", "height": 55 }, "compId": 1602 }, { "type": "Image", "props": { "y": 72, "x": 139, "width": 66, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "height": 33 }, "compId": 1603 }, { "type": "Label", "props": { "y": 76, "x": 128, "wordWrap": true, "width": 150, "text": "0/60", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1604 }, { "type": "Image", "props": { "y": 11, "x": 17, "width": 267, "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "height": 128, "alpha": 0.5 }, "compId": 1597 }, { "type": "Image", "props": { "y": 10, "x": 252, "width": 31, "skin": "ui/img_UM_ui_tick.png", "height": 33 }, "compId": 1599 }, { "type": "Image", "props": { "y": 49.5, "x": -11, "width": 112, "skin": "ui/img_UM_ui_text36.png", "rotation": -31, "height": 31 }, "compId": 1600 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_fun_rank.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_tick.png", "ui/img_UM_ui_text36.png"], "loadList3D": [] };
            test.PageTaskObj2UI = PageTaskObj2UI;
            REG("ui.test.PageTaskObj2UI", PageTaskObj2UI);
            class PageTaskObj21UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj21UI.uiView);
                }
            }
            PageTaskObj21UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 11, "width": 278, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,57,44,54", "height": 138 }, "compId": 1591 }, { "type": "Image", "props": { "y": 12, "x": 25, "width": 108, "skin": "ui/img_UM_box_rankbox2.png", "height": 108 }, "compId": 1592 }, { "type": "Label", "props": { "y": 30, "x": 135, "wordWrap": true, "width": 136, "text": "黄金宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1593 }, { "type": "Image", "props": { "y": -2, "x": 3, "width": 292, "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "41,42,42,41", "height": 149 }, "compId": 1598 }, { "type": "Image", "props": { "y": 59, "x": 0, "width": 112, "skin": "ui/img_UM_ui_text41.png", "rotation": -31, "height": 31 }, "compId": 1599 }, { "type": "Image", "props": { "y": 74, "x": 135, "width": 132, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "12,12,12,12", "height": 32, "alpha": 1 }, "compId": 1600 }, { "type": "Image", "props": { "y": 63, "x": 232, "width": 55, "skin": "ui/img_UM_fun_rank.png", "height": 55 }, "compId": 1594 }, { "type": "Image", "props": { "y": 73, "x": 135, "width": 66, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "height": 33 }, "compId": 1601 }, { "type": "Label", "props": { "y": 76, "x": 124, "wordWrap": true, "width": 150, "text": "90/90", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1602 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_box_rankbox2.png", "ui/img_UM_rank_effectbk.png", "ui/img_UM_ui_text41.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_fun_rank.png", "ui/img_UM_card_bar_green.png"], "loadList3D": [] };
            test.PageTaskObj21UI = PageTaskObj21UI;
            REG("ui.test.PageTaskObj21UI", PageTaskObj21UI);
            class PageTaskObj211UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj211UI.uiView);
                }
            }
            PageTaskObj211UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 11, "width": 278, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,57,44,54", "height": 138 }, "compId": 1591 }, { "type": "Image", "props": { "y": 12, "x": 25, "width": 108, "skin": "ui/img_UM_box_rankbox2.png", "height": 108 }, "compId": 1592 }, { "type": "Label", "props": { "y": 30, "x": 135, "wordWrap": true, "width": 136, "text": "黄金宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1593 }, { "type": "Image", "props": { "y": -2, "x": 3, "width": 292, "skin": "ui/img_UM_rank_effectbk.png", "sizeGrid": "41,42,42,41", "height": 149 }, "compId": 1598 }, { "type": "Image", "props": { "y": 59, "x": 0, "width": 112, "skin": "ui/img_UM_ui_text41.png", "rotation": -31, "height": 31 }, "compId": 1599 }, { "type": "Image", "props": { "y": 74, "x": 135, "width": 132, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "12,12,12,12", "height": 32, "alpha": 1 }, "compId": 1600 }, { "type": "Image", "props": { "y": 63, "x": 232, "width": 55, "skin": "ui/img_UM_fun_rank.png", "height": 55 }, "compId": 1594 }, { "type": "Image", "props": { "y": 73, "x": 135, "width": 66, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "height": 33 }, "compId": 1601 }, { "type": "Label", "props": { "y": 76, "x": 124, "wordWrap": true, "width": 150, "text": "90/90", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1602 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_box_rankbox2.png", "ui/img_UM_rank_effectbk.png", "ui/img_UM_ui_text41.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_fun_rank.png", "ui/img_UM_card_bar_green.png"], "loadList3D": [] };
            test.PageTaskObj211UI = PageTaskObj211UI;
            REG("ui.test.PageTaskObj211UI", PageTaskObj211UI);
            class PageTaskObj22UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj22UI.uiView);
                }
            }
            PageTaskObj22UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 300, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 6, "x": 11, "width": 278, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,57,44,54", "height": 138 }, "compId": 1591 }, { "type": "Image", "props": { "y": 12, "x": 25, "width": 108, "skin": "ui/img_UM_box_rankbox3.png", "height": 108 }, "compId": 1592 }, { "type": "Label", "props": { "y": 30, "x": 135, "wordWrap": true, "width": 136, "text": "钻石宝箱", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1593 }, { "type": "Image", "props": { "y": 73, "x": 139, "width": 132, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "12,12,12,12", "height": 32, "alpha": 1 }, "compId": 1602 }, { "type": "Image", "props": { "y": 64, "x": 236, "width": 55, "skin": "ui/img_UM_fun_rank.png", "height": 55 }, "compId": 1603 }, { "type": "Image", "props": { "y": 72, "x": 139, "width": 66, "skin": "ui/img_UM_card_bar_green.png", "sizeGrid": "12,14,16,13", "height": 33 }, "compId": 1604 }, { "type": "Label", "props": { "y": 76, "x": 128, "wordWrap": true, "width": 150, "text": "120/120", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1605 }, { "type": "Image", "props": { "y": 13, "x": 18, "width": 265, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 123, "alpha": 0.5 }, "compId": 1596 }, { "type": "Image", "props": { "y": 13, "x": 249, "width": 31, "skin": "ui/img_UM_ui_lock2.png", "height": 33 }, "compId": 1597 }, { "type": "Image", "props": { "y": 52.5, "x": -9, "width": 112, "skin": "ui/img_UM_ui_text37.png", "rotation": -31, "height": 31 }, "compId": 1598 }], "loadList": ["ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_box_rankbox3.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_fun_rank.png", "ui/img_UM_card_bar_green.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_text37.png"], "loadList3D": [] };
            test.PageTaskObj22UI = PageTaskObj22UI;
            REG("ui.test.PageTaskObj22UI", PageTaskObj22UI);
            class PageTaskObj3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj3UI.uiView);
                }
            }
            PageTaskObj3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 900, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 3, "x": 21, "width": 858, "skin": "ui/img_UM_ui_uibk3.png", "sizeGrid": "10,10,10,10", "height": 94 }, "compId": 1596 }, { "type": "Image", "props": { "y": 16, "x": 59, "width": 503, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "12,49,11,20", "height": 43, "alpha": 0.4 }, "compId": 1599 }, { "type": "Image", "props": { "y": 6, "x": 24, "width": 68, "skin": "ui/img_UM_fun_rank.png", "height": 68 }, "compId": 1597 }, { "type": "Label", "props": { "y": 71, "x": 33.5, "wordWrap": true, "width": 47, "text": "+9", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1598 }, { "type": "Label", "props": { "y": 23, "x": 100, "wordWrap": true, "width": 394, "text": "完成需要达成的条件...", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1602 }, { "type": "Image", "props": { "y": 66, "x": 98, "width": 453, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "6,6,6,6", "height": 24 }, "compId": 1606 }, { "type": "Image", "props": { "y": 67, "x": 99, "width": 30, "skin": "ui/img_UM_rank_bar.png", "sizeGrid": "6,11,7,6", "height": 22 }, "compId": 1604 }, { "type": "Image", "props": { "y": 6, "x": 593, "width": 136, "skin": "ui/img_UM_btn_YellowButton_1.png", "height": 89 }, "compId": 1608 }, { "type": "Image", "props": { "y": 10, "x": 731, "width": 141, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "35,30,36,36", "height": 80, "alpha": 0.5 }, "compId": 1610 }, { "type": "Label", "props": { "y": 65, "x": 772.5, "wordWrap": true, "width": 60, "text": "奖励", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1611 }, { "type": "Image", "props": { "y": 19, "x": 762.5, "width": 36, "skin": "ui/img_UM_Diamond.png", "height": 36 }, "compId": 1612 }, { "type": "Image", "props": { "y": 12, "x": 802.5, "width": 29, "skin": "ui/img_UM_num_5.png", "height": 47 }, "compId": 1613 }, { "type": "Image", "props": { "y": 32, "x": 607.5, "width": 105, "skin": "ui/img_UM_ui_text43.png", "height": 29 }, "compId": 1614 }, { "type": "Label", "props": { "y": 65, "x": 269, "wordWrap": true, "width": 111, "text": "1/1", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1615 }], "loadList": ["ui/img_UM_ui_uibk3.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_fun_rank.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_rank_bar.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_Diamond.png", "ui/img_UM_num_5.png", "ui/img_UM_ui_text43.png"], "loadList3D": [] };
            test.PageTaskObj3UI = PageTaskObj3UI;
            REG("ui.test.PageTaskObj3UI", PageTaskObj3UI);
            class PageTaskObj31UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTaskObj31UI.uiView);
                }
            }
            PageTaskObj31UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 900, "mouseThrough": true, "height": 100 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 3, "x": 21, "width": 858, "skin": "ui/img_UM_ui_uibk3.png", "sizeGrid": "10,10,10,10", "height": 94 }, "compId": 1596 }, { "type": "Image", "props": { "y": 16, "x": 59, "width": 503, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "12,49,11,20", "height": 43, "alpha": 0.4 }, "compId": 1599 }, { "type": "Image", "props": { "y": 6, "x": 24, "width": 68, "skin": "ui/img_UM_fun_rank.png", "height": 68 }, "compId": 1597 }, { "type": "Label", "props": { "y": 71, "x": 33.5, "wordWrap": true, "width": 47, "text": "+9", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1598 }, { "type": "Label", "props": { "y": 23, "x": 100, "wordWrap": true, "width": 394, "text": "完成需要达成的条件...", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1602 }, { "type": "Image", "props": { "y": 66, "x": 98, "width": 453, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "6,6,6,6", "height": 24 }, "compId": 1606 }, { "type": "Image", "props": { "y": 67, "x": 99, "width": 30, "skin": "ui/img_UM_rank_bar.png", "sizeGrid": "6,11,7,6", "height": 22 }, "compId": 1604 }, { "type": "Image", "props": { "y": 6, "x": 593, "width": 136, "skin": "ui/img_UM_btn_BlueButton_2.png", "height": 89 }, "compId": 1608 }, { "type": "Image", "props": { "y": 10, "x": 731, "width": 141, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "35,30,36,36", "height": 80, "alpha": 0.5 }, "compId": 1610 }, { "type": "Label", "props": { "y": 65, "x": 772.5, "wordWrap": true, "width": 60, "text": "奖励", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 20, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1611 }, { "type": "Image", "props": { "y": 19, "x": 762.5, "width": 36, "skin": "ui/img_UM_Diamond.png", "height": 36 }, "compId": 1612 }, { "type": "Image", "props": { "y": 12, "x": 802.5, "width": 29, "skin": "ui/img_UM_num_5.png", "height": 47 }, "compId": 1613 }, { "type": "Image", "props": { "y": 32, "x": 608, "width": 105, "skin": "ui/img_UM_ui_text42.png", "height": 30 }, "compId": 1614 }, { "type": "Label", "props": { "y": 65, "x": 269, "wordWrap": true, "width": 111, "text": "1/1", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1615 }], "loadList": ["ui/img_UM_ui_uibk3.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_fun_rank.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_rank_bar.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_Diamond.png", "ui/img_UM_num_5.png", "ui/img_UM_ui_text42.png"], "loadList3D": [] };
            test.PageTaskObj31UI = PageTaskObj31UI;
            REG("ui.test.PageTaskObj31UI", PageTaskObj31UI);
            class PageTeamBlueUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTeamBlueUI.uiView);
                }
            }
            PageTeamBlueUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 500, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 125, "x": 295, "width": 469, "pivotY": 116, "pivotX": 280, "height": 182 }, "compId": 1243, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 463, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 183 }, "compId": 1244 }, { "type": "List", "props": { "y": 82, "x": 26, "width": 351, "var": "list_1", "spaceX": -130, "repeatY": 1, "repeatX": 5, "name": "list_1", "height": 92 }, "compId": 1246, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "width": 200, "scaleY": 0.3, "scaleX": 0.3, "renderType": "render", "height": 319, "runtime": "ui.goods.GoodsItemUI" }, "compId": 1282 }] }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1250 }, { "type": "Label", "props": { "y": 33, "x": 92, "wordWrap": false, "width": 202, "var": "txt_name", "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1251 }, { "type": "Image", "props": { "y": 21, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1254 }, { "type": "Image", "props": { "y": 22, "x": 29, "width": 50, "var": "img_ico", "skin": "ui/img_UM_playerhead.png", "name": "img_ico", "height": 50 }, "compId": 1255 }] }, { "type": "Box", "props": { "y": 28, "x": 328, "width": 131, "height": 55 }, "compId": 1286, "child": [{ "type": "Image", "props": { "y": 4, "x": 16, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1283 }, { "type": "Image", "props": { "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1284 }, { "type": "Label", "props": { "y": 13, "x": 52, "wordWrap": false, "width": 77, "var": "txt_num", "text": "100", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1285 }] }], "loadList": ["ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png"], "loadList3D": [] };
            test.PageTeamBlueUI = PageTeamBlueUI;
            REG("ui.test.PageTeamBlueUI", PageTeamBlueUI);
            class PageTeamBlue1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTeamBlue1UI.uiView);
                }
            }
            PageTeamBlue1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 500, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 125, "x": 290, "width": 469, "pivotY": 116, "pivotX": 280, "height": 182 }, "compId": 1243, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 480, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 183 }, "compId": 1244 }, { "type": "List", "props": { "y": 78, "x": 13, "width": 351, "spaceX": -130, "repeatY": 1, "repeatX": 5, "height": 92 }, "compId": 1246, "child": [{ "type": "heroCard3", "props": { "y": 0, "x": 0, "scaleY": 0.3, "scaleX": 0.3, "renderType": "render", "runtime": "ui.test.heroCard3UI" }, "compId": 1257 }] }, { "type": "Image", "props": { "y": 20, "x": 16, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1250 }, { "type": "Label", "props": { "y": 29, "x": 79, "wordWrap": true, "width": 202, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1251 }, { "type": "Image", "props": { "y": 17, "x": 14, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1254 }, { "type": "Image", "props": { "y": 19, "x": 16, "width": 50, "skin": "ui/img_UM_playerhead.png", "height": 50 }, "compId": 1255 }] }, { "type": "Image", "props": { "y": 27, "x": 364, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1281 }, { "type": "Image", "props": { "y": 23, "x": 348, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1282 }, { "type": "Label", "props": { "y": 36, "x": 400, "wordWrap": true, "width": 63, "text": "80", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1283 }, { "type": "Image", "props": { "y": 90, "x": 384, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1284 }, { "type": "Label", "props": { "y": 102, "x": 388, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1285 }], "loadList": ["ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png", "ui/img_UM_xpicon.png"], "loadList3D": [] };
            test.PageTeamBlue1UI = PageTeamBlue1UI;
            REG("ui.test.PageTeamBlue1UI", PageTeamBlue1UI);
            class PageTeamRedUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTeamRedUI.uiView);
                }
            }
            PageTeamRedUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 500, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 125, "x": 295, "width": 469, "pivotY": 116, "pivotX": 280, "height": 182 }, "compId": 1243, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 463, "skin": "ui/img_UM_ui_team_red.png", "sizeGrid": "30,30,30,30", "height": 183 }, "compId": 1244 }, { "type": "List", "props": { "y": 82, "x": 26, "width": 351, "var": "list_1", "spaceX": -130, "repeatY": 1, "repeatX": 5, "name": "list_1", "height": 92 }, "compId": 1246, "child": [{ "type": "GoodsItem", "props": { "y": 0, "x": 0, "width": 200, "scaleY": 0.3, "scaleX": 0.3, "renderType": "render", "height": 319, "runtime": "ui.goods.GoodsItemUI" }, "compId": 1281 }] }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1250 }, { "type": "Label", "props": { "y": 33, "x": 92, "wordWrap": false, "width": 202, "var": "txt_name", "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1251 }, { "type": "Image", "props": { "y": 21, "x": 27, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1254 }, { "type": "Image", "props": { "y": 23, "x": 29, "width": 50, "var": "img_ico", "skin": "ui/img_UM_playerhead.png", "name": "img_ico", "height": 50 }, "compId": 1255 }] }, { "type": "Box", "props": { "y": 28, "x": 328 }, "compId": 1285, "child": [{ "type": "Image", "props": { "y": 4, "x": 17, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1282 }, { "type": "Image", "props": { "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1283 }, { "type": "Label", "props": { "y": 13, "x": 52, "wordWrap": false, "width": 77, "var": "txt_num", "text": "100", "strokeColor": "#000000", "stroke": 4, "name": "txt_num", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1284 }] }], "loadList": ["ui/img_UM_ui_team_red.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png"], "loadList3D": [] };
            test.PageTeamRedUI = PageTeamRedUI;
            REG("ui.test.PageTeamRedUI", PageTeamRedUI);
            class PageTeamRed1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageTeamRed1UI.uiView);
                }
            }
            PageTeamRed1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 500, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Box", "props": { "y": 125, "x": 290, "width": 469, "pivotY": 116, "pivotX": 280, "height": 182 }, "compId": 1243, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 480, "skin": "ui/img_UM_ui_team_red.png", "sizeGrid": "30,30,30,30", "height": 183 }, "compId": 1244 }, { "type": "List", "props": { "y": 78, "x": 13, "width": 351, "spaceX": -130, "repeatY": 1, "repeatX": 5, "height": 92 }, "compId": 1246, "child": [{ "type": "heroCard3", "props": { "y": 0, "x": 0, "scaleY": 0.3, "scaleX": 0.3, "renderType": "render", "runtime": "ui.test.heroCard3UI" }, "compId": 1257 }] }, { "type": "Image", "props": { "y": 20, "x": 16, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "sizeGrid": "14,16,17,13", "height": 48, "alpha": 0.3 }, "compId": 1250 }, { "type": "Label", "props": { "y": 29, "x": 79, "wordWrap": true, "width": 202, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1251 }, { "type": "Image", "props": { "y": 17, "x": 14, "width": 54, "skin": "ui/img_UM_ui_Tips2.png", "height": 54 }, "compId": 1254 }, { "type": "Image", "props": { "y": 19, "x": 16, "width": 50, "skin": "ui/img_UM_playerhead.png", "height": 50 }, "compId": 1255 }] }, { "type": "Image", "props": { "y": 27, "x": 364, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1281 }, { "type": "Image", "props": { "y": 23, "x": 348, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1282 }, { "type": "Label", "props": { "y": 36, "x": 400, "wordWrap": true, "width": 63, "text": "80", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1283 }, { "type": "Image", "props": { "y": 90, "x": 384, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1284 }, { "type": "Label", "props": { "y": 102, "x": 388, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1285 }], "loadList": ["ui/img_UM_ui_team_red.png", "ui/img_UM_ui_obj1.png", "ui/img_UM_ui_Tips2.png", "ui/img_UM_playerhead.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png", "ui/img_UM_xpicon.png"], "loadList3D": [] };
            test.PageTeamRed1UI = PageTeamRed1UI;
            REG("ui.test.PageTeamRed1UI", PageTeamRed1UI);
            class PageVictoryUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageVictoryUI.uiView);
                }
            }
            PageVictoryUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 70, "x": 193, "width": 838, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1130 }, { "type": "Label", "props": { "y": 79.5, "x": 210, "wordWrap": true, "width": 173, "text": "战斗卡组", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1131 }, { "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg.jpg" }, "compId": 1217 }, { "type": "Image", "props": { "y": 183, "x": 0, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "Box", "props": { "y": 213, "x": 360 }, "compId": 1225, "child": [{ "type": "Image", "props": { "width": 559, "skin": "ui/img_UM_ui_team_blue.png", "sizeGrid": "30,30,30,30", "height": 231 }, "compId": 1207 }, { "type": "Image", "props": { "y": 25, "x": 420, "width": 115, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 47, "alpha": 0.6 }, "compId": 1218 }, { "type": "List", "props": { "y": 88, "x": 23, "width": 407, "spaceX": -80, "repeatY": 1, "repeatX": 5, "height": 123 }, "compId": 1210, "child": [{ "type": "heroCard1", "props": { "scaleY": 0.5, "scaleX": 0.5, "renderType": "render", "runtime": "ui.test.heroCard1UI" }, "compId": 1211 }] }, { "type": "Image", "props": { "y": 21, "x": 403, "width": 51, "skin": "ui/img_UM_icon_cup.png", "height": 55 }, "compId": 1216 }, { "type": "Label", "props": { "y": 34, "x": 455, "wordWrap": true, "width": 63, "text": "+90", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 36, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1219 }, { "type": "Image", "props": { "y": 24, "x": 29, "width": 359, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1220 }, { "type": "Label", "props": { "y": 32, "x": 41, "wordWrap": true, "width": 327, "text": "玩家名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1221 }, { "type": "Image", "props": { "y": 107, "x": 444, "width": 83, "skin": "ui/img_UM_xpicon.png", "height": 83 }, "compId": 1222 }, { "type": "Label", "props": { "y": 119, "x": 448, "wordWrap": true, "width": 76, "var": "txt_phy", "valign": "middle", "text": "20", "strokeColor": "#136777", "stroke": 6, "name": "txt_phy", "height": 55, "fontSize": 38, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1223 }] }, { "type": "Image", "props": { "y": 114, "x": 447, "width": 643, "skin": "ui/img_UM_ribbon_bg_yellow.png", "sizeGrid": "43,158,53,158", "scaleY": 0.6, "scaleX": 0.6, "height": 152 }, "compId": 1237 }, { "type": "VictoryEffect", "props": { "y": -32, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.test.VictoryEffectUI" }, "compId": 1241 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }], "loadList": ["ui/img_UM_ui_obj1.png", "ui/img_UM_ui_bg.jpg", "ui/img_UM_black.png", "ui/img_UM_ui_team_blue.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_icon_cup.png", "ui/img_UM_xpicon.png", "ui/img_UM_ribbon_bg_yellow.png", "ui/img_UM_text_victory.png"], "loadList3D": [] };
            test.PageVictoryUI = PageVictoryUI;
            REG("ui.test.PageVictoryUI", PageVictoryUI);
            class PageVictory1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageVictory1UI.uiView);
                }
            }
            PageVictory1UI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 70, "x": 193, "width": 838, "skin": "ui/img_UM_ui_obj1.png", "height": 48, "alpha": 0.3 }, "compId": 1130 }, { "type": "Label", "props": { "y": 79.5, "x": 210, "wordWrap": true, "width": 173, "text": "战斗卡组", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 28, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1131 }, { "type": "Image", "props": { "y": 0, "x": 0, "skin": "ui/img_UM_ui_bg.jpg" }, "compId": 1217 }, { "type": "Image", "props": { "y": 337, "x": 640, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "pivotY": 154, "pivotX": 640, "height": 307, "alpha": 0.6 }, "compId": 1205 }, { "type": "VictoryEffect", "props": { "y": -42, "x": 120, "scaleY": 0.7, "scaleX": 2, "runtime": "ui.test.VictoryEffectUI" }, "compId": 1241 }, { "type": "Image", "props": { "y": 88, "x": 383, "skin": "ui/img_UM_end_victorybg.png" }, "compId": 1242 }, { "type": "Image", "props": { "y": 61, "x": 512, "skin": "ui/img_UM_text_victory.png" }, "compId": 1239 }, { "type": "Image", "props": { "y": 347, "x": 640, "width": 64, "skin": "ui/img_UM_vs.png", "pivotY": 24, "pivotX": 32, "height": 48 }, "compId": 1258 }, { "type": "Box", "props": { "y": 350, "x": 334, "width": 489, "pivotY": 103, "pivotX": 245, "height": 205 }, "compId": 1283, "child": [{ "type": "PageTeamBlue", "props": { "y": 100, "x": 250, "width": 500, "pivotY": 100, "pivotX": 250, "height": 200, "runtime": "ui.test.PageTeamBlueUI" }, "compId": 1281 }] }, { "type": "Box", "props": { "y": 348, "x": 934, "width": 485, "pivotY": 101, "pivotX": 243, "height": 202 }, "compId": 1284, "child": [{ "type": "PageTeamRed", "props": { "y": 100, "x": 250, "width": 500, "pivotY": 100, "pivotX": 250, "height": 200, "runtime": "ui.test.PageTeamRedUI" }, "compId": 1282 }] }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter" }, "compId": 1285 }, { "type": "Box", "props": { "y": 507, "x": 355 }, "compId": 1296, "child": [{ "type": "Image", "props": { "y": -0.5, "x": 301, "width": 269, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 95 }, "compId": 1289, "child": [{ "type": "Image", "props": { "y": 23, "x": 87, "skin": "ui/img_UM_ui_text11.png" }, "compId": 1293 }, { "type": "Image", "props": { "y": 26.5, "x": 42, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1294 }] }, { "type": "Image", "props": { "y": -0.5, "width": 269, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 95 }, "compId": 1291, "child": [{ "type": "Image", "props": { "y": 22, "x": 63, "skin": "ui/img_UM_ui_text10.png" }, "compId": 1295 }] }] }], "animations": [{ "nodes": [{ "target": 1205, "keyframes": { "scaleY": [{ "value": 0.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 5 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1205, "key": "scaleY", "index": 10 }] } }, { "target": 1258, "keyframes": { "alpha": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 20 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1258, "key": "alpha", "index": 25 }] } }, { "target": 1283, "keyframes": { "y": [{ "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 0 }, { "value": 350, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 40 }, { "value": 340, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "y", "index": 47 }, { "value": 345, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "y", "index": 52 }], "x": [{ "value": -300, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 0 }, { "value": 353, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 7 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 10 }, { "value": 343, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 20 }, { "value": 330, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 25 }, { "value": 318, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 29 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "x", "index": 33 }, { "value": 648, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 36 }, { "value": 640, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "x", "index": 40 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleY", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleY", "index": 52 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 0 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 40 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "label": null, "key": "scaleX", "index": 47 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1283, "key": "scaleX", "index": 52 }] } }, { "target": 1284, "keyframes": { "y": [{ "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 0 }, { "value": 348, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 20 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 25 }, { "value": 331, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "y", "index": 29 }, { "value": 900, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "y", "index": 40 }], "x": [{ "value": 1570, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 0 }, { "value": 913, "tweenMethod": "linearNone", "tween": true, "target": 1284, "key": "x", "index": 7 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 10 }, { "value": 923, "tweenMethod": "linearNone", "tween": true, "target": 1284, "label": null, "key": "x", "index": 20 }] } }, { "target": 1285, "keyframes": { "y": [{ "value": 351, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 0 }, { "value": 338, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "y", "index": 47 }], "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleY", "index": 47 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 0 }, { "value": 1.2, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "scaleX", "index": 47 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "label": null, "key": "alpha", "index": 42 }, { "value": 0.5, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 47 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1285, "key": "alpha", "index": 52 }] } }, { "target": 1296, "keyframes": { "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 47 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1296, "key": "alpha", "index": 52 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_ui_obj1.png", "ui/img_UM_ui_bg.jpg", "ui/img_UM_black.png", "ui/img_UM_end_victorybg.png", "ui/img_UM_text_victory.png", "ui/img_UM_vs.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text11.png", "ui/img_UM_ui2_guanggao3.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text10.png"], "loadList3D": [] };
            test.PageVictory1UI = PageVictory1UI;
            REG("ui.test.PageVictory1UI", PageVictory1UI);
            class PageVictoryQianUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(PageVictoryQianUI.uiView);
                }
            }
            PageVictoryQianUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 140, "x": 633, "width": 500, "skin": "ui/img_UM_end_defeatbg.png", "pivotY": 52, "pivotX": 250, "height": 130 }, "compId": 1242 }, { "type": "Image", "props": { "y": 121, "x": 640, "width": 256, "skin": "ui/img_UM_text_fail.png", "pivotY": 60, "pivotX": 128, "height": 119 }, "compId": 1239 }, { "type": "Image", "props": { "y": 351, "x": 640, "width": 479, "skin": "ui/img_UM_herokill_bg_yellow.png", "sizeGrid": "22,31,26,34", "scaleY": 1, "scaleX": 1, "pivotY": 99, "pivotX": 240, "height": 198, "blendMode": "lighter", "alpha": 0 }, "compId": 1285 }, { "type": "Image", "props": { "y": 512, "x": 293, "width": 693, "skin": "ui/img_UM_ui_barbg.png", "sizeGrid": "10,10,10,10", "height": 124, "alpha": 0.4 }, "compId": 1297 }, { "type": "Box", "props": { "y": 518, "x": 299 }, "compId": 1309, "child": [{ "type": "Image", "props": { "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1311 }, { "type": "Label", "props": { "y": 41, "x": 39, "wordWrap": true, "width": 202, "text": "最大Frag连击", "strokeColor": "#000000", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1312 }, { "type": "Label", "props": { "y": 21, "x": 253, "wordWrap": true, "width": 66, "text": "8", "strokeColor": "#000000", "height": 69, "fontSize": 70, "font": "SimHei", "color": "#141414", "bold": true, "align": "left" }, "compId": 1313 }] }, { "type": "Box", "props": { "y": 473, "x": 639 }, "compId": 1310, "child": [{ "type": "Image", "props": { "y": 45, "width": 341, "skin": "ui/img_UM_ui_obj9.png", "sizeGrid": "40,40,40,40", "height": 110 }, "compId": 1314 }, { "type": "Label", "props": { "y": 82, "x": 13, "wordWrap": true, "width": 202, "text": "MVP", "strokeColor": "#000000", "height": 35, "fontSize": 40, "font": "SimHei", "color": "#141414", "bold": true, "align": "center" }, "compId": 1315 }, { "type": "heroCard3", "props": { "x": 205, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.heroCard3UI" }, "compId": 1316 }] }], "animations": [{ "nodes": [{ "target": 1242, "keyframes": { "y": [{ "value": 233, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 0 }, { "value": 140, "tweenMethod": "linearNone", "tween": true, "target": 1242, "label": null, "key": "y", "index": 20 }], "scaleX": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 20 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 25 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1242, "key": "scaleX", "index": 30 }] } }, { "target": 1239, "keyframes": { "y": [{ "value": 214, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 0 }, { "value": 121, "tweenMethod": "linearNone", "tween": true, "target": 1239, "label": null, "key": "y", "index": 20 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_end_defeatbg.png", "ui/img_UM_text_fail.png", "ui/img_UM_herokill_bg_yellow.png", "ui/img_UM_ui_barbg.png", "ui/img_UM_ui_obj9.png"], "loadList3D": [] };
            test.PageVictoryQianUI = PageVictoryQianUI;
            REG("ui.test.PageVictoryQianUI", PageVictoryQianUI);
            class QianwangLvupUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(QianwangLvupUI.uiView);
                }
            }
            QianwangLvupUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -40, "x": -10, "skin": "ui/img_UM_ui_bg7.jpg" }, "compId": 1395 }, { "type": "Box", "props": { "y": 28, "x": 38 }, "compId": 1204, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 1202 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 1203 }] }, { "type": "Image", "props": { "y": 360, "x": 616, "width": 289, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "17,19,17,19", "height": 41 }, "compId": 1245 }, { "type": "Label", "props": { "y": 204, "x": 620, "wordWrap": true, "width": 285, "text": "卡牌名称", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 60, "fontSize": 50, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1246 }, { "type": "Image", "props": { "y": -18, "x": 203, "width": 592, "skin": "ui/img_UM_effect_blue.png", "height": 663, "blendMode": "lighter", "alpha": 0.5 }, "compId": 1289 }, { "type": "Image", "props": { "y": 357, "x": 614, "width": 193, "skin": "ui/img_UM_bar_green.png", "sizeGrid": "15,53,22,21", "height": 46 }, "compId": 1374 }, { "type": "Box", "props": { "y": 365, "x": 723 }, "compId": 1384, "child": [{ "type": "Image", "props": { "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1380 }, { "type": "Label", "props": { "y": 3, "x": 21, "wordWrap": true, "width": 21, "text": "/", "strokeColor": "#272727", "stroke": 4, "height": 32, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1381 }, { "type": "Image", "props": { "x": 39, "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1382 }, { "type": "Image", "props": { "x": 57, "width": 18, "skin": "ui/img_UM_num_5.png", "height": 30 }, "compId": 1383 }] }, { "type": "heroCard3", "props": { "y": 174, "x": 393, "runtime": "ui.test.heroCard3UI" }, "compId": 1396 }, { "type": "Image", "props": { "y": 163, "x": 533, "width": 76, "skin": "ui/img_UM_levelUpArrow.png", "height": 76 }, "compId": 1397 }, { "type": "Label", "props": { "y": 264, "x": 620, "wordWrap": true, "width": 135, "text": "稀有", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 33, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "left" }, "compId": 1398 }, { "type": "Label", "props": { "y": 411, "x": 667, "wordWrap": true, "width": 217, "text": "有升级可用", "strokeColor": "#000000", "stroke": 4, "name": "txt_phy", "height": 33, "fontSize": 24, "font": "SimHei", "color": "#23c02a", "bold": true, "align": "center" }, "compId": 1399 }, { "type": "Box", "props": { "y": 568, "x": 352, "width": 576, "height": 165 }, "compId": 1403, "child": [{ "type": "Box", "props": { "y": 3 }, "compId": 1285, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 270, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 1286 }, { "type": "Image", "props": { "y": 26, "x": 43, "skin": "ui/img_UM_ui_text49.png" }, "compId": 1400 }] }, { "type": "Image", "props": { "y": 55, "x": 425, "width": 303, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "27,30,40,37", "pivotY": 55, "pivotX": 152, "height": 110 }, "compId": 1401, "child": [{ "type": "Image", "props": { "y": 29, "x": 80, "skin": "ui/img_UM_ui_text50.png" }, "compId": 1402 }] }] }], "loadList": ["ui/img_UM_ui_bg7.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_effect_blue.png", "ui/img_UM_bar_green.png", "ui/img_UM_num_5.png", "ui/img_UM_levelUpArrow.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text49.png", "ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text50.png"], "loadList3D": [] };
            test.QianwangLvupUI = QianwangLvupUI;
            REG("ui.test.QianwangLvupUI", QianwangLvupUI);
            class RebornUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RebornUI.uiView);
                }
            }
            RebornUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 226, "x": 0, "width": 1280, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "5,5,5,5", "height": 126, "alpha": 0.6 }, "compId": 1147 }, { "type": "HeroKillHead", "props": { "y": 250, "x": 510, "runtime": "ui.test.HeroKillHeadUI" }, "compId": 1148 }, { "type": "Image", "props": { "y": 376, "x": 538, "width": 204, "skin": "ui/img_UM_ui_text4.png", "height": 44 }, "compId": 1149 }, { "type": "Image", "props": { "y": 431, "x": 554, "skin": "ui/img_UM_ui_text5.png" }, "compId": 1150 }], "loadList": ["ui/img_UM_ui_Tips2.png", "ui/img_UM_ui_text4.png", "ui/img_UM_ui_text5.png"], "loadList3D": [] };
            test.RebornUI = RebornUI;
            REG("ui.test.RebornUI", RebornUI);
            class RebornHeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RebornHeroUI.uiView);
                }
            }
            RebornHeroUI.uiView = { "type": "View", "props": { "y": 0, "width": 1280, "top": 0, "right": 0, "mouseThrough": true, "left": 0, "height": 720, "bottom": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 1280, "skin": "ui/img_UM_ui_bg6.jpg", "height": 720, "alpha": 1 }, "compId": 1178 }, { "type": "Image", "props": { "y": 150, "x": 148, "width": 983, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "50,50,70,50", "scaleY": 1, "scaleX": 1, "height": 429 }, "compId": 1151 }, { "type": "Image", "props": { "y": 172, "x": 167, "width": 946, "skin": "ui/img_UM_card_bg.png", "height": 50 }, "compId": 1153 }, { "type": "Image", "props": { "y": 177, "x": 182, "skin": "ui/img_UM_ui_text8.png" }, "compId": 1166 }, { "type": "Box", "props": { "y": 13, "x": 378 }, "compId": 1249, "child": [{ "type": "Image", "props": { "y": 6, "x": 209, "width": 105, "skin": "ui/img_UM_ui_black2.png", "sizeGrid": "28,28,28,28", "height": 67, "alpha": 0.6 }, "compId": 1238 }, { "type": "Image", "props": { "x": 239, "width": 46, "skin": "ui/img_UM_ui_battle_wg1.png", "height": 46 }, "compId": 1239 }, { "type": "Label", "props": { "y": 36, "x": 208, "wordWrap": true, "width": 108, "valign": "middle", "text": "03:56", "strokeColor": "#000000", "name": "txt_phy", "height": 35, "fontSize": 24, "font": "SimHei", "color": "#ffc100", "bold": true, "align": "center" }, "compId": 1240 }, { "type": "Box", "props": { "y": 17 }, "compId": 1241, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1243 }, { "type": "Image", "props": { "y": 3, "x": 86, "width": 195, "skin": "ui/img_UM_progressbar_blue2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1244 }, { "type": "Label", "props": { "y": 4, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#093d4e", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#b9fcff", "bold": true, "align": "center" }, "compId": 1245 }] }, { "type": "Box", "props": { "y": 19, "x": 317 }, "compId": 1242, "child": [{ "type": "Image", "props": { "y": 0, "x": 0, "width": 294, "skin": "ui/img_UM_progressbar_blue2_1.png", "sizeGrid": "19,21,22,21", "scaleY": 0.7, "scaleX": 0.7, "height": 64 }, "compId": 1246 }, { "type": "Image", "props": { "y": 3, "x": 3, "width": 195, "skin": "ui/img_UM_progressbar_red2.png", "sizeGrid": "17,25,22,24", "scaleY": 0.6, "scaleX": 0.6, "height": 64 }, "compId": 1247 }, { "type": "Label", "props": { "y": 5, "x": 48, "wordWrap": true, "width": 108, "valign": "middle", "text": "1300", "strokeColor": "#4e091c", "stroke": 4, "name": "txt_phy", "height": 35, "fontSize": 30, "font": "SimHei", "color": "#ffb9c7", "bold": true, "align": "center" }, "compId": 1248 }] }] }, { "type": "Map", "props": { "y": 13, "x": 0, "scaleY": 0.7, "scaleX": 0.7, "runtime": "ui.test.MapUI" }, "compId": 1250 }, { "type": "List", "props": { "y": 238, "x": 173, "width": 933, "spaceX": -10, "mouseEnabled": true, "height": 306, "hScrollBarSkin": "comp/hscroll.png" }, "compId": 1254, "child": [{ "type": "heroCard3", "props": { "y": -0.5, "scaleY": 0.8, "scaleX": 0.8, "renderType": "render", "runtime": "ui.test.heroCard3UI" }, "compId": 1253 }] }, { "type": "Image", "props": { "y": 493, "x": 231, "width": 159, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 36, "pivotX": 56, "height": 72 }, "compId": 1255, "child": [{ "type": "Image", "props": { "y": 13, "x": 42, "skin": "ui/img_UM_ui_text7.png" }, "compId": 1256 }] }, { "type": "Image", "props": { "y": 493.5, "x": 420, "width": 159, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 36, "pivotX": 56, "height": 72 }, "compId": 1257, "child": [{ "type": "Image", "props": { "y": 13, "x": 42, "skin": "ui/img_UM_ui_text7.png" }, "compId": 1258 }] }, { "type": "Image", "props": { "y": 493, "x": 611, "width": 159, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 36, "pivotX": 56, "height": 72 }, "compId": 1259, "child": [{ "type": "Image", "props": { "y": 13, "x": 42, "skin": "ui/img_UM_ui_text7.png" }, "compId": 1260 }] }, { "type": "Image", "props": { "y": 492, "x": 802, "width": 159, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 36, "pivotX": 56, "height": 72 }, "compId": 1261, "child": [{ "type": "Image", "props": { "y": 13, "x": 42, "skin": "ui/img_UM_ui_text7.png" }, "compId": 1262 }] }, { "type": "Image", "props": { "y": 492, "x": 989, "width": 159, "skin": "ui/img_UM_btn_Yellow.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 36, "pivotX": 56, "height": 72 }, "compId": 1263, "child": [{ "type": "Image", "props": { "y": 13, "x": 42, "skin": "ui/img_UM_ui_text7.png" }, "compId": 1264 }] }], "loadList": ["ui/img_UM_ui_bg6.jpg", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_card_bg.png", "ui/img_UM_ui_text8.png", "ui/img_UM_ui_black2.png", "ui/img_UM_ui_battle_wg1.png", "ui/img_UM_progressbar_blue2_1.png", "ui/img_UM_progressbar_blue2.png", "ui/img_UM_progressbar_red2.png", "comp/hscroll.png", "ui/img_UM_btn_Yellow.png", "ui/img_UM_ui_text7.png"], "loadList3D": [] };
            test.RebornHeroUI = RebornHeroUI;
            REG("ui.test.RebornHeroUI", RebornHeroUI);
            class RedAnim1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RedAnim1UI.uiView);
                }
            }
            RedAnim1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 50, "width": 93, "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "pivotY": 31, "pivotX": 47, "height": 62 }, "compId": 1174 }, { "type": "Image", "props": { "y": 22, "x": 49, "width": 68, "skin": "ui/img_UM_ui_text18.png", "pivotY": 14, "pivotX": 34, "height": 27 }, "compId": 1175 }], "animations": [{ "nodes": [{ "target": 1174, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red.png", "ui/img_UM_ui_text18.png"], "loadList3D": [] };
            test.RedAnim1UI = RedAnim1UI;
            REG("ui.test.RedAnim1UI", RedAnim1UI);
            class RedAnim2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RedAnim2UI.uiView);
                }
            }
            RedAnim2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 50, "width": 93, "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "pivotY": 31, "pivotX": 47, "height": 62 }, "compId": 1174 }, { "type": "Image", "props": { "y": 22, "x": 49, "width": 68, "skin": "ui/img_UM_ui_text19.png", "pivotY": 14, "pivotX": 34, "height": 27 }, "compId": 1175 }], "animations": [{ "nodes": [{ "target": 1174, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red.png", "ui/img_UM_ui_text19.png"], "loadList3D": [] };
            test.RedAnim2UI = RedAnim2UI;
            REG("ui.test.RedAnim2UI", RedAnim2UI);
            class RedAnim3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RedAnim3UI.uiView);
                }
            }
            RedAnim3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 100, "mouseThrough": true, "height": 60 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 30, "x": 50, "width": 110, "skin": "ui/img_UM_ui_red.png", "sizeGrid": "16,19,37,42", "pivotY": 31, "pivotX": 47, "height": 62 }, "compId": 1174 }, { "type": "Image", "props": { "y": 9, "x": 16, "width": 87, "skin": "ui/img_UM_ui_text25.png", "height": 25 }, "compId": 1177 }], "animations": [{ "nodes": [{ "target": 1174, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 9 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleY", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 9 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 12 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "key": "scaleX", "index": 15 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1174, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_ui_red.png", "ui/img_UM_ui_text25.png"], "loadList3D": [] };
            test.RedAnim3UI = RedAnim3UI;
            REG("ui.test.RedAnim3UI", RedAnim3UI);
            class RenwuUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(RenwuUI.uiView);
                }
            }
            RenwuUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 78, "x": 154, "skin": "ui/img_UM_SponsorWall3.png" }, "compId": 1192 }, { "type": "Image", "props": { "y": 93, "x": 365, "skin": "ui/img_UM_text_renwu2.png" }, "compId": 1180 }, { "type": "Image", "props": { "y": 176, "x": 267, "width": 745, "skin": "ui/img_UM_text_renwu.png", "height": 73 }, "compId": 1181 }, { "type": "huxiAnim", "props": { "y": 273, "x": 270, "runtime": "ui.test.huxiAnimUI" }, "compId": 1195 }, { "type": "Image", "props": { "y": 277, "x": 689, "width": 300, "skin": "ui/img_UM_ui_Tips2.png", "sizeGrid": "8,8,13,10", "height": 300 }, "compId": 1185 }, { "type": "huxiAnim", "props": { "y": 274, "x": 420, "runtime": "ui.test.huxiAnimUI" }, "compId": 1196 }, { "type": "GoodsCard", "props": { "y": 287, "x": 459, "scaleY": 0.6, "scaleX": 0.6, "runtime": "ui.test.GoodsCardUI" }, "compId": 1188 }, { "type": "Label", "props": { "y": 404, "x": 806, "wordWrap": true, "width": 173, "var": "txt_name", "valign": "middle", "text": "广告", "strokeColor": "#000000", "stroke": 4, "name": "txt_name", "height": 43, "fontSize": 32, "font": "SimHei", "color": "#ababab", "bold": true, "align": "left" }, "compId": 1191 }, { "type": "renwuBtn", "props": { "y": 456, "x": 302, "runtime": "ui.test.renwuBtnUI" }, "compId": 1198 }, { "type": "GoodsCard1", "props": { "y": 287, "x": 308, "width": 200, "scaleY": 0.6, "scaleX": 0.6, "height": 310, "runtime": "ui.test.GoodsCard1UI" }, "compId": 1199 }], "loadList": ["ui/img_UM_SponsorWall3.png", "ui/img_UM_text_renwu2.png", "ui/img_UM_text_renwu.png", "ui/img_UM_ui_Tips2.png"], "loadList3D": [] };
            test.RenwuUI = RenwuUI;
            REG("ui.test.RenwuUI", RenwuUI);
            class renwuBtnUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(renwuBtnUI.uiView);
                }
            }
            renwuBtnUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 280, "mouseThrough": false, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 72, "x": 140, "width": 269, "skin": "ui/img_UM_btn_OrangeButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "pivotY": 57, "pivotX": 135, "height": 114 }, "compId": 1251 }, { "type": "Image", "props": { "y": 42, "x": 89, "width": 101, "skin": "ui/img_UM_ui_text17.png", "height": 47 }, "compId": 1252 }], "animations": [{ "nodes": [{ "target": 1251, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleY", "index": 0 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleY", "index": 3 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleY", "index": 6 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleY", "index": 8 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleY", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "label": null, "key": "scaleY", "index": 16 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "label": null, "key": "scaleY", "index": 60 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleX", "index": 3 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleX", "index": 6 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleX", "index": 8 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1251, "key": "scaleX", "index": 11 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "label": null, "key": "scaleX", "index": 16 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1251, "label": null, "key": "scaleX", "index": 60 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_btn_OrangeButton_2.png", "ui/img_UM_ui_text17.png"], "loadList3D": [] };
            test.renwuBtnUI = renwuBtnUI;
            REG("ui.test.renwuBtnUI", renwuBtnUI);
            class ShiyongHeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(ShiyongHeroUI.uiView);
                }
            }
            ShiyongHeroUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 62, "x": 154, "skin": "ui/img_UM_SponsorWall.png" }, "compId": 1152 }, { "type": "Image", "props": { "y": 533, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": -1, "x": 130, "skin": "ui/img_UM_ui_text80.png" }, "compId": 1143 }, { "type": "TrialHeroAnim1", "props": { "y": -26, "x": 544.5, "runtime": "ui.test.TrialHeroAnim1UI" }, "compId": 1178 }, { "type": "TrialHeroAnim2", "props": { "y": 196, "x": 185.5, "runtime": "ui.test.TrialHeroAnim2UI" }, "compId": 1179 }, { "type": "TrialHeroAnim3", "props": { "y": 205, "x": 345, "runtime": "ui.test.TrialHeroAnim3UI" }, "compId": 1180 }, { "type": "TrialHeroAnim3", "props": { "y": 337, "x": 345, "runtime": "ui.test.TrialHeroAnim3UI" }, "compId": 1181 }, { "type": "Label", "props": { "y": 487, "x": 185.5, "wordWrap": true, "width": 226, "valign": "middle", "text": "英雄解锁进度：", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1187 }, { "type": "Box", "props": { "y": 520, "x": 199 }, "compId": 1188, "child": [{ "type": "Image", "props": { "y": 6, "x": 23, "width": 445, "skin": "ui/img_UM_herohead_bg.png", "sizeGrid": "33,33,33,33", "height": 52 }, "compId": 1184 }, { "type": "Image", "props": { "y": 9, "x": 26, "width": 624, "skin": "ui/img_UM_btn__Gold.png", "sizeGrid": "33,33,33,33", "scaleY": 0.7, "scaleX": 0.7, "height": 66 }, "compId": 1185 }, { "type": "Image", "props": { "width": 57, "skin": "ui/img_UM_icon_cup.png", "height": 62 }, "compId": 1183 }, { "type": "Label", "props": { "y": 17, "x": 114, "wordWrap": true, "width": 226, "var": "txt_info", "valign": "middle", "text": "100%", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1186 }] }, { "type": "Image", "props": { "y": 610, "x": 199, "width": 227, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "33,33,48,33", "height": 99 }, "compId": 1189, "child": [{ "type": "Label", "props": { "y": 25, "x": 0, "wordWrap": true, "width": 226, "valign": "middle", "text": "确定", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1192 }] }, { "type": "Image", "props": { "y": 610, "x": 419, "width": 227, "skin": "ui/img_UM_btn_green.png", "sizeGrid": "33,33,48,33", "height": 98 }, "compId": 1190, "child": [{ "type": "Label", "props": { "y": 23, "x": 60, "wordWrap": true, "width": 150, "valign": "middle", "text": "直接解锁", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 40, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1193 }, { "type": "Image", "props": { "y": 27.5, "x": 22, "width": 41, "skin": "ui/img_UM_ui2_guanggao3.png", "height": 33 }, "compId": 1194 }] }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text80.png", "ui/img_UM_herohead_bg.png", "ui/img_UM_btn__Gold.png", "ui/img_UM_icon_cup.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_btn_green.png", "ui/img_UM_ui2_guanggao3.png"], "loadList3D": [] };
            test.ShiyongHeroUI = ShiyongHeroUI;
            REG("ui.test.ShiyongHeroUI", ShiyongHeroUI);
            class SignDay1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignDay1UI.uiView);
                }
            }
            SignDay1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720, "centerX": 0 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -15, "x": -27, "skin": "ui/img_UM_ui_bg5.jpg" }, "compId": 600 }, { "type": "Box", "props": { "y": 38, "x": 48 }, "compId": 601, "child": [{ "type": "Image", "props": { "width": 89, "skin": "ui/img_UM_pause_btn_blue.png", "height": 107 }, "compId": 602 }, { "type": "Image", "props": { "y": 25, "x": 24, "width": 51, "skin": "ui/img_UM_icon_exit.png", "height": 46 }, "compId": 603 }] }, { "type": "Image", "props": { "y": 58, "x": 182, "width": 916, "skin": "ui/img_UM_ui_uibk.png", "sizeGrid": "37,36,36,37", "height": 543 }, "compId": 604 }, { "type": "Image", "props": { "y": 116, "x": 200, "width": 881, "skin": "ui/img_UM_ui_uibk2.png", "sizeGrid": "36,36,36,36", "height": 471 }, "compId": 605 }, { "type": "SignObj1", "props": { "y": 124, "x": 212, "width": 180, "height": 230, "runtime": "ui.test.SignObj1UI" }, "compId": 606 }, { "type": "Box", "props": { "y": 607, "x": 392.5 }, "compId": 607, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_BlueButton_2.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 608 }, { "type": "Image", "props": { "y": 28, "x": 87, "width": 74, "skin": "ui/img_UM_ui_text17.png", "height": 34 }, "compId": 609 }] }, { "type": "SignObj1", "props": { "y": 124, "x": 385, "width": 180, "height": 230, "runtime": "ui.test.SignObj1UI" }, "compId": 610 }, { "type": "SignObj2", "props": { "y": 352, "x": 212, "runtime": "ui.test.SignObj2UI" }, "compId": 611 }, { "type": "SignObj3", "props": { "y": 124, "x": 558, "runtime": "ui.test.SignObj3UI" }, "compId": 612 }, { "type": "SignObj2", "props": { "y": 352, "x": 387, "runtime": "ui.test.SignObj2UI" }, "compId": 613 }, { "type": "SignObj2", "props": { "y": 352, "x": 561, "runtime": "ui.test.SignObj2UI" }, "compId": 614 }, { "type": "SignObj4", "props": { "y": 125.5, "x": 731, "runtime": "ui.test.SignObj4UI" }, "compId": 616 }, { "type": "Image", "props": { "y": 192, "x": 141.5, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1 }, "compId": 624 }, { "type": "Image", "props": { "y": 192, "x": 1143, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleY": -1, "scaleX": -1 }, "compId": 625 }, { "type": "Image", "props": { "y": -8, "x": 226, "skin": "ui/img_UM_ui_7day_tou.png" }, "compId": 617 }, { "type": "Box", "props": { "y": 607, "x": 640 }, "compId": 618, "child": [{ "type": "Image", "props": { "y": -3, "x": 0, "width": 248, "skin": "ui/img_UM_btn_YellowButton_1.png", "sizeGrid": "35,40,45,40", "scaleY": 1, "scaleX": 1, "height": 109 }, "compId": 619 }, { "type": "Image", "props": { "y": 25, "x": 56, "skin": "ui/img_UM_ui_text46.png" }, "compId": 621 }] }, { "type": "Image", "props": { "y": 472, "x": 139, "skin": "ui/img_UM_ui_7day_bianjiao.png" }, "compId": 622 }, { "type": "Image", "props": { "y": 472, "x": 1143, "skin": "ui/img_UM_ui_7day_bianjiao.png", "scaleX": -1 }, "compId": 623 }, { "type": "SignObj5", "props": { "y": 403, "x": -430, "runtime": "ui.test.SignObj5UI" }, "compId": 626 }, { "type": "SignObj4", "props": { "y": -51, "x": -430, "runtime": "ui.test.SignObj4UI" }, "compId": 627 }, { "type": "SignObj6", "props": { "y": 865, "x": -421, "runtime": "ui.test.SignObj6UI" }, "compId": 628 }, { "type": "SignObj5", "props": { "y": 125, "x": 731, "runtime": "ui.test.SignObj5UI" }, "compId": 629 }, { "type": "SignObj6", "props": { "y": 123, "x": 731, "runtime": "ui.test.SignObj6UI" }, "compId": 630 }], "loadList": ["ui/img_UM_ui_bg5.jpg", "ui/img_UM_pause_btn_blue.png", "ui/img_UM_icon_exit.png", "ui/img_UM_ui_uibk.png", "ui/img_UM_ui_uibk2.png", "ui/img_UM_btn_BlueButton_2.png", "ui/img_UM_ui_text17.png", "ui/img_UM_ui_7day_bianjiao.png", "ui/img_UM_ui_7day_tou.png", "ui/img_UM_btn_YellowButton_1.png", "ui/img_UM_ui_text46.png"], "loadList3D": [] };
            test.SignDay1UI = SignDay1UI;
            REG("ui.test.SignDay1UI", SignDay1UI);
            class SignObj1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignObj1UI.uiView);
                }
            }
            SignObj1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 230 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 134, "x": 136, "width": 167, "skin": "ui/img_UM_rank_jlbg2.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 221, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": 49, "x": 24, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1784 }, { "type": "Image", "props": { "y": 174, "x": 24, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1785 }, { "type": "Label", "props": { "y": 169, "x": -2, "wordWrap": true, "width": 183, "valign": "middle", "text": "金币红包x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Image", "props": { "y": 21, "x": 42, "width": 95, "skin": "ui/img_UM_ui_text_sign1.png", "height": 28 }, "compId": 1791 }, { "type": "Image", "props": { "y": 5, "x": 6, "width": 167, "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "height": 219, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 95, "x": 19, "skin": "ui/img_UM_ui_text36.png" }, "compId": 1787 }, { "type": "Image", "props": { "y": 7, "x": 139.5, "width": 31, "skin": "ui/img_UM_ui_tick.png", "height": 33 }, "compId": 1789 }], "loadList": ["ui/img_UM_rank_jlbg2.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_ui_text_sign1.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_text36.png", "ui/img_UM_ui_tick.png"], "loadList3D": [] };
            test.SignObj1UI = SignObj1UI;
            REG("ui.test.SignObj1UI", SignObj1UI);
            class SignObj2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignObj2UI.uiView);
                }
            }
            SignObj2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 230 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 134, "x": 136, "width": 167, "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 221, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": 49, "x": 24, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1784 }, { "type": "Image", "props": { "y": 174, "x": 24, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1785 }, { "type": "Label", "props": { "y": 169, "x": -2, "wordWrap": true, "width": 183, "valign": "middle", "text": "金币红包x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Image", "props": { "y": 21, "x": 44.5, "width": 95, "skin": "ui/img_UM_ui_text_sign1.png", "height": 28 }, "compId": 1791 }, { "type": "Image", "props": { "y": 5, "x": 6, "width": 167, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 219, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 95, "x": 19, "skin": "ui/img_UM_ui_text37.png" }, "compId": 1787 }, { "type": "Image", "props": { "y": 7, "x": 139.5, "width": 31, "skin": "ui/img_UM_ui_lock2.png", "height": 33 }, "compId": 1789 }], "loadList": ["ui/img_UM_rank_jlbg3.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_ui_text_sign1.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_text37.png", "ui/img_UM_ui_lock2.png"], "loadList3D": [] };
            test.SignObj2UI = SignObj2UI;
            REG("ui.test.SignObj2UI", SignObj2UI);
            class SignObj3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignObj3UI.uiView);
                }
            }
            SignObj3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 230 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 134, "x": 136, "width": 167, "skin": "ui/img_UM_rank_jlbg1.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 221, "alpha": 1 }, "compId": 1783 }, { "type": "Image", "props": { "y": 49, "x": 24, "width": 131, "skin": "ui/img_UM_box_rankbox1.png", "height": 131 }, "compId": 1784 }, { "type": "Image", "props": { "y": 174, "x": 24, "width": 168, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 44, "alpha": 0.6 }, "compId": 1785 }, { "type": "Label", "props": { "y": 169, "x": -2, "wordWrap": true, "width": 183, "valign": "middle", "text": "金币红包x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 24, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Image", "props": { "y": 5, "x": 6, "width": 167, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 219, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 38.5, "x": -17.5, "width": 95, "skin": "ui/img_UM_ui_text47.png", "rotation": -31, "height": 27 }, "compId": 1787 }, { "type": "Image", "props": { "y": 7, "x": 139.5, "width": 31, "skin": "ui/img_UM_ui_lock2.png", "height": 33 }, "compId": 1789 }, { "type": "Image", "props": { "y": 21, "x": 42, "width": 95, "skin": "ui/img_UM_ui_text_sign1.png", "height": 28 }, "compId": 1791 }], "loadList": ["ui/img_UM_rank_jlbg1.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_text47.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_text_sign1.png"], "loadList3D": [] };
            test.SignObj3UI = SignObj3UI;
            REG("ui.test.SignObj3UI", SignObj3UI);
            class SignObj4UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignObj4UI.uiView);
                }
            }
            SignObj4UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 350, "mouseThrough": true, "height": 450 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 133, "x": 141, "width": 328, "skin": "ui/img_UM_rank_jlbg2.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 444, "alpha": 1 }, "compId": 1791 }, { "type": "Image", "props": { "y": -112, "x": -90, "width": 523, "skin": "ui/img_UM_effect_gold.png", "height": 593, "blendMode": "lighter", "alpha": 0.6 }, "compId": 1799 }, { "type": "Image", "props": { "y": 8, "x": 25, "skin": "ui/img_UM_ui_botemama.png" }, "compId": 1803 }, { "type": "Image", "props": { "y": 18, "x": 85, "skin": "ui/img_UM_ui_text_sign7.png" }, "compId": 1794 }, { "type": "Image", "props": { "y": 317, "x": 30, "width": 301, "skin": "ui/img_UM_ui_7day_text1.png", "height": 48 }, "compId": 1795 }, { "type": "Image", "props": { "y": 366, "x": 30, "width": 188, "skin": "ui/img_UM_ui_7day_text2.png", "height": 59 }, "compId": 1796 }, { "type": "Image", "props": { "y": 357, "x": 216.5, "width": 103, "skin": "ui/img_UM_ui_7day_text3.png", "height": 66 }, "compId": 1797 }, { "type": "Image", "props": { "y": 4, "x": 13, "width": 325, "skin": "ui/img_UM_rank_jlbg_wlq.png", "sizeGrid": "53,45,53,51", "height": 443, "alpha": 0.5 }, "compId": 1800 }, { "type": "Image", "props": { "y": 205, "x": 104, "skin": "ui/img_UM_ui_text36.png" }, "compId": 1801 }, { "type": "Image", "props": { "y": 18, "x": 292.5, "width": 31, "skin": "ui/img_UM_ui_tick.png", "height": 33 }, "compId": 1802 }], "loadList": ["ui/img_UM_rank_jlbg2.png", "ui/img_UM_effect_gold.png", "ui/img_UM_ui_botemama.png", "ui/img_UM_ui_text_sign7.png", "ui/img_UM_ui_7day_text1.png", "ui/img_UM_ui_7day_text2.png", "ui/img_UM_ui_7day_text3.png", "ui/img_UM_rank_jlbg_wlq.png", "ui/img_UM_ui_text36.png", "ui/img_UM_ui_tick.png"], "loadList3D": [] };
            test.SignObj4UI = SignObj4UI;
            REG("ui.test.SignObj4UI", SignObj4UI);
            class SignObj5UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignObj5UI.uiView);
                }
            }
            SignObj5UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 350, "mouseThrough": true, "height": 450 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 133, "x": 141, "width": 328, "skin": "ui/img_UM_rank_jlbg3.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 444, "alpha": 1 }, "compId": 1791 }, { "type": "Image", "props": { "y": -112, "x": -90, "width": 523, "skin": "ui/img_UM_effect_gold.png", "height": 593, "blendMode": "lighter", "alpha": 0.6 }, "compId": 1799 }, { "type": "Image", "props": { "y": 8.5, "x": 24.5, "skin": "ui/img_UM_ui_botemama.png" }, "compId": 1800 }, { "type": "Image", "props": { "y": 18, "x": 85, "skin": "ui/img_UM_ui_text_sign7.png" }, "compId": 1794 }, { "type": "Image", "props": { "y": 317, "x": 30, "width": 301, "skin": "ui/img_UM_ui_7day_text1.png", "height": 48 }, "compId": 1795 }, { "type": "Image", "props": { "y": 366, "x": 30, "width": 188, "skin": "ui/img_UM_ui_7day_text2.png", "height": 59 }, "compId": 1796 }, { "type": "Image", "props": { "y": 357, "x": 216.5, "width": 103, "skin": "ui/img_UM_ui_7day_text3.png", "height": 66 }, "compId": 1797 }, { "type": "Image", "props": { "y": 3, "x": 12, "width": 325, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 443, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 15.5, "x": 289.5, "width": 31, "skin": "ui/img_UM_ui_lock2.png", "height": 33 }, "compId": 1789 }, { "type": "Image", "props": { "y": 205, "x": 104, "skin": "ui/img_UM_ui_text37.png" }, "compId": 1787 }], "loadList": ["ui/img_UM_rank_jlbg3.png", "ui/img_UM_effect_gold.png", "ui/img_UM_ui_botemama.png", "ui/img_UM_ui_text_sign7.png", "ui/img_UM_ui_7day_text1.png", "ui/img_UM_ui_7day_text2.png", "ui/img_UM_ui_7day_text3.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_ui_text37.png"], "loadList3D": [] };
            test.SignObj5UI = SignObj5UI;
            REG("ui.test.SignObj5UI", SignObj5UI);
            class SignObj6UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SignObj6UI.uiView);
                }
            }
            SignObj6UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 350, "mouseThrough": true, "height": 450 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 133, "x": 141, "width": 328, "skin": "ui/img_UM_rank_jlbg1.png", "sizeGrid": "53,45,53,51", "pivotY": 130, "pivotX": 130, "height": 444, "alpha": 1 }, "compId": 1791 }, { "type": "Image", "props": { "y": 102, "x": 52, "width": 246, "skin": "ui/img_UM_box_rankbox1.png", "height": 246 }, "compId": 1784 }, { "type": "Image", "props": { "y": 369, "x": 41, "width": 334, "skin": "ui/img_UM_ui_head_namebg.png", "sizeGrid": "20,20,20,20", "scaleY": 0.8, "scaleX": 0.8, "height": 56, "alpha": 0.6 }, "compId": 1785 }, { "type": "Label", "props": { "y": 369, "x": 83, "wordWrap": true, "width": 183, "valign": "middle", "text": "金币红包x4", "strokeColor": "#000000", "stroke": 2, "height": 43, "fontSize": 30, "font": "SimHei", "color": "#ffffff", "bold": true, "align": "center" }, "compId": 1786 }, { "type": "Image", "props": { "y": 32, "x": 85, "skin": "ui/img_UM_ui_text_sign1.png" }, "compId": 1792 }, { "type": "Image", "props": { "y": 3, "x": 12, "width": 325, "skin": "ui/img_UM_rank_jlbg_wdb.png", "sizeGrid": "53,45,53,51", "height": 443, "alpha": 0.5 }, "compId": 1788 }, { "type": "Image", "props": { "y": 15.5, "x": 289.5, "width": 31, "skin": "ui/img_UM_ui_lock2.png", "height": 33 }, "compId": 1789 }, { "type": "Image", "props": { "y": -112, "x": -90, "width": 523, "skin": "ui/img_UM_effect_gold.png", "height": 593, "blendMode": "lighter", "alpha": 0.6 }, "compId": 1799 }, { "type": "Image", "props": { "y": 6, "x": 25, "skin": "ui/img_UM_ui_botemama.png" }, "compId": 1801 }, { "type": "Image", "props": { "y": 205, "x": 104, "skin": "ui/img_UM_ui_text43.png" }, "compId": 1787 }, { "type": "Image", "props": { "y": 18, "x": 85, "skin": "ui/img_UM_ui_text_sign7.png" }, "compId": 1794 }, { "type": "Image", "props": { "y": 317, "x": 30, "width": 301, "skin": "ui/img_UM_ui_7day_text1.png", "height": 48 }, "compId": 1795 }, { "type": "Image", "props": { "y": 366, "x": 30, "width": 188, "skin": "ui/img_UM_ui_7day_text2.png", "height": 59 }, "compId": 1796 }, { "type": "Image", "props": { "y": 357, "x": 216.5, "width": 103, "skin": "ui/img_UM_ui_7day_text3.png", "height": 66 }, "compId": 1797 }, { "type": "Image", "props": { "y": 45, "x": -19, "skin": "ui/img_UM_ui_text47.png", "rotation": -31 }, "compId": 1800 }], "loadList": ["ui/img_UM_rank_jlbg1.png", "ui/img_UM_box_rankbox1.png", "ui/img_UM_ui_head_namebg.png", "ui/img_UM_ui_text_sign1.png", "ui/img_UM_rank_jlbg_wdb.png", "ui/img_UM_ui_lock2.png", "ui/img_UM_effect_gold.png", "ui/img_UM_ui_botemama.png", "ui/img_UM_ui_text43.png", "ui/img_UM_ui_text_sign7.png", "ui/img_UM_ui_7day_text1.png", "ui/img_UM_ui_7day_text2.png", "ui/img_UM_ui_7day_text3.png", "ui/img_UM_ui_text47.png"], "loadList3D": [] };
            test.SignObj6UI = SignObj6UI;
            REG("ui.test.SignObj6UI", SignObj6UI);
            class SkilliconUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(SkilliconUI.uiView);
                }
            }
            SkilliconUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 150, "mouseThrough": true, "height": 200 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": -1, "x": 3, "skin": "ui/img_UM_btn_purple.png" }, "compId": 1171 }, { "type": "Image", "props": { "y": 32, "x": 28, "width": 93, "skin": "ui/img_UM_hero_skill_icon1.png", "height": 89 }, "compId": 1170 }, { "type": "Label", "props": { "y": 136, "x": 21, "width": 108, "text": "技能名称", "strokeColor": "#404040", "stroke": 2, "height": 22, "fontSize": 22, "font": "SimHei", "color": "#ffffff", "align": "center" }, "compId": 1172 }], "loadList": ["ui/img_UM_btn_purple.png", "ui/img_UM_hero_skill_icon1.png"], "loadList3D": [] };
            test.SkilliconUI = SkilliconUI;
            REG("ui.test.SkilliconUI", SkilliconUI);
            class TrialHeroUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TrialHeroUI.uiView);
                }
            }
            TrialHeroUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 80, "x": 154, "skin": "ui/img_UM_SponsorWall.png" }, "compId": 1152 }, { "type": "Image", "props": { "y": 551, "x": 713, "skin": "ui/img_UM_ui_obj7.png" }, "compId": 1145 }, { "type": "Image", "props": { "y": 17, "x": 130, "skin": "ui/img_UM_ui_text6.png" }, "compId": 1143 }, { "type": "TrialHeroAnim1", "props": { "y": -9, "x": 544.5, "runtime": "ui.test.TrialHeroAnim1UI" }, "compId": 1178 }, { "type": "BtnLjsy", "props": { "y": 508, "x": 280.5, "scaleY": 1.3, "scaleX": 1.3, "runtime": "ui.test.BtnLjsyUI" }, "compId": 1151 }, { "type": "TrialHeroAnim2", "props": { "y": 214, "x": 185.5, "runtime": "ui.test.TrialHeroAnim2UI" }, "compId": 1179 }, { "type": "TrialHeroAnim3", "props": { "y": 223, "x": 345, "runtime": "ui.test.TrialHeroAnim3UI" }, "compId": 1180 }, { "type": "TrialHeroAnim3", "props": { "y": 355, "x": 345, "runtime": "ui.test.TrialHeroAnim3UI" }, "compId": 1181 }, { "type": "NothanksBtn", "props": { "y": 618, "x": 290, "runtime": "ui.test.NothanksBtnUI" }, "compId": 1182 }], "loadList": ["ui/img_UM_SponsorWall.png", "ui/img_UM_ui_obj7.png", "ui/img_UM_ui_text6.png"], "loadList3D": [] };
            test.TrialHeroUI = TrialHeroUI;
            REG("ui.test.TrialHeroUI", TrialHeroUI);
            class TrialHeroAnim1UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TrialHeroAnim1UI.uiView);
                }
            }
            TrialHeroAnim1UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 700, "mouseThrough": true, "height": 700 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 350, "x": 370, "width": 904, "skin": "ui/img_UM_effect_zi.png", "pivotY": 451, "pivotX": 472, "height": 902, "blendMode": "lighter", "alpha": 0.7 }, "compId": 1170 }], "animations": [{ "nodes": [{ "target": 1170, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1170, "key": "rotation", "index": 100 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_effect_zi.png"], "loadList3D": [] };
            test.TrialHeroAnim1UI = TrialHeroAnim1UI;
            REG("ui.test.TrialHeroAnim1UI", TrialHeroAnim1UI);
            class TrialHeroAnim2UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TrialHeroAnim2UI.uiView);
                }
            }
            TrialHeroAnim2UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 180, "mouseThrough": true, "height": 300 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 150, "x": 90, "width": 163, "skin": "ui/img_UM_herokill_bg_zi.png", "pivotY": 149, "pivotX": 82, "height": 298, "blendMode": "lighter" }, "compId": 1178 }, { "type": "Image", "props": { "y": 16, "x": 20, "width": 140, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "height": 267, "alpha": 0.6 }, "compId": 1179 }, { "type": "Image", "props": { "y": 22, "x": 26, "width": 128, "var": "img_hero", "skin": "ui/img_UM_herohead_big.png", "name": "img_hero", "height": 256 }, "compId": 1180 }, { "type": "Image", "props": { "y": 1, "x": 4, "skin": "ui/img_UM_hero_text1.png" }, "compId": 1181 }], "animations": [{ "nodes": [{ "target": 1178, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleY", "index": 0 }, { "value": 1.05, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "label": null, "key": "scaleY", "index": 10 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleX", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleX", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "label": null, "key": "scaleX", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png", "ui/img_UM_black.png", "ui/img_UM_herohead_big.png", "ui/img_UM_hero_text1.png"], "loadList3D": [] };
            test.TrialHeroAnim2UI = TrialHeroAnim2UI;
            REG("ui.test.TrialHeroAnim2UI", TrialHeroAnim2UI);
            class TrialHeroAnim3UI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TrialHeroAnim3UI.uiView);
                }
            }
            TrialHeroAnim3UI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 350, "mouseThrough": true, "height": 150 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 75, "x": 175, "width": 361, "skin": "ui/img_UM_herokill_bg_zi.png", "pivotY": 70, "pivotX": 181, "height": 139, "blendMode": "lighter", "alpha": 1 }, "compId": 1188 }, { "type": "Image", "props": { "y": 17, "x": 9, "width": 332, "skin": "ui/img_UM_ui_obj8.png", "sizeGrid": "30,30,30,30", "height": 120 }, "compId": 1183 }, { "type": "Image", "props": { "y": 7, "x": 9, "width": 96, "skin": "ui/img_UM_btn_purple.png", "height": 135 }, "compId": 1184 }, { "type": "Image", "props": { "y": 35, "x": 25, "width": 64, "var": "img_ico", "skin": "ui/img_UM_hero_skill_icon1.png", "name": "img_ico", "height": 61 }, "compId": 1185 }, { "type": "Label", "props": { "y": 25, "x": 143, "wordWrap": false, "width": 143, "var": "txt_name", "valign": "middle", "text": "技能名称", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_name", "height": 35, "fontSize": 26, "font": "SimHei", "color": "#e2b0ff", "bold": true, "align": "center" }, "compId": 1186 }, { "type": "Label", "props": { "y": 57, "x": 105, "wordWrap": true, "width": 226, "var": "txt_info", "valign": "middle", "text": "技能描述内容", "strokeColor": "#0d0d0d", "stroke": 4, "name": "txt_info", "height": 29, "fontSize": 20, "font": "SimHei", "color": "#aaaaaa", "bold": true, "align": "left" }, "compId": 1187 }], "animations": [{ "nodes": [{ "target": 1188, "keyframes": { "scaleY": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleY", "index": 0 }, { "value": 1.06, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "label": null, "key": "scaleY", "index": 10 }], "scaleX": [{ "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleX", "index": 0 }, { "value": 1.03, "tweenMethod": "linearNone", "tween": true, "target": 1188, "key": "scaleX", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1188, "label": null, "key": "scaleX", "index": 10 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_herokill_bg_zi.png", "ui/img_UM_ui_obj8.png", "ui/img_UM_btn_purple.png", "ui/img_UM_hero_skill_icon1.png"], "loadList3D": [] };
            test.TrialHeroAnim3UI = TrialHeroAnim3UI;
            REG("ui.test.TrialHeroAnim3UI", TrialHeroAnim3UI);
            class TrialHeroUIUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(TrialHeroUIUI.uiView);
                }
            }
            TrialHeroUIUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 1280, "mouseThrough": true, "height": 720 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 360, "x": 640, "width": 1280, "skin": "ui/img_UM_black.png", "sizeGrid": "8,8,8,8", "pivotY": 279, "pivotX": 640, "height": 558, "alpha": 0.3 }, "compId": 1178 }, { "type": "ShiyongHero", "props": { "y": 360, "x": 640, "width": 1280, "pivotY": 360, "pivotX": 640, "height": 720, "runtime": "ui.test.ShiyongHeroUI" }, "compId": 1179 }], "animations": [{ "nodes": [{ "target": 1179, "keyframes": { "scaleY": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1179, "key": "scaleY", "index": 0 }, { "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1179, "label": null, "key": "scaleY", "index": 6 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1179, "key": "scaleY", "index": 10 }, { "value": 0.9, "tweenMethod": "linearNone", "tween": true, "target": 1179, "key": "scaleY", "index": 13 }, { "value": 1.03, "tweenMethod": "linearNone", "tween": true, "target": 1179, "key": "scaleY", "index": 17 }, { "value": 0.95, "tweenMethod": "linearNone", "tween": true, "target": 1179, "key": "scaleY", "index": 21 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1179, "key": "scaleY", "index": 25 }] } }, { "target": 1178, "keyframes": { "scaleY": [{ "value": 0.1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleY", "index": 0 }, { "value": 1.1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleY", "index": 3 }, { "value": 1, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "scaleY", "index": 6 }], "alpha": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "alpha", "index": 0 }, { "value": 0.3, "tweenMethod": "linearNone", "tween": true, "target": 1178, "key": "alpha", "index": 3 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 1 }], "loadList": ["ui/img_UM_black.png"], "loadList3D": [] };
            test.TrialHeroUIUI = TrialHeroUIUI;
            REG("ui.test.TrialHeroUIUI", TrialHeroUIUI);
            class VictoryEffectUI extends View {
                constructor() {
                    super();
                }
                createChildren() {
                    super.createChildren();
                    this.createView(VictoryEffectUI.uiView);
                }
            }
            VictoryEffectUI.uiView = { "type": "View", "props": { "y": 0, "x": 0, "width": 520, "mouseThrough": true, "height": 520 }, "compId": 2, "child": [{ "type": "Image", "props": { "y": 260, "x": 260, "width": 520, "skin": "ui/img_UM_effect_gold.png", "pivotY": 260, "pivotX": 260, "height": 519, "blendMode": "lighter", "alpha": 0.7 }, "compId": 1240 }], "animations": [{ "nodes": [{ "target": 1240, "keyframes": { "rotation": [{ "value": 0, "tweenMethod": "linearNone", "tween": true, "target": 1240, "key": "rotation", "index": 0 }, { "value": 360, "tweenMethod": "linearNone", "tween": true, "target": 1240, "key": "rotation", "index": 100 }] } }], "name": "ani1", "id": 1, "frameRate": 24, "action": 2 }], "loadList": ["ui/img_UM_effect_gold.png"], "loadList3D": [] };
            test.VictoryEffectUI = VictoryEffectUI;
            REG("ui.test.VictoryEffectUI", VictoryEffectUI);
        })(test = ui.test || (ui.test = {}));
    })(ui || (ui = {}));

    class BattleAimAnmimationView extends ui.battle.BattleAimAnimationUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class BattleAimAnmimationViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleAimAnmimationView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.vo = this.data.vo;
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.close);
            TimerUtil.loopFrame(1, this, this.posHandler);
            this.posHandler();
        }
        posHandler() {
            if (this.vo.isDie) {
                this.ui.visible = false;
                return;
            }
            var playerVo = SceneModel.model.vo.playerVo;
            var monV4 = Display3DUtil.worldToViewportPoint(SceneModel.model.camera, this.vo.x, this.vo.y + 2.5, this.vo.z);
            this.ui.x = monV4.x;
            this.ui.y = monV4.y;
            var dis = DisplayUtil.distance(playerVo.x, playerVo.z, this.vo.x, this.vo.z);
            if (dis > 60) {
                dis = 60;
            }
            var scale = 1 - dis / 60;
            if (scale < 0.2) {
                scale = 0.1;
            }
            else if (scale > 0.8) {
                scale = 0.8;
            }
            this.ui.scale(scale, scale);
            var dir = Display3DUtil.angle(this.vo.x, this.vo.z, playerVo.x, playerVo.z);
            var diff = DisplayUtil.angleDiff(dir, playerVo.dir);
            if (diff < 90 && diff > -90) {
                this.ui.visible = true;
            }
            else {
                this.ui.visible = false;
            }
        }
    }

    class SoundConfig {
    }
    SoundConfig.soundFormat = '.mp3';
    SoundConfig.musicFormat = '.mp3';

    class CommonEvent {
    }
    CommonEvent.PROMPT_VIEW_SHOW = 'PROMPT_VIEW_SHOW';
    CommonEvent.ALERT_VIEW_SHOW = 'ALERT_VIEW_SHOW';
    CommonEvent.NOTICE_VIEW_SHOW = 'NOTICE_VIEW_SHOW';
    CommonEvent.LOG_VIEW_SHOW = 'LOG_VIEW_SHOW';
    CommonEvent.TEXT_COPY_VIEW_SHOW = 'TEXT_COPY_VIEW_SHOW';
    CommonEvent.TIPS_VIEW_SHOW = 'TIPS_VIEW_SHOW';
    CommonEvent.OPEN_URL_VIEW_SHOW = 'OPEN_URL_VIEW_SHOW';
    CommonEvent.VIDEO_VIEW_SHOW = 'VIDEO_VIEW_SHOW';
    CommonEvent.PARTICLE_VIEW_SHOW = 'PARTICLE_VIEW_SHOW';
    CommonEvent.BANGS_VIEW_SHOW = 'BANGS_VIEW_SHOW';
    CommonEvent.VIBRATE_START = 'VIBRATE_START';
    CommonEvent.WINDOW_FOCUS = 'WINDOW_FOCUS';
    CommonEvent.QUEUE_EVENT_UNSHIFT = 'QUEUE_EVENT_UNSHIFT';
    CommonEvent.QUEUE_EVENT_ADD = 'QUEUE_EVENT_ADD';

    class SoundTool {
        static playSound(sound, volume = 0, checkTime = 0) {
            if (this.pause) {
                return;
            }
            if (this.soundPause) {
                return;
            }
            if (sound) {
                var url = "sound/" + sound + SoundConfig.soundFormat;
                if (checkTime) {
                    var t = TimeUtil.getLocalTime();
                    if (t - this.lastSoundTime < checkTime) {
                        return;
                    }
                    this.lastSoundTime = t;
                }
                if (this.soundList.length >= 9) {
                    var sc = this.soundList.shift();
                    if (sc) {
                        sc.stop();
                    }
                }
                var c = Laya.SoundManager.playSound(url, 1);
                if (c) {
                    if (volume == 0) {
                        volume = this.soundVolume;
                    }
                    c.volume = volume;
                    this.soundList.push(c);
                }
            }
        }
        static setSoundVolume(v) {
            this.soundVolume = v;
        }
        static playMusic(sound = null) {
            this.musicSound = sound;
            if (this.pause) {
                return;
            }
            if (this.musicPause) {
                return;
            }
            LogTool.log("playMusic:" + sound);
            this.stopMusic();
            this.musicSound = sound;
            var url = "sound/" + sound + SoundConfig.musicFormat;
            this.musicUrl = url;
            if (sound) {
                this.musicChannel = Laya.SoundManager.playSound(this.musicUrl, 0);
                if (this.musicChannel) {
                    this.musicChannel.volume = this.musicVolume;
                }
            }
            if (this.isFirst) {
                this.isFirst = false;
                ControllerManager.root.addEventListener(CommonEvent.WINDOW_FOCUS, this, this.resumeMusic);
                Laya.stage.once(Laya.Event.CLICK, this, this.resumeMusic);
            }
        }
        static stopMusic() {
            LogTool.log("stopMusic");
            if (this.musicChannel) {
                this.musicChannel.pause();
                this.musicChannel.stop();
                this.musicChannel = null;
            }
            if (this.musicUrl) {
                Laya.SoundManager.stopSound(this.musicUrl);
                this.musicUrl = '';
                this.musicSound = '';
            }
        }
        static checkMusic() {
            if (this.musicChannel) {
                if (this.pause || this.musicPause) {
                    this.musicChannel.pause();
                }
                else {
                    this.musicChannel.resume();
                }
            }
            else {
                this.resumeMusic();
            }
        }
        static resumeMusic() {
            if (this.musicSound) {
                this.playMusic(this.musicSound);
            }
        }
        static setMusicVolume(v) {
            this.musicVolume = v;
            if (this.musicChannel) {
                this.musicChannel.volume = v;
            }
        }
        static setPause(key, bool) {
            if (bool) {
                this.pauseLib[key] = true;
                this.pause = true;
            }
            else {
                delete this.pauseLib[key];
                this.pause = this.checkPause();
            }
            this.checkMusic();
        }
        static getPause(key) {
            return MathUtil.bool(this.pauseLib[key]);
        }
        static checkPause() {
            for (var k in this.pauseLib) {
                return true;
            }
            return false;
        }
        static setMusicPause(key, bool) {
            if (bool) {
                this.musicPauseLib[key] = true;
                this.musicPause = true;
            }
            else {
                delete this.musicPauseLib[key];
                this.musicPause = this.checkMuiscPause();
            }
            this.checkMusic();
        }
        static getMusicPause(key) {
            return MathUtil.bool(this.musicPauseLib[key]);
        }
        static checkMuiscPause() {
            if (this.pause) {
                return true;
            }
            for (var k in this.musicPauseLib) {
                return true;
            }
            return false;
        }
        static setSoundPause(key, bool) {
            if (bool) {
                this.soundPauseLib[key] = true;
                this.soundPause = true;
            }
            else {
                delete this.soundPauseLib[key];
                this.soundPause = this.checkSoundPause();
            }
        }
        static getSoundPause(key) {
            return MathUtil.bool(this.soundPauseLib[key]);
        }
        static checkSoundPause() {
            if (this.pause) {
                return true;
            }
            for (var k in this.soundPauseLib) {
                return true;
            }
            return false;
        }
    }
    SoundTool.lastSoundTime = 0;
    SoundTool.soundVolume = 1;
    SoundTool.soundList = [];
    SoundTool.musicVolume = 1;
    SoundTool.isFirst = true;
    SoundTool.pauseLib = {};
    SoundTool.pause = false;
    SoundTool.musicPauseLib = {};
    SoundTool.musicPause = false;
    SoundTool.soundPauseLib = {};
    SoundTool.soundPause = false;

    class ViewConfig {
    }
    ViewConfig.PANEL_ANIM_OPEN = null;
    ViewConfig.PANEL_ANIM_CLOSE = null;
    ViewConfig.PANEL_SOUND_OPEN = 'open';
    ViewConfig.PANEL_SOUND_CLOSE = 'close';
    ViewConfig.DIALOG_ANIM_OPEN = null;
    ViewConfig.DIALOG_ANIM_CLOSE = null;
    ViewConfig.DIALOG_SOUND_OPEN = 'open';
    ViewConfig.DIALOG_SOUND_CLOSE = 'close';

    class PanelAnim extends Laya.EventDispatcher {
        constructor() {
            super();
            this.time = 350;
        }
        play() {
        }
        stop() {
        }
        complete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class AlphaInAnim extends PanelAnim {
        constructor() {
            super();
        }
        play() {
            this.view.alpha = 0;
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { alpha: 1 }, this.time, Laya.Ease.linearOut, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class AlphaOutAnim extends PanelAnim {
        constructor() {
            super();
        }
        play() {
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { alpha: 0 }, this.time, Laya.Ease.linearIn, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class DownInAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            this.view.y = -Laya.stage.height;
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { y: 0 }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class DownOutAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartIn;
        }
        play() {
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { y: Laya.stage.height }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class FrameInAnim extends PanelAnim {
        constructor() {
            super();
            this.anim = null;
            this.animName = 'ani_open';
        }
        play() {
            if (this.anim) {
                this.anim.stop();
            }
            this.anim = this.view[this.animName];
            this.anim.on(Laya.Event.COMPLETE, this, this.openAnimComplete);
            this.anim.play(0, false);
        }
        stop() {
            if (this.anim) {
                this.anim.stop();
            }
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class FrameOutAnim extends PanelAnim {
        constructor() {
            super();
            this.anim = null;
            this.animName = 'ani_close';
        }
        play() {
            if (this.anim) {
                this.anim.stop();
            }
            this.anim = this.view[this.animName];
            this.anim.on(Laya.Event.COMPLETE, this, this.openAnimComplete);
            this.anim.play(0, false);
        }
        stop() {
            if (this.anim) {
                this.anim.stop();
            }
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class HorizontalInAnim extends PanelAnim {
        constructor() {
            super();
            this.dir = 0;
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            this.dir = ParamUtil.getInt(this.data, 'animDir');
            if (this.dir >= 0) {
                this.view.x = -Laya.stage.width;
            }
            else {
                this.view.x = Laya.stage.width;
            }
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { x: 0 }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class HorizontalInAnim$1 extends PanelAnim {
        constructor() {
            super();
            this.dir = 0;
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            this.dir = ParamUtil.getInt(this.data, 'animDir');
            if (this.dir >= 0) {
                var tx = Laya.stage.width;
            }
            else {
                var tx = -Laya.stage.width;
            }
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { x: tx }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class LeftInAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            this.view.x = -Laya.stage.width;
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { x: 0 }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class LeftOutAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { x: -Laya.stage.width }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class RightInAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            this.view.x = Laya.stage.width;
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { x: 0 }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class RightOutAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { x: Laya.stage.width }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class UpInAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartOut;
        }
        play() {
            this.view.y = Laya.stage.height;
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { y: 0 }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class UpOutAnim extends PanelAnim {
        constructor() {
            super();
            this.ease = Laya.Ease.quartIn;
        }
        play() {
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { y: -Laya.stage.height }, this.time, this.ease, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class ZoomInAnim extends PanelAnim {
        constructor() {
            super();
            this.x = 'NaN';
            this.y = 'NaN';
        }
        play() {
            if (this.x == 'NaN') {
                this.x = StageUtil.stageWidth / 2;
            }
            if (this.y == 'NaN') {
                this.y = StageUtil.stageHeight / 2;
            }
            this.view.pivotX = this.view.width / 2;
            this.view.pivotY = this.view.height / 2;
            this.view.x = this.x;
            this.view.y = this.y;
            this.view.scaleX = this.view.scaleY = 0;
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { scaleX: 1, scaleY: 1 }, this.time, Laya.Ease.backOut, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class ZoomOutAnim extends PanelAnim {
        constructor() {
            super();
        }
        play() {
            Laya.Tween.clearAll(this.view);
            Laya.Tween.to(this.view, { scaleX: 0, scaleY: 0 }, this.time, Laya.Ease.linearIn, HandlerUtil.create(this, this.openAnimComplete));
        }
        stop() {
            Laya.Tween.clearAll(this.view);
        }
        openAnimComplete() {
            this.event(Laya.Event.COMPLETE);
        }
    }

    class ViewAnimTool {
        static getViewAnim(type, data = null) {
            var anim = null;
            if (type == 'AlphaIn') {
                anim = new AlphaInAnim();
            }
            else if (type == 'AlphaOut') {
                anim = new AlphaOutAnim();
            }
            else if (type == 'DownIn') {
                anim = new DownInAnim();
            }
            else if (type == 'DownOut') {
                anim = new DownOutAnim();
            }
            else if (type == 'UpIn') {
                anim = new UpInAnim();
            }
            else if (type == 'UpOut') {
                anim = new UpOutAnim();
            }
            else if (type == 'LeftIn') {
                anim = new LeftInAnim();
            }
            else if (type == 'LeftOut') {
                anim = new LeftOutAnim();
            }
            else if (type == 'RightIn') {
                anim = new RightInAnim();
            }
            else if (type == 'RightOut') {
                anim = new RightOutAnim();
            }
            else if (type == 'HorizontalIn') {
                anim = new HorizontalInAnim();
            }
            else if (type == 'HorizontalOut') {
                anim = new HorizontalInAnim$1();
            }
            else if (type == 'ZoomIn') {
                anim = new ZoomInAnim();
            }
            else if (type == 'ZoomOut') {
                anim = new ZoomOutAnim();
            }
            else if (type == 'FrameIn') {
                anim = new FrameInAnim();
            }
            else if (type == 'FrameOut') {
                anim = new FrameOutAnim();
            }
            if (data && anim) {
                ObjectUtil.copy(data, anim);
            }
            return anim;
        }
    }

    class PanelViewController extends ViewController {
        constructor() {
            super();
            this.isShowOpenAnim = true;
            this.isShowCloseAnim = true;
            this.openSound = 'open';
            this.closeSound = 'close';
            this.isShow = false;
            this.changeMouseEnabled = false;
            this.openSound = ViewConfig.PANEL_SOUND_OPEN;
            this.closeSound = ViewConfig.PANEL_SOUND_CLOSE;
            this.openAnim = ViewAnimTool.getViewAnim(ViewConfig.PANEL_ANIM_OPEN);
            this.closeAnim = ViewAnimTool.getViewAnim(ViewConfig.PANEL_ANIM_CLOSE);
        }
        openComplete() {
            super.openComplete();
            if (this.isAutoShow) {
                this.showOpenAnim();
            }
        }
        showOpenAnim() {
            this.showView();
            this.isShowOpenAnim = ParamUtil.getBool(this.data, 'isShowOpenAnim', true);
            this.isShowCloseAnim = ParamUtil.getBool(this.data, 'isShowCloseAnim', true);
            if (this.isShow == false) {
                this.isShow = true;
                this.stopAnim();
                if (this.isShowOpenAnim) {
                    if (this.view instanceof Laya.Sprite) {
                        this.view.visible = false;
                    }
                    TimerUtil.callLater(this, this.playOpenAinm);
                }
            }
        }
        playOpenAinm() {
            if (this.isShow == true) {
                if (this.view instanceof Laya.Sprite) {
                    this.view.visible = true;
                }
                this.stopAnim();
                if (this.openAnim && this.view) {
                    this.openAnim.on(Laya.Event.COMPLETE, this, this.openAnimComplete);
                    this.openAnim.view = this.view;
                    this.openAnim.data = this.data;
                    this.openAnim.play();
                }
                else {
                    this.openAnimComplete();
                }
                SoundTool.playSound(this.openSound);
            }
        }
        openAnimComplete() {
            if (this.view instanceof Laya.Sprite && this.changeMouseEnabled) {
                this.view.mouseEnabled = true;
            }
        }
        closeView() {
            if (this.view instanceof Laya.Sprite && this.view.mouseEnabled) {
                this.changeMouseEnabled = true;
                this.view.mouseEnabled = false;
            }
            this.isShow = false;
            this.stopAnim();
            if (this.view && this.isShowCloseAnim) {
                if (this.closeAnim && this.view) {
                    this.closeAnim.on(Laya.Event.COMPLETE, this, this.closeAnimComplete);
                    this.closeAnim.view = this.view;
                    this.closeAnim.data = this.data;
                    this.closeAnim.play();
                    Laya.timer.once(this.closeAnim.time, this, this.closeAnimComplete);
                }
                else {
                    Laya.timer.callLater(this, this.closeAnimComplete);
                }
                SoundTool.playSound(this.closeSound);
            }
            else {
                Laya.timer.callLater(this, this.closeAnimComplete);
            }
        }
        closeAnimComplete() {
            if (!this.view) {
                return;
            }
            if (this.view.parent == null) {
                return;
            }
            super.closeView();
        }
        stopAnim() {
            Laya.timer.clear(this, this.closeAnimComplete);
            if (this.openAnim) {
                this.openAnim.stop();
            }
            if (this.closeAnim) {
                this.closeAnim.stop();
            }
        }
    }

    class BattleAntikillTipView extends ui.battle.BattleAntikillTipUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleAntikillTipViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = BattleAntikillTipView;
            this.openAnim = ViewAnimTool.getViewAnim('ZoomIn');
            this.closeAnim = ViewAnimTool.getViewAnim('ZoomOut');
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.mouseEnabled = false;
                TimerUtil.onceTimer(1500, this, this.close);
            }
        }
    }

    class BattleAttTextView extends ui.battle.BattleAttTextUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleAttTextViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleAttTextView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var vo = this.data.vo;
            var atter = this.data.atter;
            var att = this.data.att;
            this.ui.txt_att.text = '' + att;
            this.setPos(vo);
            TimerUtil.onceTimer(300, this, this.close);
        }
        setPos(vo) {
            if (vo.isPlayer) {
                this.ui.x = StageUtil.stageWidth / 2;
                this.ui.y = 700;
            }
            else {
                var monV4 = Display3DUtil.worldToViewportPoint(SceneModel.model.camera, vo.x, vo.y, vo.z);
                this.ui.x = monV4.x;
                this.ui.y = monV4.y - 50;
            }
        }
    }

    class TweenController extends Controller {
        constructor() {
            super();
            this.list = {};
        }
        stop() {
            this.stopAllTween();
            super.stop();
        }
        stopAllTween() {
            for (var k in this.list) {
                var t = this.list[k];
                t.clear();
            }
            this.list = {};
        }
        stopTween(t) {
            this.removeTween(t);
            t.clear();
        }
        removeTween(t) {
            var id = t['__tweenId'];
            if (this.list[id]) {
                delete this.list[id];
            }
        }
        to(c, target, props, duration, ease, complete, arg, delay, coverBefore, autoRecover) {
            var compHandler = () => {
                this.removeTween(t);
                if (complete != null) {
                    complete.apply(c, arg);
                }
            };
            var t = Laya.Tween.to(target, props, duration, ease, HandlerUtil.create(this, compHandler), delay, coverBefore, autoRecover);
            var id = t['__tweenId'] = IdUtil.getId();
            this.list[id] = t;
            return t;
        }
    }

    class TweenUtil {
        static getTween(c) {
            var tween = c.getChild('tween');
            if (!tween) {
                tween = new TweenController();
                tween.id = 'tween';
                c.startChild(tween);
            }
            return tween;
        }
        static to(c, target, props, duration, ease, complete, arg, delay, coverBefore, autoRecover = false) {
            var tc = this.getTween(c);
            var tween = tc.to(c, target, props, duration, ease, complete, arg, delay, coverBefore, autoRecover);
            return tween;
        }
        static clean(c, tweem) {
            var tc = this.getTween(c);
            tc.stopTween(tweem);
        }
        static stopAllTween(c) {
            var tc = this.getTween(c);
            tc.stopAllTween();
        }
    }

    class BattleBoxFloatView extends ui.battle.BattleBoxFloatUI {
        constructor() {
            super();
            this.zOrder = 200;
        }
    }

    class BattleBoxFloatViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleBoxFloatView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var vo = ParamUtil.getObject(this.data, 'vo');
            var sx = ParamUtil.getInt(this.data, 'sx', 0);
            var sy = ParamUtil.getInt(this.data, 'sy', 0);
            var tx = ParamUtil.getInt(this.data, 'tx', 0);
            var ty = ParamUtil.getInt(this.data, 'ty', 0);
            var scale = ParamUtil.getInt(this.data, 'scale', 1);
            this.ui.x = sx;
            this.ui.y = sy;
            this.ui.scaleX = scale;
            this.ui.scaleY = scale;
            TweenUtil.to(this, this.ui, { x: tx, y: ty }, 1000, Laya.Ease.quadOut, this.endHander);
        }
        endHander() {
            this.close();
        }
    }

    class ModalView extends Laya.Box {
        constructor() {
            super();
            this.width = 720;
            this.height = 1280;
            this.top = 0;
            this.left = 0;
            this.right = 0;
            this.bottom = 0;
            this.mouseEnabled = true;
            Laya.stage.on(Laya.Event.RESIZE, this, this.resizeHandler);
            this.resizeHandler();
        }
        resizeHandler() {
            this.graphics.clear();
            this.graphics.drawRect(-100, -100, Laya.stage.width + 200, Laya.stage.height + 200, 0);
        }
        close() {
            Laya.stage.off(Laya.Event.RESIZE, this, this.resizeHandler);
            this.removeSelf();
        }
    }

    class DialogViewController extends PanelViewController {
        constructor() {
            super();
            this.isModal = true;
            this.modalClickClose = false;
            this.modalOpenAnimTime = 350;
            this.modalCloseAnimTime = 350;
            this.modalAlpha = 0.75;
            this.openSound = ViewConfig.DIALOG_SOUND_OPEN;
            this.closeSound = ViewConfig.DIALOG_SOUND_CLOSE;
            this.openAnim = ViewAnimTool.getViewAnim(ViewConfig.DIALOG_ANIM_OPEN);
            this.closeAnim = ViewAnimTool.getViewAnim(ViewConfig.DIALOG_ANIM_CLOSE);
        }
        showOpenAnim() {
            super.showOpenAnim();
            if (this.isModal) {
                if (!this.modalView) {
                    this.modalView = new ModalView();
                    this.modalView.alpha = 0;
                    if (this.view instanceof Laya.Sprite) {
                        this.modalView.zOrder = this.view.zOrder;
                    }
                    this.modalView.on(Laya.Event.CLICK, this, () => { LogUtil.log("DialogViewController.modalView.click:" + this.viewName); });
                }
                this.modalView.removeSelf();
                var i = this.parentView.getChildIndex(this.view);
                this.parentView.addChildAt(this.modalView, i);
                this.playModalOpen(this.modalAlpha);
            }
        }
        close() {
            this.playModalClose();
            super.close();
        }
        playModalOpen(alpha = 1) {
            if (this.modalView) {
                TweenUtil.to(this, this.modalView, { alpha: alpha }, this.modalOpenAnimTime, Laya.Ease.cubicInOut, this.playModalOpenHandler, null, 0, true);
            }
        }
        playModalOpenHandler() {
            if (this.modalClickClose) {
                this.modalView.on(Laya.Event.CLICK, this, this.close);
            }
        }
        playModalClose() {
            if (this.modalView) {
                TweenUtil.to(this, this.modalView, { alpha: 0 }, this.modalCloseAnimTime, Laya.Ease.cubicInOut, this.removeModalHandler, null, 0, true);
                Laya.timer.once(this.modalCloseAnimTime, this, this.removeModalHandler);
            }
        }
        removeModalHandler() {
            if (this.modalView) {
                this.modalView.close();
            }
        }
    }

    class PromptType {
    }
    PromptType.PROMPT_NULL = 'PROMPT_NULL';
    PromptType.PROMPT_OK = 'PROMPT_OK';
    PromptType.PROMPT_INFO = 'PROMPT_INFO';
    PromptType.PROMPT_WARNING = 'PROMPT_WARNING';
    PromptType.PROMPT_ERROR = 'PROMPT_ERROR';
    PromptType.PROMPT_BANNED = 'PROMPT_BANNED';

    class MouseTool {
        static init() {
            Laya.stage.on(Laya.Event.MOUSE_DOWN, this, this.mouseDownHandler);
        }
        static mouseDownHandler() {
            this.x = Laya.stage.mouseX;
            this.y = Laya.stage.mouseY;
            this.downTime = TimeUtil.getTime();
        }
        static checkClick(e = null, name = '') {
            if (Math.abs(Laya.stage.mouseX - this.x) > 20) {
                return false;
            }
            if (Math.abs(Laya.stage.mouseY - this.y) > 20) {
                return false;
            }
            if (e && name && e.target.name != name) {
                return false;
            }
            return true;
        }
        static checkDoubleClick(target) {
            if (TimeUtil.getTime() - this.doubleClickTime < 400) {
                if (this.checkClick()) {
                    return true;
                }
            }
            this.doubleClickTime = TimeUtil.getTime();
            return false;
        }
        static checkLongClick() {
            if (TimeUtil.getTime() - this.downTime > 500) {
                if (this.checkClick()) {
                    return true;
                }
            }
            return false;
        }
        static getTouches(view, e, touchId = 0) {
            var list = [];
            if (e.touches) {
                list = e.touches;
            }
            else {
                list = [{ mouseX: view.mouseX, mouseY: view.mouseY }];
            }
            return list[touchId];
        }
    }
    MouseTool.downTime = 0;
    MouseTool.doubleClickTime = 0;

    class ViewDataTool {
        static setDataSource(view, data) {
            for (var k in data) {
                if (k in view) {
                    var box = view[k];
                    if (box instanceof Laya.View) {
                        box.dataSource = data[k];
                    }
                    else if (box instanceof Laya.UIComponent) {
                        box.dataSource = data[k];
                    }
                }
            }
        }
        static getDataValue(view, key = 'vo') {
            if (!view) {
                return null;
            }
            if ('dataSource' in view) {
            }
            else {
                return null;
            }
            var data = view.dataSource;
            if (!data) {
                return null;
            }
            return data[key];
        }
    }

    class GoodsCostTool {
        static checkCost(cid, num) {
            var hasNum = GoodsModel.model.getGoodsNum(cid);
            if (num < 0) {
                num = -num;
            }
            if (hasNum >= num) {
                return true;
            }
            return false;
        }
        static checkCostConfig(config) {
            return this.checkCost(config.cid, config.num);
        }
        static checkCostList(list) {
            for (var item of list) {
                if (this.checkCostConfig(item) == false) {
                    return item;
                }
            }
            return null;
        }
        static checkCostListName(list) {
            for (var item of list) {
                if (this.checkCostConfig(item) == false) {
                    return GoodsVoBuilder.getGoodsName(item.cid);
                }
            }
            return null;
        }
        static setCostLabel(text, cost, okColor = "#ffffff", noColor = "#ff0000") {
            if (!cost.cid) {
                cost = cost[0];
            }
            if (this.checkCost(cost.cid, cost.num)) {
                text.color = okColor;
            }
            else {
                text.color = noColor;
            }
            text.text = cost.num;
        }
        static setNumLabel(text, num, numMax, okColor = "#ffffff", noColor = "#ff0000") {
            if (num >= numMax) {
                text.color = okColor;
            }
            else {
                text.color = noColor;
            }
            text.text = num + '/' + numMax;
        }
        static getCostNum(list) {
            if (list.num) {
                return list.num;
            }
            var co = list[0];
            if (co.num) {
                return co.num;
            }
            return 0;
        }
    }

    class ViewDataType {
        static get ON() { return { visible: true }; }
        ;
        static get OFF() { return { visible: false }; }
        ;
    }

    class GoodsPartConfig {
        static getPartAttr(cid, stype) {
            if (stype == 1) {
                return this.partDis[cid];
            }
            else if (stype == 2) {
                return this.partV[cid];
            }
            else if (stype == 3) {
                return this.partNum[cid];
            }
            return '';
        }
    }
    GoodsPartConfig.partDis = {
        30041501: { value: 0.05, money: 100, },
        30041502: { value: 0.06, money: 100, },
        30041503: { value: 0.05, money: 100, },
        30041504: { value: 0.06, money: 150, },
        30041505: { value: 0.07, money: 200, },
        30041506: { value: 0.07, money: 200, },
        30041507: { value: 0.07, money: 200, },
        30041508: { value: 0.07, money: 200, },
        30041509: { value: 0.07, money: 200, },
        30041510: { value: 0.08, money: 250, },
        30041511: { value: 0.09, money: 250, },
        30041512: { value: 0.08, money: 250, },
        30041513: { value: 0.09, money: 250, },
        30041514: { value: 0.08, money: 250, },
        30041515: { value: 0.1, money: 300, },
        30041516: { value: 0.09, money: 300, },
        30041517: { value: 0.10, money: 300, },
        30041518: { value: 0.10, money: 300, },
        30041519: { value: 0.10, money: 300, },
        30041520: { value: 0.10, money: 300, },
    };
    GoodsPartConfig.partV = {
        30041501: { value: 0.10, money: 150, },
        30041502: { value: 0.10, money: 150, },
        30041503: { value: 0.10, money: 150, },
        30041504: { value: 0.09, money: 200, },
        30041505: { value: 0.08, money: 200, },
        30041506: { value: 0.06, money: 250, },
        30041507: { value: 0.06, money: 250, },
        30041508: { value: 0.06, money: 250, },
        30041509: { value: 0.06, money: 250, },
        30041510: { value: 0.04, money: 300, },
        30041511: { value: 0.04, money: 300, },
        30041512: { value: 0.04, money: 300, },
        30041513: { value: 0.04, money: 300, },
        30041514: { value: 0.04, money: 300, },
        30041515: { value: 0.02, money: 350, },
        30041516: { value: 0.03, money: 350, },
        30041517: { value: 0.02, money: 350, },
        30041518: { value: 0.02, money: 350, },
        30041519: { value: 0.02, money: 350, },
        30041520: { value: 0.02, money: 350, },
    };
    GoodsPartConfig.partNum = {
        30041501: { value: 2, money: 200, },
        30041502: { value: 1, money: 200, },
        30041503: { value: 2, money: 200, },
        30041504: { value: 6, money: 250, },
        30041505: { value: 8, money: 250, },
        30041506: { value: 9, money: 300, },
        30041507: { value: 9, money: 300, },
        30041508: { value: 9, money: 300, },
        30041509: { value: 9, money: 300, },
        30041510: { value: 9, money: 350, },
        30041511: { value: 4, money: 350, },
        30041512: { value: 3, money: 350, },
        30041513: { value: 4, money: 350, },
        30041514: { value: 3, money: 350, },
        30041515: { value: 16, money: 400, },
        30041516: { value: 4, money: 400, },
        30041517: { value: 6, money: 400, },
        30041518: { value: 6, money: 400, },
        30041519: { value: 6, money: 400, },
        30041520: { value: 6, money: 400, },
    };

    class GoodsType {
    }
    GoodsType.GOODS_TYPE_USER = 10;
    GoodsType.GOODS_TYPE_PLAYER = 11;
    GoodsType.GOODS_TYPE_ATTR = 20;
    GoodsType.GOODS_TYPE_ELEMENT = 30;
    GoodsType.GOODS_TYPE_SKILL = 40;
    GoodsType.GOODS_TYPE_EQUIP = 50;
    GoodsType.GOODS_TYPE_SKIN = 51;
    GoodsType.GOODS_TYPE_MATE = 60;
    GoodsType.GOODS_TYPE_GIFT = 80;
    GoodsType.GOODS_STYPE_ARMS = 11;
    GoodsType.GOODS_STYPE_SHIELD = 12;
    GoodsType.GOODS_STYPE_HELNET = 21;
    GoodsType.GOODS_STYPE_CLOTHES = 22;
    GoodsType.GOODS_STYPE_TROU = 23;
    GoodsType.GOODS_STYPE_GLOVE = 24;
    GoodsType.GOODS_STYPE_SHOES = 25;
    GoodsType.GOODS_STYPE_BELT = 26;
    GoodsType.GOODS_STYPE_NECK = 31;
    GoodsType.GOODS_STYPE_RING = 32;
    GoodsType.GOODS_STYPE_RONA = 33;
    GoodsType.GOODS_STYPE_DADGE = 34;
    GoodsType.GOODS_STYPE_ROLE = 1;
    GoodsType.GOODS_STYPE_MON = 3;
    GoodsType.GOODS_STYPE_EQUIP = 4;
    GoodsType.GOODS_STYPE_BOX = 5;
    GoodsType.GOODS_LIB_ALL = 0;
    GoodsType.GOODS_LIB_ATTR = 1;
    GoodsType.GOODS_LIB_BAG = 11;
    GoodsType.GOODS_LIB_EQUIP = 21;

    class GoodsViewTool {
        static getGoodsData(goods, isSelf = true) {
            var data = { visible: true };
            if (goods) {
                data.cid = goods.cid;
                data.vo = goods;
                data.txt_name = goods.name;
                data.img_ico = "res/ico/" + goods.ico + ".png";
                data.img_img = "res/image/" + goods.ico + ".png";
                data.txt_num = "";
                data.img_lock = ViewDataType.OFF;
                data.img_isNew = ViewDataType.OFF;
                data.guideName = 'goods_' + goods.cid;
                data.img_perm = ViewDataType.OFF;
                if (goods.lib != GoodsType.GOODS_LIB_ATTR) {
                    if (goods.lv) {
                        data.txt_lv = "Lv." + goods.lv;
                    }
                    else {
                        data.txt_lv = "";
                    }
                }
                else {
                    data.txt_lv = "";
                }
                if (goods.type == GoodsType.GOODS_TYPE_ELEMENT) {
                    if (goods.count == 0) {
                        data.img_perm = ViewDataType.ON;
                    }
                    else {
                        data.img_perm = ViewDataType.OFF;
                    }
                }
                else {
                    data.img_perm = ViewDataType.OFF;
                }
                if (goods.type == GoodsType.GOODS_TYPE_ELEMENT) {
                    if (goods.isNew == true) {
                        data.img_isNew = ViewDataType.ON;
                    }
                    else {
                        data.img_isNew = ViewDataType.OFF;
                    }
                }
                else {
                    data.img_isNew = ViewDataType.OFF;
                }
                if (isSelf == false) {
                    data.img_lock = ViewDataType.OFF;
                    data.img_loc = ViewDataType.OFF;
                    data.txt_num = goods.num;
                    data.gray = false;
                    data.alpha = 1;
                    data.txt_state = "";
                }
                else if (goods.isHas) {
                    data.gray = false;
                    data.alpha = 1;
                    if (goods.loc) {
                        data.txt_state = "已装备";
                    }
                    else {
                        data.txt_state = "";
                    }
                }
                else {
                    data.txt_state = "";
                    data.img_lock = ViewDataType.ON;
                    data.img_loc = ViewDataType.OFF;
                    data.img_isNew = ViewDataType.OFF;
                    data.gray = true;
                    data.alpha = 0.5;
                }
            }
            else {
                data.txt_name = '';
                data.img_ico = '';
                data.txt_lv = "";
                data.txt_num = "";
                data.img_lock = ViewDataType.OFF;
                data.img_loc = ViewDataType.OFF;
                data.img_isNew = ViewDataType.OFF;
            }
            return data;
        }
        static getGoodsRewardData(item) {
            var ogoods = GoodsVoBuilder.createGoodsVo(item);
            var odata = this.getGoodsData(ogoods, false);
            return odata;
        }
        static getGoodsRewardListData(list) {
            var llist = [];
            for (var key in list) {
                var co = list[key];
                var item = this.getGoodsRewardData(co);
                llist.push(item);
            }
            return llist;
        }
        static getIcoUrl(cid) {
            if (!cid) {
                return '';
            }
            var obj = GoodsListConfig.list[cid];
            if (obj) {
                return GoodsConfig.getIcoUrl(obj.ico);
            }
            return '';
        }
        static getIconUrl(cid) {
            if (!cid) {
                return '';
            }
            var obj = GoodsListConfig.list[cid];
            if (obj) {
                return GoodsConfig.getIconUrl(obj.ico);
            }
            return '';
        }
        static getImgUrl(cid) {
            if (!cid) {
                return '';
            }
            var obj = GoodsListConfig.list[cid];
            if (obj) {
                return GoodsConfig.getImgUrl(obj.image);
            }
            return '';
        }
        static getIcoData(cid) {
            var url = this.getIcoUrl(cid);
            if (url) {
                var data = ViewDataType.ON;
                data.img_ico = url;
                return data;
            }
            return ViewDataType.OFF;
        }
        static getPartAttr(cid, partCid) {
            var goodsVo = GoodsVoBuilder.getGoodsVo(partCid);
            var attr = GoodsPartConfig.getPartAttr(cid, goodsVo.stype);
            if (goodsVo.stype == 1) {
                return goodsVo.info + '+' + MathUtil.int(attr.value * 100) + '%';
            }
            else if (goodsVo.stype == 2) {
                return goodsVo.info + '+' + MathUtil.int(attr.value * 100) + '%';
            }
            else if (goodsVo.stype == 3) {
                return goodsVo.info + '+' + attr.value;
            }
            return '';
        }
    }

    class PageEvent {
    }
    PageEvent.PAGE_VIEW_SHOW = 'PAGE_VIEW_SHOW';
    PageEvent.PAGE_COMPLETE_VIEW_SHOW = 'PAGE_COMPLETE_VIEW_SHOW';
    PageEvent.PAGE_STORE_VIEW_SHOW = 'PAGE_STORE_VIEW_SHOW';
    PageEvent.PAGE_GIFT_VIEW_SHOW = 'PAGE_GIFT_VIEW_SHOW';
    PageEvent.PAGE_SKIN_VIEW_SHOW = 'PAGE_SKIN_VIEW_SHOW';
    PageEvent.PAGE_PROGRESS_VIEW_SHOW = 'PAGE_PROGRESS_VIEW_SHOW';
    PageEvent.PAGE_UP_VIEW_SHOW = 'PAGE_UP_VIEW_SHOW';
    PageEvent.PAGE_EXPORT_VIEW_SHOW = 'PAGE_EXPORT_VIEW_SHOW';
    PageEvent.PAGE_LOAD_VIEW_SHOW = 'PAGE_LOAD_VIEW_SHOW';
    PageEvent.PAGE_SHARE_VIEW_SHOW = 'PAGE_SHARE_VIEW_SHOW';
    PageEvent.PAGE_COLLECTION_VIEW_SHOW = 'PAGE_COLLECTION_VIEW_SHOW';
    PageEvent.PAGE_GET_JIN_RESPONSE = 'PAGE_GET_JIN_RESPONSE';
    PageEvent.PAGE_GET_TONG_RESPONSE = 'PAGE_GET_TONG_RESPONSE';
    PageEvent.PAGE_FAIL_VIEW_SHOW = 'PAGE_FAIL_VIEW_SHOW';
    PageEvent.PAGE_BEFORE_COMPLETE_VIEW_SHOW = 'PAGE_BEFORE_COMPLETE_VIEW_SHOW';
    PageEvent.PAGE_BATTLE_START = 'PAGE_BATTLE_START';
    PageEvent.PAGE_COMPLETE_VIEW_END = 'PAGE_COMPLETE_VIEW_END';
    PageEvent.PAGE_GIFT_OPEN = 'PAGE_GIFT_OPEN';
    PageEvent.PAGE_VIEW_BUTTON_SHOW = 'PAGE_VIEW_BUTTON_SHOW';
    PageEvent.PAGE_GOLD_GUN_GET_SHOW = 'PAGE_GOLD_GUN_GET_SHOW';
    PageEvent.PAGE_LOTTERY_TIP_SHOW = 'PAGE_LOTTERY_TIP_SHOW';
    PageEvent.PAGE_SIGN_TIP_SHOW = 'PAGE_SIGN_TIP_SHOW';
    PageEvent.PAGE_REWARD_VIEW_SHOW = 'PAGE_REWARD_VIEW_SHOW';
    PageEvent.PAGE_GOLD_GUN_TYPE = 'PAGE_GOLD_GUN_TYPE';
    PageEvent.PAGE_VIEW_REFRESH = 'PAGE_VIEW_REFRESH';
    PageEvent.PAGE_GET_CHEST_RESPONSE = 'PAGE_GET_CHEST_RESPONSE';
    PageEvent.PAGE_GET_CHEST_REQUEST = 'PAGE_GET_CHEST_REQUEST';
    PageEvent.PAGE_GET_GIFT_RESPONSE = 'PAGE_GET_GIFT_RESPONSE';
    PageEvent.PAGE_GET_GIFT_REQUEST = 'PAGE_GET_GIFT_REQUEST';
    PageEvent.PAGE_VOIDE_BTN_SHOW = 'PAGE_VOIDE_BTN_SHOW';

    class BattleCardGroupView extends ui.battle.BattleCardGrondUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleCardGroupViewController extends DialogViewController {
        constructor() {
            super();
            this.battleType = 1;
            this.viewClass = BattleCardGroupView;
            this.viewName = 'BattleCardGroupView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.box_start.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.ui_list1.on(Laya.Event.CLICK, this, this.selectHeroHandler);
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 1);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showLocHero);
            this.setList1();
            this.setList2();
            this.showLocHero();
        }
        showLocHero() {
            var goods = GoodsModel.model.getFirstByType(30, 9, 1, 1);
            if (goods) {
                this.ui.ui_palyer.txt_name.text = goods.name;
                this.ui.ui_palyer.img_img.skin = GoodsViewTool.getImgUrl(goods.cid);
                BattleModel.model.playerCid = goods.cid;
            }
            else {
                var vo = SceneVoBuilder.getElementVo(BattleModel.model.playerCid);
                this.ui.ui_palyer.txt_name.text = vo.name;
                this.ui.ui_palyer.img_img.skin = GoodsViewTool.getImgUrl(vo.cid);
            }
            this.setList2();
        }
        setList1() {
            var list = SceneConfig.npcList;
            var nlist = [];
            var index = 2;
            for (var cid of list) {
                var vo = SceneVoBuilder.getElementVo(cid);
                var item = {};
                item.txt_name = '玩家' + index;
                item.img_img = 'ui/img_UM_ui_herohead.png';
                nlist.push(item);
                index++;
            }
            this.ui.ui_list.dataSource = nlist;
        }
        setList2() {
            var list = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            var nlist = [];
            for (var k in list) {
                var vo = list[k];
                var item = {};
                item.txt_name = vo.name;
                item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                if (vo.loc == 1) {
                    item.img_use = { skin: 'ui/img_UM_btn_BlueButton_2.png' };
                    item.img_use2 = { skin: 'ui/img_UM_ui_text15.png', x: 48 };
                }
                else {
                    item.img_use = { skin: 'ui/img_UM_btn_YellowButton_1.png', vo: vo };
                    item.img_use2 = { skin: 'ui/img_UM_ui_text7.png', vo: vo, x: 60 };
                }
                nlist.push(item);
            }
            this.ui.ui_list1.dataSource = nlist;
        }
        okHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType });
            this.close();
        }
        selectHeroHandler(e) {
            if (MouseTool.checkClick(e, 'img_use') || MouseTool.checkClick(e, 'img_use2')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    var card = e.target.parent;
                    var sp = DisplayUtil.localToGlobal(card, new Laya.Point());
                    var tp = DisplayUtil.localToGlobal(this.ui.ui_palyer, new Laya.Point());
                    this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: vo.id });
                    this.dispatchEvent(GoodsEvent.GOODS_CARD_FLOAT_VIEW_SHOW, { vo: vo, sx: sp.x, sy: sp.y, tx: tp.x, ty: tp.y, showType: ViewType.NEW });
                }
            }
        }
    }

    class ProgressBarViewTool {
        static getBarDataSource(n, m) {
            var txt = n + '/' + m;
            if (m == 0) {
                return { progress_bar: { visible: false, value: 0 }, progress_txt: txt, progress_full: ViewDataType.OFF };
            }
            if (n >= m) {
                return { progress_bar: ViewDataType.OFF, progress_txt: txt, progress_full: ViewDataType.ON };
            }
            else {
                return { progress_bar: { visible: true, value: n / m }, progress_txt: txt, progress_full: ViewDataType.OFF };
            }
        }
        static getProgressImageDataSource(n, m) {
            var value = MathUtil.int(n) / MathUtil.int(m);
            if (m == 0) {
                return { scaleX: 0 };
            }
            if (n >= m) {
                return { scaleX: 1 };
            }
            else {
                return { scaleX: value };
            }
        }
        static getBarValue(n, m) {
            if (m == 0) {
                return 0;
            }
            if (n >= m) {
                return 1;
            }
            else {
                return n / m;
            }
        }
        static setRectBarValue(bar, v) {
            if (!bar) {
                return;
            }
            if (bar.destroyed) {
                return;
            }
            if (v < 0) {
                v = 0;
            }
            if (v > 1) {
                v = 1;
            }
            var w = bar.width * v;
            var h = bar.height;
            var rec = bar.scrollRect || new Laya.Rectangle(0, 0, w, h);
            rec.width = w;
            bar.scrollRect = rec;
        }
        static setPieBarValue(bar, v, startAngle = 0) {
            if (!bar) {
                return;
            }
            if (bar.destroyed) {
                return;
            }
            if (v < 0) {
                v = 0;
            }
            if (v > 1) {
                v = 1;
            }
            if (bar.mask) {
                var cMask = bar.mask;
            }
            else {
                var cMask = new Laya.Sprite();
            }
            var startAng = startAngle - 90;
            var endAng = MathUtil.int(360 * v + startAngle - 90);
            cMask.graphics.clear();
            cMask.graphics.drawPie(bar.width / 2, bar.height / 2, bar.width, startAng, endAng, "#fff");
            bar.mask = cMask;
        }
    }

    class BattleBattleCrazyChest1View extends ui.battle.BattleCrazyChest1UI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class BattleCrazyChest1ViewController extends DialogViewController {
        constructor() {
            super();
            this.isEnd = false;
            this.viewClass = BattleBattleCrazyChest1View;
            this.viewName = 'BattleBattleCrazyChestView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.num = 0;
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.MOUSE_DOWN, this, this.okHandler);
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                TimerUtil.loopFrame(1, this, this.subNumHandler);
                this.ui.btn_get.visible = false;
                this.ui.img_bar.visible = true;
                this.ui.btn_ok.visible = true;
            }
            this.showData();
        }
        okHandler() {
            this.num += 10;
            this.showData();
            this.checkNumMax();
        }
        getRwHandler() {
            this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "获得宝箱" });
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_BANNER_SHOW, { showType: ViewType.CLOSE });
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: this.data.cid, battleType: this.data.battleType, isTry: false });
            this.getReward();
            this.close();
        }
        checkNumMax() {
            var nums = RandomUtil.randomInt(30, 70);
            LogTool.log('checkNumMax:' + nums);
            LogTool.log('checkNumMax:' + this.num);
            if (this.isEnd == false && this.num >= nums) {
                this.isEnd = true;
                this.success();
            }
        }
        subNumHandler() {
            if (this.num > 0) {
                this.num -= 0.5;
                if (this.num < 0) {
                    this.num = 0;
                }
                this.showData();
            }
        }
        success() {
            if (AdModel.model.isShieldCity == false) {
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_BANNER_SHOW, { showType: ViewType.OPEN });
                TimerUtil.onceTimer(3000, this, this.showBtn);
            }
            else {
                this.showBtn();
            }
        }
        showBtn() {
            this.ui.btn_get.visible = true;
            this.ui.img_bar.visible = false;
            this.ui.btn_ok.visible = false;
        }
        showData() {
            ProgressBarViewTool.setRectBarValue(this.ui.bar_num, this.num / 100);
            this.showPross();
        }
        showPross() {
            var num = MathUtil.int(this.num);
            if (num >= 100) {
                this.ui.txt_num.text = 100 + '%';
            }
            else {
                this.ui.txt_num.text = num + '%';
            }
        }
        getReward() {
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: 20010001, num: 100 }], showType: 2 });
        }
    }

    class BattleBattleCrazyChestView extends ui.battle.BattleCrazyChestUI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class BattleCrazyChestViewController extends DialogViewController {
        constructor() {
            super();
            this.isEnd = false;
            this.viewClass = BattleBattleCrazyChestView;
            this.viewName = 'BattleBattleCrazyChestView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.num = 0;
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.MOUSE_DOWN, this, this.okHandler);
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                TimerUtil.loopFrame(1, this, this.subNumHandler);
                this.ui.btn_get.visible = false;
                this.ui.img_bar.visible = true;
                this.ui.btn_ok.visible = true;
            }
            this.showData();
        }
        okHandler() {
            this.num += 10;
            this.showData();
            this.checkNumMax();
        }
        getRwHandler() {
            this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "获得宝箱" });
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_BANNER_SHOW, { showType: ViewType.CLOSE });
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: this.data.cid, battleType: this.data.battleType, isTry: false });
            this.getReward();
            this.close();
        }
        checkNumMax() {
            var nums = RandomUtil.randomInt(30, 70);
            LogTool.log('checkNumMax:' + nums);
            LogTool.log('checkNumMax:' + this.num);
            if (this.isEnd == false && this.num >= nums) {
                this.isEnd = true;
                this.success();
            }
        }
        subNumHandler() {
            if (this.num > 0) {
                this.num -= 0.5;
                if (this.num < 0) {
                    this.num = 0;
                }
                this.showData();
            }
        }
        success() {
            if (AdTool.checkRate('wudian')) {
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_BANNER_SHOW, { showType: ViewType.OPEN });
                TimerUtil.onceTimer(3000, this, this.showBtn);
            }
            else {
                this.showBtn();
            }
        }
        showBtn() {
            this.ui.btn_get.visible = true;
            this.ui.img_bar.visible = false;
            this.ui.btn_ok.visible = false;
        }
        showData() {
            ProgressBarViewTool.setRectBarValue(this.ui.bar_num, this.num / 100);
            this.showPross();
        }
        showPross() {
            var num = MathUtil.int(this.num);
            if (num >= 100) {
                this.ui.txt_num.text = 100 + '%';
            }
            else {
                this.ui.txt_num.text = num + '%';
            }
        }
        getReward() {
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: 20010001, num: 100 }], showType: 2 });
        }
    }

    class BattleDefeat1View extends ui.battle.BattleDefeat1UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeat1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeat1View;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.subTriphy();
            this.showbtn();
            SoundTool.playSound('defeat');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleDefeat2View extends ui.battle.BattleDefeat2UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeat2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeat2View;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.subTriphy();
            this.showbtn();
            SoundTool.playSound('defeat');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleDefeat3View extends ui.battle.BattleDefeat3UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeat3ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeat3View;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.subTriphy();
            this.showbtn();
            SoundTool.playSound('defeat');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleDefeat4View extends ui.battle.BattleDefeat4UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeat4ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeat4View;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.subTriphy();
            SoundTool.playSound('defeat');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleDefeat5View extends ui.battle.BattleDefeat5UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeat5ViewController extends DialogViewController {
        constructor() {
            super();
            this.btnEnble = true;
            this.viewClass = BattleDefeat5View;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.subTriphy();
            if (AdTool.checkRate('wzsy', true)) {
                this.ui.ui_anim.txt_one.x = 559;
                this.btnEnble = false;
                TimerUtil.onceTimer(1400, this, () => {
                    this.showBtn();
                    this.btnEnble = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.x = 110;
            }
            SoundTool.playSound('defeat');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (this.btnEnble) {
                if (BattleModel.model.battleType == 3) {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
                }
                else {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
                }
                this.close();
                this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
                this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
                BattleModel.model.isSettlement = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        showBtn() {
            this.ui.ui_anim.txt_one.x = 110;
        }
    }

    class BattleDefeat6View extends ui.battle.BattleDefeat6UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeat6ViewController extends DialogViewController {
        constructor() {
            super();
            this.btnEnble = true;
            this.viewClass = BattleDefeat6View;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.subTriphy();
            SoundTool.playSound('defeat');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (this.btnEnble) {
                if (BattleModel.model.battleType == 3) {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
                }
                else {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
                }
                this.close();
                this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
                this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
                BattleModel.model.isSettlement = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        showBtn() {
            this.ui.ui_anim.txt_one.x = 110;
        }
    }

    class BattleDefeat7View extends ui.battle.BattleDefeat7UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeat7ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeat7View;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
                this.ui.check_ad.on(Laya.Event.CLICK, this, this.checkHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.ui.ui_anim.img_light.visible = false;
            this.ui.ui_anim.box_1.visible = false;
            this.ui.ui_anim.box_2.visible = false;
            this.ui.ui_anim.box_3.y = 294;
            if (AdModel.model.isShieldCity == false) {
                this.ui.ui_anim.img_one.visible = false;
                this.ui.ui_anim.txt_one.visible = true;
            }
            else {
                this.ui.ui_anim.img_one.visible = true;
                this.ui.ui_anim.txt_one.visible = false;
            }
            this.victoryNum = BattleModel.model.victoryNum;
            if (AdTool.checkRate('mrgx', true)) {
                this.ui.check_ad.selected = true;
            }
            else {
                this.ui.check_ad.selected = false;
            }
            this.checkShow();
            this.showMoney();
            this.subTriphy();
            this.showbtn();
            SoundTool.playSound('defeat');
        }
        checkHandler() {
            if (this.ui.check_ad.selected) {
                this.ui.check_ad.selected = false;
            }
            else {
                this.ui.check_ad.selected = true;
            }
            this.checkShow();
        }
        checkShow() {
            if (this.ui.check_ad.selected) {
                this.ui.ui_anim.img_ad.visible = false;
                this.ui.ui_anim.img_get3.x = 63;
            }
            else {
                this.ui.ui_anim.img_ad.visible = true;
                this.ui.ui_anim.img_get3.x = 87;
            }
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleDefeatMvpView extends ui.battle.BattleDefeatMvpUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeatMvpViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeatMvpView;
            this.viewName = 'BattleDefeatMvpView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.addEventListener(SceneEvent.SCENE_END_CAMERA_COMPLETE, this, this.closeHandler);
            this.showInfo();
            this.dispatchEvent(BattleEvent.BATTLE_CLOSE_CLICK);
            SoundTool.playSound('defeat');
        }
        showInfo() {
            var victoryNum = BattleModel.model.victoryNum;
            var nameList = BattleModel.model.nameList;
            var list = SceneModel.model.vo.unitList;
            var enemyList = [];
            var enemyNameList = [];
            for (var k in list) {
                if (list[k].ttype == 1 && list[k].camp != 1) {
                    var vo = list[k];
                    enemyList.push(vo);
                }
            }
            for (var i = 5; i < 10; i++) {
                enemyNameList.push(nameList[i]);
            }
            var npc = RandomUtil.randomItem(enemyList);
            var name = RandomUtil.randomItem(enemyNameList);
            if (npc) {
                this.ui.ui_npc.txt_name.text = '' + GoodsListConfig.getVo(npc.cid).name;
                this.ui.ui_npc.img_ico.skin = GoodsViewTool.getImgUrl(npc.cid);
            }
            this.ui.txt_kill.text = '' + RandomUtil.randomInt(2, 5);
            this.ui.ui_npc.txt_lv.text = '' + BattleConfig.getNpcLv(victoryNum);
            this.ui.ui_npc.txt_airdrop.text = '' + name;
        }
        closeHandler() {
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_DEFEAT_VIEW_SHOW);
        }
    }

    class BattleDefeatNoticeView extends ui.battle.BattleDefeatNoticeUI {
        constructor() {
            super();
            this.zOrder = 46;
        }
    }

    class BattleDefeatNoticeViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeatNoticeView;
            this.viewName = 'BattleDefeatNoticeView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.vo = SceneModel.model.vo;
            this.ui.txt_kill_1.text = "" + this.vo.teamKillNum;
            this.ui.txt_kill_2.text = "" + this.vo.foeKillNum;
            this.ui.on(Laya.Event.CLICK, this, this.close);
        }
    }

    class BattleDefeatView extends ui.battle.BattleDefeatUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleDefeatViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleDefeatView;
            this.viewName = 'BattleDefeatView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.subTriphy();
            SoundTool.playSound('defeat');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        subTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getDefeatTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = GoodsListConfig.getVo(vo.cid).name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            BattleModel.model.isSettlement = true;
        }
    }

    class BattleEndMysteryBoxView extends ui.battle.BattleEndCrazyChestUI {
        constructor() {
            super();
            this.zOrder = 60;
        }
    }

    class BattleEndCrazyChestViewController extends DialogViewController {
        constructor() {
            super();
            this.isEnd = false;
            this.viewClass = BattleEndMysteryBoxView;
            this.viewName = 'BattleEndMysteryBoxView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.num = 0;
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.MOUSE_DOWN, this, this.okHandler);
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                TimerUtil.loopFrame(1, this, this.subNumHandler);
                this.ui.btn_get.visible = false;
                this.ui.img_bar.visible = true;
                this.ui.btn_ok.visible = true;
            }
            this.showData();
        }
        okHandler() {
            this.num += 10;
            this.showData();
            this.checkNumMax();
        }
        getRwHandler() {
            this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "获得宝箱" });
            this.getReward();
            this.close();
        }
        checkNumMax() {
            var nums = RandomUtil.randomInt(30, 70);
            LogTool.log('checkNumMax:' + nums);
            LogTool.log('checkNumMax:' + this.num);
            if (this.isEnd == false && this.num >= nums) {
                this.isEnd = true;
                this.success();
            }
        }
        subNumHandler() {
            if (this.num > 0) {
                this.num -= 0.5;
                if (this.num < 0) {
                    this.num = 0;
                }
                this.showData();
            }
        }
        success() {
            if (AdTool.checkRate('wudian')) {
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_APPBOX_SHOW);
                TimerUtil.onceTimer(3000, this, this.showBtn);
            }
            else {
                this.showBtn();
            }
        }
        showBtn() {
            this.ui.btn_get.visible = true;
            this.ui.img_bar.visible = false;
            this.ui.btn_ok.visible = false;
        }
        showData() {
            ProgressBarViewTool.setRectBarValue(this.ui.bar_num, this.num / 100);
            this.showPross();
        }
        showPross() {
            var num = MathUtil.int(this.num);
            if (num >= 100) {
                this.ui.txt_num.text = 100 + '%';
            }
            else {
                this.ui.txt_num.text = num + '%';
            }
        }
        getReward() {
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: 20010001, num: 100 }], showType: 2 });
        }
    }

    class BattleEndNoticeView extends ui.battle.BattleEndNoticeUI {
        constructor() {
            super();
            this.zOrder = 46;
        }
    }

    class BattleEndNoticeViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleEndNoticeView;
            this.viewName = 'BattleEndNoticeView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.vo = SceneModel.model.vo;
            this.ui.txt_kill_1.text = "" + this.vo.playerKillNum;
            this.ui.txt_kill_2.text = "" + SceneTool.getPlayerRank();
            this.ui.on(Laya.Event.CLICK, this, this.close);
        }
    }

    class BattleEndView extends ui.battle.BattleEndUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleEndViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleEndView;
            this.viewName = 'BattleEndView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.img_ok.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.showMoney();
            SoundTool.playSound('victory');
        }
        showMoney() {
            this.ui.txt_exp.text = '' + BattleConfig.partExp;
            this.ui.txt_tong.text = '' + BattleConfig.partTong;
            var fullTong = 0;
            if (SceneModel.model.vo.isExit == false) {
                fullTong = BattleConfig.fullTong;
            }
            this.ui.txt_tongFull.text = '' + fullTong;
            var killJin = BattleConfig.killJin * SceneModel.model.vo.playerKillNum;
            this.ui.txt_jinKill.text = '' + killJin;
            var mvpJin = 0;
            if (SceneModel.model.vo.playerKillNum >= 5) {
                mvpJin = BattleConfig.mvpJin;
            }
            this.ui.txt_jinMvp.text = '' + mvpJin;
            this.jin = killJin + mvpJin;
            this.tong = BattleConfig.partTong + fullTong;
            this.exp = BattleConfig.partExp;
            this.ui.txt_expAll.text = '' + this.exp;
            this.ui.txt_jinAll.text = '' + this.jin;
            this.ui.txt_tongAll.text = '' + this.tong;
        }
        closeHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
        }
    }

    class BattleExhaustTipView extends ui.battle.BattleExhaustTipUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleExhaustTipViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleExhaustTipView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                TimerUtil.onceTimer(1500, this, this.close);
            }
        }
    }

    class BattleFullTipView extends ui.battle.BattleFullTipUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleFullTipViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleFullTipView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                TimerUtil.onceTimer(2000, this, this.close);
            }
        }
    }

    class BattlleGameOverView extends ui.battle.BattleGameOverUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleGameOverViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = BattlleGameOverView;
            this.viewName = 'BattlleGameOverView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            TimerUtil.onceTimer(2000, this, this.close);
        }
    }

    class GoodsLvUpConfig {
        static getEquipAtt(lv, att) {
            var att = MathUtil.int(att * (1 + lv * 0.05));
            return att;
        }
    }
    GoodsLvUpConfig.lvMax = 60;

    class SceneAirdropEvent {
    }
    SceneAirdropEvent.SCENE_AIRDROP_ADD = 'SCENE_AIRDROP_ADD';
    SceneAirdropEvent.SCENE_AIRDROP_SHOW = 'SCENE_AIRDROP_SHOW';
    SceneAirdropEvent.SCENE_AIRDROP_REMOVE = 'SCENE_AIRDROP_REMOVE';

    class SceneElementEvent {
        static SCENE_ELEMENT_STOP(id) { return 'SCENE_ELEMENT_STOP@' + id; }
        static SCENE_ELEMENT_CLOSEED(id) { return 'SCENE_ELEMENT_CLOSE@' + id; }
        static SCENE_ELEMENT_RELOAD(id) { return 'SCENE_ELEMENT_RELOAD@' + id; }
        static SCENE_ELEMENT_EFFECT_SHOW(id) { return 'SCENE_ELEMENT_EFFECT_SHOW@' + id; }
        static SCENE_ELEMENT_EFFECT_CLOSE(id) { return 'SCENE_ELEMENT_EFFECT_CLOSE@' + id; }
        static SCENE_ELEMENT_ACTION_ADD(id) { return 'SCENE_ELEMENT_ACTION_ADD@' + id; }
        static SCENE_ELEMENT_ATTR_SET(id) { return 'SCENE_ELEMENT_ATTR_SET@' + id; }
    }
    SceneElementEvent.SCENE_ELEMENT_ADDED = 'SCENE_ELEMENT_ADDED';
    SceneElementEvent.SCENE_ELEMENT_REMOVEED = 'SCENE_ELEMENT_REMOVEED';

    class ScenePlayerEvent {
        static SCENE_PLAYER_PICKUP_CONPLETE(cid) { return 'SCENE_PLAYER_PICKUP_CONPLETE@' + cid; }
    }
    ScenePlayerEvent.SCENE_PLAYER_MOVE = 'SCENE_PLAYER_MOVE';
    ScenePlayerEvent.SCENE_PLAYER_MOVE_STOP = 'SCENE_ROLE_MOVE_STOP';
    ScenePlayerEvent.SCENE_PLAYER_ATT = 'SCENE_PLAYER_ATT';
    ScenePlayerEvent.SCENE_PLAYER_ATT_STOP = 'SCENE_PLAYER_ATT_STOP';
    ScenePlayerEvent.SCENE_PLAYER_DIR = 'SCENE_ROLE_DIR';
    ScenePlayerEvent.SCENE_PLAYER_AIM = 'SCENE_PLAYER_AIM';
    ScenePlayerEvent.SCENE_PLAYER_AIM_CHANGE = 'SCENE_PLAYER_AIM_CHANGE';
    ScenePlayerEvent.SCENE_PLAYER_VIS = 'SCENE_PLAYER_VIS';
    ScenePlayerEvent.SCENE_PLAYER_LOOKAT = 'SCENE_PLAYER_LOOKAT';
    ScenePlayerEvent.SCENE_PLAYER_JUMP = 'SCENE_PLAYER_JUMP';
    ScenePlayerEvent.SCENE_PLAYER_AUTO_AIM_SET = 'SCENE_PLAYER_AUTO_ANIM_SET';
    ScenePlayerEvent.SCENE_PLAYER_LOCK_TARGET = 'SCENE_PLAYER_LOCK_TARGET';
    ScenePlayerEvent.SCENE_PLAYER_SWITCH_AIM = 'SCENE_PLAYER_SWITCH_AIM';
    ScenePlayerEvent.SCENE_PLAYER_COLL_CHANGE = 'SCENE_PLAYER_COLL_CHANGE';
    ScenePlayerEvent.SCENE_PLAYER_GOODS_CHANGE = 'SCENE_PLAYER_GOODS_CHANGE';
    ScenePlayerEvent.SCENE_PLAYER_GUN_CHANGE = 'SCENE_PLAYER_GUN_CHANGE';
    ScenePlayerEvent.SCENE_PLAYER_PICKUP = 'SCENE_PLAYER_PICKUP';
    ScenePlayerEvent.SCENE_PLAYER_PICKUP_RESPONSE = 'SCENE_PLAYER_PICKUP_RESPONSE';
    ScenePlayerEvent.SCENE_PLAYER_ATT_FULL = 'SCENE_PLAYER_ATT_FULL';
    ScenePlayerEvent.SCENE_CIRCLE_CHANGE_TIP = 'SCENE_CIRCLE_CHANGE_TIP';
    ScenePlayerEvent.SCENE_PLAYER_UNPICK = 'SCENE_PLAYER_UNPICK';
    ScenePlayerEvent.SCENE_PLAYER_REVIVE = 'SCENE_PLAYER_REVIVE';
    ScenePlayerEvent.SCENE_PLAYER_SHOCK = 'SCENE_PLAYER_SHOCK';
    ScenePlayerEvent.SCENE_PLAYER_INVIN = 'SCENE_PLAYER_INVIN';
    ScenePlayerEvent.SCENE_PLAYER_VIP_BUFF_ADD = 'SCENE_PLAYER_VIP_BUFF_ADD';
    ScenePlayerEvent.SCENE_PLAYER_BUFF_ADD = 'SCENE_PLAYER_BUFF_ADD';
    ScenePlayerEvent.SCENE_PLAYER_GUN_SHOW = 'SCENE_PLAYER_GUN_SHOW';
    ScenePlayerEvent.SCENE_PLAYER_INVIN_SHOW = 'SCENE_PLAYER_INVIN_SHOW';
    ScenePlayerEvent.SCENE_PLAYER_INVIN_SET = 'SCENE_PLAYER_INVIN_SET';
    ScenePlayerEvent.SCENE_PLAYER_GUN_TRY = 'SCENE_PLAYER_GUN_TRY';
    ScenePlayerEvent.SCENE_PLAYER_GOODS_USE = 'SCENE_PLAYER_GOODS_USE';
    ScenePlayerEvent.SCENE_PLAYER_GOODS_CHEANGE = 'SCENE_PLAYER_GOODS_CHEANGE';
    ScenePlayerEvent.SCENE_PLAYER_ACTION_STOP = 'SCENE_PLAYER_ACTION_STOP';
    ScenePlayerEvent.SCENE_PLAYER_AIM_ATT = 'SCENE_PLAYER_AIM_ATT';
    ScenePlayerEvent.SCENE_PLAYEER_SELECT = 'SCENE_PLAYEER_SELECT';
    ScenePlayerEvent.SCENE_PLAYEER_RELPACE = 'SCENE_PLAYEER_RELPACE';
    ScenePlayerEvent.SCENE_PLAYEER_CHANGE = 'SCENE_PLAYEER_CHANGE';

    class BattleGetGunView extends ui.battle.BattleGetGunUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleGetGunViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleGetGunView;
            this.viewName = 'BattleGetGunView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_use.on(Laya.Event.CLICK, this, this.adHandler);
                this.ui.btn_use1.on(Laya.Event.CLICK, this, this.videoHandler);
            }
            this.showGoods(this.data.vo.cid);
            if (BattleModel.model.aridorpNum == 0) {
                this.ui.btn_use.visible = false;
                this.ui.btn_use1.visible = true;
            }
            else {
                this.ui.btn_use.visible = true;
                this.ui.btn_use1.visible = false;
            }
            BattleModel.model.aridorpNum++;
            this.dispatchEvent(SceneEvent.SCENE_STATE_PAUSE, { isPause: true });
        }
        showGoods(cid) {
            var vo = GoodsVoBuilder.getGoodsVo(cid);
            this.ui.txt_name.text = vo.name;
            this.ui.img_1.skin = GoodsViewTool.getImgUrl(vo.cid);
            var elementVo = SceneVoBuilder.getElementVo(vo.cid);
            if (vo.stype == 1) {
                this.ui.txt_ctype.text = "类型: " + GoodsConfig.getCtypeText(vo.ctype);
                this.ui.txt_attStype.text = "口径: " + GoodsConfig.getGunStypeText(vo.stype);
                this.ui.txt_attBulletMax.text = "弹容: " + MathUtil.int(elementVo.attBulletMax);
                this.ui.txt_attCd.text = "射速: " + MathUtil.number(elementVo.attCd / 1000) + "秒";
                this.ui.txt_attAcc.text = "精度: " + MathUtil.number(elementVo.attAcc);
                this.ui.txt_attBulletTime.text = '换弹: ' + MathUtil.number(elementVo.attBulletTime / 1000) + "秒";
                this.ui.txt_att.text = "伤害: " + GoodsLvUpConfig.getEquipAtt(vo.lv, elementVo.att);
            }
            else {
                if (vo.stype == 2) {
                    this.ui.txt_attCd.text = "杀伤力" + MathUtil.int(elementVo.attPro * 100) + "%";
                    this.ui.txt_ctype.text = "类型: 头盔";
                }
                else {
                    this.ui.txt_ctype.text = "类型: 防弹衣";
                    this.ui.txt_attCd.text = "血量值" + MathUtil.int(elementVo.hpPro * 100) + "%";
                }
                this.ui.txt_attStype.text = "";
                this.ui.txt_attBulletMax.text = "";
                this.ui.txt_quality.text = "";
                this.ui.txt_att.text = "血量: " + GoodsLvUpConfig.getEquipAtt(vo.lv, elementVo.hp);
                this.ui.txt_attAcc.text = "";
                this.ui.txt_attBulletTime.text = "";
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.videoHandler);
        }
        videoHandler() {
            this.close();
            var vo = this.data.vo;
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(vo.id));
            this.dispatchEvent(SceneEvent.SCENE_STATE_PAUSE, { isPause: false });
            this.dispatchEvent(SceneAirdropEvent.SCENE_AIRDROP_REMOVE);
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_PICKUP, { vo: vo });
        }
        closeHandler() {
            this.close();
            var vo = this.data.vo;
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(vo.id));
            this.dispatchEvent(SceneEvent.SCENE_STATE_PAUSE, { isPause: false });
            this.dispatchEvent(SceneAirdropEvent.SCENE_AIRDROP_REMOVE);
        }
    }

    class BattleGetVipView extends ui.battle.BattleGetVipUI {
        constructor() {
            super();
            this.zOrder = 31;
        }
    }

    class BattleGetVipViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleGetVipView;
            this.viewName = 'BattleGetVipView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.adHandler);
            }
            BattleModel.model.vipBuff = 0;
        }
        adHandler() {
            AdTool.videoAdShow(this, this.videoHandler);
        }
        videoHandler() {
            this.close();
            BattleModel.model.vipBuff = 1;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_VIP_BUFF_ADD);
        }
    }

    class BattleHpPillView extends ui.battle.BattleHpPillUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class BattleHpPillViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleHpPillView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.vo = this.data.vo;
            if (this.vo.camp == 1) {
                this.ui.img_hp.skin = 'ui/img_UM_hp_p_1.png';
            }
            else {
                this.ui.img_hp.skin = 'ui/img_UM_hp_p_2.png';
            }
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_CLOSEED(this.vo.id), this, this.close);
            this.addEventListener(SceneEvent.SCENE_STATE_END, this, this.close);
            TimerUtil.loopFrame(1, this, this.posHandler);
            this.posHandler();
        }
        posHandler() {
            var playerVo = SceneModel.model.vo.playerVo;
            var monV4 = Display3DUtil.worldToViewportPoint(SceneModel.model.camera, this.vo.x, this.vo.y + 4, this.vo.z);
            this.ui.x = monV4.x;
            this.ui.y = monV4.y;
            var dis = DisplayUtil.distance(playerVo.x, playerVo.z, this.vo.x, this.vo.z);
            if (dis > 100) {
                dis = 100;
            }
            var scale = 1 - dis / 100;
            if (scale < 0.2) {
                scale = 0.2;
            }
            else if (scale > 1) {
                scale = 1;
            }
            this.ui.scale(scale, scale);
            var dir = Display3DUtil.angle(this.vo.x, this.vo.z, playerVo.x, playerVo.z);
            var diff = DisplayUtil.angleDiff(dir, playerVo.dir);
            if (diff < 90 && diff > -90) {
                this.ui.visible = true;
            }
            else {
                this.ui.visible = false;
            }
        }
    }

    class SceneUnitEvent {
        static SCENE_UNIT_ATT(id) { return 'SCENE_UNIT_ATT@' + id; }
        static SCENE_UNIT_ATT_START(id) { return 'SCENE_UNIT_ATT_START@' + id; }
        static SCENE_UNIT_ATT_LAUNCH(id) { return 'SCENE_UNIT_ATT_LAUNCH@' + id; }
        static SCENE_UNIT_ATT_TARGET(id) { return 'SCENE_UNIT_ATT_TARGET@' + id; }
        static SCENE_UNIT_ATT_STOP(id) { return 'SCENE_UNIT_ATT_STOP@' + id; }
        static SCENE_UNIT_GUN_ATT_STOP(id) { return 'SCENE_UNIT_GUN_ATT_STOP@' + id; }
        static SCENE_UNIT_CAMERA_SHOCK(id) { return 'SCENE_UNIT_CAMERA_SHOCK@' + id; }
        static SCENE_UNIT_STATE_SET(id) { return 'SCENE_UNIT_STATE_SET@' + id; }
        static SCENE_UNIT_ANIM_PLAY(id) { return 'SCENE_UNIT_ANIM_PLAY@' + id; }
        static SCENE_UNIT_DIR_SET(id) { return 'SCENE_UNIT_DIR_SET@' + id; }
        static SCENE_UNIT_HP_ADD(id) { return 'SCENE_UNIT_HP_ADD@' + id; }
        static SCENE_UNIT_HP_CHANGE(id) { return 'SCENE_UNIT_HP_CHANGE@' + id; }
        static SCENE_UNIT_EP_CHANGE(id) { return 'SCENE_UNIT_EP_CHANGE@' + id; }
        static SCENE_UNIT_DIE(id) { return 'SCENE_UNIT_DIE@' + id; }
        static SCENE_UNIT_REMOVE(id) { return 'SCENE_UNIT_REMOVE@' + id; }
        static SCENE_UNIT_MOVE_COMPLETE(id) { return 'SCENE_UNIT_MOVE_COMPLETE@' + id; }
        static SCENE_UNIT_OBST(id) { return 'SCENE_UNIT_OBST@' + id; }
        static SCENE_UNIT_REVIVED(id) { return 'SCENE_UNIT_REVIVED@' + id; }
        static SCENE_UNIT_SKILL_USE(id) { return 'SCENE_UNIT_SKILL_USE@' + id; }
        static SCENE_UNIT_SKILL_USE_COMPLETE(id) { return 'SCENE_UNIT_SKILL_USE_COMPLETE@' + id; }
        static SCENE_UNIT_FLY(id) { return 'SCENE_UNIT_FLY@' + id; }
        static SCENE_UNIT_STATE_MOVE(id) { return 'SCENE_UNIT_STATE_MOVE@' + id; }
        static SCENE_UNIT_STATE_STAND(id) { return 'SCENE_UNIT_STATE_STAND@' + id; }
        static SCENE_UNIT_BULLET_EXHAUST(id) { return 'SCENE_UNIT_BULLET_EXHAUST@' + id; }
        static SCENE_UNIT_AIM(id) { return 'SCENE_UNIT_AIM@' + id; }
        static SCENE_UNIT_JUMP(id) { return 'SCENE_UNIT_JUMP@' + id; }
        ;
        static SCENE_UNIT_REPEL(id) { return 'SCENE_UNIT_REPEL@' + id; }
        ;
        static SCENE_UNIT_HIDE(id) { return 'SCENE_UNIT_HIDE@' + id; }
    }
    SceneUnitEvent.SCENE_UNIT_ADDED = 'SCENE_UNIT_ADDED';
    SceneUnitEvent.SCENE_UNIT_HP_CHANGES = 'SCENE_UNIT_HP_CHANGES';
    SceneUnitEvent.SCENE_UNIT_DEATH = 'SCENE_UNIT_DEATH';
    SceneUnitEvent.SCENE_UNIT_REMOVEED = 'SCENE_UNIT_REMOVEED';
    SceneUnitEvent.SCENE_UNIT_KILL = 'SCENE_UNIT_KILL';
    SceneUnitEvent.SCENE_UNIT_REVIVED_COMPLETE = 'SCENE_UNIT_REVIVED_COMPLETE';

    class BattleHpView extends ui.battle.BattleHpUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class BattleHpViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleHpView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.vo = this.data.vo;
            if (this.vo.camp == 1) {
                this.ui.img_lv.skin = 'ui/img_UM_Payload_HP_blue.png';
                this.ui.img_hp.skin = 'ui/img_UM_hp_1.png';
            }
            else {
                this.ui.img_lv.skin = 'ui/img_UM_Payload_HP_red.png';
                this.ui.img_hp.skin = 'ui/img_UM_hp_2.png';
            }
            var victoryNum = BattleModel.model.victoryNum;
            this.ui.txt_lv.text = '' + BattleConfig.getNpcLv(victoryNum);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_HP_CHANGE(this.vo.id), this, this.hpHandler);
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_CLOSEED(this.vo.id), this, this.close);
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.close);
            TimerUtil.loopFrame(1, this, this.posHandler);
            this.hpHandler();
            this.posHandler();
        }
        hpHandler() {
            if (this.vo.isDie) {
                ProgressBarViewTool.setRectBarValue(this.ui.img_hp, 0);
            }
            else {
                var hpv = this.vo.hp / this.vo.hpMax;
                ProgressBarViewTool.setRectBarValue(this.ui.img_hp, hpv);
            }
        }
        posHandler() {
            if (this.vo.isDie) {
                this.ui.visible = false;
                return;
            }
            var playerVo = SceneModel.model.vo.playerVo;
            var monV4 = Display3DUtil.worldToViewportPoint(SceneModel.model.camera, this.vo.x, this.vo.y + 2.5, this.vo.z);
            this.ui.x = monV4.x;
            this.ui.y = monV4.y;
            var dis = DisplayUtil.distance(playerVo.x, playerVo.z, this.vo.x, this.vo.z);
            if (dis > 60) {
                dis = 60;
            }
            var scale = 1 - dis / 60;
            if (scale < 0.2) {
                scale = 0.1;
            }
            else if (scale > 0.8) {
                scale = 0.8;
            }
            this.ui.scale(scale, scale);
            var dir = Display3DUtil.angle(this.vo.x, this.vo.z, playerVo.x, playerVo.z);
            var diff = DisplayUtil.angleDiff(dir, playerVo.dir);
            if (diff < 90 && diff > -90) {
                this.ui.visible = true;
            }
            else {
                this.ui.visible = false;
            }
        }
    }

    class BitmapFonts {
        constructor() {
            this.completes = [];
            this.textureMap = {};
            this.isLoaded = false;
            this.imgLib = {};
        }
        static loadFont(url, complete) {
            var font = this.lib[url];
            if (!font) {
                font = new BitmapFonts();
                this.lib[url] = font;
            }
            font.load(url, complete);
        }
        static getFont(url) {
            return this.lib[url];
        }
        load(url, complete) {
            if (this.isLoaded) {
                complete.run();
                return;
            }
            this.completes.push(complete);
            if (this.url) {
                return;
            }
            this.url = url;
            Laya.loader.load(url, HandlerUtil.create(this, this.jsonCompHandeler), null, Laya.Loader.JSON);
        }
        jsonCompHandeler(data) {
            this.data = data;
            var pngurl = this.url.replace('.fnt', '.png');
            pngurl = pngurl.replace('.json', '.png');
            Laya.loader.load(pngurl, HandlerUtil.create(this, this.loadCompHandeler), null, Laya.Loader.IMAGE);
        }
        loadCompHandeler(img) {
            this.isLoaded = true;
            this.texture = img;
            for (var fun of this.completes) {
                fun.run();
            }
            this.completes = [];
        }
        getTextTexture(text) {
            if (text == "/") {
                text = "╱";
            }
            else if (text == ":") {
                text = "：";
            }
            else if (text == "\\") {
                text = "╲";
            }
            if (this.textureMap[text] == 'null') {
                return null;
            }
            if (this.textureMap[text]) {
                return this.textureMap[text];
            }
            if (!this.texture) {
                return null;
            }
            if (!this.data) {
                return null;
            }
            if (!this.data.frames) {
                return null;
            }
            var list = this.data.frames;
            if (!list[text]) {
                return null;
            }
            var co = list[text];
            if (!co) {
                this.textureMap[text] = 'null';
                return null;
            }
            var tt = Laya.Texture.createFromTexture(this.texture, co.x, co.y, co.w, co.h);
            tt.offsetY = co.offY;
            tt.sourceHeight = co.sourceH;
            this.textureMap[text] = tt;
            return tt;
        }
        getImage(text) {
            var imgList = this.getImageList(text);
            if (imgList.length > 0) {
                return imgList.pop();
            }
            var tt = this.getTextTexture(text);
            if (tt) {
                var img = new Laya.Sprite();
                img.graphics.drawTexture(tt, 0, 0);
                img.width = tt.width;
                img.height = tt.sourceHeight;
                img.name = text;
                return img;
            }
            else if (text == ' ') {
                var img = new Laya.Sprite();
                img.name = text;
                return img;
            }
            return null;
        }
        getImageList(text) {
            var list = this.imgLib[text];
            if (!list) {
                list = this.imgLib[text] = [];
            }
            return list;
        }
        recoverImage(img) {
            if (img) {
                var imgList = this.getImageList(img.name);
                imgList.push(img);
            }
        }
    }
    BitmapFonts.lib = {};

    class BitmapText extends Laya.Box {
        constructor() {
            super();
            this.spaceWidth = 10;
            this.maxWidth = 700;
            this.widthGap = 0;
            this.heightGap = 0;
            this.textWidth = 0;
            this.textHeight = 0;
        }
        load(url) {
            this.fontUrl = url;
            BitmapFonts.loadFont(url, HandlerUtil.create(this, this.loadCompHandeler, [url]));
        }
        loadCompHandeler(url) {
            if (this.fontUrl == url) {
                this.font = BitmapFonts.getFont(url);
                this.showText();
            }
        }
        set text(v) {
            this._text = '' + v;
            this.showText();
        }
        get text() {
            return this._text;
        }
        showText() {
            this.width = 0;
            this.height = 0;
            if (this.font) {
                this.clear();
                if (this._text) {
                    var l = this._text.length;
                    var maxWidth = this.maxWidth;
                    var widthGap = this.width;
                    var heightGap = this.heightGap;
                    var mw = 0;
                    var mh = 0;
                    var cx = 0;
                    var cy = 0;
                    for (var i = 0; i < l; i++) {
                        var c = this._text.charAt(i);
                        if (c == '\n') {
                            cx = 0;
                            cy = mh + heightGap;
                        }
                        else {
                            var img = this.font.getImage(c);
                            if (img) {
                                if (this.spaceWidth && c == ' ') {
                                    img.width = this.spaceWidth;
                                    img.height = this.spaceWidth;
                                }
                                this.addChild(img);
                                if (cx + img.width + widthGap > maxWidth) {
                                    img.x = 0;
                                    img.y = mh + heightGap;
                                    cx = img.x + img.width;
                                    cy = img.y;
                                    mw = Math.max(mw, img.x + img.width);
                                    mh = Math.max(mh, img.y + img.height);
                                }
                                else {
                                    img.x = cx + widthGap;
                                    img.y = cy;
                                    cx = img.x + img.width;
                                    cy = img.y;
                                    mw = Math.max(mw, img.x + img.width);
                                    mh = Math.max(mh, img.y + img.height);
                                }
                            }
                        }
                    }
                    this.width = this.textWidth = mw;
                    this.height = this.textHeight = mh;
                }
            }
        }
        clear() {
            if (this.font) {
                var l = this.numChildren;
                for (var i = 0; i < l; i++) {
                    var view = this.getChildAt(i);
                    this.font.recoverImage(view);
                }
            }
            this.removeChildren();
        }
        set dataSource(value) {
            if (typeof (value) == 'number' || typeof (value) == 'string') {
                this.text = value + "";
            }
            else {
                super.dataSource = value;
            }
        }
    }

    class BitmapLabelView extends Laya.Box {
        constructor(url, scale = 1, label = null) {
            super();
            this.label = new BitmapText();
            this.label.load(url);
            this.label.scale(scale, scale);
            this.addChild(this.label);
            if (label) {
                this.width = label.width;
                this.height = label.height;
                if (label.align == 'right') {
                    this.label.right = 0;
                }
                else if (label.align == 'center') {
                    this.label.centerX = 0;
                }
                else {
                    this.label.left = 0;
                }
                if (label.valign == 'top') {
                    this.label.top = 0;
                }
                else if (label.valign == 'middle') {
                    this.label.centerY = 0;
                }
                else {
                    this.label.bottom = 0;
                }
                if (label.parent) {
                    label.parent.addChild(this);
                    label.removeSelf();
                    this.x = label.x;
                    this.y = label.y;
                }
                this.text = label.text;
            }
        }
        set text(value) {
            this.label.text = value;
        }
        get text() {
            return this.label.text;
        }
        set dataSource(value) {
            if (typeof (value) == 'number' || typeof (value) == 'string') {
                this.text = value + "";
            }
            else {
                super.dataSource = value;
            }
        }
    }

    class BattleKillAnimView extends ui.battle.BattleKlllAnimUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleKillAnimViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleKillAnimView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var vo = this.data.killer;
            if (vo) {
                var monV4 = Display3DUtil.worldToViewportPoint(SceneModel.model.camera, vo.x, vo.y + 2.5, vo.z);
                this.ui.x = monV4.x;
                this.ui.y = monV4.y;
            }
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.lable = new BitmapLabelView('font/white.json', 1, this.ui.txt_soc);
            this.lable.text = '+' + (25 + (lv - 1) * 3);
            TimerUtil.onceTimer(2000, this, this.close);
        }
    }

    class BattleKillTipView extends ui.battle.BattleKillTipUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleKillTipViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleKillTipView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var num = this.data.num;
            var seckill = ParamUtil.getBool(this.data, 'seckill');
            if (num >= 10) {
                this.ui.ui_kill.img_ico.skin = 'ui/img_uj_kill_10.png';
            }
            else {
                this.ui.ui_kill.img_ico.skin = 'ui/img_uj_kill_' + num + '.png';
            }
            this.ui.txt_kill.text = '击杀x' + num;
            TimerUtil.stopAllTimer(this);
            if (seckill) {
                TimerUtil.onceTimer(2500, this, this.close);
                TimerUtil.onceTimer(1000, this, this.showKill);
                this.showSceKill();
            }
            else {
                TimerUtil.onceTimer(1500, this, this.close);
                this.showKill();
            }
        }
        showKill() {
            this.ui.ui_kill.visible = true;
            this.ui.ui_sceKill.visible = false;
            this.ui.ui_kill.ani1.play(1, false);
        }
        showSceKill() {
            this.ui.ui_kill.visible = false;
            this.ui.ui_sceKill.visible = true;
            this.ui.ui_sceKill.ani1.play(1, false);
        }
    }

    class ShopEvent {
    }
    ShopEvent.SHOP_MALL_VIEW_SHOW = 'SHOP_MALL_VIEW_SHOW';
    ShopEvent.SHOP_ROLL_VIEW_SHOW = 'SHOP_ROLL_VIEW_SHOW';
    ShopEvent.SHOP_BUY_VIEW_SHOW = 'SHOP_BUY_VIEW_SHOW';
    ShopEvent.SHOP_CHEST_VIEW_SHOW = 'SHOP_CHEST_VIEW_SHOW';
    ShopEvent.SHOP_ROLL_SUCCESS = 'SHOP_ROLL_SUCCESS';
    ShopEvent.SHOP_ROLLBOX_SUCCESS = 'SHOP_ROLLBOX_SUCCESS';
    ShopEvent.SHOP_ROLLTWO_SUCCESS = 'SHOP_ROLLTWO_SUCCESS';
    ShopEvent.SHOP_MEDAL_VIEW_SHOW = 'SHOP_MEDAL_VIEW_SHOW';
    ShopEvent.SHOP_MEDALBUY_VIEW_SHOW = 'SHOP_MEDALBUY_VIEW_SHOW';
    ShopEvent.SHOP_GETREWARD_COMPLETE = 'SHOP_GETREWARD_COMPLETE';
    ShopEvent.SHOP_VIEW_REFRESH = 'SHOP_VIEW_REFRESH';

    class BattleLevModesView extends ui.battle.BattleLevModesUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleLevModesViewController extends PanelViewController {
        constructor() {
            super();
            this.battleType = 3;
            this.viewClass = BattleLevModesView;
            this.viewName = 'BattleLevModesView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 3);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.medal_shop.on(Laya.Event.CLICK, this, this.okMedalShopHandler);
            this.ui.benefits.on(Laya.Event.CLICK, this, this.benefitsHandler);
            this.showList();
            this.ui.list_lev.selectedIndex = 0;
            if (this.data && this.data.isShowBanefits) {
                this.ui.benefits.visible = true;
            }
            else {
                this.ui.benefits.visible = false;
            }
        }
        showList() {
            var nlist = [];
            var maxLev = 7;
            var lev = BattleModel.model.lev + 1;
            for (var i = 1; i <= maxLev; i++) {
                var data = {};
                data.img_bg = 'ui/img_uk_scenebg5_' + i + '.png';
                data.vo = { lev: i };
                if (lev >= i) {
                    data.img_dis = ViewDataType.OFF;
                    data.disabled = false;
                }
                else {
                    data.img_dis = ViewDataType.ON;
                    data.disabled = true;
                }
                nlist.push(data);
            }
            this.ui.list_lev.dataSource = nlist;
        }
        okHandler() {
            var data = this.ui.list_lev.selectedItem;
            var vo = data.vo;
            if (vo) {
                var lev = vo.lev;
                if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phyLev) == false) {
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                    this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                    return;
                }
                LogTool.log('BattleLevModesViewController.lev:' + lev);
                this.dispatchEvent(BattleEvent.BATTLE_READY_VIEW_SHOW, { cid: 3, battleType: this.battleType, difficulty: lev, lev: lev });
                this.close();
            }
        }
        okMedalShopHandler() {
            this.dispatchEvent(ShopEvent.SHOP_MEDAL_VIEW_SHOW, { showType: ViewType.OPEN });
            this.close();
        }
        benefitsHandler() {
            this.close();
        }
    }

    class BattleLevReplaceView extends ui.battle.BattleLevReplaceUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleLevReplaceViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleLevReplaceView;
            this.viewName = 'BattleLevReplaceView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.btn_ad.on(Laya.Event.CLICK, this, this.adHandler);
            this.showData1(this.data.item);
            this.showData2(this.data.item);
        }
        showData1(item) {
            this.ui.txt_name_1.text = item.name;
            this.ui.txt_info_1.text = item.info;
            this.ui.img_ico_1.skin = item.ico;
        }
        showData2(item) {
            this.ui.txt_name_2.text = item.name + ' x2';
            this.ui.txt_info_2.text = item.info + ' x2';
            this.ui.img_ico_2.skin = item.ico;
        }
        closeHandler() {
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_LEV_SUPPLY_VIEW_SHOW, { showType: ViewType.CLOSE });
            this.dispatchEvent(BattleEvent.BATTLE_WAVE_NEXT);
            var item = this.data.item;
            this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: item.info });
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_BUFF_ADD, { type: item.type, value: item.value });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.videoHandler);
        }
        videoHandler() {
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_LEV_SUPPLY_VIEW_SHOW, { showType: ViewType.CLOSE });
            this.dispatchEvent(BattleEvent.BATTLE_WAVE_NEXT);
            var item = this.data.item;
            this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: item.infoDoub });
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_BUFF_ADD, { type: item.type, value: item.value * 2 });
        }
    }

    class BattleLevSupplyView extends ui.battle.BattleLevSupplyUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleLevSupplyViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleLevSupplyView;
            this.viewName = ' BattleLevSupplyView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.btn_ad.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.randomData();
        }
        randomData() {
            var list = this.data.list;
            var item = RandomUtil.randomItem(list);
            this.item = item;
            if (this.item.stype == 'equip') {
                this.ui.img_close.visible = true;
            }
            else {
                this.ui.img_close.visible = false;
            }
            this.showData(item);
        }
        showData(item) {
            this.ui.txt_name.text = item.name;
            this.ui.txt_info.text = item.info;
            if (item.ico) {
                this.ui.img_ico.skin = item.ico;
                this.ui.img_gun.skin = '';
            }
            else {
                this.ui.img_ico.skin = '';
                this.ui.img_gun.skin = GoodsViewTool.getIcoUrl(item.value);
            }
        }
        adHandler() {
            this.randomData();
        }
        okHandler() {
            if (this.item.stype == 'buff' || this.item.stype == 'supply') {
                this.dispatchEvent(BattleEvent.BATTLE_LEV_REPLACE_VIEW_SHOW, { list: this.data.list, item: this.item });
            }
            else {
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_BUFF_ADD, { type: this.item.type, value: this.item.value });
                this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '获得' + this.item.info });
                this.dispatchEvent(BattleEvent.BATTLE_WAVE_NEXT);
            }
            this.close();
        }
        closeHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_WAVE_NEXT);
            this.close();
        }
    }

    class BattleLevConfig {
    }
    BattleLevConfig.partExp = 200;
    BattleLevConfig.killJin = 20;
    BattleLevConfig.partTong = 60;
    BattleLevConfig.passMedalReward = 100;

    class BattleLevUnlockView extends ui.battle.BattleLevUnlockUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleLevUnlockViewController extends DialogViewController {
        constructor() {
            super();
            this.battleType = 3;
            this.viewClass = BattleLevUnlockView;
            this.viewName = 'BattleLevUnlockView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_triple.on(Laya.Event.CLICK, this, this.challengeHandler);
            }
            this.showMoney();
            SoundTool.playSound('victory');
        }
        showMoney() {
            if (this.vo.difficulty == 1) {
                var tongFull = BattleLevConfig.partTong * BattleModel.model.wave;
                var killJin = BattleLevConfig.killJin * BattleModel.model.wave;
                var medalNum = SceneModel.model.vo.playerKillNum;
                var medalNum2 = BattleLevConfig.passMedalReward;
                this.ui.img_difficult.skin = 'ui/img_uk_scenebg5_2.png';
            }
            else {
                var tongFull = BattleLevConfig.partTong * BattleModel.model.wave * (1 + (this.vo.difficulty - 1) * 0.2);
                var killJin = BattleLevConfig.killJin * BattleModel.model.wave * (1 + (this.vo.difficulty - 1) * 0.2);
                var medalNum = SceneModel.model.vo.playerKillNum * this.vo.difficulty;
                var medalNum2 = BattleLevConfig.passMedalReward * this.vo.difficulty;
                var lev = this.vo.difficulty + 1;
                if (this.vo.difficulty == 7) {
                    lev = 7;
                }
                this.ui.img_difficult.skin = 'ui/img_uk_scenebg5_' + lev + '.png';
            }
            this.jin = tongFull;
            this.tong = killJin;
            this.medal = medalNum + medalNum2;
            this.ui.txt_expAll.text = '' + this.medal;
            this.ui.txt_tongAll.text = '' + this.jin;
            this.ui.txt_jinAll.text = '' + this.tong;
        }
        closeHandler() {
            this.close();
        }
        challengeHandler() {
            LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
            LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phyLev) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                return;
            }
            var battleLevNext = BattleModel.model.battleLev + 1;
            this.dispatchEvent(BattleEvent.BATTLE_READY_VIEW_SHOW, { cid: 3, battleType: this.battleType, difficulty: battleLevNext, lev: battleLevNext });
            this.close();
        }
    }

    class BattleLoadView extends ui.battle.BattleLoadUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleLoadViewController extends DialogViewController {
        constructor() {
            super();
            this.lastTime = 0;
            this.num = 0;
            this.viewClass = BattleLoadView;
            this.viewName = 'BattleLoadView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.isShowBtn = ParamUtil.getBool(this.data, 'isShowBtn', true);
            this.label = new BitmapLabelView("font/white.json", 0.9, this.ui.txt_time);
            this.ui.box_no.on(Laya.Event.CLICK, this, this.close);
            this.num = RandomUtil.randomInt(5, 10);
            this.lastTime = 0;
            if (this.isShowBtn == true) {
                this.ui.box_no.visible = true;
            }
            else {
                this.ui.box_no.visible = false;
            }
            TimerUtil.loopTimer(1000, this, this.countDownHandler);
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_START);
        }
        countDownHandler() {
            this.lastTime += 1;
            this.label.text = '' + this.lastTime;
            if (this.lastTime >= this.num) {
                this.readyHandler();
                TimerUtil.stopTimer(this, this.countDownHandler);
            }
        }
        readyHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_MATCH_VIEW_SHOW, this.data);
            this.close();
        }
    }

    class PlayerConfig {
        static getPlayerName() {
            var type = MathUtil.randomInt(1, 5);
            if (type == 1) {
                var x = ArrayUtil.randomItem(this.playerNameConfig);
                return x;
            }
            else if (type == 2) {
                var x = ArrayUtil.randomItem(this.playerNameAConfig);
                var y = ArrayUtil.randomItem(this.playerNameBConfig);
                return x + y;
            }
            else if (type == 3) {
                var x = ArrayUtil.randomItem(this.playerNameAConfig);
                var y = ArrayUtil.randomItem(this.playerNameBConfig);
                var z = ArrayUtil.randomItem(this.playerNameCConfig);
                return x + z + y;
            }
            else if (type == 4) {
                var x = ArrayUtil.randomItem(this.playerNameAConfig);
                var y = ArrayUtil.randomItem(this.playerNameBConfig);
                var z = ArrayUtil.randomItem(this.playerNameCConfig);
                return z + x + y + z;
            }
            else if (type == 5) {
                var x = ArrayUtil.randomItem(this.playerNameAConfig);
                var y = ArrayUtil.randomItem(this.playerNameBConfig);
                var z = ArrayUtil.randomItem(this.playerNameCConfig);
                var m = ArrayUtil.randomItem(this.playerNameCConfig);
                return z + x + y + m;
            }
            else {
                var x = ArrayUtil.randomItem(this.playerNameAConfig);
                var y = ArrayUtil.randomItem(this.playerNameBConfig);
                return x + y;
            }
        }
    }
    PlayerConfig.IsShowModifyName = true;
    PlayerConfig.playerType = 0;
    PlayerConfig.playerNameConfig = ['假装不在乎',
        'Magicman',
        'Another',
        'famous',
        'Happy世界',
        'junior',
        'Soledad',
        'sunshine',
        '有点纠结',
        '泪湿了眼',
        '破碎之光',
        'cool breeze',
        '拾间',
        '﹏ 失心疯。',
        '空念河',
        '#厌世',
        '\"忘却丶',
        'sky丨留白',
        'ωǒ小懶潴',
        'り小乖乖',
        'ate曼',
        '很温柔',
        '别来无恙',
        '春暖花開',
        '岛格 センタ',
        '女神',
        '给我顶住',
        '海水不比泪咸',
        '蓝色ン天空灬',
        '欢脱',
        '狂爵',
        '老街头',
        '冷面MAN',
        '明若轻兮',
        '陪衬',
        '情绪化',
        '茶香',
        '时间',
        '战术拖孩',
        '左眸°',
        '蓝颜。',
        '木槿',
        '柠栀',
        '弦已断',
        '零度萤火',
        '浅 笑 ζ',
        '夏の樱',
        '冷温柔°triste',
        '枯守一座城',
        '蓝樱雪',
        '樱飞',
        '心☆晴つ',
        '沐晴つ',
        '资深六学家',
        '久居孤海',
        '夏目柚子',
        '有你心安',
        '客串',
        '品茗听雪',
        'victorME',
        '冷面男',
        '我没开挂',
        '别打我',
        '对面',
        '堪忧斯比克',
        '真假是非',
        '热冰反应',
        '魔法之手',
        '空口无凭',
        '花粥没抄袭',
        '最强指甲刀',
        '飞鼠桑',
        '骨傲天',
        'Scoundrel',
        '冰狼堡',
        '玫瑰纹章',
        '辉煌之夜',
        '你不忠诚',
        '自由飞',
        '无敌光环',
        '钞能力',
        '竹鼠的愤怒',
        '没钱任性',
        '梦璃子',
        '绝情LEO',
        '淺淺的初夏',
        '彪悍的菇凉',
        '微笑向暖',
        '一切╮免谈',
        '草编戒指',
        '微雨清凉',
        '夜尽天明',
        '渡你成佛',
        '白色ゞ樱花',
        '夢殇♀轻尘',
        '神仙#',
        '陌上流桑ゞ',
        '浅夏初雨',
        '火舞灬迷殇',
        '怜听雨声',
        '天台边的鱼丸',
        '反向扔桶怕不怕',
        '茶暖桉',
        '年少得痣',
        '昕夕靡爽',
        '涟彩寻',
        '不醒梦',
        '大绿小烧烤',
        '霧鳶城',
        '发愁者联盟',
        '萢萢糖',
        '小笑',
        '摆布°Manipula',
        '壳de霸气',
        '青春这么假',
        '查无此人',
        '火之高兴',
        '让你三英雄',
        '人生似梦Eron',
        '飞桶海',
        '能力不足',
        '气定大火球',
        '你看我厉害吗',
        '要用脑子玩',
        '别找我',
        '请假条',
        '你打不到我哟',
        '教科书',
        '弓法合一',
        '无无卡牌',
        '配卡天才',
        '惹了方丈还想跑',
        '超级不对称',
        'ní若成疯',
        '真香真香',
        '只爱弓箭手',
        '小猪猪',
        '演员与修养',
        '从来不组队',
        '学人精',
        '战歌起',
        '不贪怎么赢',
        '狮鹫骑脸',
        '单身汪╯ε╰',
        '仇猫',
        '晚春初夏',
        '打打对面',
        '念',
        'just DO it',
        'Never',
        '易拉狗',
        '观海听涛',
        '一曲忠诚的赞歌',
        '傾旎',
        '清新不倾心',
        'only ',
        'Hypocritical',
        '诡手',
        '限时搞怪',
        '今日之日',
        '地大物博',
        '啦梁非凡',
        '怒送一血',
        '天空不空',
        '凉生初雨',
        '一世霸主',
        '夜ゞ月影',
        '狱王',
        'ワ孤影月下ワ',
        '咆哮战歌',
        '影猎',
        '神话',
        '嗜メ狂',
        '南半球',
        '命фㄨ紸啶',
        '忆城花音',
        '過期關系',
        '森屿麋鹿',
        '猫扑风铃',
        '柠檬味拥抱',
        'arrogance',
        'shoulder依靠',
        'existence°鱼',
        '牵手°sunset',
        'ざ懒癌',
        'ⓛ影孓',
        '残月☠',
        'dreamer°',
        '盘他！',
        'だ泣',
        '狂傲一身',
        '小心有炸',
        'Carmen',
        '阳光',
        '劝退卡组',
        'ζ浮世德',
        '￠燃烧军团¤',
        '天才之域',
        '幽冥神舞',
        '萌面人°',
        '|苍穹之巅|',
        '一身龙狼',
        '傲骨依旧',
        'memory',
        '要饭诗人',
        '太美',
        'ι尐吜',
        'Naked',
        '满身大汉',
        '翡翠の城',
        '苍蓝风暴',
        '兔之月',
        '敌在白马城',
        '旅店老板ル',
        '小宅误我',
        '华容三笑',
        '赛达尔号',
        '观尔插标卖首',
        '小破门的选择',
        '人马星来客',
        '列国云都',
        '初栀°',
        '岛森屿夏',
        '『呆呆』',
        '骡马驾日',
        '文体两开花',
        '浪味仙♪',
        'raphael',
        '〞drew love丶',
        '●北极星●',
        '§紫水晶§',
        '黑色梦',
        '`_ァ绝版少年♂',
        '♂乖乖站好♂',
        '折学♂大师',
        '秋♆风追猎者',
        '＼冇灰机,﹏',
        '马鹿丶射手',
        '活在当下',
        '专业古董师',
        '猪蹄',
        '甜度超标',
        '中国好学渣',
        'enteral丶不朽',
        '₯㎕。 迷茫',
        '心怀大海',
        '专业演员',
        'stlメ霸主',
        '谁还不是个宝宝',
        '钻石糖❀',
        'aries°气质',
        '妄醉无凭',
        '谁起了我的名',
        '总有刁民想害朕',
        '天台风',
        '霸气',
        '孤痞°',
        '人心囡测',
        '八百里开外',
        '逗逼克星',
        '打不过就加入',
        '哆啦c灬豬',
        '很有量的人',
        '天使灬',
        '真猪奶茶',
        '千之永恒',
        '灰常鸡动',
        '坟头蹦迪',
        '覆灭神话',
        '貓耳朵兒',
        '月如神夜',
        '强壮的病猫',
        '潮人',
        '乡镇魔法师',
        '超级♂比利王',
        '巡完南山巡北山',
        '伏铁',
        '苇名新秀',
        '后退一步算我输',
        '捕心达人',
        '汝听人言否',
        '虾仁猪心',
        '四斋蒸鹅心',
        '嘻哈王语嫣',
        '土味情话',
        '请你吃辣条',
        '无极鲅鱼',
        '我钟意你啊',
        '安静别说话',
        '见者暴富',
        '意中人',
        '时光',
        '失足的斑马',
        '时光守恒',
        '寂寞先生',
        '说散就散',
        '无事可乐',
        '平你眉间川',
    ];
    PlayerConfig.playerNameAConfig = [
        '假装',
        '有点',
        '泪湿了',
        '温柔',
        '小懶潴',
        '小乖乖',
        '凹凸曼',
        '春暖',
        '给我顶住',
        '海水不比泪咸',
        '冷面',
        '明若',
        '陪衬',
        '情绪化',
        '左眸',
        '蓝颜',
        '弦已断',
        '零度萤火',
        '浅 笑',
        '夏',
        '冷温柔',
        '枯守',
        '心晴',
        '沐晴',
        '资深',
        '久居',
        '夏目柚子',
        '有你',
        '客串',
        '我没',
        '对面',
        '堪忧斯',
        '热冰',
        '魔法',
        '挚爱',
        '花粥',
        '最强',
        '飞鼠',
        '史诗级',
        '冰狼',
        '玫瑰',
        '辉煌',
        '你不',
        '不如',
        '颤抖吧',
        '原装',
        '梦',
        '绝情',
        '我叫',
        '淺淺',
        '微笑',
        '一切',
        '草编',
        '微雨',
        '夜尽',
        '白色',
        '夢殇',
        '陌上',
        '浅夏',
        '火舞',
        '怜听',
        '天台边',
        '茶暖桉',
        '昕夕',
        '涟彩',
        '不醒',
        '霧鳶城',
        '萢萢糖',
        '火之',
        '让你',
        '人生似梦',
        '不行啊',
        '气定',
        '你看',
        '要用',
        '别',
        '教你',
        '你打不到',
        '教科书',
        '弓法',
        '无无',
        '转角',
        '配卡',
        '惹了',
        '超级',
        '若成疯',
        '真香',
        '只爱',
        '小猪猪',
        '演员',
        '从来',
        '战歌',
        '空气',
        '不贪',
        '狮鹫',
        '单身',
        '观海',
        '一曲',
        '傾旎',
        '清新',
        '天空不空',
        '凉生',
        '一世',
        '夜ゞ',
        'ワ孤',
        '咆哮',
        '南半球',
        '命',
        '忆城',
        '過期',
        '森屿',
        '猫扑',
        '柠檬味',
        '依靠',
        '鱼',
        '牵手',
        'ざ懒癌',
        '影孓',
        '残月',
        '盘他',
        '一路',
        '小心',
        '成功',
        '劝退',
        '八线',
        '燃烧',
        '萌面人',
        '苍穹',
        '一身',
        '傲骨',
        '要饭',
        '你好吖',
        'ι尐吜',
        '满身',
        '翡翠',
        '苍蓝',
        '旅店',
        '小宅',
        '人马星',
        '浪味仙♪',
        '●北极星●',
        '§紫水晶§',
        '绝版少年',
        '折学',
        '秋♆风',
        '冇灰机',
        '马鹿',
        '感',
        '甜度',
        '₯㎕',
        '心噬',
        '专业',
        'stlメ',
        '钻石',
        'aries°',
        '妄醉',
        '谁起了',
        '总有',
        '天台',
        '霸气',
        '孤痞°',
        '逗',
        '打不过',
        '哆啦',
        '很有',
        '天使',
        '真猪',
        '千之',
        '灰常',
        '貓耳',
        '月如',
        '强壮的',
        '乡镇',
        '超级',
        '巡完',
        '伏铁',
        '苇名',
        '后退一步',
        '捕心',
        '汝听人',
        '四斋',
        '嘻哈',
        '土味',
        '请你',
        '无极鱼',
        '我钟意',
        '阳光',
        '见者',
        '意中人是',
        '时光',
        '说散',
        '无事',
    ];
    PlayerConfig.playerNameBConfig = ['不在乎',
        '世界',
        '纠结',
        '眼',
        '力',
        '忘却',
        '留白',
        '花開',
        '天空',
        '萝莉',
        '轻兮',
        '拖孩',
        '樱',
        '一座城',
        '六学家',
        '孤海',
        '警告',
        '心安',
        '舞',
        '情人',
        '听雪',
        '比克',
        '反应',
        '无据',
        '抄袭',
        '指甲刀',
        '桑',
        '堡',
        '纹章',
        '之夜',
        '无双',
        '光环',
        '能力',
        '愤怒',
        '我们',
        '任性',
        '凡人们',
        '技巧',
        '讨论',
        '璃子',
        '实践',
        '初夏',
        '菇凉',
        '向暖',
        '免谈',
        '戒指',
        '清凉',
        '天明',
        '成佛',
        '眼了',
        '轻尘',
        '你好',
        '流桑',
        '初雨',
        '迷殇',
        '雨声',
        '鱼丸',
        '得痣',
        '靡爽',
        '寻',
        '梦',
        '棒子',
        '小烧烤',
        '特么',
        '高兴',
        '求交往',
        '三英雄',
        '大火球',
        '我吗',
        '脑子玩',
        '我哟',
        '合一',
        '卡牌',
        '方丈',
        '还想跑',
        '不对称',
        '香',
        '弓箭手',
        '修养',
        '不组队',
        '达人',
        '起',
        '怎么赢',
        '汪',
        '初夏',
        '对面',
        'の城',
        '听涛',
        '忠诚',
        '赞歌',
        '不倾心',
        '果腹',
        '搞怪',
        '物博',
        '啦梁',
        '非凡',
        '一血',
        '初雨',
        '霸主',
        '月影',
        '狱王',
        '影月',
        '下ワ',
        '紸啶',
        '不好么',
        '花音',
        '關系',
        '麋鹿',
        '风铃',
        '拥抱',
        '向钱',
        '一身',
        '卡组',
        '之域',
        '神舞',
        '之巅',
        '龙狼',
        '依旧',
        '诗人',
        '你太美',
        '风暴',
        '之月',
        '白马城',
        '老板ル',
        '误我',
        '三笑',
        '插标',
        '选择',
        '来客',
        '云都',
        '屿夏',
        '驾日',
        '两开花',
        '站好',
        '大师',
        '追猎者',
        '现在',
        '猪蹄',
        '超标',
        '好学渣',
        '不朽',
        '迷茫',
        '演员',
        '霸主',
        '宝宝',
        '糖❀',
        '帅比',
        '气质',
        '菜刀',
        '无凭',
        '我的名',
        '刁民',
        '想害朕',
        '风神',
        '囡测',
        '开外',
        '克星',
        '加入',
        'c灬豬',
        '奶茶',
        '永恒',
        '鸡动',
        '蹦迪',
        '神话',
        '朵兒',
        '神夜',
        '病猫',
        '潮人',
        '魔法师',
        '比利王',
        '南山',
        '巡北山',
        '新秀',
        '孝斩',
        '算我输',
        '达人',
        '言否',
        '猪心',
        '蒸鹅心',
        '情话',
        '吃辣条',
        '鲅',
        '别说话',
        '混',
        '斑马',
        '守恒',
        '就散',
        '可乐',
        '眉间川',
    ];
    PlayerConfig.playerNameCConfig = [
        'sky',
        '﹏ ',
        '。',
        '#',
        '\"',
        '丶',
        '丨',
        'ωǒ',
        'り',
        '！',
        '灬',
        'ン',
        'の',
        'ぢ',
        '°',
        ' ζ',
        '☆',
        'つ',
        '°triste',
        '与',
        '没',
        'セ',
        'ン',
        'タ',
        '的',
        '与',
        'de',
        'ní',
        '╯ε╰',
        '＆',
        'ㄨ',
        'ф',
        '゛',
        'ⓛ',
        '`_ァ',
        '♂',
        'ぁ',
        'あ',
        'ぃ',
        'い',
        'ぅ',
        'う',
        'ぇ',
        'え',
        'ぉ',
        'お',
        'か',
        'が',
        'き',
        'ぎ',
        'く',
        'ぐ',
        'け',
        'げ',
        'こ',
        'ご',
        'さ',
        'ざ',
        'し',
        'じ',
        'す',
        'ず',
        'せ',
        'ぜ',
        'そ',
        'ぞ',
        'た',
        'だ',
        'ち',
        'ぢ',
        'っ',
        'つ',
        'づ',
        'て',
        'で',
        'と',
        'ど',
        'な',
        'に',
        'ぬ',
        'ね',
        'の',
        'は',
        'ば',
        'ぱ',
        'ひ',
        'び',
        'ぴ',
        'ふ',
        'ぶ',
        'ぷ',
        'へ',
        'べ',
        'ぺ',
        'ほ',
        'ぼ',
        'ぽ',
        'ま',
        'み',
        'む',
        'め',
        'も',
        'ゃ',
        'や',
        'ゅ',
        'ゆ',
        'ょ',
        'よ',
        'ら',
        'り',
        'る',
        'れ',
        'ろ',
        'ゎ',
        'わ',
        'ゐ',
        'ゑ',
        'を',
        'ん',
        'ァ',
        'ア',
        'ィ',
        'イ',
        'ゥ',
        'ウ',
        'ェ',
        'エ',
        'ォ',
        'オ',
        'カ',
        'ガ',
        'キ',
        'ギ',
        'ク',
        'グ',
        'ケ',
        'ゲ',
        'コ',
        'ゴ',
        'サ',
        'ザ',
        'シ',
        'ジ',
        'ス',
        'ズ',
        'セ',
        'ゼ',
        'ソ',
        'ゾ',
        'タ',
        'ダ',
        'チ',
        'ヂ',
        'ッ',
        'ツ',
        'ヅ',
        'テ',
        'デ',
        'ト',
        'ド',
        'ナ',
        'ニ',
        'ヌ',
        'ネ',
        'ノ',
        'ハ',
        'バ',
        'パ',
        'ヒ',
        'ビ',
        'ピ',
        'フ',
        'ブ',
        'プ',
        'ヘ',
        'ベ',
        'ペ',
        'ホ',
        'ボ',
        'ポ',
        'マ',
        'ミ',
        'ム',
        'メ',
        'モ',
        'ャ',
        'ヤ',
        'ュ',
        'ユ',
        'ョ',
        'ヨ',
        'ラ',
        'リ',
        'ル',
        'レ',
        'ロ',
        'ヮ',
        'ワ',
        'ヰ',
        'ヱ',
        'ヲ',
        'ン',
        'ヴ',
        'ヵ',
        'ヶ',
        'ㄅ',
        'ㄆ',
        'ㄇ',
        'ㄈ',
        'ㄉ',
        'ㄊ',
        'ㄋ',
        'ㄌ',
        'ㄍ',
        'ㄎ',
        'ㄏ',
        'ㄐ',
        'ㄑ',
        'ㄒ',
        'ㄓ',
        'ㄔ',
        'ㄕ',
        'ㄖ',
        'ㄗ',
        'ㄘ',
        'ㄙ',
        'ㄚ',
        'ㄛ',
        'ㄜ',
        'ㄝ',
        'ㄞ',
        'ㄟ',
        'ㄠ',
        'ㄡ',
        'ㄢ',
        'ㄣ',
        'ㄤ',
        'ㄥ',
        'ㄦ',
        'ㄧ',
        'ㄨ',
        'ㄩ',
    ];

    class PlayerIcoConfig {
        static getIco(ico) {
            return 'res/player/' + ico + '.png';
        }
    }
    PlayerIcoConfig.icoMax = 10;

    class BattleMatchView extends ui.battle.BattleMatchUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleMatchViewController extends DialogViewController {
        constructor() {
            super();
            this.list1 = [];
            this.list2 = [];
            this.viewClass = BattleMatchView;
            this.viewName = 'BattleMatchView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.isBattle = ParamUtil.getBool(this.data, 'isBattle', true);
            this.ui.ui_ani.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_ani.img_head.skin = PlayerModel.model.ico;
            var name = PlayerConfig.getPlayerName();
            var url = PlayerIcoConfig.getIco(MathUtil.randomInt(0, 9));
            this.ui.ui_ani.txt_foeName.text = name;
            this.ui.ui_ani.img_head2.skin = url;
            BattleModel.model.foeName = name;
            BattleModel.model.foeIco = url;
            this.addEventListener(SceneEvent.SCENE_LOAD_COMPLETE, this, this.loadHandler);
            this.victoryNum = BattleModel.model.victoryNum;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            if (this.isBattle == true) {
                TimerUtil.onceTimer(1000, this, this.startBattle);
                this.ui.ui_ani.txt_num.text = '' + triphyNum;
                var enemyTriphyNum = BattleModel.model.enemyTriphyNum = (MathUtil.randomInt(triphyNum * (1 - 0.2), triphyNum * (1 + 0.2)));
                this.ui.ui_ani.txt_num2.text = '' + enemyTriphyNum;
            }
            TimerUtil.onceTimer(500, this, this.playInAnim);
            this.ui.ui_ani.txt_lv1.text = '' + lv;
            this.ui.ui_ani.txt_lv2.text = '' + lv;
            this.list1 = [];
            this.list2 = [];
            this.setList1();
            this.setList2();
        }
        setList1() {
            if (this.isBattle == true) {
                this.list1 = [];
                this.list1.push(BattleModel.model.playerCid);
                var npcList = RandomUtil.randomArray(SceneConfig.npcList, 4);
                for (var k in npcList) {
                    this.list1.push(npcList[k]);
                }
            }
            else {
                this.list1 = [30011001, 30011002, 30011003, 30011004, 30011005];
            }
            var index = 0;
            var nlist = [];
            for (var cid of this.list1) {
                var vo = SceneVoBuilder.getElementVo(cid);
                var item = {};
                item.txt_name = vo.name;
                item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                if (index == 0) {
                    item.txt_name1 = { text: '我', color: '#e2a015' };
                    BattleModel.model.nameList.push(PlayerModel.model.name);
                    item.txt_lv = '' + GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid).lv;
                }
                else {
                    var name = PlayerConfig.getPlayerName();
                    BattleModel.model.nameList.push(name);
                    item.txt_name1 = { text: name, color: '#e5e2da' };
                    item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                }
                nlist.push(item);
                index++;
            }
            this.ui.ui_ani.ui_list1.dataSource = nlist;
        }
        setList2() {
            if (this.isBattle == true) {
                this.list2 = RandomUtil.randomArray(SceneConfig.npcList, 5);
            }
            else {
                this.list2 = [30011006, 30011007, 30011008, 30011009, 30011010];
            }
            var nlist = [];
            var index = 0;
            for (var cid of this.list2) {
                var vo = SceneVoBuilder.getElementVo(cid);
                var item = {};
                item.txt_name = vo.name;
                item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                if (index == 0) {
                    item.txt_name1 = { text: '队长', color: '#e2a015' };
                    BattleModel.model.nameList.push(BattleModel.model.foeName);
                    item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                }
                else {
                    var name = PlayerConfig.getPlayerName();
                    BattleModel.model.nameList.push(name);
                    item.txt_name1 = { text: name, color: '#e5e2da' };
                    item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                }
                nlist.push(item);
                index++;
            }
            this.ui.ui_ani.ui_list2.dataSource = nlist;
        }
        startBattle() {
            this.dispatchEvent(BattleEvent.BATTLE_START, { cid: this.data.cid, battleType: this.data.battleType, list1: this.list1, list2: this.list2, isTry: this.data.isTry });
        }
        loadHandler() {
            TimerUtil.onceTimer(1000, this, this.playOutAnim);
            TimerUtil.onceTimer(2000, this, this.closeHandler);
        }
        playInAnim() {
            this.ui.ui_ani.ani_in.play(0, false);
        }
        playOutAnim() {
            this.ui.ui_ani.ani_out.play(0, false);
        }
        closeHandler() {
            this.close();
            this.dispatchEvent(SceneEvent.SCENE_VIEW_START);
        }
    }

    class PageConfig {
        static getGoldGun(index) {
            return this.goldGunList[index];
        }
        static getTreasureChest(index) {
            return this.treasureChestList[index];
        }
        static getGift(index) {
            return this.GiftList[index];
        }
    }
    PageConfig.pageScale = 1;
    PageConfig.pageRewardViewType = 0;
    PageConfig.pageRewardType = 0;
    PageConfig.pageQqShow = false;
    PageConfig.pageType = 0;
    PageConfig.isShowRank = true;
    PageConfig.isShowName = true;
    PageConfig.isShowGift = true;
    PageConfig.isShowBox = true;
    PageConfig.goldGunMax = 5;
    PageConfig.goldGunList = {
        1: { index: 1, num: 1, goods: [{ cid: 30042501, num: 1, count: 0 }] },
        2: { index: 2, num: 5, goods: [{ cid: GoodsAttrType.ATTR_JIN, num: 300 }, { cid: GoodsAttrType.ATTR_TONG, num: 1000 }] },
        3: { index: 3, num: 5, goods: [{ cid: 30042502, num: 1, count: 0 }] },
        4: { index: 4, num: 10, goods: [{ cid: GoodsAttrType.ATTR_JIN, num: 800 }, { cid: GoodsAttrType.ATTR_TONG, num: 3000 }] },
        5: { index: 5, num: 10, goods: [{ cid: 30042503, num: 1, count: 0 }] },
    };
    PageConfig.ChestMax = 4;
    PageConfig.treasureChestList = [
        { cid: 3002, num: 1, name: '黄金宝箱', index: 1 },
        { cid: 3003, num: 1, name: '钻石宝箱', index: 2 },
        { cid: 3004, num: 1, name: '传说宝箱', index: 3 },
        { cid: 3005, num: 1, name: '彩虹宝箱', index: 4 }
    ];
    PageConfig.GiftMax = 10;
    PageConfig.GiftList = [
        { index: 1, unlockTroNum: 100, goods: { cid: 30011001, num: 80 } },
        { index: 2, unlockTroNum: 120, goods: { cid: 30011003, num: 80 } },
        { index: 3, unlockTroNum: 160, goods: { cid: 30011002, num: 80 } },
        { index: 4, unlockTroNum: 200, goods: { cid: 30011005, num: 80 } },
        { index: 5, unlockTroNum: 300, goods: { cid: 30011004, num: 40 } },
        { index: 6, unlockTroNum: 400, goods: { cid: 30011006, num: 80 } },
        { index: 7, unlockTroNum: 500, goods: { cid: 30011007, num: 80 } },
        { index: 8, unlockTroNum: 600, goods: { cid: 30011008, num: 80 } },
        { index: 9, unlockTroNum: 700, goods: { cid: 30011009, num: 40 } },
        { index: 10, unlockTroNum: 800, goods: { cid: 30011010, num: 10 } },
    ];

    class BattleModesView extends ui.battle.BattleModesUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleModesViewController extends PanelViewController {
        constructor() {
            super();
            this.battleType = 1;
            this.selectIndex = 0;
            this.viewClass = BattleModesView;
            this.viewName = 'BattleModesView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_scale.scale(PageConfig.pageScale, PageConfig.pageScale);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_1.on(Laya.Event.CLICK, this, this.ok1Handler);
            this.ui.btn_2.on(Laya.Event.CLICK, this, this.ok2Handler);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 1);
            if (this.battleType == 1) {
                this.ui.img_title.skin = 'ui/img_uk_text_td.png';
            }
            else {
                this.ui.img_title.skin = 'ui/img_uk_text_zy.png';
            }
            this.showSelect(0);
        }
        okHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            if (this.selectIndex == 0) {
                this.dispatchEvent(BattleEvent.BATTLE_READY_VIEW_SHOW, { cid: 1, battleType: this.battleType });
            }
            else {
                this.dispatchEvent(BattleEvent.BATTLE_READY_VIEW_SHOW, { cid: 2, battleType: this.battleType });
            }
            this.close();
        }
        ok1Handler() {
            this.showSelect(0);
        }
        ok2Handler() {
            this.showSelect(1);
        }
        showSelect(index) {
            this.selectIndex = index;
            if (index == 0) {
                this.ui.img_select.x = this.ui.btn_1.x;
                this.ui.img_select.y = this.ui.btn_1.y;
            }
            else {
                this.ui.img_select.x = this.ui.btn_2.x;
                this.ui.img_select.y = this.ui.btn_2.y;
            }
        }
    }

    class BattleMysteryBox extends ui.battle.BattleMysteryBoxUI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class BattleMysteryBoxViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleMysteryBox;
            this.viewName = 'BattleMysteryBoxView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.num = 0;
                this.ui = this.view;
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_ok.on(Laya.Event.MOUSE_DOWN, this, this.okHandler);
                TimerUtil.loopFrame(1, this, this.subNumHandler);
                this.ui.ani1.gotoAndStop(1);
            }
            this.showData();
        }
        okHandler() {
            this.num += 10;
            this.showData();
            this.checkNumMax();
        }
        checkNumMax() {
            var nums = RandomUtil.randomInt(70, 80);
            LogTool.log('checkNumMax:' + nums);
            LogTool.log('checkNumMax:' + this.num);
            if (this.num >= nums) {
                this.ui.ani1.play(1, false);
                this.success();
            }
        }
        subNumHandler() {
            if (this.num > 0) {
                this.num -= 0.5;
                if (this.num < 0) {
                    this.num = 0;
                }
                this.showData();
            }
        }
        success() {
            var list = RandomUtil.randomWeight(BattleConfig.mysteryBoxList, 1);
            var vo = list[0];
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var index = this.checkLv(lv);
            if (vo.index == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: vo.goods[index].cid, num: vo.goods[index].num }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: vo.goods });
            }
            this.close();
        }
        showData() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            ProgressBarViewTool.setRectBarValue(this.ui.bar_num, this.num / 100);
            var vo = BattleConfig.getMtBoxList(3);
            var index = this.checkLv(lv);
            var co = GoodsVoBuilder.getGoodsVo(vo.goods[index].cid);
            this.ui.txt_num.text = '' + co.name;
            this.ui.img_ico.skin = GoodsViewTool.getIcoUrl(vo.goods[index].cid);
            this.showPross();
        }
        showPross() {
            var num = MathUtil.int(this.num);
            if (num >= 100) {
                this.ui.txt_num.text = 100 + '%';
            }
            else {
                this.ui.txt_num.text = num + '%';
            }
        }
        checkLv(lv) {
            if (lv <= 10) {
                return 0;
            }
            else if (lv > 10 && lv <= 30) {
                return 1;
            }
            else {
                return 2;
            }
        }
        closeHandler() {
            this.close();
        }
    }

    class View3DController extends ViewController {
        constructor() {
            super();
        }
        open() {
            if (this.data && this.data.parentView) {
                this.parentView = this.data.parentView;
            }
            if (this.viewURL) {
                if (this.view == null) {
                    LoaderUtil.loads(this.viewURL, this, this.open3DHandler);
                }
                else {
                    this.open3DHandler(this.view);
                }
            }
            else {
                this.open3DHandler(this.view);
            }
        }
        open3DHandler(obj) {
            if (obj instanceof Laya.Sprite3D) {
                if (this.parentView instanceof Laya.Scene3D) {
                    this.view = obj;
                }
                else if (this.parentView instanceof Laya.Sprite3D) {
                    this.view = obj;
                }
                else if (this.parentView) {
                    this.view = new Laya.Scene3D();
                    this.view.addChild(obj);
                }
            }
            else if (obj instanceof Laya.Scene3D) {
                this.view = obj;
            }
            if (this.parentView) {
                if (this.view) {
                    this.showView();
                }
                else if (this.viewClass) {
                    this.showView();
                }
                this.opened = true;
            }
            this.openComplete();
        }
    }

    class Scene3DController extends View3DController {
        constructor() {
            super();
            this.isAutoDestroy = false;
        }
    }

    class SceneViewTool {
        static getElementUrl(cid) {
            var img = SceneVoBuilder.getImage(cid);
            return SceneConfig.getElementUrl(img);
        }
    }

    class Goods3DViewController extends Scene3DController {
        constructor(ui) {
            super();
            this.animName = 'idle';
            this.roleCid = 1;
            this.x = 0;
            this.y = 0;
            this.z = 0;
            this.s = 1;
            this.ry = 0;
            this;
            this.parentView = ui;
            this.viewURL = SceneConfig.getSceneUrl(0);
        }
        openComplete() {
            super.openComplete();
            this.scene = this.view = Display3DUtil.copyScene3D(this.view, true);
            this.showCamera();
            this.showole();
        }
        showCamera() {
            if (this.scene) {
                var camera = DisplayUtil.getChildByName(this.scene, 'Camera');
                camera.clearFlag = Laya.CameraClearFlags.DepthOnly;
                camera.enableHDR = false;
            }
        }
        showRole(roleCid, clothesCid = 0, helmetCid = 0, gunCid = 0, x = 0, y = 0, z = 0, scale = 1, rx = 0, ry = 0, rz = 0) {
            this.clothesImage = SceneViewTool.getElementUrl(clothesCid);
            this.helmetImage = SceneViewTool.getElementUrl(helmetCid);
            this.gunImage = SceneViewTool.getElementUrl(gunCid);
            this.x = x;
            this.y = y;
            this.z = z;
            this.s = scale;
            this.ry = ry;
            if (this.role && this.roleCid == roleCid) {
                this.showole();
            }
            else {
                if (this.role) {
                    this.role.removeSelf();
                }
                this.roleCid = roleCid;
                var img = SceneVoBuilder.getImage(roleCid);
                var url = SceneConfig.getUnitUrl(img);
                LoaderUtil.load3D(url, null, this, this.loadHandler);
            }
        }
        loadHandler(obj) {
            if (this.role) {
                this.role.removeSelf();
            }
            this.role = obj;
            this.showole();
        }
        showole() {
            if (!this.scene) {
                return;
            }
            if (!this.role) {
                return;
            }
            var obj = this.role;
            this.scene.addChild(obj);
            obj.transform.localRotationEulerY = this.ry;
            obj.transform.localPositionX = this.x;
            obj.transform.localPositionY = this.y;
            obj.transform.localPositionZ = this.z;
            obj.transform.localScaleX = this.s;
            obj.transform.localScaleY = this.s;
            obj.transform.localScaleZ = this.s;
            obj.transform.localRotationEulerY = this.ry;
            this.unitAnim = DisplayUtil.getComponent(obj, Laya.Animator);
            this.playAnim(this.animName);
            var fireBox = DisplayUtil.getChildByName(this.role, 'fireBox');
            if (fireBox) {
                fireBox.removeChildren();
            }
        }
        showGun() {
            this.showEquip(this.gunImage, 'gunBox');
        }
        showHelmet() {
            this.showEquip(this.helmetImage, 'headBox');
        }
        showClothes() {
            this.showEquip(this.clothesImage, 'bodyBox');
        }
        showEquip(name, boxName) {
            var box = DisplayUtil.getChildByName(this.role, boxName);
            if (box) {
                box.removeChildren();
                if (this.clothesImage) {
                    LoaderUtil.load3D(name, box, this);
                }
            }
        }
        playAnim(name = '') {
            if (!name) {
                name = this.animName;
            }
            if (this.unitAnim) {
                this.unitAnim.play(name);
            }
        }
        close() {
            super.close();
            if (this.role) {
                ViewPoolUtil.recover(this.role);
            }
        }
    }

    class GoodsElementTool {
        static getGunLoc() {
            var list = GoodsModel.model.getGoodsByType(30, 1, 2, 1);
            var vo = list[0];
            if (!vo) {
                return 30042101;
            }
            return vo.cid;
        }
        static getHelmetLoc() {
            var list = GoodsModel.model.getGoodsByType(30, 2, 1, 1);
            var vo = list[0];
            if (!vo) {
                return 0;
            }
            return vo.cid;
        }
        static getClothesLoc() {
            var list = GoodsModel.model.getGoodsByType(30, 3, 1, 1);
            var vo = list[0];
            if (!vo) {
                return 0;
            }
            return vo.cid;
        }
    }

    class BattleReadyView extends ui.battle.BattleReadyUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleReadyViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = BattleReadyView;
            this.viewName = 'BattleReadyView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui);
                this.startChild(this.goods3D);
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.btn_trial.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.btn_trial2.on(Laya.Event.CLICK, this, this.ad2Handler);
            this.ui.btn_trial3.on(Laya.Event.CLICK, this, this.ad3Handler);
            this.ui.img_bg.on(Laya.Event.CLICK, this, this.checkAdHandler);
            this.addEventListener(GoodsEvent.GOODS_LOC_SET_REQUEST, this, this.showInfo);
            this.showInfo();
        }
        close() {
            super.close();
            this.goods3D.close();
        }
        showInfo() {
            this.ui.item_goods1.dataSource = GoodsViewTool.getGoodsRewardData(GoodsElementTool.getGunLoc());
            this.ui.item_goods2.dataSource = GoodsViewTool.getGoodsRewardData(GoodsElementTool.getHelmetLoc());
            this.ui.item_goods3.dataSource = GoodsViewTool.getGoodsRewardData(GoodsElementTool.getClothesLoc());
            var list = this.checkList();
            this.ui.item_ad1.dataSource = GoodsViewTool.getGoodsRewardData(list[0]);
            this.ui.item_ad2.dataSource = GoodsViewTool.getGoodsRewardData(list[1]);
            this.ui.item_ad3.dataSource = GoodsViewTool.getGoodsRewardData(list[2]);
            this.showRole();
        }
        showRole() {
            var head = GoodsElementTool.getHelmetLoc();
            var body = GoodsElementTool.getClothesLoc();
            var gun = GoodsElementTool.getGunLoc();
            this.goods3D.showRole(0, body, head, gun, -0.8, 0, 1, 0, 50);
        }
        checkList() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var list = BattleConfig.lotteryList;
            var nlist = [];
            for (var k in list) {
                var glist = list[k];
                var goods = this.checkGoods(lv, glist);
                nlist.push(goods);
            }
            return nlist;
        }
        checkGoods(lv, list) {
            var item = null;
            for (var i = list.length - 1; i >= 0; i--) {
                var item = list[i];
                if (!item.lvn) {
                    return item;
                }
                else if (item.lvn <= lv) {
                    return item;
                }
            }
            return null;
        }
        okHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_START, this.data);
            this.close();
        }
        adHandler() {
            AdTool.videoAdShow(this, this.trialHandler);
        }
        ad2Handler() {
            AdTool.videoAdShow(this, this.trial2Handler);
        }
        ad3Handler() {
            AdTool.videoAdShow(this, this.trial3Handler);
        }
        checkAdHandler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
        trialHandler() {
            var list = this.checkList();
            var goodsVo = list[0];
            console.log(goodsVo);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: goodsVo.cid, num: 1 }] });
            var co = GoodsModel.model.getGoodsByCid(goodsVo.cid);
            this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: co.id });
        }
        trial2Handler() {
            var list = this.checkList();
            var goodsVo = list[1];
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: goodsVo.cid, num: 1 }] });
            var co = GoodsModel.model.getGoodsByCid(goodsVo.cid);
            this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: co.id });
        }
        trial3Handler() {
            var list = this.checkList();
            var goodsVo = list[2];
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: goodsVo.cid, num: 1 }] });
            var co = GoodsModel.model.getGoodsByCid(goodsVo.cid);
            this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: co.id });
        }
    }

    class BattleRebornHeroView extends ui.battle.BattleRebornHeroUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleRebornHeroViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleRebornHeroView;
            this.viewName = 'BattleRebornHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.list_card.on(Laya.Event.CLICK, this, this.selectHandler);
            this.showList();
        }
        showList() {
            var nlist = [];
            var unitList = SceneModel.model.vo.unitList;
            for (var i in unitList) {
                var vo = unitList[i];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var data = {};
                    data.img_battle = { vo: vo };
                    data.img_ico = GoodsViewTool.getImgUrl(vo.cid);
                    data.txt_name = vo.name;
                    nlist.push(data);
                }
            }
            this.ui.list_card.dataSource = nlist;
        }
        selectHandler(e) {
            if (MouseTool.checkClick(e, 'img_battle')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    var playerVo = SceneModel.model.vo.playerVo;
                    if (playerVo.id == vo.id) {
                        this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_REVIVE);
                    }
                    else {
                        playerVo = BattleTool.getBattleData(1, vo.cid).playerVo;
                        this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_SELECT, { selectVo: vo, playerVo: playerVo });
                    }
                    this.close();
                }
            }
        }
    }

    class BattleReloadView extends ui.battle.BattleReloadUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleReloadViewController extends PanelViewController {
        constructor() {
            super();
            this.startTime = 0;
            this.tatalTime = 0;
            this.viewClass = BattleReloadView;
            this.viewName = 'BattleTimeView';
            this.openSound = 'reload';
            this.closeSound = 'reloaded';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.tatalTime = this.data.time;
            this.startTime = TimeUtil.getTime();
            TimerUtil.loopFrame(1, this, this.timerHandler);
        }
        timerHandler() {
            var ct = TimeUtil.getTime() - this.startTime;
            var lt = this.tatalTime - ct;
            var v = ct / this.tatalTime;
            if (lt <= 0) {
                TimerUtil.stopTimer(this, this.timerHandler);
                this.close();
                return;
            }
            this.ui.img_time.rotation = v * 360;
            this.ui.txt_time.text = '' + (lt / 1000).toFixed(2);
        }
    }

    class BattleResurrecView extends ui.battle.BattleResurrecUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleResurrecViewController extends DialogViewController {
        constructor() {
            super();
            this.timeTotal = 5;
            this.viewClass = BattleResurrecView;
            this.viewName = 'BattleResurrecView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
                this.ui.btn_ad.on(Laya.Event.CLICK, this, this.adHandler);
                this.ui.btn_no.on(Laya.Event.CLICK, this, this.closeHandler);
            }
            this.ui.btn_ok.visible = false;
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.txt_time);
            var playerVo = SceneModel.model.vo.playerVo;
            var atter = this.data.atter;
            if (atter) {
                this.ui.txt_name2.text = atter.name;
                this.ui.img_head2.skin = GoodsViewTool.getIconUrl(atter.cid);
            }
            if (playerVo) {
                this.ui.txt_name.text = playerVo.name;
                this.ui.img_head.skin = GoodsViewTool.getIconUrl(playerVo.cid);
            }
            if (atter.cid == 30071001) {
                this.ui.box_show.visible = false;
                this.ui.txt_tip.visible = true;
                this.ui.txt_tip.text = '因坠落而死';
            }
            else {
                this.ui.box_show.visible = true;
                this.ui.txt_tip.visible = false;
            }
            if (BattleModel.model.battleType != 3) {
                TimerUtil.loopTimer(1000, this, this.showTime);
                this.ui.btn_ad.visible = false;
                this.ui.btn_no.visible = false;
                this.ui.btn_ad.disabled = true;
                this.ui.btn_no.disabled = true;
            }
            else {
                if (SceneModel.model.vo.playerDieNum > BattleConfig.levReviveMaxNum) {
                    this.ui.btn_ad.visible = false;
                    this.ui.btn_no.visible = false;
                    this.ui.btn_ad.disabled = true;
                    this.ui.btn_no.disabled = true;
                    this.ui.btn_ok.visible = false;
                    this.ui.btn_ok.disabled = true;
                    TimerUtil.loopTimer(1000, this, this.showTime2);
                }
                else {
                    TimerUtil.loopTimer(1000, this, this.showTime);
                    this.ui.btn_ad.visible = false;
                    this.ui.btn_no.visible = false;
                    this.ui.btn_ad.disabled = true;
                    this.ui.btn_no.disabled = true;
                }
            }
        }
        showTime2() {
            this.timeTotal--;
            this.label.text = '' + this.timeTotal;
            if (this.timeTotal <= 0) {
                this.ui.btn_ad.visible = true;
                this.ui.btn_no.visible = true;
                this.ui.btn_ad.disabled = false;
                this.ui.btn_no.disabled = false;
                TimerUtil.stopTimer(this, this.showTime2);
            }
        }
        showTime() {
            this.timeTotal--;
            this.label.text = '' + this.timeTotal;
            if (this.timeTotal <= 0) {
                this.ui.btn_ok.visible = false;
                TimerUtil.stopTimer(this, this.showTime);
                this.okHandler();
            }
        }
        okHandler() {
            this.close();
            if (SceneModel.model.vo.state >= 2) {
                return;
            }
            this.dispatchEvent(BattleEvent.BATTLE_TRY_HERO_VIEW_SHOW);
        }
        closeHandler() {
            this.dispatchEvent(SceneEvent.SCENE_VIEW_EXIT, { isExit: true });
        }
        adHandler() {
            if (this.ui.btn_ad.visible == true) {
                AdTool.videoAdShow(this, this.okHandler);
            }
            else {
                this.okHandler();
            }
        }
    }

    class BattleReviveTipView extends ui.battle.BattleReviveTipUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class BattleReviveTipViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleReviveTipView;
        }
        openComplete() {
            super.openComplete();
            this.addEventListener(BattleEvent.BATTLE_STATE_END, this, this.close);
            TimerUtil.onceTimer(4000, this, this.close);
        }
    }

    class BattleStartTipView extends ui.battle.BattleStartTipUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleStartTipViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleStartTipView;
            this.viewName = 'BattleStartTipView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.ui_1.visible = true;
            this.ui.ui_2.visible = false;
            this.ui.ui_3.visible = false;
            this.ui.ui_1.ani1.play(1, false);
            TimerUtil.onceTimer(2000, this, this.nextTimerHandler);
        }
        nextTimerHandler() {
            this.ui.ui_1.visible = false;
            this.ui.ui_2.visible = true;
            this.ui.ui_3.visible = true;
            this.ui.ui_2.ani1.play(1, false);
            this.ui.ui_3.ani1.play(1, false);
            TimerUtil.onceTimer(3000, this, this.close);
        }
    }

    class HeroConfig {
    }
    HeroConfig.lvMax = 30;
    HeroConfig.tongNumNormal = 400;
    HeroConfig.tongNumRare = 600;
    HeroConfig.tongNumEpic = 1000;
    HeroConfig.cardNumNormal = 20;
    HeroConfig.cardNumRare = 5;
    HeroConfig.cardNumEpic = 1;
    HeroConfig.expNumNormal = 2;
    HeroConfig.expNumRare = 6;
    HeroConfig.expNumEpic = 8;
    HeroConfig.defaultHero = 30011001;
    HeroConfig.unlockTipType = 1;
    HeroConfig.heroList = [
        30011002,
        30011005,
        30011004,
        30011006,
        30011007,
        30011008,
        30011009,
        30011010,
    ];

    class HeroTool {
        static getLocHero() {
            var vo = GoodsModel.model.getFirstByType(30, 9, 1, 1);
            if (!vo) {
                vo = GoodsVoBuilder.getGoodsVo(HeroConfig.defaultHero);
            }
            return vo;
        }
        static getSkillVo(cid) {
            var vo = SceneVoBuilder.getElementVo(cid);
            var skillCid = vo.skills[0];
            if (skillCid) {
                var skillVo = SceneVoBuilder.getElementVo(skillCid);
                return skillVo;
            }
            return null;
        }
        static getGunVo(cid) {
            var vo = SceneVoBuilder.getElementVo(cid);
            var gunCid = vo.attCid;
            if (gunCid) {
                var unitVo = SceneVoBuilder.getElementVo(gunCid);
                return unitVo;
            }
            return null;
        }
        static getUnitHp(cid) {
            var vo = SceneVoBuilder.getElementVo(cid);
            var hp = vo.hp;
            if (hp) {
                return hp;
            }
            return null;
        }
        static getHeroIndex(cid) {
            var index = 0;
            var heroList = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            for (var k in heroList) {
                if (heroList[k].cid != cid) {
                    index++;
                }
                else {
                    return index;
                }
            }
        }
        static getFirstByUnlock() {
            var heroList = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            for (var k in heroList) {
                var heroVo = heroList[k];
                if (heroVo.isUnlock == false && heroVo.triphyNum > SegmentModel.model.maxTriphyNum) {
                    return heroVo;
                }
            }
            return null;
        }
    }

    class BattleStartTryHero1View extends ui.battle.BattleStartTryHero1UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleStartTryHero1ViewController extends DialogViewController {
        constructor() {
            super();
            this.battleType = 1;
            this.viewClass = BattleStartTryHero1View;
            this.viewName = 'BattleStartTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.txt_no.on(Laya.Event.CLICK, this, this.rebornHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 1);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            this.showbtn();
            this.showRoleHandler();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            this.goods3D.close();
            this.close();
        }
        adHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryPreWar');
        }
        closeHandler() {
            BattleModel.model.playerCid = BattleModel.model.tryHerocid;
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: true });
            this.goods3D.close();
            this.close();
        }
        showbtn() {
            this.ui.txt_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.txt_no.visible = true;
                });
            }
            else {
                this.ui.txt_no.visible = true;
            }
        }
    }

    class BattleStartTryHero2View extends ui.battle.BattleStartTryHero2UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleStartTryHero2ViewController extends DialogViewController {
        constructor() {
            super();
            this.battleType = 1;
            this.adNum = 0;
            this.viewClass = BattleStartTryHero2View;
            this.viewName = 'BattleStartTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.txt_no.on(Laya.Event.CLICK, this, this.rebornHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 1);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            this.adNum = 0;
            this.showbtn();
            this.showRoleHandler();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            var gameNum = BattleModel.model.victoryNum + BattleModel.model.defeatNum;
            if (AdTool.checkRate('shipin', true)) {
                if (gameNum >= 1) {
                    if (this.adNum >= 1) {
                        this.enterGameHandler();
                        LogTool.log('rebornHandler333333');
                    }
                    else {
                        AdTool.videoAdShow(this, this.adEnterGameHandler);
                        LogTool.log('rebornHandler222222');
                    }
                    this.adNum++;
                }
                else {
                    this.enterGameHandler();
                    LogTool.log('rebornHandler1111111:' + gameNum);
                }
            }
            else {
                this.enterGameHandler();
                LogTool.log('rebornHandler4444444:' + gameNum);
            }
        }
        adEnterGameHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            this.goods3D.close();
            this.close();
        }
        enterGameHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            if (AdTool.checkRate('wudian', true)) {
                this.dispatchEvent(BattleEvent.BATTLE_CRAZY_CHEST_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            }
            else {
                this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            }
            this.goods3D.close();
            this.close();
        }
        adHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryPreWar');
        }
        closeHandler() {
            BattleModel.model.playerCid = BattleModel.model.tryHerocid;
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: true });
            this.goods3D.close();
            this.close();
        }
        showbtn() {
            this.ui.txt_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.txt_no.visible = true;
                });
            }
            else {
                this.ui.txt_no.visible = true;
            }
        }
    }

    class BattleStartTryHero3View extends ui.battle.BattleStartTryHero3UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleStartTryHero3ViewController extends DialogViewController {
        constructor() {
            super();
            this.battleType = 1;
            this.adNum = 0;
            this.viewClass = BattleStartTryHero3View;
            this.viewName = 'BattleStartTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.txt_no.on(Laya.Event.CLICK, this, this.rebornHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 1);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            this.adNum = 0;
            this.showbtn();
            this.showRoleHandler();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            this.enterGameHandler();
        }
        adEnterGameHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            this.goods3D.close();
            this.close();
        }
        enterGameHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            if (AdModel.model.isShieldCity == false) {
                this.dispatchEvent(BattleEvent.BATTLE_CRAZY_CHEST_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            }
            else {
                this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            }
            this.goods3D.close();
            this.close();
        }
        adHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryPreWar');
        }
        closeHandler() {
            BattleModel.model.playerCid = BattleModel.model.tryHerocid;
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: true });
            this.goods3D.close();
            this.close();
        }
        showbtn() {
            this.ui.txt_no.visible = false;
            if (AdModel.model.isShieldCity == false) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.txt_no.visible = true;
                });
            }
            else {
                this.ui.txt_no.visible = true;
            }
        }
    }

    class BattleStartTryHero4View extends ui.battle.BattleStartTryHero4UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleStartTryHero4ViewController extends DialogViewController {
        constructor() {
            super();
            this.battleType = 1;
            this.viewClass = BattleStartTryHero4View;
            this.viewName = 'BattleStartTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.txt_no.on(Laya.Event.CLICK, this, this.rebornHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 1);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            if (AdModel.model.isShieldCity == false) {
                this.ui.ui_try.img_ad.visible = false;
                this.ui.ui_try.img_try.x = 73;
            }
            else {
                this.ui.ui_try.img_ad.visible = true;
                this.ui.ui_try.img_try.x = 101;
            }
            this.showbtn();
            this.showRoleHandler();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            this.goods3D.close();
            this.close();
        }
        adHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryPreWar');
        }
        closeHandler() {
            BattleModel.model.playerCid = BattleModel.model.tryHerocid;
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: true });
            this.goods3D.close();
            this.close();
        }
        showbtn() {
            this.ui.txt_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.txt_no.visible = true;
                });
            }
            else {
                this.ui.txt_no.visible = true;
            }
        }
    }

    class BattleStartTryHeroView extends ui.battle.BattleStartTryHeroUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleStartTryHeroViewController extends DialogViewController {
        constructor() {
            super();
            this.battleType = 1;
            this.viewClass = BattleStartTryHeroView;
            this.viewName = 'BattleStartTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.img_close.on(Laya.Event.CLICK, this, this.rebornHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            this.battleType = ParamUtil.getInt(this.data, 'battleType', 1);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            if (AdTool.checkVideoIco('ys_jili')) {
                this.ui.ui_try.img_ad.visible = true;
            }
            else {
                this.ui.ui_try.img_ad.visible = false;
            }
            this.showRoleHandler();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: false });
            this.goods3D.close();
            this.close();
        }
        adHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryPreWar');
        }
        closeHandler() {
            BattleModel.model.playerCid = BattleModel.model.tryHerocid;
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: this.battleType, isTry: true });
            this.goods3D.close();
            this.close();
        }
    }

    class BattleTask1View extends ui.battle.BattleTask1UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTask1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTask1View;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
            this.showbtn();
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
        showbtn() {
            this.ui.btn_get.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_get.visible = true;
            }
        }
    }

    class BattleTask2View extends ui.battle.BattleTask2UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTask2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTask2View;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
    }

    class BattleTask3View extends ui.battle.BattleTask3UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTask3ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTask3View;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
            this.showbtn();
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
        showbtn() {
            this.ui.btn_get.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_get.visible = true;
            }
        }
    }

    class BattleTask4View extends ui.battle.BattleTask4UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTask4ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTask4View;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
    }

    class BattleTask5View extends ui.battle.BattleTask5UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTask5ViewController extends DialogViewController {
        constructor() {
            super();
            this.btnEnble = true;
            this.viewClass = BattleTask5View;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
            if (AdTool.checkRate('wzsy', true)) {
                this.ui.btn_get.y = 269;
                this.btnEnble = false;
                TimerUtil.onceTimer(1400, this, () => {
                    this.showBtn();
                    this.btnEnble = true;
                });
            }
            else {
                this.ui.btn_get.y = 111;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
        showBtn() {
            this.ui.btn_get.y = 111;
        }
    }

    class BattleTask6View extends ui.battle.BattleTask6UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTask6ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTask6View;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
            this.showbtn();
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
        showbtn() {
            this.ui.btn_get.visible = false;
            if (AdModel.model.isShieldCity == false) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_get.visible = true;
            }
        }
    }

    class BattleTask7View extends ui.battle.BattleTask7UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTask7ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTask7View;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
                this.ui.check_ad.on(Laya.Event.CLICK, this, this.checkHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
            if (AdModel.model.isShieldCity == false) {
                this.ui.img_ad2.visible = false;
                this.ui.img_double.x = 56;
            }
            else {
                this.ui.img_ad2.visible = true;
                this.ui.img_double.x = 79;
            }
            if (AdTool.checkRate('mrgx', true)) {
                this.ui.check_ad.selected = true;
            }
            else {
                this.ui.check_ad.selected = false;
            }
            this.checkShow();
            this.showbtn();
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        checkHandler() {
            if (this.ui.check_ad.selected) {
                this.ui.check_ad.selected = false;
            }
            else {
                this.ui.check_ad.selected = true;
            }
            this.checkShow();
        }
        checkShow() {
            if (this.ui.check_ad.selected) {
                this.ui.img_ad2.visible = false;
                this.ui.img_double.x = 56;
            }
            else {
                this.ui.img_ad2.visible = true;
                this.ui.img_double.x = 79;
            }
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
        showbtn() {
            this.ui.btn_get.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_get.visible = true;
            }
        }
    }

    class BattleTaskView extends ui.battle.BattleTaskUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTaskViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTaskView;
            this.viewName = 'BattleTaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.getRwHandler);
                this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.label = new BitmapLabelView("font/white.json", 1, this.ui.ui_tong.txt_num);
            this.label2 = new BitmapLabelView("font/white.json", 1, this.ui.ui_card.txt_num);
            LogTool.log(JSONUtil.stringify(this.data.list));
            this.label.text = '' + this.data.list[0].num;
            this.label2.text = '' + this.data.list[1].num;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.list[1].cid);
        }
        adHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
            this.close();
        }
        getRwHandler() {
            this.close();
        }
    }

    class BattleTextTipView extends ui.battle.BattleTextTipUI {
        constructor() {
            super();
            this.zOrder = 100;
        }
    }

    class BattleTextTipViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BattleTextTipView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                TimerUtil.onceTimer(1500, this, this.close);
            }
            this.ui.txt_1.text = this.data.text;
        }
    }

    class BattleTryHero1View extends ui.battle.BattleTryHero1UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTryHero1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTryHero1View;
            this.viewName = 'BattleTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.txt_no.on(Laya.Event.CLICK, this, this.rebornHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            this.showRoleHandler();
            this.showbtn();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            this.close();
            this.goods3D.close();
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_REVIVE);
        }
        closeHandler() {
            this.close();
            this.goods3D.close();
            var playerVo = SceneModel.model.vo.playerVo;
            playerVo = BattleTool.getBattleData(1, BattleModel.model.tryHerocid, true).playerVo;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_RELPACE, { playerVo: playerVo });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryBattle');
        }
        showbtn() {
            this.ui.txt_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.txt_no.visible = true;
                });
            }
            else {
                this.ui.txt_no.visible = true;
            }
        }
    }

    class BattleTryHero2View extends ui.battle.BattleTryHero2UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTryHero2ViewController extends DialogViewController {
        constructor() {
            super();
            this.adNum = 0;
            this.viewClass = BattleTryHero2View;
            this.viewName = 'BattleTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.txt_no.on(Laya.Event.CLICK, this, this.reviveHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            this.adNum = 0;
            this.showRoleHandler();
            this.showbtn();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            if (AdTool.checkRate('shipin', true)) {
                var gameNum = BattleModel.model.victoryNum + BattleModel.model.defeatNum;
                if (gameNum >= 1) {
                    if (this.adNum >= 1) {
                        this.reviveHandler();
                        LogTool.log('rebornHandler333333');
                    }
                    else {
                        AdTool.videoAdShow(this, this.reviveHandler);
                        LogTool.log('rebornHandler222222');
                    }
                    this.adNum++;
                }
                else {
                    this.reviveHandler();
                    LogTool.log('rebornHandler1111111:' + gameNum);
                }
            }
            else {
                this.reviveHandler();
            }
        }
        reviveHandler() {
            this.close();
            this.goods3D.close();
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_REVIVE);
        }
        closeHandler() {
            this.close();
            this.goods3D.close();
            var playerVo = SceneModel.model.vo.playerVo;
            playerVo = BattleTool.getBattleData(1, BattleModel.model.tryHerocid, true).playerVo;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_RELPACE, { playerVo: playerVo });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryBattle');
        }
        showbtn() {
            this.ui.txt_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.txt_no.visible = true;
                });
            }
            else {
                this.ui.txt_no.visible = true;
            }
        }
    }

    class BattleTryHero3View extends ui.battle.BattleTryHero3UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTryHero3ViewController extends DialogViewController {
        constructor() {
            super();
            this.adNum = 0;
            this.viewClass = BattleTryHero3View;
            this.viewName = 'BattleTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.txt_no.on(Laya.Event.CLICK, this, this.reviveHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            this.adNum = 0;
            if (AdModel.model.isShieldCity == false) {
                this.ui.ui_try.img_ad.visible = false;
                this.ui.ui_try.img_try.x = 73;
            }
            else {
                this.ui.ui_try.img_ad.visible = true;
                this.ui.ui_try.img_try.x = 101;
            }
            this.showRoleHandler();
            this.showbtn();
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            if (AdTool.checkRate('shipin', true)) {
                var gameNum = BattleModel.model.victoryNum + BattleModel.model.defeatNum;
                if (gameNum >= 1) {
                    if (this.adNum >= 1) {
                        this.reviveHandler();
                        LogTool.log('rebornHandler333333');
                    }
                    else {
                        AdTool.videoAdShow(this, this.reviveHandler);
                        LogTool.log('rebornHandler222222');
                    }
                    this.adNum++;
                }
                else {
                    this.reviveHandler();
                    LogTool.log('rebornHandler1111111:' + gameNum);
                }
            }
            else {
                this.reviveHandler();
            }
        }
        reviveHandler() {
            this.close();
            this.goods3D.close();
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_REVIVE);
        }
        closeHandler() {
            this.close();
            this.goods3D.close();
            var playerVo = SceneModel.model.vo.playerVo;
            playerVo = BattleTool.getBattleData(1, BattleModel.model.tryHerocid, true).playerVo;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_RELPACE, { playerVo: playerVo });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryBattle');
        }
        showbtn() {
            this.ui.txt_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.txt_no.visible = true;
                });
            }
            else {
                this.ui.txt_no.visible = true;
            }
        }
    }

    class BattleTryHeroView extends ui.battle.BattleTryHeroUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleTryHeroViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleTryHeroView;
            this.viewName = 'BattleTryHeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.img_close.on(Laya.Event.CLICK, this, this.rebornHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler);
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(BattleModel.model.tryHerocid);
            var skillVo = HeroTool.getSkillVo(BattleModel.model.tryHerocid);
            var gunVo = HeroTool.getGunVo(BattleModel.model.tryHerocid);
            this.ui.ui_up.txt_name.text = skillVo.name;
            this.ui.ui_up.txt_info.text = skillVo.info;
            this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.ui_down.txt_name.text = gunVo.name;
            this.ui.ui_down.txt_info.text = gunVo.info;
            this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            this.showRoleHandler();
            if (AdTool.checkVideoIco('ys_jili')) {
                this.ui.ui_try.img_ad.visible = true;
            }
            else {
                this.ui.ui_try.img_ad.visible = false;
            }
        }
        showRoleHandler() {
            this.goods3D.showRole(BattleModel.model.tryHerocid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        rebornHandler() {
            this.close();
            this.goods3D.close();
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_REVIVE);
        }
        closeHandler() {
            this.close();
            this.goods3D.close();
            var playerVo = SceneModel.model.vo.playerVo;
            playerVo = BattleTool.getBattleData(1, BattleModel.model.tryHerocid, true).playerVo;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_RELPACE, { playerVo: playerVo });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.closeHandler, 'heroTryBattle');
        }
    }

    class PageModel {
        constructor() {
            this.gameNum = 0;
            this.statueView = true;
            this.gameTs = 0;
            this.startGameTs = 0;
            this.battleType = 1;
            this.goldGunIndex = 1;
            this.goldGunNum = 0;
            this.chestNum = 0;
            this.giftNum = 0;
            this.phyAdNum = 0;
            this.jinAdNum = 0;
            this.tongAdNum = 0;
        }
        static get model() {
            return ModelManager.getModel('PageModel', PageModel);
        }
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.gameNum = this.gameNum;
            data.startGameTs = this.startGameTs;
            data.goldGunNum = this.goldGunNum;
            data.goldGunIndex = this.goldGunIndex;
            data.chestNum = this.chestNum;
            data.giftNum = this.giftNum;
            data.phyAdNum = this.phyAdNum;
            data.jinAdNum = this.jinAdNum;
            data.tongAdNum = this.tongAdNum;
            StorageModel.model.setData("page", data);
        }
        loadData() {
            var data = StorageModel.model.getData("page");
            this.gameNum = ParamUtil.getInt(data, 'gameNum', 0);
            this.startGameTs = ParamUtil.getNumber(data, 'startGameTs', 0);
            this.goldGunNum = ParamUtil.getInt(data, 'goldGunNum', 0);
            this.goldGunIndex = ParamUtil.getInt(data, 'goldGunIndex', 1);
            this.chestNum = ParamUtil.getNumber(data, 'chestNum', 0);
            this.giftNum = ParamUtil.getNumber(data, 'giftNum', 0);
            this.phyAdNum = ParamUtil.getNumber(data, 'phyAdNum', 0);
            this.jinAdNum = ParamUtil.getNumber(data, 'jinAdNum', 0);
            this.tongAdNum = ParamUtil.getNumber(data, 'tongAdNum', 0);
            return data;
        }
    }

    class BattleVictory1View extends ui.battle.BattleVictory1UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictory1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleVictory1View;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.addTriphy();
            this.showbtn();
            SoundTool.playSound('victory');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
            LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleVictory2View extends ui.battle.BattleVictory2UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictory2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleVictory2View;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.addTriphy();
            this.showbtn();
            SoundTool.playSound('victory');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
            LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleVictory3View extends ui.battle.BattleVictory3UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictory3ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleVictory3View;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.addTriphy();
            this.showbtn();
            SoundTool.playSound('victory');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
            LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleVictory4View extends ui.battle.BattleVictory4UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictory4ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleVictory4View;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.addTriphy();
            SoundTool.playSound('victory');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
            LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleVictory5View extends ui.battle.BattleVictory5UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictory5ViewController extends DialogViewController {
        constructor() {
            super();
            this.btnEnble = true;
            this.viewClass = BattleVictory5View;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.addTriphy();
            if (AdTool.checkRate('wzsy', true)) {
                this.ui.ui_anim.txt_one.x = 559;
                this.btnEnble = false;
                TimerUtil.onceTimer(1400, this, () => {
                    this.showBtn();
                    this.btnEnble = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.x = 110;
            }
            SoundTool.playSound('victory');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (this.btnEnble) {
                if (BattleModel.model.battleType == 3) {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
                }
                else {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
                }
                this.close();
                this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
                this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
                this.goldGunHandler();
                BattleModel.model.isSettlement = true;
                LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
                LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
                if (BattleModel.model.battleType == 3) {
                    if (BattleModel.model.isUnlock == true) {
                        this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                    }
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
        showBtn() {
            this.ui.ui_anim.txt_one.x = 110;
        }
    }

    class BattleVictory6View extends ui.battle.BattleVictory6UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictory6ViewController extends DialogViewController {
        constructor() {
            super();
            this.btnEnble = true;
            this.viewClass = BattleVictory6View;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.addTriphy();
            SoundTool.playSound('victory');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (this.btnEnble) {
                if (BattleModel.model.battleType == 3) {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
                }
                else {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
                }
                this.close();
                this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
                this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
                this.goldGunHandler();
                BattleModel.model.isSettlement = true;
                LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
                LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
                if (BattleModel.model.battleType == 3) {
                    if (BattleModel.model.isUnlock == true) {
                        this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                    }
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
        showBtn() {
            this.ui.ui_anim.txt_one.x = 110;
        }
    }

    class BattleVictory7View extends ui.battle.BattleVictory7UI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictory7ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleVictory7View;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.txt_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
                this.ui.check_ad.on(Laya.Event.CLICK, this, this.checkHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.ui.ui_anim.img_light.visible = false;
            this.ui.ui_anim.box_1.visible = false;
            this.ui.ui_anim.box_2.visible = false;
            this.ui.ui_anim.box_3.y = 294;
            if (AdModel.model.isShieldCity == false) {
                this.ui.ui_anim.img_one.visible = false;
                this.ui.ui_anim.txt_one.visible = true;
            }
            else {
                this.ui.ui_anim.img_one.visible = true;
                this.ui.ui_anim.txt_one.visible = false;
            }
            this.victoryNum = BattleModel.model.victoryNum;
            if (AdTool.checkRate('mrgx', true)) {
                this.ui.check_ad.selected = true;
            }
            else {
                this.ui.check_ad.selected = false;
            }
            this.checkShow();
            this.showMoney();
            this.addTriphy();
            this.showbtn();
            SoundTool.playSound('victory');
        }
        checkHandler() {
            if (this.ui.check_ad.selected) {
                this.ui.check_ad.selected = false;
            }
            else {
                this.ui.check_ad.selected = true;
            }
            this.checkShow();
        }
        checkShow() {
            if (this.ui.check_ad.selected) {
                this.ui.ui_anim.img_ad.visible = false;
                this.ui.ui_anim.img_get3.x = 63;
            }
            else {
                this.ui.ui_anim.img_ad.visible = true;
                this.ui.ui_anim.img_get3.x = 87;
            }
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
            LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
        showbtn() {
            this.ui.ui_anim.txt_one.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.ui_anim.txt_one.visible = true;
                });
            }
            else {
                this.ui.ui_anim.txt_one.visible = true;
            }
        }
    }

    class BattleVictoryMvpView extends ui.battle.BattleVictoryMvpUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictoryMvpViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = BattleVictoryMvpView;
            this.viewName = 'BattleVictoryMvpView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.dispatchEvent(BattleEvent.BATTLE_CLOSE_CLICK);
            this.addEventListener(SceneEvent.SCENE_END_CAMERA_COMPLETE, this, this.closeHandler);
            this.showInfo();
            SoundTool.playSound('victory');
        }
        showInfo() {
            if (this.vo.playerKillNum >= 10) {
                this.playerInfo();
            }
            else if (this.vo.playerKillNum <= 6 && this.vo.playerKillNum >= 9) {
                var random = RandomUtil.randomInt(1, 2);
                if (random == 1) {
                    this.playerInfo();
                }
                else {
                    this.enemyInfo();
                }
            }
            else {
                var random = RandomUtil.randomInt(1, 4);
                if (random > 1) {
                    this.enemyInfo();
                }
                else {
                    this.playerInfo();
                }
            }
        }
        enemyInfo() {
            var victoryNum = BattleModel.model.victoryNum;
            var nameList = BattleModel.model.nameList;
            var list = SceneModel.model.vo.unitList;
            var enemyList = [];
            var enemyNameList = [];
            for (var k in list) {
                if (list[k].ttype == 1 && list[k].camp == 1) {
                    var vo = list[k];
                    enemyList.push(vo);
                }
            }
            for (var i = 0; i < 5; i++) {
                enemyNameList.push(nameList[i]);
            }
            var npc = RandomUtil.randomItem(enemyList);
            var name = RandomUtil.randomItem(enemyNameList);
            if (npc) {
                this.ui.ui_npc.txt_name.text = '' + GoodsListConfig.getVo(npc.cid).name;
                this.ui.ui_npc.img_ico.skin = GoodsViewTool.getImgUrl(npc.cid);
            }
            this.ui.ui_npc.txt_lv.text = '' + BattleConfig.getNpcLv(victoryNum);
            this.ui.ui_npc.txt_airdrop.text = '' + name;
            this.ui.txt_kill.text = '' + RandomUtil.randomInt(2, 5);
        }
        playerInfo() {
            this.ui.txt_kill.text = '' + this.vo.playerKillNum;
            this.ui.ui_npc.txt_name.text = '' + GoodsListConfig.getVo(BattleModel.model.playerCid).name;
            this.ui.ui_npc.img_ico.skin = GoodsViewTool.getImgUrl(BattleModel.model.playerCid);
            this.ui.ui_npc.txt_lv.text = '' + GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid).lv;
            this.ui.ui_npc.txt_airdrop.text = '' + PlayerModel.model.name;
        }
        closeHandler() {
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_VICTORY_VIEW_SHOW);
        }
    }

    class BattleVictoryNoticeView extends ui.battle.BattleVictoryNoticeUI {
        constructor() {
            super();
            this.zOrder = 46;
        }
    }

    class BattleVictoryNoticeViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleVictoryNoticeView;
            this.viewName = 'BattleVictoryNoticeView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.vo = SceneModel.model.vo;
            this.ui.txt_kill_1.text = "" + this.vo.teamKillNum;
            this.ui.txt_kill_2.text = "" + this.vo.foeKillNum;
            this.ui.on(Laya.Event.CLICK, this, this.close);
        }
    }

    class BattleVictoryView extends ui.battle.BattleVictoryUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleVictoryViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = BattleVictoryView;
            this.viewName = 'BattleVictoryView';
            this.vo = SceneModel.model.vo;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.ui_anim.img_one.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.ui_anim.img_three.on(Laya.Event.CLICK, this, this.adHandler);
            }
            this.ui.ui_anim.ui_left.txt_name.text = '' + PlayerModel.model.name;
            this.ui.ui_anim.ui_left.img_ico.skin = '' + PlayerModel.model.ico;
            this.ui.ui_anim.ui_right.txt_name.text = '' + BattleModel.model.foeName;
            this.ui.ui_anim.ui_right.img_ico.skin = '' + BattleModel.model.foeIco;
            var triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_anim.ui_left.txt_num.text = '' + triphyNum;
            this.ui.ui_anim.ui_right.txt_num.text = '' + BattleModel.model.enemyTriphyNum;
            this.victoryNum = BattleModel.model.victoryNum;
            this.showMoney();
            this.addTriphy();
            SoundTool.playSound('victory');
        }
        showMoney() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.exp = 0;
            this.jin = (2 + lv) * this.vo.playerKillNum + BattleModel.model.pickJinNum;
            this.tong = (10 + lv * 5) * this.vo.playerKillNum + BattleModel.model.pickTongNum;
            this.medal = 0;
            this.ui.txt_jin.text = '' + this.jin;
            this.ui.txt_tong.text = '' + this.tong;
            this.ui.ui_anim.ui_left.list_1.dataSource = this.getList1();
            this.ui.ui_anim.ui_right.list_1.dataSource = this.getList2();
        }
        getList1() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 0;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp == 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 0) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + GoodsModel.model.getGoodsByCid(vo.cid).lv;
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        getList2() {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var index = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1 && vo.ttype == 1) {
                    var item = {};
                    item.txt_name = vo.name;
                    item.img_img = GoodsViewTool.getImgUrl(vo.cid);
                    if (index == 5) {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e2a015' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    else {
                        var name = BattleModel.model.nameList[index];
                        item.txt_name1 = { text: name, color: '#e5e2da' };
                        item.txt_lv = '' + BattleConfig.getNpcLv(this.victoryNum);
                    }
                    nlist.push(item);
                    index++;
                }
            }
            return nlist;
        }
        addTriphy() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = BattleConfig.getVictoryTriphy(lv);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: triphyNum }] });
        }
        closeHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.exp }, { cid: GoodsAttrType.ATTR_TONG, num: this.tong }, { cid: GoodsAttrType.ATTR_JIN, num: this.jin }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            LogTool.log('BattleModel.model.battleLev:' + BattleModel.model.battleLev);
            LogTool.log('BattleModel.model.lev:' + BattleModel.model.lev);
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tripleHandler);
        }
        tripleHandler() {
            if (BattleModel.model.battleType == 3) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }, { cid: GoodsAttrType.ATTR_MEDAL, num: this.medal * 3 }] });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: (this.exp * 3) }, { cid: GoodsAttrType.ATTR_TONG, num: (this.tong * 3) }, { cid: GoodsAttrType.ATTR_JIN, num: (this.jin * 3) }] });
            }
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_SETTLE_COMPLETE);
            this.dispatchEvent(BattleEvent.BATTLE_STATE_END);
            this.goldGunHandler();
            BattleModel.model.isSettlement = true;
            if (BattleModel.model.battleType == 3) {
                if (BattleModel.model.isUnlock == true) {
                    this.dispatchEvent(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW);
                }
            }
        }
        goldGunHandler() {
            if (PageModel.model.gameNum == 1) {
            }
        }
    }

    class TimeFormatUtil {
        static formatDate(time, format = 'YY-MM-DD hh:mm:ss') {
            var date = new Date(time * 1000);
            var year = date.getFullYear() + '';
            var month = this.check(date.getMonth() + 1);
            var day = this.check(date.getDate());
            var hour = this.check(date.getHours());
            var min = this.check(date.getMinutes());
            var sec = this.check(date.getSeconds());
            var newTime = format.replace(/YY/g, year);
            newTime = newTime.replace(/MM/g, month);
            newTime = newTime.replace(/DD/g, day);
            newTime = newTime.replace(/hh/g, hour);
            newTime = newTime.replace(/mm/g, min);
            newTime = newTime.replace(/ss/g, sec);
            return newTime;
        }
        static formatTime(time, showDay = false) {
            if (showDay) {
                return this.formatTimeDhms(time);
            }
            else {
                return this.formatTimeHms(time);
            }
        }
        static formatTimeHms(time) {
            var s = time % 60;
            var m = Math.floor(time / 60) % 60;
            var h = Math.floor(time / 60 / 60);
            var newTime = '';
            if (h > 0) {
                newTime += h + ':';
            }
            if (m < 10) {
                newTime += '0' + m + ':';
            }
            else {
                newTime += m + ':';
            }
            if (s < 10) {
                newTime += '0' + s;
            }
            else {
                newTime += s;
            }
            return newTime;
        }
        static formatTimeDhms(time) {
            var s = time % 60;
            var m = Math.floor(time / 60) % 60;
            var h = Math.floor(time / 60 / 60) % 24;
            var d = Math.floor(time / 60 / 60 / 24);
            var newTime = '';
            if (d > 0) {
                newTime += d + '-';
            }
            if (h > 0 || newTime) {
                newTime += h + ':';
            }
            if (m < 10) {
                newTime += '0' + m + ':';
            }
            else {
                newTime += m + ':';
            }
            if (s < 10) {
                newTime += '0' + s;
            }
            else {
                newTime += s;
            }
            return newTime;
        }
        static formatTimeCn(time) {
            var s = time % 60;
            var m = Math.floor(time / 60) % 60;
            var h = Math.floor(time / 60 / 60) % 24;
            var d = Math.floor(time / 60 / 60 / 24);
            var newTime = '';
            if (d > 0) {
                newTime += d + '天';
            }
            if (h > 0) {
                newTime += h + '小时';
            }
            if (m > 0) {
                newTime += m + '分';
            }
            if (s > 0) {
                newTime += s + '秒';
            }
            return newTime;
        }
        static check(n) {
            if (n < 10) {
                return '0' + n;
            }
            return '' + n;
        }
    }

    class SceneFightEvent {
    }
    SceneFightEvent.SCENE_FIGHT_NPC_KILL = 'SCENE_FIGHT_NPC_KILL';
    SceneFightEvent.SCENE_FIGHT_FAKE_KILL = 'SCENE_FIGHT_FAKE_KILL';

    class SceneGunEvent {
        static SCENE_GUN_RELOAD(id) { return 'SCENE_GUN_RELOAD@' + id; }
        static SCENE_GUN_RELOAD_START(id) { return 'SCENE_GUN_RELOAD_START@' + id; }
        static SCENE_GUN_RELOAD_STOP(id) { return 'SCENE_GUN_RELOAD_STOP@' + id; }
        static SCENE_GUN_RELOAD_CONPLETE(id) { return 'SCENE_GUN_RELOAD_CONPLETE@' + id; }
        static SCENE_GUN_BULLET_EXHAUST(id) { return 'SCENE_GUN_BULLET_EXHAUST@' + id; }
        static SCENE_UNIT_BULLET_CHANGE(id) { return 'SCENE_UNIT_BULLET_CHANGE@' + id; }
    }

    class BattleView1 extends ui.battle.Battle1UI {
        constructor() {
            super();
            this.zOrder = 20;
        }
    }

    class BattleAimAttController extends Controller {
        constructor(ui) {
            super();
            this.initX = 0;
            this.initY = 0;
            this.argX = 0;
            this.argY = 0;
            this.touchId = 0;
            this.isManualAim = false;
            this.ui = ui;
        }
        run() {
            super.run();
            this.ui.on(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            this.ui.stage.on(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.ui.stage.on(Laya.Event.MOUSE_OUT, this, this.upHandler);
            this.initX = this.ui.btn_dir.x;
            this.initY = this.ui.btn_dir.y;
            this.initXY();
        }
        initXY() {
            this.ui.btn_dir.x = this.ui.btn_dir_bg.x = this.initX;
            this.ui.btn_dir.y = this.ui.btn_dir_bg.y = this.initY;
        }
        downHandler(e) {
            this.touchId = e.touchId;
            this.argX = this.ui.mouseX;
            this.argY = this.ui.mouseY;
            this.ui.btn_dir.x = this.ui.btn_dir_bg.x;
            this.ui.btn_dir.y = this.ui.btn_dir_bg.y;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_ATT);
            this.ui.stage.on(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
        }
        upHandler(e) {
            if (e.touchId == this.touchId) {
                this.ui.stage.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
                this.initXY();
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_ATT_STOP);
                this.isManualAim = false;
            }
        }
        moveHandler(e) {
            if (e.touchId == this.touchId) {
                var dx = this.ui.mouseX - this.argX;
                var dy = this.ui.mouseY - this.argY;
                this.ui.btn_dir.x = this.ui.mouseX;
                this.ui.btn_dir.y = this.ui.mouseY;
                if (this.isManualAim == false) {
                    if (Math.abs(dx) > 20 || Math.abs(dy) > 20) {
                        this.isManualAim = true;
                    }
                }
                if (this.isManualAim) {
                    this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AUTO_AIM_SET, { isAutoAim: false });
                    this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_DIR, { dx: -dx / 5, dy: -dy / 5 });
                    this.argX = this.ui.mouseX;
                    this.argY = this.ui.mouseY;
                }
            }
        }
        stop() {
            super.stop();
            this.ui.stage.off(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.ui.stage.off(Laya.Event.MOUSE_OUT, this, this.upHandler);
            this.ui.stage.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
        }
    }

    class BattleDirController extends Controller {
        constructor(ui) {
            super();
            this.argX = 0;
            this.argY = 0;
            this.ui = ui;
        }
        run() {
            super.run();
            this.ui.on(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            this.ui.stage.on(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.ui.stage.on(Laya.Event.MOUSE_OUT, this, this.upHandler);
        }
        downHandler(e) {
            if (this.checkLR() == "R") {
                this.touchId = e.touchId;
                this.argX = this.ui.mouseX;
                this.argY = this.ui.mouseY;
                this.ui.stage.on(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AUTO_AIM_SET, { isAutoAim: false });
            }
        }
        upHandler(e) {
            if (e.touchId == this.touchId) {
                this.ui.stage.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
            }
        }
        moveHandler(e) {
            if (e.touchId == this.touchId) {
                var dx = this.ui.mouseX - this.argX;
                var dy = this.ui.mouseY - this.argY;
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_DIR, { dx: -dx / 5, dy: -dy / 5 });
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AUTO_AIM_SET, { isAutoAim: false });
                this.argX = this.ui.mouseX;
                this.argY = this.ui.mouseY;
            }
        }
        checkLR() {
            if (this.ui.mouseX < 300 && this.ui.mouseY > 400) {
                return "L";
            }
            else {
                return "R";
            }
        }
        stop() {
            super.stop();
            this.ui.stage.off(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.ui.stage.off(Laya.Event.MOUSE_OUT, this, this.upHandler);
            this.ui.stage.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
        }
    }

    class BattleKillInfoViewController extends ViewController {
        constructor(ui) {
            super();
            this.sx = -400;
            this.ui = ui;
        }
        run() {
            super.run();
            this.ui.right = this.sx;
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_KILL, this, this.killHandler);
        }
        killHandler(data) {
            var vo = data.vo;
            var atter = data.atter;
            if (atter.stype == 6) {
                this.ui.ui_kill.visible = false;
                this.ui.ui_fall.visible = true;
                this.ui.ui_fall.txt_name2.text = vo.name;
                this.ui.ui_fall.img_head2.skin = GoodsViewTool.getIconUrl(vo.cid);
            }
            else {
                this.ui.ui_fall.visible = false;
                this.ui.ui_kill.visible = true;
                this.ui.ui_kill.txt_name1.text = vo.name;
                this.ui.ui_kill.img_head1.skin = GoodsViewTool.getIconUrl(vo.cid);
                this.ui.ui_kill.txt_name2.text = atter.name;
                this.ui.ui_kill.img_head2.skin = GoodsViewTool.getIconUrl(atter.cid);
            }
            this.ui.right = this.sx;
            TweenUtil.to(this, this.ui, { right: 25 }, 200, Laya.Ease.backOut);
            TimerUtil.onceTimer(2000, this, this.outHandeer);
        }
        outHandeer() {
            this.ui.right = 25;
            TweenUtil.to(this, this.ui, { right: -400 }, 200, Laya.Ease.backOut);
        }
    }

    class BattleMapsViewController extends PanelViewController {
        constructor(ui) {
            super();
            this.list = {};
            this.p = 600 / 300;
            this.ui = this.view = ui;
        }
        openComplete() {
            super.openComplete();
            this.vo = SceneModel.model.vo;
            TimerUtil.loopFrame(2, this, this.timerHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_REMOVEED, this, this.deathHandler);
        }
        timerHandler() {
            var list = this.vo.unitList;
            for (var k in list) {
                var vo = list[k];
                var img = this.getImage(vo.id);
                if (vo.isDie) {
                    if (img) {
                        this.removeImage(vo.id);
                    }
                }
                else {
                    if (!img) {
                        img = this.addImage(vo.id, vo);
                    }
                    img.x = -(vo.x * this.p);
                    img.y = -(vo.z * this.p);
                }
            }
        }
        deathHandler(data) {
            var vo = data.vo;
            var img = this.getImage(vo.id);
            if (img) {
                this.removeImage(vo.id);
            }
        }
        addImage(id, vo) {
            var image;
            if (vo.isPlayer) {
                image = new ui.battle.BattleMapItem3UI();
                image.zOrder = 1;
            }
            else if (vo.camp == 1) {
                if (vo.ttype == 2) {
                    image = new ui.battle.BattleMapPillItem1UI();
                }
                else {
                    image = new ui.battle.BattleMapItem1UI();
                    image.zOrder = 1;
                }
            }
            else {
                if (vo.ttype == 2) {
                    image = new ui.battle.BattleMapPillItem2UI();
                }
                else {
                    image = new ui.battle.BattleMapItem2UI();
                    image.zOrder = 1;
                }
            }
            this.list[id] = image;
            this.ui.box_role.addChild(image);
            return image;
        }
        removeImage(id) {
            var img = this.list[id];
            if (img) {
                img.removeSelf();
                delete this.list[id];
            }
        }
        getImage(id) {
            return this.list[id];
        }
    }

    class BattleMoveController extends Controller {
        constructor(ui) {
            super();
            this.isAtt = false;
            this.initX = 0;
            this.initY = 0;
            this.touchId = 0;
            this.argX = 0;
            this.argY = 0;
            this.isManualAim = false;
            this.ui = ui;
        }
        run() {
            super.run();
            this.ui.on(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            this.ui.stage.on(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.ui.stage.on(Laya.Event.MOUSE_OUT, this, this.upHandler);
            this.ui.btn_att.on(Laya.Event.MOUSE_DOWN, this, this.downAttHandler);
            this.ui.btn_att.on(Laya.Event.MOUSE_UP, this, this.upAttHandler);
            this.ui.btn_att.on(Laya.Event.MOUSE_OUT, this, this.upAttHandler);
            this.initX = this.ui.btn_dir.x;
            this.initY = this.ui.btn_dir.y;
            this.initXY();
        }
        initXY() {
            this.ui.btn_dir.x = this.ui.btn_dir_bg.x = this.initX;
            this.ui.btn_dir.y = this.ui.btn_dir_bg.y = this.initY;
        }
        downHandler(e) {
            this.argX = this.ui.mouseX;
            this.argY = this.ui.mouseY;
            if (this.isAtt == false) {
                this.touchId = e.touchId;
                this.ui.btn_dir.x = this.ui.btn_dir_bg.x = this.ui.mouseX;
                this.ui.btn_dir.y = this.ui.btn_dir_bg.y = this.ui.mouseY;
                this.ui.stage.on(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
            }
        }
        upHandler(e) {
            if (e.touchId == this.touchId) {
                this.ui.stage.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
                this.initXY();
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_MOVE_STOP);
                this.isManualAim = false;
            }
        }
        moveHandler(e) {
            if (e.touchId == this.touchId) {
                this.ui.btn_dir.x = this.ui.mouseX;
                this.ui.btn_dir.y = this.ui.mouseY;
                var dir = Display3DUtil.angle(this.ui.mouseX, this.ui.mouseY, this.ui.btn_dir_bg.x, this.ui.btn_dir_bg.y) + 180;
                if (isNaN(dir)) {
                    return;
                }
                var dx = this.ui.mouseX - this.argX;
                var dy = this.ui.mouseY - this.argY;
                if (this.isManualAim == false) {
                    this.isManualAim = true;
                }
                if (this.isManualAim) {
                    this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AUTO_AIM_SET, { isAutoAim: false });
                }
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_MOVE, { dir: dir });
            }
        }
        downAttHandler() {
            this.isAtt = true;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_ATT);
        }
        upAttHandler() {
            this.isAtt = false;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_ATT_STOP);
        }
        stop() {
            super.stop();
            this.ui.stage.off(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.ui.stage.off(Laya.Event.MOUSE_OUT, this, this.upHandler);
            this.ui.stage.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
        }
    }

    class SceneNpcEvent {
        static SCENE_NPC_FLG(id) { return 'SCENE_NPC_FLG@' + id; }
    }
    SceneNpcEvent.SCENE_NPC_FLG_CHANGE = 'SCENE_NPC_FLG_CHANGE';

    class SceneSkillEvent {
        static SCENE_SKILL_USEED(id) { return 'SCENE_SKILL_USEED@' + id; }
        static SCENE_SKILL_RECOVERY_USED(id) { return 'SCENE_SKILL_RECOVERY_USED@' + id; }
    }

    class BattleCollViewController extends ViewController {
        constructor(ui) {
            super();
            this.ui = ui;
        }
        openComplete() {
            super.openComplete();
            this.playerVo = SceneModel.model.vo.playerVo;
            this.ui.img_coll_3.visible = false;
            this.ui.img_coll_6.visible = false;
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_COLL_CHANGE, this, this.collHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_SHOCK, this, this.shockHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_AIM_CHANGE, this, this.checkMirror);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_LOCK_TARGET, this, this.lockatHandler);
            this.checkMirror();
        }
        collHandler(data) {
            if (data.state == 2) {
                this.ui.img_coll_1.visible = false;
                this.ui.img_coll_2.visible = true;
                this.ui.img_coll_5.visible = false;
            }
            else if (data.state == 4) {
                this.ui.img_coll_1.visible = false;
                this.ui.img_coll_2.visible = false;
                this.ui.img_coll_5.visible = true;
                this.ui.img_coll_3.visible = false;
            }
            else if (data.state == 3) {
                this.ui.img_coll_1.visible = false;
                this.ui.img_coll_2.visible = false;
                this.ui.img_coll_5.visible = false;
                this.ui.img_coll_3.visible = true;
                this.ui.img_coll_3.ani1.play(1, false);
                TimerUtil.onceTimer(100, this, this.collEndHandler);
            }
            else {
                this.ui.img_coll_1.visible = true;
                this.ui.img_coll_2.visible = false;
                this.ui.img_coll_5.visible = false;
                this.ui.img_coll_3.visible = false;
            }
        }
        collEndHandler() {
            this.ui.img_coll_3.visible = false;
        }
        checkMirror() {
            if (this.playerVo.isAim && this.playerVo.aimType == 4) {
                this.ui.img_coll_4.visible = true;
            }
            else {
                this.ui.img_coll_4.visible = false;
            }
        }
        shockHandler(data) {
            if (this.ui.img_coll_4.visible) {
                if (data.state) {
                    this.ui.img_coll_4.scale(1.1, 1.1);
                }
                else {
                    this.ui.img_coll_4.scale(1, 1);
                }
            }
        }
        lockatHandler(data) {
            if (this.lockTarget != data.vo) {
                this.lockTarget = data.vo;
                if (this.lockTarget) {
                    this.ui.img_coll_6.visible = true;
                    this.ui.img_coll_6.ani1.play(1, false);
                }
                else {
                    this.ui.img_coll_6.visible = false;
                }
            }
        }
    }

    class BattlePlayerController extends Controller {
        constructor(ui) {
            super();
            this.startTime = 0;
            this.tatalTime = 0;
            this.ui = ui;
        }
        run() {
            super.run();
            this.sceneVo = SceneModel.model.vo;
            var vo = this.playerVo;
            if (vo) {
                this.addEventListener(SceneUnitEvent.SCENE_UNIT_HP_CHANGE(vo.id), this, this.showHpHandler);
                this.addEventListener(SceneGunEvent.SCENE_GUN_RELOAD_START(vo.id), this, this.bulletChangeHandler);
                this.addEventListener(SceneGunEvent.SCENE_GUN_RELOAD_STOP(vo.id), this, this.bulletStopHandler);
                this.addEventListener(SceneGunEvent.SCENE_GUN_RELOAD_CONPLETE(vo.id), this, this.bulletCompHandler);
                this.addEventListener(SceneGunEvent.SCENE_UNIT_BULLET_CHANGE(vo.id), this, this.showBulletHandler);
                this.addEventListener(SceneGunEvent.SCENE_GUN_BULLET_EXHAUST(vo.id), this, this.exhTipHandler);
                this.addEventListener(SceneSkillEvent.SCENE_SKILL_RECOVERY_USED(vo.id), this, this.recoveryHandler);
                this.addEventListener(SceneNpcEvent.SCENE_NPC_FLG_CHANGE, this, this.flgHandler);
                this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_ATT_FULL, this, this.attFullTipHandler);
                this.addEventListener(SceneUnitEvent.SCENE_UNIT_KILL, this, this.killHandler);
                this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_INVIN, this, this.invinHandler);
                this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_PICKUP_RESPONSE, this, this.pickupHandler);
                this.addEventListener(SceneFightEvent.SCENE_FIGHT_NPC_KILL, this, this.showKillHandle);
                this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_UNPICK, this, this.pickRwHandler);
                this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_REVIVE, this, this.showHpHandler);
                this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_REVIVE, this, this.cdHandler);
                this.addEventListener(SceneUnitEvent.SCENE_UNIT_HP_CHANGES, this, this.showAttPillBoxTipHandler);
                this.addEventListener(BattleEvent.BATTLE_PLAYER_STOP, this, this.stop);
                this.startChild(new BattleCollViewController(this.ui.ui_coll));
                this.ui.ui_bottom.img_ico.skin = GoodsViewTool.getIcoUrl(this.playerVo.cid);
                this.invinHandler();
                this.showHpHandler();
                this.initSkill();
                this.showBulletHandler();
            }
        }
        initSkill() {
            var cid = this.playerVo.skills[0];
            var skillVo = this.skillVo = this.playerVo.getSkillVo(cid);
            this.ui.ui_right.ui_skill.img_bg2.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_SKILL_USE_COMPLETE(skillVo.id), this, this.playerSkillCd);
            this.cdHandler();
        }
        playerSkillCd() {
            TimerUtil.loopFrame(2, this, this.cdHandler);
        }
        cdHandler() {
            var leftTime = SceneSkillTool.lastCdTime(this.skillVo);
            var v = (this.skillVo.attCd - leftTime) / this.skillVo.attCd;
            if (leftTime <= 0) {
                ProgressBarViewTool.setPieBarValue(this.ui.ui_right.ui_skill.img_skillCd, 1);
                TimerUtil.stopTimer(this, this.cdHandler);
                this.ui.ui_right.ui_skill.img_bg.skin = 'ui/img_UM_btn_Skill.png';
                this.ui.ui_right.ui_skill.img_bg2.skin = GoodsConfig.getSkillIcoUrl(this.skillVo.ico, "white");
                this.ui.ui_right.ui_hand.visible = true;
            }
            else {
                ProgressBarViewTool.setPieBarValue(this.ui.ui_right.ui_skill.img_skillCd, v);
                this.ui.ui_right.ui_skill.img_bg.skin = 'ui/img_UM_btn_Skill2.png';
                this.ui.ui_right.ui_skill.img_bg2.skin = GoodsConfig.getSkillIcoUrl(this.skillVo.ico, "yellow");
                this.ui.ui_right.ui_hand.visible = false;
            }
        }
        pickRwHandler(data) {
            var goods = data.vo;
            if (goods.cid == 30021001) {
                var reward = [{ cid: 20010001, num: goods.num }];
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
                BattleModel.model.pickJinNum += goods.num;
            }
            else {
                var reward1 = [{ cid: 20010003, num: goods.num }];
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward1, showView: false });
                BattleModel.model.pickTongNum += goods.num;
            }
        }
        invinHandler() {
            if (this.playerVo.isInvin) {
                this.invinTime = this.playerVo.invinTime;
                TimerUtil.loopTimer(1000, this, this.timerHandler);
            }
            else {
                this.ui.ui_top.txt_inv.text = '';
                TimerUtil.stopTimer(this, this.timerHandler);
            }
        }
        timerHandler() {
            if (this.invinTime > 0) {
                this.invinTime--;
            }
            this.ui.ui_top.txt_inv.text = '无敌时间:' + TimeFormatUtil.formatTime(this.invinTime);
            if (this.invinTime <= 0) {
                this.ui.ui_top.txt_inv.text = '';
                TimerUtil.stopTimer(this, this.timerHandler);
            }
        }
        pickupHandler(data) {
            var goods = data.vo;
            if (goods) {
                if (goods.stype == 2) {
                }
                else if (goods.stype == 3) {
                }
                else if (goods.stype == 1) {
                }
                else if (goods.stype == 4) {
                    this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '子弹补给+' + goods.num + '发' });
                }
                else if (goods.stype == 11) {
                    var buff = goods;
                    this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '无敌状态+' + buff.invinTime + '秒' });
                }
                else if (goods.stype == 12) {
                    this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '伤害增强+20%' });
                }
                else if (goods.stype == 13) {
                    this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '血量回复+20%' });
                }
                else if (goods.stype == 5) {
                    if (goods.cid == 30021001) {
                        this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '砖石+' + goods.num + '个' });
                    }
                    else if (goods.cid == 30021002) {
                        this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '金币+' + goods.num + '个' });
                    }
                    else {
                        this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '恢复生命:' + goods.num });
                    }
                }
            }
        }
        showBulletHandler() {
            var gunVo = this.sceneVo.playerVo.attVo;
            this.ui.ui_right.txt_num.text = '' + gunVo.attBulletNum;
        }
        bulletChangeHandler(data) {
            this.dispatchEvent(BattleEvent.BATTLE_RELOAD_VIEW_SHOW, { showType: ViewType.OPEN, time: data.time });
            this.tatalTime = data.time;
            this.startTime = TimeUtil.getTime();
            TimerUtil.loopFrame(2, this, this.bulletTimerHandler);
        }
        bulletTimerHandler() {
            var ct = TimeUtil.getTime() - this.startTime;
            var lt = this.tatalTime - ct;
            var v = ct / this.tatalTime;
            if (lt <= 0) {
                TimerUtil.stopTimer(this, this.bulletTimerHandler);
                ProgressBarViewTool.setPieBarValue(this.ui.ui_right.img_cd, 1);
            }
            else {
                ProgressBarViewTool.setPieBarValue(this.ui.ui_right.img_cd, v);
            }
        }
        bulletStopHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_RELOAD_VIEW_SHOW, { showType: ViewType.CLOSE });
        }
        bulletCompHandler() {
        }
        flgHandler(data) {
            this.dispatchEvent(BattleEvent.BATTLE_ANTKILL_TIP_VIEW_SHOW);
        }
        showHpHandler(data = null) {
            var pvo = this.playerVo;
            var v = pvo.hp / pvo.hpMax;
            if (v < 0.4) {
                this.ui.ui_bottom.img_hp.skin = 'ui/img_UM_hp_2.png';
            }
            else {
                this.ui.ui_bottom.img_hp.skin = 'ui/img_UM_hp_1.png';
            }
            this.showTextColor(v);
            ProgressBarViewTool.setRectBarValue(this.ui.ui_bottom.img_hp, v);
            this.ui.ui_bottom.txt_num1.text = '' + pvo.hp;
            this.ui.ui_bottom.txt_num.text = '/' + pvo.hpMax;
            this.ui.ui_bottom.txt_lv.text = '' + pvo.lv;
            if (data && data.type == "att") {
                TimerUtil.loopFrame(1, this, this.loopHandler, [v]);
                this.ui.img_hurt.skin = 'ui/img_uk_ui2_obj22.png';
                this.ui.img_hurt.alpha = 1;
                this.ui.img_hurt.visible = true;
                this.ui.ui_bottom.txt_num1.color = '#dbee0c';
            }
            else if (data && data.type == 'add') {
                TimerUtil.loopFrame(1, this, this.loopHandler, [v]);
                this.ui.img_hurt.skin = 'ui/img_uk_ui2_obj22_1.png';
                this.ui.img_hurt.alpha = 1;
                this.ui.img_hurt.visible = true;
                this.ui.ui_bottom.txt_num1.color = '#00ff00';
            }
        }
        loopHandler(v) {
            this.ui.img_hurt.alpha -= 0.02;
            if (this.ui.img_hurt.alpha == 0) {
                this.ui.img_hurt.visible = false;
                this.showTextColor(v);
                TimerUtil.stopTimer(this, this.loopHandler);
            }
        }
        showTextColor(v) {
            if (v < 0.4) {
                this.ui.ui_bottom.txt_num1.color = '#f41c18';
            }
            else {
                this.ui.ui_bottom.txt_num1.color = '#ffffff';
            }
        }
        killHandler() {
            this.ui.ui_top.txt_kill_1.text = "" + this.sceneVo.teamKillNum;
            this.ui.ui_top.txt_kill_2.text = "" + this.sceneVo.foeKillNum;
        }
        showKillHandle(data) {
            this.dispatchEvent(BattleEvent.BATTLE_KILL_TIP_VIEW_SHOW, { showType: ViewType.OPEN, num: data.num, seckill: data.seckill });
            this.dispatchEvent(BattleEvent.BATTLE_KILL_ANIM_VIEW_SHOW, { showType: ViewType.OPEN, num: data.num, seckill: data.seckill, killer: data.killer });
        }
        showAttPillBoxTipHandler(data) {
            var unitVo = data.vo;
            if (unitVo.ttype == 2) {
                if (unitVo.camp == 1) {
                    this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '我方基地被攻击' });
                }
                else {
                    this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '红方碉堡被攻击' });
                }
            }
        }
        attFullTipHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_FULL_TIP_VIEW_SHOW, { showType: ViewType.OPEN });
        }
        exhTipHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_EXHAUST_TIP_VIEW_SHOW, { showType: ViewType.OPEN });
        }
        recoveryHandler(data) {
            this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '恢复生命:' + data.skillHpRc * 10 });
        }
        get playerVo() {
            return SceneModel.model.vo.playerVo;
        }
    }

    class BattleView1Controller extends ViewController {
        constructor() {
            super();
            this.taskIndex = 0;
            this.viewClass = BattleView1;
            this.viewName = 'BattleView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.hpLabel1 = new BitmapLabelView("font/white.json", 0.5, this.ui.ui_top.txt_ph1);
            this.hpLabel2 = new BitmapLabelView("font/white.json", 0.5, this.ui.ui_top.txt_ph2);
            this.ui.img_hurt.visible = false;
            this.ui.ui_top.txt_inv.text = '';
            this.ui.ui_top.txt_airdrop.text = '';
            this.ui.ui_right.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.ui_right.btn_reload.on(Laya.Event.CLICK, this, this.reloadHandler);
            this.ui.ui_right.btn_aim.on(Laya.Event.CLICK, this, this.aimHandler);
            this.ui.ui_right.btn_jump.on(Laya.Event.CLICK, this, this.jumpHandler);
            this.ui.ui_right.btn_vis.on(Laya.Event.CLICK, this, this.visHandler);
            this.ui.ui_right.box_skill.on(Laya.Event.CLICK, this, this.skillHandler);
            this.ui.ui_right.box_switch.on(Laya.Event.CLICK, this, this.switchHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler1);
            this.ui.list_task.on(Laya.Event.CLICK, this, this.getRewardHandler);
            this.ui.ui_right.ui_recovery.on(Laya.Event.CLICK, this, this.adRecoveryHandler);
            this.ui.ui_right.ui_bullet.on(Laya.Event.CLICK, this, this.adLaunchHandler);
            this.ui.txt_skip.visible = true;
            this.dispatchEvent(BattleEvent.BATTLE_CLOSE_CLICK, { time: 3000 });
            this.sceneVisualHandler1();
            this.showGudie();
            this.addEventListener(SceneEvent.SCENE_BEGAIN_CAMERA_COMPLETE, this, this.sceneVisualHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.sceneVisualHandler1);
            this.addEventListener(SceneEvent.SCENE_STATE_READY, this, this.showReadyHandler);
            this.addEventListener(SceneFightEvent.SCENE_FIGHT_NPC_KILL, this, this.killRecord);
            this.addEventListener(SceneFightEvent.SCENE_FIGHT_NPC_KILL, this, this.showTaskList);
            this.addEventListener(BattleEvent.BATTLE_TASK_RESPONSE, this, this.showTaskList);
            this.addEventListener(StageMouseEvent.STAGE_MOUSE_CLICK, this, this.skipHandler);
            this.showReadyHandler();
            this.showTaskList();
        }
        showGudie() {
        }
        sceneVisualHandler() {
            this.ui.ui_coll.visible = true;
            this.ui.ui_dir.visible = true;
            this.ui.img_hurt.visible = true;
            this.ui.ui_move.visible = true;
            this.ui.ui_top.visible = true;
            this.ui.ui_att.visible = true;
            this.ui.ui_right.visible = true;
            this.ui.ui_bottom.visible = true;
            this.ui.ui_map.visible = true;
            this.ui.ui_info.visible = true;
            this.ui.ui_record.visible = true;
            this.ui.txt_skip.visible = false;
            this.ui.ui_try.visible = true;
            this.ui.list_task.visible = true;
        }
        sceneVisualHandler1() {
            this.ui.ui_coll.visible = false;
            this.ui.ui_dir.visible = false;
            this.ui.img_hurt.visible = false;
            this.ui.ui_move.visible = false;
            this.ui.ui_top.visible = false;
            this.ui.ui_att.visible = false;
            this.ui.ui_right.visible = false;
            this.ui.ui_bottom.visible = false;
            this.ui.ui_map.visible = false;
            this.ui.ui_info.visible = false;
            this.ui.ui_record.visible = false;
            this.ui.ui_try.visible = false;
            this.ui.list_task.visible = false;
            if (AdTool.checkVideoIco('ys_jili')) {
                this.ui.ui_right.ui_bullet.img_ad.visible = true;
                this.ui.ui_right.ui_recovery.img_ad.visible = true;
                this.ui.ui_try.img_ad.visible = true;
            }
            else {
                this.ui.ui_right.ui_bullet.img_ad.visible = false;
                this.ui.ui_right.ui_recovery.img_ad.visible = false;
                this.ui.ui_try.img_ad.visible = false;
            }
        }
        skipHandler() {
            this.ui.txt_skip.visible = false;
        }
        showReadyHandler() {
            this.sceneVo = SceneModel.model.vo;
            if (this.sceneVo.state != 1) {
                return;
            }
            this.startChild(new BattlePlayerController(this.ui));
            this.startChild(new BattleMoveController(this.ui.ui_move));
            this.startChild(new BattleDirController(this.ui.ui_dir));
            this.startChild(new BattleMapsViewController(this.ui.ui_map));
            this.startChild(new BattleKillInfoViewController(this.ui.ui_info));
            this.startChild(new BattleAimAttController(this.ui.ui_att));
            if (this.sceneVo.totalTime) {
                TimerUtil.loopTimer(1000, this, this.loopTimerHandler);
            }
            TimerUtil.loopTimer(500, this, this.teamHpHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ADDED, this, this.unitAddedHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYEER_CHANGE, this, this.playerChangeHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_DEATH, this, this.showUnitState);
            this.initHpBarHandler();
            this.showUnitState();
            this.killRecord();
        }
        playerChangeHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_PLAYER_STOP);
            this.startChild(new BattlePlayerController(this.ui));
        }
        loopTimerHandler() {
            this.ui.ui_top.txt_time.text = TimeFormatUtil.formatTime(this.sceneVo.leftTime);
        }
        skillHandler() {
            this.ui.ui_right.ui_hand.visible = false;
            var playerVo = this.playerVo;
            var cid = playerVo.skills[0];
            var skillVo = playerVo.getSkillVo(cid);
            if (skillVo) {
                if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(playerVo.id), { cid: cid });
                }
            }
        }
        adRecoveryHandler() {
            AdTool.videoAdShow(this, this.recoveryHandler, 'firstAid');
        }
        recoveryHandler() {
            var playerVo = this.playerVo;
            var cid = playerVo.skills[2];
            var skillVo = playerVo.getSkillVo(cid);
            if (skillVo) {
                if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(playerVo.id), { cid: cid });
                }
            }
        }
        adLaunchHandler() {
            AdTool.videoAdShow(this, this.launchHandler, 'launchMissile');
        }
        launchHandler() {
            var playerVo = this.playerVo;
            var cid = playerVo.skills[3];
            var skillVo = playerVo.getSkillVo(cid);
            if (skillVo) {
                if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(playerVo.id), { cid: cid });
                }
            }
        }
        reloadHandler() {
            this.dispatchEvent(SceneGunEvent.SCENE_GUN_RELOAD(this.playerVo.id));
        }
        aimHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AIM);
        }
        jumpHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_JUMP);
        }
        visHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_VIS);
        }
        teamHpHandler() {
            this.hpLabel1.text = '' + this.sceneVo.teamIntegralTotal;
            this.hpLabel2.text = '' + this.sceneVo.foeIntegralTotal;
            this.ui.ui_top.txt_kill_1.text = '' + this.sceneVo.teamKillNum;
            this.ui.ui_top.txt_kill_2.text = '' + this.sceneVo.foeKillNum;
            if (this.sceneVo.teamKillNum == this.sceneVo.foeKillNum) {
                this.ui.ui_top.box_lead2.visible = false;
                this.ui.ui_top.box_lead1.visible = false;
            }
            else if (this.sceneVo.teamKillNum > this.sceneVo.foeKillNum) {
                this.ui.ui_top.box_lead2.visible = true;
                this.ui.ui_top.box_lead1.visible = false;
            }
            else {
                this.ui.ui_top.box_lead2.visible = false;
                this.ui.ui_top.box_lead1.visible = true;
            }
        }
        killRecord() {
            var reward = [];
            this.ui.ui_record.txt_kill_1.text = '' + this.sceneVo.playerKillNum;
            if (this.sceneVo.playerKillNum == 0) {
                this.ui.ui_record.txt_kill_2.text = '3';
                return;
            }
            if (this.sceneVo.playerKillNum == 16) {
                this.ui.ui_record.txt_kill_2.visible = false;
                this.ui.ui_record.txt_info1.visible = false;
                this.ui.ui_record.txt_info.text = '已完成任务！';
                return;
            }
            if (this.taskIndex >= 4) {
                return;
            }
            if (this.sceneVo.playerKillNum >= BattleConfig.killRewardList[this.taskIndex].killNum) {
                this.ui.ui_record.txt_kill_2.text = '' + BattleConfig.killRewardList[this.taskIndex].taskKill;
                var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
                if (hero) {
                    if (hero.quality == 0) {
                        reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                    }
                    else if (hero.quality == 1) {
                        reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                    }
                    else {
                        reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                    }
                }
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "！达成击杀目标，发现神秘宝箱" });
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
                var sp1 = StageUtil.stageWidth / 2;
                var sp2 = StageUtil.stageHeight / 2;
                var card = this.ui.list_task;
                var tp = DisplayUtil.localToGlobal(card, new Laya.Point());
                this.dispatchEvent(BattleEvent.BATTLE_BOX_FLOAT_VIEW_SHOW, { sx: sp1, sy: sp2, tx: tp.x, ty: tp.y, showType: ViewType.NEW });
                this.taskIndex++;
            }
        }
        showUnitState() {
            var isTimer = this.checkStatTimer();
            if (isTimer) {
                TimerUtil.loopTimer(1000, this, this.showUnitStateHandler);
            }
            else {
                TimerUtil.stopTimer(this, this.showUnitStateHandler);
            }
            this.showUnitStateHandler();
        }
        showUnitStateHandler() {
            this.ui.ui_top.list_team.dataSource = this.getUnitStateList(1);
            this.ui.ui_top.list_foe.dataSource = this.getUnitStateList(2);
        }
        getUnitStateList(camp) {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var ts = TimeUtil.getTimestamp();
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.camp == camp) {
                        var item = {};
                        if (vo.isPlayer) {
                            var time = vo.dieTs + SceneConfig.playeRreviveTime - ts;
                        }
                        else {
                            var time = vo.dieTs + SceneConfig.reviveTime - ts;
                        }
                        if (vo.camp == 1) {
                            item.img_bg = 'ui/img_UM_herokill_bg_blue.png';
                        }
                        else {
                            item.img_bg = 'ui/img_UM_herokill_bg_red.png';
                        }
                        if (vo.isDie && time > 0) {
                            item.img_npc = { skin: GoodsViewTool.getImgUrl(vo.cid), gray: true };
                            item.txt_time = '' + time;
                            item.img_bg2 = { visible: true };
                        }
                        else {
                            item.img_npc = { skin: GoodsViewTool.getImgUrl(vo.cid), gray: false };
                            item.txt_time = '';
                            item.img_bg2 = { visible: false };
                        }
                        nlist.push(item);
                    }
                }
            }
            return nlist;
        }
        checkStatTimer() {
            var list = SceneModel.model.vo.unitList;
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.isDie) {
                        return true;
                    }
                }
            }
            return false;
        }
        stateHandler() {
            var list = SceneModel.model.vo.unitList;
            var index = 0;
            var index2 = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.camp == 1) {
                        if (vo.isDie) {
                        }
                        else {
                        }
                        index++;
                    }
                }
            }
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.camp != 1) {
                        if (vo.isDie) {
                        }
                        else {
                        }
                        index2++;
                    }
                }
            }
        }
        initHpBarHandler() {
            var list = this.sceneVo.unitList;
            for (var k in list) {
                var vo = list[k];
                this.showHp(vo);
            }
        }
        unitAddedHandler(data) {
            this.showHp(data.vo);
        }
        showHp(vo) {
            if (vo) {
                if (vo.isDie == false) {
                    if (vo.ttype == 2) {
                        this.dispatchEvent(BattleEvent.BATTLE_HP_PILL_VIEW_SHOW, { showType: ViewType.NEW, vo: vo });
                    }
                    else {
                        this.dispatchEvent(BattleEvent.BATTLE_HP_VIEW_SHOW, { showType: ViewType.NEW, vo: vo });
                    }
                }
            }
        }
        switchHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_SWITCH_AIM);
        }
        showTaskList() {
            var taskList = BattleConfig.killRewardList;
            var nlist = [];
            for (var k in taskList) {
                var taskVo = taskList[k];
                var data = {};
                if (this.sceneVo.playerKillNum >= taskVo.killNum) {
                    if (taskVo.isReceive) {
                        data.img_frame = { visible: false };
                        data.img_box = { gray: true };
                        data.ui_bubble = { visible: false };
                        data.img_receive = { visible: true, skin: 'ui/img_UM_ui_text36.png' };
                    }
                    else {
                        data.vo = taskVo;
                        data.img_frame = { visible: true };
                        data.img_box = { gray: false };
                        data.ui_bubble = { visible: true };
                        data.img_receive = { visible: false, skin: 'ui/img_UM_ui_text37.png' };
                        if (BattleConfig.isAutoShowTask) {
                            this.dispatchEvent(BattleEvent.BATTLE_TASK_REQUEST, { vo: taskVo });
                        }
                    }
                }
                else {
                    data.img_frame = { visible: true };
                    data.img_box = { gray: false };
                    data.ui_bubble = { visible: false };
                    data.img_receive = { visible: true, skin: 'ui/img_UM_ui_text37.png' };
                }
                nlist.push(data);
            }
            this.ui.list_task.dataSource = nlist;
        }
        getRewardHandler(e) {
            if (MouseTool.checkClick(e)) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.dispatchEvent(BattleEvent.BATTLE_TASK_REQUEST, { vo: vo });
                }
            }
        }
        tryHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_TRY_HERO_VIEW_SHOW);
        }
        closeHandler1() {
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            var playerVo = SceneModel.model.vo.playerVo;
            playerVo = BattleTool.getBattleData(1, BattleModel.model.tryHerocid, true).playerVo;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_RELPACE, { playerVo: playerVo });
        }
        adHandler1() {
            AdTool.videoAdShow(this, this.closeHandler1, 'heroTryBattle');
        }
        adHandler() {
        }
        closeHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_CLOSE_CLICK);
            this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: '您确认要退出战斗吗?', okHandler: HandlerUtil.create(this, this.closeOkHandler) });
        }
        closeOkHandler() {
            this.dispatchEvent(SceneEvent.SCENE_VIEW_EXIT, { isExit: true });
        }
        get playerVo() {
            return SceneModel.model.vo.playerVo;
        }
    }

    class BattleView extends ui.battle.BattleUI {
        constructor() {
            super();
            this.zOrder = 20;
        }
    }

    class BattleViewController extends ViewController {
        constructor() {
            super();
            this.taskIndex = 0;
            this.viewClass = BattleView;
            this.viewName = 'BattleView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.hpLabel1 = new BitmapLabelView("font/white.json", 0.5, this.ui.ui_top.txt_ph1);
            this.hpLabel2 = new BitmapLabelView("font/white.json", 0.5, this.ui.ui_top.txt_ph2);
            this.ui.img_hurt.visible = false;
            this.ui.ui_top.txt_inv.text = '';
            this.ui.ui_top.txt_airdrop.text = '';
            this.ui.ui_right.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.ui_right.btn_reload.on(Laya.Event.CLICK, this, this.reloadHandler);
            this.ui.ui_right.btn_aim.on(Laya.Event.CLICK, this, this.aimHandler);
            this.ui.ui_right.btn_jump.on(Laya.Event.CLICK, this, this.jumpHandler);
            this.ui.ui_right.btn_vis.on(Laya.Event.CLICK, this, this.visHandler);
            this.ui.ui_right.box_skill.on(Laya.Event.CLICK, this, this.skillHandler);
            this.ui.ui_right.box_switch.on(Laya.Event.CLICK, this, this.switchHandler);
            this.ui.ui_try.on(Laya.Event.CLICK, this, this.adHandler1);
            this.ui.list_task.on(Laya.Event.CLICK, this, this.getRewardHandler);
            this.ui.ui_right.ui_recovery.on(Laya.Event.CLICK, this, this.adRecoveryHandler);
            this.ui.ui_right.ui_bullet.on(Laya.Event.CLICK, this, this.adLaunchHandler);
            this.ui.txt_skip.visible = true;
            this.sceneVisualHandler1();
            this.showGudie();
            this.addEventListener(SceneEvent.SCENE_BEGAIN_CAMERA_COMPLETE, this, this.sceneVisualHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.sceneVisualHandler1);
            this.addEventListener(SceneEvent.SCENE_STATE_READY, this, this.showReadyHandler);
            this.addEventListener(SceneFightEvent.SCENE_FIGHT_NPC_KILL, this, this.killRecord);
            this.addEventListener(SceneFightEvent.SCENE_FIGHT_NPC_KILL, this, this.showTaskList);
            this.addEventListener(BattleEvent.BATTLE_TASK_RESPONSE, this, this.showTaskList);
            this.addEventListener(StageMouseEvent.STAGE_MOUSE_CLICK, this, this.skipHandler);
            this.showReadyHandler();
            this.showTaskList();
            if (BattleConfig.isShowAd) {
                this.ui.ui_right.ui_bullet.visible = true;
                this.ui.ui_right.ui_recovery.visible = true;
            }
            else {
                this.ui.ui_right.ui_bullet.visible = false;
                this.ui.ui_right.ui_recovery.visible = false;
            }
        }
        showGudie() {
        }
        sceneVisualHandler() {
            this.ui.ui_coll.visible = true;
            this.ui.ui_dir.visible = true;
            this.ui.img_hurt.visible = true;
            this.ui.ui_move.visible = true;
            this.ui.ui_top.visible = true;
            this.ui.ui_att.visible = true;
            this.ui.ui_right.visible = true;
            this.ui.ui_bottom.visible = true;
            this.ui.ui_map.visible = true;
            this.ui.ui_info.visible = true;
            this.ui.ui_record.visible = true;
            this.ui.txt_skip.visible = false;
            if (BattleConfig.isShowAd) {
                this.ui.ui_try.visible = true;
            }
            else {
                this.ui.ui_try.visible = false;
            }
            if (BattleConfig.isShowTaskList) {
                this.ui.list_task.visible = true;
            }
            else {
                this.ui.list_task.visible = false;
            }
        }
        sceneVisualHandler1() {
            this.ui.ui_coll.visible = false;
            this.ui.ui_dir.visible = false;
            this.ui.img_hurt.visible = false;
            this.ui.ui_move.visible = false;
            this.ui.ui_top.visible = false;
            this.ui.ui_att.visible = false;
            this.ui.ui_right.visible = false;
            this.ui.ui_bottom.visible = false;
            this.ui.ui_map.visible = false;
            this.ui.ui_info.visible = false;
            this.ui.ui_record.visible = false;
            this.ui.ui_try.visible = false;
            this.ui.list_task.visible = false;
        }
        skipHandler() {
            this.ui.txt_skip.visible = false;
        }
        showReadyHandler() {
            this.sceneVo = SceneModel.model.vo;
            if (this.sceneVo.state != 1) {
                return;
            }
            this.startChild(new BattlePlayerController(this.ui));
            this.startChild(new BattleMoveController(this.ui.ui_move));
            this.startChild(new BattleDirController(this.ui.ui_dir));
            this.startChild(new BattleMapsViewController(this.ui.ui_map));
            this.startChild(new BattleKillInfoViewController(this.ui.ui_info));
            this.startChild(new BattleAimAttController(this.ui.ui_att));
            if (this.sceneVo.totalTime) {
                TimerUtil.loopTimer(1000, this, this.loopTimerHandler);
            }
            TimerUtil.loopTimer(500, this, this.teamHpHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ADDED, this, this.unitAddedHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYEER_CHANGE, this, this.playerChangeHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_DEATH, this, this.showUnitState);
            this.initHpBarHandler();
            this.showUnitState();
            this.killRecord();
        }
        playerChangeHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_PLAYER_STOP);
            this.startChild(new BattlePlayerController(this.ui));
        }
        loopTimerHandler() {
            this.ui.ui_top.txt_time.text = TimeFormatUtil.formatTime(this.sceneVo.leftTime);
        }
        skillHandler() {
            this.ui.ui_right.ui_hand.visible = false;
            var playerVo = this.playerVo;
            var cid = playerVo.skills[0];
            var skillVo = playerVo.getSkillVo(cid);
            if (skillVo) {
                if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(playerVo.id), { cid: cid });
                }
            }
        }
        adRecoveryHandler() {
            AdTool.videoAdShow(this, this.recoveryHandler, 'firstAid');
        }
        recoveryHandler() {
            var playerVo = this.playerVo;
            var cid = playerVo.skills[2];
            var skillVo = playerVo.getSkillVo(cid);
            if (skillVo) {
                if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(playerVo.id), { cid: cid });
                }
            }
        }
        adLaunchHandler() {
            AdTool.videoAdShow(this, this.launchHandler, 'launchMissile');
        }
        launchHandler() {
            var playerVo = this.playerVo;
            var cid = playerVo.skills[3];
            var skillVo = playerVo.getSkillVo(cid);
            if (skillVo) {
                if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(playerVo.id), { cid: cid });
                }
            }
        }
        reloadHandler() {
            this.dispatchEvent(SceneGunEvent.SCENE_GUN_RELOAD(this.playerVo.id));
        }
        aimHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AIM);
        }
        jumpHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_JUMP);
        }
        visHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_VIS);
        }
        teamHpHandler() {
            this.hpLabel1.text = '' + this.sceneVo.teamIntegralTotal;
            this.hpLabel2.text = '' + this.sceneVo.foeIntegralTotal;
            this.ui.ui_top.txt_kill_1.text = '' + this.sceneVo.teamKillNum;
            this.ui.ui_top.txt_kill_2.text = '' + this.sceneVo.foeKillNum;
            if (this.sceneVo.teamKillNum == this.sceneVo.foeKillNum) {
                this.ui.ui_top.box_lead2.visible = false;
                this.ui.ui_top.box_lead1.visible = false;
            }
            else if (this.sceneVo.teamKillNum > this.sceneVo.foeKillNum) {
                this.ui.ui_top.box_lead2.visible = true;
                this.ui.ui_top.box_lead1.visible = false;
            }
            else {
                this.ui.ui_top.box_lead2.visible = false;
                this.ui.ui_top.box_lead1.visible = true;
            }
        }
        killRecord() {
            var reward = [];
            this.ui.ui_record.txt_kill_1.text = '' + this.sceneVo.playerKillNum;
            if (this.sceneVo.playerKillNum == 0) {
                this.ui.ui_record.txt_kill_2.text = '3';
                return;
            }
            if (this.sceneVo.playerKillNum == 16) {
                this.ui.ui_record.txt_kill_2.visible = false;
                this.ui.ui_record.txt_info1.visible = false;
                this.ui.ui_record.txt_info.text = '已完成任务！';
                return;
            }
            if (this.taskIndex >= 4) {
                return;
            }
            if (this.sceneVo.playerKillNum >= BattleConfig.killRewardList[this.taskIndex].killNum) {
                this.ui.ui_record.txt_kill_2.text = '' + BattleConfig.killRewardList[this.taskIndex].taskKill;
                var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
                if (hero) {
                    if (hero.quality == 0) {
                        reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                    }
                    else if (hero.quality == 1) {
                        reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                    }
                    else {
                        reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                    }
                }
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "！达成击杀目标，发现神秘宝箱" });
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: reward, showView: false });
                var sp1 = StageUtil.stageWidth / 2;
                var sp2 = StageUtil.stageHeight / 2;
                var card = this.ui.list_task;
                var tp = DisplayUtil.localToGlobal(card, new Laya.Point());
                this.dispatchEvent(BattleEvent.BATTLE_BOX_FLOAT_VIEW_SHOW, { sx: sp1, sy: sp2, tx: tp.x, ty: tp.y, showType: ViewType.NEW });
                this.taskIndex++;
            }
        }
        showUnitState() {
            var isTimer = this.checkStatTimer();
            if (isTimer) {
                TimerUtil.loopTimer(1000, this, this.showUnitStateHandler);
            }
            else {
                TimerUtil.stopTimer(this, this.showUnitStateHandler);
            }
            this.showUnitStateHandler();
        }
        showUnitStateHandler() {
            this.ui.ui_top.list_team.dataSource = this.getUnitStateList(1);
            this.ui.ui_top.list_foe.dataSource = this.getUnitStateList(2);
        }
        getUnitStateList(camp) {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            var ts = TimeUtil.getTimestamp();
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.camp == camp) {
                        var item = {};
                        if (vo.isPlayer) {
                            var time = vo.dieTs + SceneConfig.playeRreviveTime - ts;
                        }
                        else {
                            var time = vo.dieTs + SceneConfig.reviveTime - ts;
                        }
                        if (vo.camp == 1) {
                            item.img_bg = 'ui/img_UM_herokill_bg_blue.png';
                        }
                        else {
                            item.img_bg = 'ui/img_UM_herokill_bg_red.png';
                        }
                        if (vo.isDie && time > 0) {
                            item.img_npc = { skin: GoodsViewTool.getImgUrl(vo.cid), gray: true };
                            item.txt_time = '' + time;
                            item.img_bg2 = { visible: true };
                        }
                        else {
                            item.img_npc = { skin: GoodsViewTool.getImgUrl(vo.cid), gray: false };
                            item.txt_time = '';
                            item.img_bg2 = { visible: false };
                        }
                        nlist.push(item);
                    }
                }
            }
            return nlist;
        }
        checkStatTimer() {
            var list = SceneModel.model.vo.unitList;
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.isDie) {
                        return true;
                    }
                }
            }
            return false;
        }
        stateHandler() {
            var list = SceneModel.model.vo.unitList;
            var index = 0;
            var index2 = 5;
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.camp == 1) {
                        if (vo.isDie) {
                        }
                        else {
                        }
                        index++;
                    }
                }
            }
            for (var k in list) {
                var vo = list[k];
                if (vo.ttype == 1) {
                    if (vo.camp != 1) {
                        if (vo.isDie) {
                        }
                        else {
                        }
                        index2++;
                    }
                }
            }
        }
        initHpBarHandler() {
            var list = this.sceneVo.unitList;
            for (var k in list) {
                var vo = list[k];
                this.showHp(vo);
            }
        }
        unitAddedHandler(data) {
            this.showHp(data.vo);
        }
        showHp(vo) {
            if (vo) {
                if (vo.isDie == false) {
                    if (vo.ttype == 2) {
                        this.dispatchEvent(BattleEvent.BATTLE_HP_PILL_VIEW_SHOW, { showType: ViewType.NEW, vo: vo });
                    }
                    else {
                        this.dispatchEvent(BattleEvent.BATTLE_HP_VIEW_SHOW, { showType: ViewType.NEW, vo: vo });
                    }
                }
            }
        }
        switchHandler() {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_SWITCH_AIM);
        }
        showTaskList() {
            var taskList = BattleConfig.killRewardList;
            var nlist = [];
            for (var k in taskList) {
                var taskVo = taskList[k];
                var data = {};
                if (this.sceneVo.playerKillNum >= taskVo.killNum) {
                    if (taskVo.isReceive) {
                        data.img_frame = { visible: false };
                        data.img_box = { gray: true };
                        data.ui_bubble = { visible: false };
                        data.img_receive = { visible: true, skin: 'ui/img_UM_ui_text36.png' };
                    }
                    else {
                        data.vo = taskVo;
                        data.img_frame = { visible: true };
                        data.img_box = { gray: false };
                        data.ui_bubble = { visible: true };
                        data.img_receive = { visible: false, skin: 'ui/img_UM_ui_text37.png' };
                    }
                }
                else {
                    data.img_frame = { visible: true };
                    data.img_box = { gray: false };
                    data.ui_bubble = { visible: false };
                    data.img_receive = { visible: true, skin: 'ui/img_UM_ui_text37.png' };
                }
                nlist.push(data);
            }
            this.ui.list_task.dataSource = nlist;
        }
        getRewardHandler(e) {
            if (MouseTool.checkClick(e)) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.dispatchEvent(BattleEvent.BATTLE_TASK_REQUEST, { vo: vo });
                }
            }
        }
        tryHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_TRY_HERO_VIEW_SHOW);
        }
        closeHandler1() {
            if (BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum)) {
                BattleModel.model.tryHerocid = BattleTryTool.getTryHero(SegmentModel.model.maxTriphyNum).cid;
            }
            var playerVo = SceneModel.model.vo.playerVo;
            playerVo = BattleTool.getBattleData(1, BattleModel.model.tryHerocid, true).playerVo;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_RELPACE, { playerVo: playerVo });
        }
        adHandler1() {
            AdTool.videoAdShow(this, this.closeHandler1, 'heroTryBattle');
        }
        adHandler() {
        }
        closeHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_CLOSE_CLICK);
            this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: '您确认要退出战斗吗?', okHandler: HandlerUtil.create(this, this.closeOkHandler) });
        }
        closeOkHandler() {
            this.dispatchEvent(SceneEvent.SCENE_VIEW_EXIT, { isExit: true });
        }
        get playerVo() {
            return SceneModel.model.vo.playerVo;
        }
    }

    class BattleStartTipView$1 extends ui.battle.BattleWaveTipUI {
        constructor() {
            super();
            this.zOrder = 30;
        }
    }

    class BattleWaveTipViewController extends ViewController {
        constructor() {
            super();
            this.timeTotal = 5;
            this.viewClass = BattleStartTipView$1;
            this.viewName = 'BattleWaveTipView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            if (this.data.textType == 'end') {
                this.ui.ui_2.visible = false;
                this.ui.ui_1.visible = true;
                this.ui.ui_1.ani1.play(1, false);
                this.ui.ui_1.txt_con.text = '第' + this.data.wave + '波敌人已被击败！';
                TimerUtil.onceTimer(2000, this, this.close);
            }
            else if (this.data.textType == 'start') {
                this.ui.ui_1.visible = false;
                this.ui.ui_2.visible = true;
                this.ui.ui_2.ani1.play(1, false);
                TimerUtil.loopTimer(1000, this, this.nextTimerHandler);
                this.ui.ui_2.txt_con.text = '第' + this.data.wave + '波敌人正在赶来！';
            }
        }
        nextTimerHandler() {
            this.timeTotal--;
            this.ui.txt_time.text = '' + this.timeTotal;
            if (this.timeTotal <= 0) {
                this.close();
            }
        }
    }

    class BattleController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            BattleModel.model.init();
            ViewManager.register(BattleEvent.BATTLE_RELOAD_VIEW_SHOW, this, BattleReloadViewController);
            ViewManager.register(BattleEvent.BATTLE_ATT_TEXT_VIEW_SHOW, this, BattleAttTextViewController);
            ViewManager.register(BattleEvent.BATTLE_EXHAUST_TIP_VIEW_SHOW, this, BattleExhaustTipViewController);
            ViewManager.register(BattleEvent.BATTLE_FULL_TIP_VIEW_SHOW, this, BattleFullTipViewController);
            ViewManager.register(BattleEvent.BATTLE_KILL_TIP_VIEW_SHOW, this, BattleKillTipViewController);
            ViewManager.register(BattleEvent.BATTLE_KILL_ANIM_VIEW_SHOW, this, BattleKillAnimViewController);
            ViewManager.register(BattleEvent.BATTLE_REVIVE_TIP_VIEW_SHOW, this, BattleReviveTipViewController);
            ViewManager.register(BattleEvent.BATTLE_ANTKILL_TIP_VIEW_SHOW, this, BattleAntikillTipViewController);
            ViewManager.register(BattleEvent.BATTLE_RESURREC_VIEW_SHOW, this, BattleResurrecViewController);
            ViewManager.register(BattleEvent.BATTLE_MODES_VIEW_SHOW, this, BattleModesViewController);
            ViewManager.register(BattleEvent.BATTLE_MATCH_VIEW_SHOW, this, BattleMatchViewController);
            ViewManager.register(BattleEvent.BATTLE_START_TIP_VIEW_SHOW, this, BattleStartTipViewController);
            ViewManager.register(BattleEvent.BATTLE_GET_VIP_VIEW_SHOW, this, BattleGetVipViewController);
            ViewManager.register(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, this, BattleTextTipViewController);
            ViewManager.register(BattleEvent.BATTLE_WAVE_TIP_VIEW_SHOW, this, BattleWaveTipViewController);
            ViewManager.register(BattleEvent.BATTLE_LEV_MODES_VIEW_SHOW, this, BattleLevModesViewController);
            ViewManager.register(BattleEvent.BATTLE_LEV_SUPPLY_VIEW_SHOW, this, BattleLevSupplyViewController);
            ViewManager.register(BattleEvent.BATTLE_LEV_REPLACE_VIEW_SHOW, this, BattleLevReplaceViewController);
            ViewManager.register(BattleEvent.BATTLE_LEV_UNLOCK_VIEW_SHOW, this, BattleLevUnlockViewController);
            ViewManager.register(BattleEvent.BATTLE_CARD_GROUP_VIEW_SHOW, this, BattleCardGroupViewController);
            ViewManager.register(BattleEvent.BATTLE_HP_VIEW_SHOW, this, BattleHpViewController);
            ViewManager.register(BattleEvent.BATTLE_AIM_AINMATION_VIEW_SHOW, this, BattleAimAnmimationViewController);
            ViewManager.register(BattleEvent.BATTLE_HP_PILL_VIEW_SHOW, this, BattleHpPillViewController);
            ViewManager.register(BattleEvent.BATTLE_REBORN_HERO_VIEW_SHOW, this, BattleRebornHeroViewController);
            ViewManager.register(BattleEvent.BATTLE_VICTORY_MVP_VIEW_SHOW, this, BattleVictoryMvpViewController);
            ViewManager.register(BattleEvent.BATTLE_DEFEAT_MVP_VIEW_SHOW, this, BattleDefeatMvpViewController);
            ViewManager.register(BattleEvent.BATTLE_GAME_OVER_VIEW_SHOW, this, BattleGameOverViewController);
            ViewManager.register(BattleEvent.BATTLE_READY_VIEW_SHOW, this, BattleReadyViewController);
            ViewManager.register(BattleEvent.BATTLE_LOAD_VIEW_SHOW, this, BattleLoadViewController);
            ViewManager.register(BattleEvent.BATTLE_BOX_VIEW_SHOW, this, BattleMysteryBoxViewController);
            ViewManager.register(BattleEvent.BATTLE_VICTORY_NOTICE_VIEW_SHOW, this, BattleVictoryNoticeViewController);
            ViewManager.register(BattleEvent.BATTLE_DEFEAT_NOTICE_VIEW_SHOW, this, BattleDefeatNoticeViewController);
            ViewManager.register(BattleEvent.BATTLE_END_NOTICE_VIEW_SHOW, this, BattleEndNoticeViewController);
            ViewManager.register(BattleEvent.BATTLE_BOX_FLOAT_VIEW_SHOW, this, BattleBoxFloatViewController);
            ViewManager.register(BattleEvent.BATTLE_END_CRAZY_CHEST_VIEW_SHOW, this, BattleEndCrazyChestViewController);
            this.addEventListener(BattleEvent.BATTLE_TRY_HERO_VIEW_SHOW, this, this.try1Handler);
            this.addEventListener(BattleEvent.BATTLE_START_TRY_HERO_VIEW_SHOW, this, this.tryHandler);
            this.addEventListener(BattleEvent.BATTLE_TASK_VIEW_SHOW, this, this.taskTypeHandler);
            this.addEventListener(BattleEvent.BATTLE_CRAZY_CHEST_VIEW_SHOW, this, this.crazyTypeHandler);
            this.addEventListener(BattleEvent.BATTLE_VIEW_SHOW, this, this.battleViewHandler);
            this.addEventListener(BattleEvent.BATTLE_DEFEAT_VIEW_SHOW, this, this.defeatHandler);
            this.addEventListener(BattleEvent.BATTLE_END_VIEW_SHOW, this, this.endHandler);
            this.addEventListener(BattleEvent.BATTLE_VICTORY_VIEW_SHOW, this, this.victoryHandler);
            this.addEventListener(BattleEvent.BATTLE_GET_GUN_VIEW_SHOW, this, this.getGunHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.overHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_FALL, this, this.fallHandler);
            this.addEventListener(BattleEvent.BATTLE_START, this, this.battleStartHandler);
            this.addEventListener(BattleEvent.BATTLE_RESTART, this, this.restartHandler);
            this.addEventListener(BattleEvent.BATTLE_STATE_END, this, this.endDateHandler);
            this.addEventListener(SceneEvent.SCENE_VIEW_START, this, this.titleShowHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(BattleEvent.BATTLE_TASK_REQUEST, this, this.taskHandler);
            this.initPauseCheck();
        }
        initHandler() {
            this.checkLoc();
        }
        battleStartHandler(data) {
            LogTool.log('battleStartHandler.data:' + JSONUtil.stringify(data));
            BattleModel.model.isBattle = true;
            BattleModel.model.isLvUpTip = false;
            var cid = ParamUtil.getInt(data, 'cid', 1);
            var battleType = ParamUtil.getInt(data, 'battleType', 1);
            var difficulty = ParamUtil.getInt(data, 'difficulty', 1);
            var isTry = ParamUtil.getBool(data, 'isTry', false);
            var lev = ParamUtil.getInt(data, 'lev', 1);
            var list1 = ParamUtil.getObject(data, 'list1', []);
            var list2 = ParamUtil.getObject(data, 'list2', []);
            BattleModel.model.isSettlement = false;
            BattleModel.model.cid = cid;
            BattleModel.model.battleType = battleType;
            BattleModel.model.aridorpNum = 0;
            BattleModel.model.battleLev = lev;
            BattleModel.model.pickJinNum = 0;
            BattleModel.model.pickTongNum = 0;
            for (var k in BattleConfig.killRewardList) {
                var taskVo = BattleConfig.killRewardList[k];
                taskVo.isReceive = false;
            }
            var data = BattleTool.getBattleData(cid, BattleModel.model.playerCid, isTry, battleType, difficulty, list1, list2);
            this.dispatchEvent(SceneEvent.SCENE_BATTLE_VIEW_SHOW, data);
            this.dispatchEvent(BattleEvent.BATTLE_VIEW_SHOW, { showType: ViewType.OPEN });
            this.dispatchEvent(BattleEvent.BATTLE_STATE_START);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { list: [{ cid: GoodsAttrType.ATTR_PHY, num: BattleConfig.phy }] });
            this.checkLoc();
        }
        overHandler(data) {
            BattleModel.model.result = ParamUtil.getInt(data, 'result', -1);
            BattleModel.model.isUnlock = false;
            BattleModel.model.isLvUpTip = true;
            if (BattleModel.model.result == 1) {
                BattleModel.model.victoryNum++;
            }
            else {
                BattleModel.model.defeatNum++;
            }
            BattleModel.model.isBattle = false;
            BattleModel.model.saveData();
            this.dispatchEvent(BattleEvent.BATTLE_GAME_OVER_VIEW_SHOW);
            TimerUtil.onceTimer(2000, this, this.showResultHandler);
            if (BattleModel.model.result == -1) {
                this.dispatchEvent(BattleEvent.BATTLE_STATE_DEFEAT);
            }
            else {
                this.dispatchEvent(BattleEvent.BATTLE_STATE_VICTORY);
            }
            this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_BTN_VIEW_CLOSE);
            this.dispatchEvent(BattleEvent.BATTLE_RESURREC_VIEW_SHOW, { showType: ViewType.CLOSE });
            this.dispatchEvent(BattleEvent.BATTLE_STATE_OVER);
        }
        showResultHandler() {
            if (BattleModel.model.result == 1) {
                this.dispatchEvent(BattleEvent.BATTLE_VICTORY_MVP_VIEW_SHOW);
            }
            else if (BattleModel.model.result == -1) {
                this.dispatchEvent(BattleEvent.BATTLE_DEFEAT_MVP_VIEW_SHOW);
            }
            else {
                this.dispatchEvent(BattleEvent.BATTLE_END_VIEW_SHOW);
            }
            this.dispatchEvent(BattleEvent.BATTLE_VIEW_SHOW, { showType: ViewType.CLOSE });
        }
        endDateHandler() {
            this.dispatchEvent(SceneEvent.SCENE_BATTLE_VIEW_SHOW, { showType: ViewType.CLOSE });
            if (AdTool.checkRate('wudian', true) && BattleConfig.isShowEndCrazyChest == true) {
                this.dispatchEvent(BattleEvent.BATTLE_END_CRAZY_CHEST_VIEW_SHOW);
            }
        }
        fallHandler(data) {
            data.showType = ViewType.OPEN;
            this.dispatchEvent(BattleEvent.BATTLE_RESURREC_VIEW_SHOW, data);
        }
        restartHandler() {
            var data = BattleTool.getBattleData(BattleModel.model.cid, BattleModel.model.playerCid, false, BattleModel.model.battleType);
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { showType: ViewType.OPEN });
            this.dispatchEvent(SceneEvent.SCENE_BATTLE_VIEW_SHOW, data);
            this.dispatchEvent(BattleEvent.BATTLE_VIEW_SHOW, { showType: ViewType.OPEN });
        }
        checkLoc() {
            var vo = BattleLocTool.getGun1Loc();
            if (!vo || vo.num <= 0) {
                vo = GoodsModel.model.getGoodsByCid(BattleConfig.defGun1Cid);
                if (vo) {
                    this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: vo.id });
                }
            }
            var vo = BattleLocTool.getGun2Loc();
            if (!vo || vo.num <= 0) {
                vo = GoodsModel.model.getGoodsByCid(BattleConfig.defGun2Cid);
                if (vo) {
                    this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: vo.id });
                }
            }
            var vo = BattleLocTool.getHelmetLoc();
            if (!vo || vo.num <= 0) {
                vo = GoodsModel.model.getGoodsByCid(BattleConfig.defHelmetCid);
                if (vo) {
                    this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: vo.id });
                }
            }
            var vo = BattleLocTool.getClothesLoc();
            if (!vo || vo.num <= 0) {
                vo = GoodsModel.model.getGoodsByCid(BattleConfig.defClothesCid);
                if (vo) {
                    this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: vo.id });
                }
            }
        }
        getGunHandler(data) {
            ViewManager.show(this, BattleGetGunViewController, data);
        }
        titleShowHandler() {
            this.dispatchEvent(BattleEvent.BATTLE_START_TIP_VIEW_SHOW);
        }
        defeatHandler(data) {
            LogTool.log('defeatHandler.defeatType:' + BattleConfig.defeatType);
            if (BattleConfig.defeatType == 1) {
                ViewManager.show(this, BattleDefeat1ViewController, data);
            }
            else if (BattleConfig.defeatType == 2) {
                ViewManager.show(this, BattleDefeat2ViewController, data);
            }
            else if (BattleConfig.defeatType == 3) {
                ViewManager.show(this, BattleDefeat3ViewController, data);
            }
            else if (BattleConfig.defeatType == 4) {
                ViewManager.show(this, BattleDefeat4ViewController, data);
            }
            else if (BattleConfig.defeatType == 5) {
                ViewManager.show(this, BattleDefeat5ViewController, data);
            }
            else if (BattleConfig.defeatType == 6) {
                ViewManager.show(this, BattleDefeat6ViewController, data);
            }
            else if (BattleConfig.defeatType == 7) {
                ViewManager.show(this, BattleDefeat7ViewController, data);
            }
            else {
                ViewManager.show(this, BattleDefeatViewController, data);
            }
        }
        endHandler(data) {
            LogTool.log('endHandler.endType:' + BattleConfig.endType);
            ViewManager.show(this, BattleEndViewController, data);
        }
        victoryHandler(data) {
            LogTool.log('victoryHandler.victoryType:' + BattleConfig.victoryType);
            if (BattleConfig.victoryType == 1) {
                ViewManager.show(this, BattleVictory1ViewController, data);
            }
            else if (BattleConfig.victoryType == 2) {
                ViewManager.show(this, BattleVictory2ViewController, data);
            }
            else if (BattleConfig.victoryType == 3) {
                ViewManager.show(this, BattleVictory3ViewController, data);
            }
            else if (BattleConfig.victoryType == 4) {
                ViewManager.show(this, BattleVictory4ViewController, data);
            }
            else if (BattleConfig.victoryType == 5) {
                ViewManager.show(this, BattleVictory5ViewController, data);
            }
            else if (BattleConfig.victoryType == 6) {
                ViewManager.show(this, BattleVictory6ViewController, data);
            }
            else if (BattleConfig.victoryType == 7) {
                ViewManager.show(this, BattleVictory7ViewController, data);
            }
            else {
                ViewManager.show(this, BattleVictoryViewController, data);
            }
        }
        battleViewHandler(data) {
            LogTool.log('battleViewHandler.battleViewType:' + BattleConfig.battleViewType);
            if (BattleConfig.battleViewType == 1) {
                ViewManager.show(this, BattleView1Controller, data);
            }
            else {
                ViewManager.show(this, BattleViewController, data);
            }
        }
        taskHandler(data) {
            data.vo.isReceive = true;
            var reward = [];
            var hero = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
            if (hero) {
                if (hero.quality == 0) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 50 }, { cid: BattleModel.model.playerCid, num: 10 }];
                }
                else if (hero.quality == 1) {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 100 }, { cid: BattleModel.model.playerCid, num: 3 }];
                }
                else {
                    reward = [{ cid: GoodsAttrType.ATTR_TONG, num: 150 }, { cid: BattleModel.model.playerCid, num: 1 }];
                }
            }
            this.dispatchEvent(BattleEvent.BATTLE_TASK_VIEW_SHOW, { list: reward });
            this.dispatchEvent(BattleEvent.BATTLE_TASK_RESPONSE);
        }
        initPauseCheck() {
            var list = ['BattleTryHeroView', 'BattleResurrecView', 'AlertView', 'BattleRebornHeroView', 'BattleTaskView', 'GuideBattleView', 'GuideDialogView', 'GuideBattleAimView', 'GuideBattleAttView', 'GuideBattleSkillView', 'PlatformShareView', 'BattleEndMysteryBoxView'];
            this.startChild(new CheckViewShowController(BattleEvent.BATTLE_PAUSE, null, list));
            this.addEventListener(BattleEvent.BATTLE_PAUSE, this, this.pauseHandler);
        }
        pauseHandler(data) {
            if (data && data.showType == ViewType.OPEN) {
                this.dispatchEvent(SceneEvent.SCENE_PAUSE_REQUEST, { type: 'check', isPause: true });
            }
            else {
                this.dispatchEvent(SceneEvent.SCENE_PAUSE_REQUEST, { type: 'check', isPause: false });
            }
        }
        tryHandler(data) {
            if (BattleConfig.battleTryType == 1) {
                ViewManager.show(this, BattleStartTryHero1ViewController, data);
            }
            else if (BattleConfig.battleTryType == 2) {
                ViewManager.show(this, BattleStartTryHero2ViewController, data);
            }
            else if (BattleConfig.battleTryType == 3) {
                ViewManager.show(this, BattleStartTryHero3ViewController, data);
            }
            else if (BattleConfig.battleTryType == 4) {
                ViewManager.show(this, BattleStartTryHero4ViewController, data);
            }
            else {
                ViewManager.show(this, BattleStartTryHeroViewController, data);
            }
        }
        try1Handler(data) {
            if (BattleConfig.battleTryTypeTwo == 1) {
                ViewManager.show(this, BattleTryHero1ViewController, data);
            }
            else if (BattleConfig.battleTryTypeTwo == 2) {
                ViewManager.show(this, BattleTryHero2ViewController, data);
            }
            else if (BattleConfig.battleTryTypeTwo == 3) {
                ViewManager.show(this, BattleTryHero3ViewController, data);
            }
            else {
                ViewManager.show(this, BattleTryHeroViewController, data);
            }
        }
        taskTypeHandler(data) {
            if (BattleConfig.battleTaskType == 1) {
                ViewManager.show(this, BattleTask1ViewController, data);
            }
            else if (BattleConfig.battleTaskType == 2) {
                ViewManager.show(this, BattleTask2ViewController, data);
            }
            else if (BattleConfig.battleTaskType == 3) {
                ViewManager.show(this, BattleTask3ViewController, data);
            }
            else if (BattleConfig.battleTaskType == 4) {
                ViewManager.show(this, BattleTask4ViewController, data);
            }
            else if (BattleConfig.battleTaskType == 5) {
                ViewManager.show(this, BattleTask5ViewController, data);
            }
            else if (BattleConfig.battleTaskType == 6) {
                ViewManager.show(this, BattleTask6ViewController, data);
            }
            else if (BattleConfig.battleTaskType == 7) {
                ViewManager.show(this, BattleTask7ViewController, data);
            }
            else {
                ViewManager.show(this, BattleTaskViewController, data);
            }
        }
        crazyTypeHandler(data) {
            if (BattleConfig.crazyType == 1) {
                ViewManager.show(this, BattleCrazyChest1ViewController, data);
            }
            else {
                ViewManager.show(this, BattleCrazyChestViewController, data);
            }
        }
    }

    class HttpEvent {
    }
    HttpEvent.HTTP_RESPONSE_ERROR = 'HTTP_RESPONSE_ERROR';

    class AlertView extends ui.comp.AlertUI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class CommonConfig {
    }
    CommonConfig.ALERT_ANIM_OPEN = null;
    CommonConfig.ALERT_ANIM_CLOSE = null;
    CommonConfig.ALERT_SOUND_OPEN = 'open';
    CommonConfig.ALERT_SOUND_CLOSE = 'close';
    CommonConfig.alertType = 0;

    class AlertViewController extends DialogViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = AlertView;
            this.lasting = true;
            this.openSound = CommonConfig.ALERT_SOUND_OPEN;
            this.closeSound = CommonConfig.ALERT_SOUND_CLOSE;
            this.openAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_OPEN);
            this.closeAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_CLOSE);
            this.viewName = 'AlertView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            if (this.ui) {
                this.ui.txt_content.text = ParamUtil.getString(this.data, 'text', "");
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
                this.ui.btn_no.on(Laya.Event.CLICK, this, this.noHandler);
            }
        }
        okHandler() {
            if (this.data) {
                var okHandler = this.data.okHandler;
                if (okHandler) {
                    okHandler.run();
                }
            }
            this.close();
        }
        noHandler() {
            if (this.data) {
                var noHandler = this.data.noHandler;
                if (noHandler) {
                    noHandler.run();
                }
            }
            this.close();
        }
        close() {
            super.close();
            if (this.data) {
                var closeHandler = this.data.closeHandler;
                if (closeHandler) {
                    closeHandler.run();
                }
            }
            this.data = null;
        }
    }

    class BangsView extends ui.comp.BangsUI {
        constructor() {
            super();
            this.zOrder = 10000;
        }
    }

    class BangsViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = BangsView;
        }
        openComplete() {
            super.openComplete();
        }
    }

    class EventQueueController extends Controller {
        constructor() {
            super();
            this.list = [];
            this.currentEvent = null;
        }
        addEvent(name, data = null, exitEvnet = null) {
            this.list.push({ eventName: name, data: data, exitEvnet: exitEvnet });
            this.checkEvent();
        }
        unshiftEvent(name, data = null, exitEvnet = null) {
            this.list.unshift({ eventName: name, data: data, exitEvnet: exitEvnet });
            this.checkEvent();
        }
        checkEvent() {
            if (this.currentEvent == null) {
                if (this.list.length > 0) {
                    this.currentEvent = this.list.shift();
                    if (this.currentEvent) {
                        this.dispatchEvent(this.currentEvent.eventName, this.currentEvent.data);
                        if (this.currentEvent.exitEvnet) {
                            this.onceEventListener(this.currentEvent.exitEvnet, this, this.nextHandler);
                        }
                        else {
                            this.nextHandler();
                        }
                    }
                }
            }
        }
        nextHandler() {
            TimerUtil.callLater(this, this.exitHandler);
        }
        exitHandler() {
            this.currentEvent = null;
            this.checkEvent();
        }
    }

    class LogView extends ui.comp.LogUI {
        constructor() {
            super();
            this.zOrder = 901;
        }
    }

    class LogViewController extends DialogViewController {
        constructor() {
            super();
            this.num = 0;
            this.viewClass = LogView;
            this.viewName = 'LogView';
            this.openAnim = null;
            this.closeAnim = null;
            this.lasting = true;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_cmd.on(Laya.Event.CLICK, this, this.cmdHandler);
            this.ui.txt_cmd.on(Laya.Event.KEY_DOWN, this, this.keyHandler);
            this.ui.btn_clear.on(Laya.Event.CLICK, this, this.clearHandler);
            var txt = "";
            var list = LogModel.model.logList;
            for (var t of list) {
                txt = (t + '\n') + txt;
            }
            this.ui.txt_content.text = txt;
            this.ui.txt_content.autoSize = true;
        }
        cmdHandler() {
            var cmd = this.ui.txt_cmd.text;
            var cmdList = cmd.split(' ');
            var cmdName = cmdList[0];
            if (cmdName == 'shuishishangdi') {
            }
            else if (cmdName == 'clearAll') {
                Laya.LocalStorage.clear();
                if (window && window.location) {
                    window.location.reload();
                }
            }
            else if (cmdName == 'map') {
                this.dispatchEvent(SceneEvent.SCENE_EDITOR_VIEW_SHOW);
                this.dispatchEvent(PageEvent.PAGE_VIEW_SHOW, { showType: ViewType.CLOSE });
            }
            this.ui.txt_cmd.text = '';
            this.close();
        }
        keyHandler(e) {
            if (e.keyCode == 13) {
                this.cmdHandler();
            }
        }
        clearHandler() {
            this.num++;
            if (this.num > 10) {
                Laya.LocalStorage.clear();
                LogTool.log('LogViewController.clearHandler:' + this.num);
            }
        }
    }

    class NativeEvent {
        static NATIVE_CALL_RESPONSE(name) {
            return 'NATIVE_CALL_RESPONSE@' + name;
        }
    }
    NativeEvent.NATIVE_CALL_REQUEST = 'NATIVE_CALL_REQUEST';

    class NativeModel {
        static getNativeApi() {
            if (typeof nativeApi == "undefined") {
                return null;
            }
            else {
                return nativeApi;
            }
        }
        static getClientApi() {
            if (typeof clientApi == "undefined") {
                return null;
            }
            else {
                return clientApi;
            }
        }
    }

    class NativeTool {
        static available() {
            if (Laya.Browser.window && Laya.Browser.window.conchMarket) {
                return true;
            }
            if (NativeModel.getNativeApi()) {
                return true;
            }
            return false;
        }
        static callNative(name, param = null) {
            var api = NativeModel.getNativeApi();
            LogTool.log('callNative:' + api);
            if (api && api.callNative) {
                LogTool.log('callNative.api:' + api.callNative);
                api.callNative(name, JSONUtil.stringify(param));
            }
        }
        static setNativeListener(caller, fun) {
            LogTool.log('NativeTool.setNativeListener');
            var clientApi = NativeModel.getClientApi();
            if (clientApi) {
                LogTool.log('NativeTool.setNativeListener.clientApi');
                clientApi.callClient = (name, param) => {
                    LogTool.log('NativeTool.callClient(' + name + ',' + param + ')');
                    var data = JSONUtil.parse(param);
                    fun.call(caller, name, data);
                };
            }
        }
        static shareImage(title, text, image, url) {
            if (this.available() == false) {
                return;
            }
            var sData = {
                type: "shareImage",
                title: title,
                text: text,
                image: image,
                url: url
            };
            var api = NativeModel.getNativeApi();
            if (api) {
                this.callNative("shareImage", sData);
            }
            else {
                Laya.Browser.window.conchMarket.enterShareAndFeed(JSONUtil.stringify(sData), function (data) {
                    LogTool.log(data);
                });
            }
        }
        static shareText(title, text, url) {
            if (this.available() == false) {
                return;
            }
            var sData = {
                type: "shareText",
                title: title,
                text: text,
                url: url
            };
            var api = NativeModel.getNativeApi();
            if (api) {
                this.callNative("shareText", sData);
            }
            else {
                Laya.Browser.window.conchMarket.enterShareAndFeed(JSONUtil.stringify(sData), function (data) {
                    LogTool.log(data);
                });
            }
        }
        static openUrl(url) {
            if (this.available() == false) {
                return;
            }
            var sData = {
                type: "openUrl",
                url: url,
            };
            var api = NativeModel.getNativeApi();
            if (api) {
                this.callNative("openUrl", sData);
            }
            else {
                Laya.Browser.window.conchMarket.enterShareAndFeed(JSONUtil.stringify(sData), function (data) {
                    LogTool.log(data);
                });
            }
        }
        static openView(uri) {
            if (this.available() == false) {
                return;
            }
            var sData = {
                type: "openView",
                uri: uri,
            };
            var api = NativeModel.getNativeApi();
            if (api) {
                this.callNative("openView", sData);
            }
            else {
                Laya.Browser.window.conchMarket.enterShareAndFeed(JSONUtil.stringify(sData), function (data) {
                    LogTool.log(data);
                });
            }
        }
        static textCopy(text) {
            if (this.available() == false) {
                return;
            }
            var sData = {
                type: "textCopy",
                text: text,
            };
            var api = NativeModel.getNativeApi();
            if (api && api.textCopy) {
                this.callNative("textCopy", sData);
            }
            else {
                Laya.Browser.window.conchMarket.enterShareAndFeed(JSONUtil.stringify(sData), function (data) {
                    LogTool.log(data);
                });
            }
        }
        static callSdk(name, param = null) {
            var api = NativeModel.getNativeApi();
            if (api && api.callSdk) {
                api.callSdk(name, JSONUtil.stringify(param));
            }
        }
        static showLogin() {
            this.callNative("login");
        }
        static showVideoAd() {
            this.callNative("showVideoAd");
        }
        static showBannerAd(data = null) {
            this.callNative("showBannerAd", data);
        }
        static closeBannerAd() {
            this.callNative("closeBannerAd");
        }
        static showInsterAd() {
            this.callNative("showInsertAd");
        }
        static showFullAd() {
            this.callNative("showFullAd");
        }
        static showSplashAd() {
            this.callNative("showSplashAd");
        }
        static showFeedAd(data = null) {
            this.callNative("showFeedAd", data);
        }
        static closeFeedAd() {
            this.callNative("closeFeedAd");
        }
        static showPlatformView() {
            this.callNative("showPlatformView");
        }
        static exitGame() {
            this.callNative("exitGame");
        }
        static userAgreed() {
            this.callNative("agree");
        }
    }

    class NativeController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.addEventListener(NativeEvent.NATIVE_CALL_REQUEST, this, this.callHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            NativeTool.setNativeListener(this, this.callClientHandler);
        }
        callHandler(data) {
            NativeTool.callNative(data);
        }
        callClientHandler(name, data) {
            LogTool.log('NativeController.callClientHandler');
            this.dispatchEvent(NativeEvent.NATIVE_CALL_RESPONSE(name), data);
        }
    }

    class NoticeView extends ui.comp.NoticeUI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class NoticeViewController extends PanelViewController {
        constructor() {
            super();
            this.list = [];
            this.isRun = false;
            this.iy = 0;
            this.index = 0;
            this.line = 50;
            this.ui = this.view = new Laya.Sprite();
            this.ui.y = 200;
            this.ui.zOrder = 900;
            this.openSound = null;
            this.closeSound = null;
            this.viewName = 'NoticeView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            var list = ParamUtil.getObject(this.data, 'list');
            for (var k in list) {
                this.list.push(list[k]);
            }
            this.showList();
            TimerUtil.onceTimer(2000, this, this.close);
        }
        showList() {
            if (this.isRun) {
                return;
            }
            if (this.list.length > 0) {
                var txt = this.list.shift();
                this.showNext(txt);
            }
            this.isRun = true;
            TimerUtil.onceTimer(200, this, this.showEndHandler);
        }
        showEndHandler() {
            this.isRun = false;
            if (this.list.length > 0) {
                this.showList();
            }
        }
        showNext(txt) {
            this.index++;
            var item = ViewPoolUtil.getObject('NoticeItem', NoticeView);
            item.txt_content.text = txt;
            item.y = this.iy + 200;
            this.ui.addChild(item);
            TweenUtil.to(this, item, { y: this.iy }, 200);
            this.iy += this.line;
            if (this.index > 5) {
                var n = this.index - 5;
                TweenUtil.to(this, this.ui, { y: 200 - n * this.line }, 200);
                var item0 = this.ui.getChildAt(0);
                ViewPoolUtil.recover(item0);
            }
        }
    }

    class OpenUrlView extends ui.comp.AlertUI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class OpenUrlViewController extends PanelViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = OpenUrlView;
            this.lasting = true;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            if (this.ui) {
                if (this.data && this.data.text) {
                    this.ui.txt_content.text = this.data.text;
                }
                this.ui.btn_no.on(Laya.Event.CLICK, this, this.close);
                this.okFun = () => { this.okHandler(); };
                window.addEventListener('click', this.okFun);
                window.addEventListener('touchend', this.okFun);
            }
        }
        close() {
            super.close();
            window.removeEventListener('click', this.okFun);
            window.removeEventListener('touchend', this.okFun);
        }
        okHandler() {
            var target = this.ui.btn_ok;
            if (target.stage) {
                if (target.hitTestPoint(target.stage.mouseX, target.stage.mouseY)) {
                    window.open(this.data.url);
                    this.close();
                }
            }
        }
    }

    class ParticleViewController extends ViewController {
        constructor() {
            super();
            this.imgList = [];
            this.disMin = 100;
            this.disMax = 300;
            this.rotateMix = 0;
            this.rotateMax = 360;
            this.angleMix = 0;
            this.angleMax = 360;
            this.alphaMin = 0;
            this.alphaMax = 0;
            this.intervalTime = 0;
            this.durationTime = 2000;
            this.num = 10;
            this.gravity = false;
            this.cnum = 0;
            this.view = this.ui = new Laya.Sprite();
        }
        openComplete() {
            super.openComplete();
            this.setDatas(this.data);
            this.startShow();
        }
        setDatas(data) {
            this.imgList = ParamUtil.getObject(data, 'imgList');
            this.ui.x = ParamUtil.getInt(data, 'x', StageUtil.stageWidth / 2);
            this.ui.y = ParamUtil.getInt(data, 'y', StageUtil.stageHeight / 2);
            this.ui.zOrder = ParamUtil.getInt(data, 'zOrder', 999);
            this.disMin = ParamUtil.getInt(data, 'disMin', this.disMin);
            this.disMax = ParamUtil.getInt(data, 'disMax', this.disMax);
            this.rotateMix = ParamUtil.getInt(data, 'rotateMix', this.rotateMix);
            this.rotateMax = ParamUtil.getInt(data, 'rotateMax', this.rotateMax);
            this.alphaMin = ParamUtil.getInt(data, 'alphaMin', this.alphaMin);
            this.alphaMax = ParamUtil.getInt(data, 'alphaMax', this.alphaMax);
            this.angleMix = ParamUtil.getInt(data, 'angleMix', this.angleMix);
            this.angleMax = ParamUtil.getInt(data, 'angleMax', this.angleMax);
            this.intervalTime = ParamUtil.getInt(data, 'intervalTime', this.intervalTime);
            this.durationTime = ParamUtil.getInt(data, 'durationTime', this.durationTime);
            this.num = ParamUtil.getInt(data, 'num', this.num);
            this.gravity = ParamUtil.getBool(data, 'gravity', this.gravity);
        }
        startShow() {
            if (this.intervalTime == 0) {
                for (var i = 0; i < this.num; i++) {
                    this.showItem();
                }
                this.startEnd();
            }
            else {
                this.cnum = 0;
                TimerUtil.loopTimer(this.intervalTime, this, this.timerHandler);
            }
        }
        timerHandler() {
            this.showItem();
            this.cnum++;
            if (this.cnum >= this.num) {
                TimerUtil.stopTimer(this, this.timerHandler);
                this.startEnd();
            }
        }
        showItem() {
            var url = ArrayUtil.randomItem(this.imgList);
            var img = new Laya.Image(url);
            var box = new Laya.Box();
            box.addChild(img);
            box.anchorX = 0.5;
            box.anchorY = 0.5;
            this.ui.addChild(box);
            var dis = MathUtil.randomInt(this.disMin, this.disMax);
            var angle = MathUtil.randomInt(this.angleMix, this.angleMax);
            var rotate = MathUtil.randomInt(this.rotateMix, this.rotateMax);
            var tx = MathUtil.cos(angle) * dis;
            var ty = MathUtil.sin(angle) * dis;
            var alpha = MathUtil.randomNumber(this.alphaMin, this.alphaMax);
            TweenUtil.to(this, box, { x: tx, y: ty, rotation: rotate }, this.durationTime, Laya.Ease.quadOut);
            TweenUtil.to(this, box, { alpha: alpha }, this.durationTime, Laya.Ease.quadIn);
        }
        startEnd() {
            TimerUtil.onceTimer(this.durationTime, this, this.close);
        }
    }

    class PromptView extends ui.comp.PromptUI {
        constructor() {
            super();
            this.zOrder = 901;
        }
    }

    class PromptViewController extends PanelViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = PromptView;
            this.lasting = true;
            this.openSound = null;
            this.closeSound = null;
            this.openAnim = ViewAnimTool.getViewAnim('ZoomIn', { y: 300 });
            this.closeAnim = ViewAnimTool.getViewAnim('ZoomOut');
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.showData();
        }
        showData() {
            if (this.ui) {
                if (this.data) {
                    if (this.data.text) {
                        this.ui.txt_content.text = this.data.text;
                    }
                    if (this.data.type == PromptType.PROMPT_OK) {
                        this.ui.img_ico.skin = 'comp/img_ok.png';
                    }
                    else if (this.data.type == PromptType.PROMPT_INFO) {
                        this.ui.img_ico.skin = 'comp/img_warning.png';
                    }
                    else if (this.data.type == PromptType.PROMPT_WARNING) {
                        this.ui.img_ico.skin = 'comp/img_warning.png';
                        SoundTool.playSound('prompt');
                    }
                    else if (this.data.type == PromptType.PROMPT_ERROR) {
                        this.ui.img_ico.skin = 'comp/img_warning.png';
                        SoundTool.playSound('prompt');
                    }
                    else if (this.data.type == PromptType.PROMPT_BANNED) {
                        this.ui.img_ico.skin = 'comp/img_warning.png';
                        SoundTool.playSound('prompt');
                    }
                    else {
                        this.ui.img_ico.skin = '';
                    }
                }
                TimerUtil.stopAllTimer(this);
                TimerUtil.onceTimer(1000, this, this.close);
            }
        }
    }

    class TipsView extends ui.comp.TipsUI {
        constructor() {
            super();
            this.zOrder = 901;
        }
    }

    class TipsViewController extends PanelViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = TipsView;
            this.openSound = null;
            this.closeSound = null;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            if (this.data) {
                if (this.data.text) {
                    this.ui.txt_content.text = this.data.text;
                }
            }
            Laya.stage.on(Laya.Event.MOUSE_UP, this, this.upHandler);
        }
        close() {
            super.close();
            Laya.stage.off(Laya.Event.MOUSE_UP, this, this.upHandler);
        }
        upHandler() {
            this.close();
        }
    }

    class VideoView {
        constructor(url, autoplay = true, box = null) {
            var videoElement = document.createElement("video");
            this.videoElement = videoElement;
            document.body.appendChild(videoElement);
            videoElement.src = url;
            videoElement.controls = true;
            videoElement.style.zIndex = '200000';
            videoElement.style.position = 'absolute';
            videoElement.style.top = '0';
            videoElement.style.transformOrigin = Laya.Render.canvas.style.transformOrigin;
            videoElement.style.transform = Laya.Render.canvas.style.transform;
            videoElement.autoplay = autoplay;
            if (box) {
                Laya.Utils.fitDOMElementInArea(videoElement, box, 0, 0, box.width, box.height);
                Laya.stage.on(Laya.Event.RESIZE, this, Laya.Utils.fitDOMElementInArea, [videoElement, box, 0, 0, box.width, box.height]);
                videoElement.setAttribute("webkit-playsinline", 'true');
                videoElement.setAttribute("playsinline", 'true');
            }
            else {
                videoElement.style.width = '100%';
                videoElement.style.height = '100%';
            }
        }
        close() {
            if (this.videoElement) {
                this.videoElement.remove();
            }
            Laya.stage.off(Laya.Event.RESIZE, this, Laya.Utils.fitDOMElementInArea);
        }
    }

    class VideoViewController extends DialogViewController {
        constructor() {
            super();
            this.viewName = 'VideoView';
            this.view = this.ui = new Laya.Box();
            this.ui.zOrder = 800;
            this.modalClickClose = true;
        }
        openComplete() {
            super.openComplete();
            this.ui.width = ParamUtil.getInt(this.data, 'width', this.ui.stage.width);
            this.ui.height = ParamUtil.getInt(this.data, 'height', this.ui.stage.height);
            this.ui.centerX = 0;
            this.ui.centerY = 0;
            this.video = new VideoView(this.data.url, true, this.ui);
            var closeBtn = document.createElement("input");
            closeBtn.type = "button";
            closeBtn.className = "button btn btn-primary";
            closeBtn.id = "closeBtn";
            closeBtn.value = "X";
            closeBtn.style.zIndex = '200002';
            closeBtn.style.position = 'absolute';
            closeBtn.style.width = '40px';
            closeBtn.style.height = '40px';
            closeBtn.style.top = '0';
            closeBtn.style.transform = Laya.Render.canvas.style.transform;
            closeBtn.style.transformOrigin = Laya.Render.canvas.style.transformOrigin;
            closeBtn.onclick = (e) => { this.close(); };
            document.body.appendChild(closeBtn);
            this.closeBtn = closeBtn;
            SoundTool.setPause('VideoView', true);
        }
        close() {
            super.close();
            SoundTool.setPause('VideoView', false);
            this.video.close();
            this.closeBtn.remove();
        }
    }

    class Alert1View extends ui.comp.Alert1UI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class Alert1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = Alert1View;
            this.lasting = true;
            this.openSound = CommonConfig.ALERT_SOUND_OPEN;
            this.closeSound = CommonConfig.ALERT_SOUND_CLOSE;
            this.openAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_OPEN);
            this.closeAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_CLOSE);
            this.viewName = 'AlertView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            if (this.ui) {
                this.ui.txt_content.text = ParamUtil.getString(this.data, 'text', "");
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
                this.ui.btn_no.on(Laya.Event.CLICK, this, this.noHandler);
            }
        }
        okHandler() {
            if (this.data) {
                var okHandler = this.data.okHandler;
                if (okHandler) {
                    okHandler.run();
                }
            }
            this.close();
        }
        noHandler() {
            if (this.data) {
                var noHandler = this.data.noHandler;
                if (noHandler) {
                    noHandler.run();
                }
            }
            this.close();
        }
        close() {
            super.close();
            if (this.data) {
                var closeHandler = this.data.closeHandler;
                if (closeHandler) {
                    closeHandler.run();
                }
            }
            this.data = null;
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class Alert2View extends ui.comp.Alert2UI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class Alert2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = Alert2View;
            this.lasting = true;
            this.openSound = CommonConfig.ALERT_SOUND_OPEN;
            this.closeSound = CommonConfig.ALERT_SOUND_CLOSE;
            this.openAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_OPEN);
            this.closeAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_CLOSE);
            this.viewName = 'AlertView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            if (this.ui) {
                this.ui.txt_content.text = ParamUtil.getString(this.data, 'text', "");
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
                this.ui.btn_no.on(Laya.Event.CLICK, this, this.noHandler);
            }
        }
        okHandler() {
            if (this.data) {
                var okHandler = this.data.okHandler;
                if (okHandler) {
                    okHandler.run();
                }
            }
            this.close();
        }
        noHandler() {
            if (this.data) {
                var noHandler = this.data.noHandler;
                if (noHandler) {
                    noHandler.run();
                }
            }
            this.close();
        }
        close() {
            super.close();
            if (this.data) {
                var closeHandler = this.data.closeHandler;
                if (closeHandler) {
                    closeHandler.run();
                }
            }
            this.data = null;
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class Alert3View extends ui.comp.Alert3UI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class Alert3ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = Alert3View;
            this.lasting = true;
            this.openSound = CommonConfig.ALERT_SOUND_OPEN;
            this.closeSound = CommonConfig.ALERT_SOUND_CLOSE;
            this.openAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_OPEN);
            this.closeAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_CLOSE);
            this.viewName = 'AlertView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            if (this.ui) {
                this.ui.txt_content.text = ParamUtil.getString(this.data, 'text', "");
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
                this.ui.btn_no.on(Laya.Event.CLICK, this, this.noHandler);
            }
        }
        okHandler() {
            if (this.data) {
                var okHandler = this.data.okHandler;
                if (okHandler) {
                    okHandler.run();
                }
            }
            this.close();
        }
        noHandler() {
            if (this.data) {
                var noHandler = this.data.noHandler;
                if (noHandler) {
                    noHandler.run();
                }
            }
            this.close();
        }
        close() {
            super.close();
            if (this.data) {
                var closeHandler = this.data.closeHandler;
                if (closeHandler) {
                    closeHandler.run();
                }
            }
            this.data = null;
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class Alert4View extends ui.comp.Alert4UI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class Alert4ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/comp.atlas';
            this.viewClass = Alert4View;
            this.lasting = true;
            this.openSound = CommonConfig.ALERT_SOUND_OPEN;
            this.closeSound = CommonConfig.ALERT_SOUND_CLOSE;
            this.openAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_OPEN);
            this.closeAnim = ViewAnimTool.getViewAnim(CommonConfig.ALERT_ANIM_CLOSE);
            this.viewName = 'AlertView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            if (this.ui) {
                this.ui.txt_content.text = ParamUtil.getString(this.data, 'text', "");
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
                this.ui.btn_no.on(Laya.Event.CLICK, this, this.noHandler);
            }
        }
        okHandler() {
            if (this.data) {
                var okHandler = this.data.okHandler;
                if (okHandler) {
                    okHandler.run();
                }
            }
            this.close();
        }
        noHandler() {
            if (this.data) {
                var noHandler = this.data.noHandler;
                if (noHandler) {
                    noHandler.run();
                }
            }
            this.close();
        }
        close() {
            super.close();
            if (this.data) {
                var closeHandler = this.data.closeHandler;
                if (closeHandler) {
                    closeHandler.run();
                }
            }
            this.data = null;
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class CommonController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            StorageModel.model.name = 'gum_';
            ViewConfig.PANEL_ANIM_OPEN = 'AlphaIn';
            ViewConfig.PANEL_ANIM_CLOSE = 'AlphaOut';
            ViewConfig.DIALOG_ANIM_OPEN = 'AlphaIn';
            ViewConfig.DIALOG_ANIM_CLOSE = 'AlphaOut';
            MouseTool.init();
            this.startChild(new NativeController());
            this.compQueue = new EventQueueController();
            this.startChild(this.compQueue);
            this.addEventListener(CommonEvent.PROMPT_VIEW_SHOW, this, this.showPromptHandler);
            this.addEventListener(CommonEvent.ALERT_VIEW_SHOW, this, this.showAlertHandler);
            this.addEventListener(CommonEvent.NOTICE_VIEW_SHOW, this, this.showNiticetHandler);
            this.addEventListener(CommonEvent.LOG_VIEW_SHOW, this, this.showLogHandler);
            this.addEventListener(CommonEvent.TIPS_VIEW_SHOW, this, this.showTipsHandler);
            this.addEventListener(CommonEvent.OPEN_URL_VIEW_SHOW, this, this.showOpenUrlHandler);
            this.addEventListener(CommonEvent.PARTICLE_VIEW_SHOW, this, this.showParticleHandler);
            this.addEventListener(CommonEvent.QUEUE_EVENT_UNSHIFT, this, this.eventUnshiftHandler);
            this.addEventListener(CommonEvent.QUEUE_EVENT_ADD, this, this.eventAddHandler);
            this.addEventListener(HttpEvent.HTTP_RESPONSE_ERROR, this, this.httpErrorHandler);
            ViewManager.register(CommonEvent.BANGS_VIEW_SHOW, this, BangsViewController);
            ViewManager.register(CommonEvent.VIDEO_VIEW_SHOW, this, VideoViewController);
            Laya.stage.on(Laya.Event.FOCUS, this, this.focusHandler);
        }
        focusHandler() {
            this.dispatchEvent(CommonEvent.WINDOW_FOCUS);
        }
        httpErrorHandler(data) {
            LogTool.log(JSONUtil.stringify(data));
        }
        showPromptHandler(data) {
            if (data && !data.showType) {
                data.showType = ViewType.OPEN;
            }
            ViewManager.show(this, PromptViewController, data);
        }
        showAlertHandler(data) {
            if (data && !data.showType) {
                data.showType = ViewType.OPEN;
            }
            if (CommonConfig.alertType == 1) {
                ViewManager.show(this, Alert1ViewController, data);
            }
            else if (CommonConfig.alertType == 2) {
                ViewManager.show(this, Alert2ViewController, data);
            }
            else if (CommonConfig.alertType == 3) {
                ViewManager.show(this, Alert3ViewController, data);
            }
            else if (CommonConfig.alertType == 4) {
                ViewManager.show(this, Alert4ViewController, data);
            }
            else {
                ViewManager.show(this, AlertViewController, data);
            }
        }
        showNiticetHandler(data) {
            if (data && !data.showType) {
                data.showType = ViewType.OPEN;
            }
            ViewManager.show(this, NoticeViewController, data);
        }
        showLogHandler(data) {
            if (data && !data.showType) {
                data.showType = ViewType.OPEN;
            }
            ViewManager.show(this, LogViewController, data);
        }
        showTipsHandler(data) {
            if (data && !data.showType) {
                data.showType = ViewType.OPEN;
            }
            ViewManager.show(this, TipsViewController, data);
        }
        showOpenUrlHandler(data) {
            ViewManager.show(this, OpenUrlViewController, data);
        }
        showParticleHandler(data) {
            if (data && !data.showType) {
                data.showType = ViewType.NEW;
            }
            ViewManager.show(this, ParticleViewController, data);
        }
        eventUnshiftHandler(data) {
            this.compQueue.unshiftEvent(data.eventName, data.data, data.exitEvent);
        }
        eventAddHandler(data) {
            this.compQueue.addEvent(data.eventName, data.data, data.exitEvent);
        }
    }

    class EpEvent {
    }
    EpEvent.EP_PAGE1_VIEW_SHOW = 'EP_PAGE1_VIEW_SHOW';
    EpEvent.EP_PAGE2_VIEW_SHOW = 'EP_PAGE2_VIEW_SHOW';
    EpEvent.EP_PAGE3_VIEW_SHOW = 'EP_PAGE3_VIEW_SHOW';
    EpEvent.EP_PAGE4_VIEW_SHOW = 'EP_PAGE4_VIEW_SHOW';
    EpEvent.EP_PAGE5_VIEW_SHOW = 'EP_PAGE5_VIEW_SHOW';
    EpEvent.EP_PAGE6_VIEW_SHOW = 'EP_PAGE6_VIEW_SHOW';
    EpEvent.EP_PAGE7_VIEW_SHOW = 'EP_PAGE7_VIEW_SHOW';
    EpEvent.EP_PAGE8_VIEW_SHOW = 'EP_PAGE8_VIEW_SHOW';
    EpEvent.EP_PAGE9_VIEW_SHOW = 'EP_PAGE9_VIEW_SHOW';
    EpEvent.EP_PAGE11_VIEW_SHOW = 'EP_PAGE11_VIEW_SHOW';
    EpEvent.EP_PAGE12_VIEW_SHOW = 'EP_PAGE12_VIEW_SHOW';
    EpEvent.EP_PAGE13_VIEW_SHOW = 'EP_PAGE13_VIEW_SHOW';
    EpEvent.EP_PAGE14_VIEW_SHOW = 'EP_PAGE14_VIEW_SHOW';
    EpEvent.EP_PAGE15_VIEW_SHOW = 'EP_PAGE15_VIEW_SHOW';
    EpEvent.EP_PAGE06_VIEW_SHOW = 'EP_PAGE06_VIEW_SHOW';
    EpEvent.EP_PAGE19_VIEW_SHOW = 'EP_PAGE19_VIEW_SHOW';
    EpEvent.EP_PAGE02_VIEW_SHOW = 'EP_PAGE02_VIEW_SHOW';
    EpEvent.EP_PAGE09_VIEW_SHOW = 'EP_PAGE09_VIEW_SHOW';
    EpEvent.EP_PAGE10_VIEW_SHOW = 'EP_PAGE10_VIEW_SHOW';
    EpEvent.EP_DATA_RESPONSE = 'EP_DATA_RESPONSE';

    class ClipView {
        constructor(clip) {
            this.clip = clip;
        }
        load(url) {
            this.url = url;
            LoaderUtil.loads(url, this, this.loadedHandler, [url]);
        }
        loadedHandler(url) {
            var res = Laya.Loader.getRes(url);
            if (res) {
                var w = this.clip.clipWidth || this.clip.width || res.width;
                var h = this.clip.clipHeight || this.clip.height || res.height;
                this.clip.clipX = Math.ceil(res.width / w);
                this.clip.clipY = Math.ceil(res.height / h);
                this.clip.skin = url;
            }
        }
    }

    class Layouts {
        constructor(target) {
            this.target = target;
        }
        layout() {
        }
    }

    class AveLayout extends Layouts {
        constructor(target, totalWidth = 0) {
            super(target);
            if (totalWidth) {
                this.totalWidth = totalWidth;
            }
            else {
                this.totalWidth = target.width;
            }
        }
        layout() {
            var sprite = this.target;
            if (sprite) {
                var l = sprite.numChildren;
                var w = this.totalWidth / (l + 1);
                for (var i = 0; i < l; i++) {
                    var grid = sprite.getChildAt(i);
                    grid.x = i * w - grid.width / 2 + w;
                }
            }
            super.layout();
        }
    }

    class CenterLayout extends Layouts {
        constructor(target) {
            super(target);
            this.maxWidth = 700;
            this.maxHeight = 999999;
            this.widthGap = 0;
            this.heightGap = 0;
            this.overflow = false;
            this.isUpdateHeight = true;
            this.width = 0;
            this.height = 0;
            if (target) {
                this.maxWidth = target.width;
            }
        }
        ;
        layout() {
            this.overflow = false;
            this.width = 0;
            this.height = 0;
            var maxWidth = this.maxWidth;
            var maxHeight = this.maxHeight;
            var widthGap = this.widthGap;
            var heightGap = this.heightGap;
            var sprite = this.target;
            var l = sprite.numChildren;
            var cx = 0;
            var cy = 0;
            var maxH = 0;
            var lineList = [];
            for (var i = 0; i < l; i++) {
                var grid = sprite.getChildAt(i);
                if (cx + grid.width <= maxWidth) {
                    lineList.push(grid);
                    if (maxH + grid.height <= maxHeight) {
                        grid.x = cx;
                        grid.y = cy;
                        cx = cx + grid.width + widthGap;
                        maxH = Math.max(cy + grid.height, maxH);
                    }
                    else {
                        this.overflow = true;
                        LogUtil.log("FlowLayoutManager:layout height not enough : maxWidth:" + maxWidth + ",maxHeight:" + maxHeight);
                    }
                }
                else if (grid.width <= maxWidth) {
                    this.setLineX(lineList);
                    lineList.push(grid);
                    if (maxH + grid.height <= maxHeight) {
                        grid.x = 0;
                        grid.y = maxH + heightGap;
                        cx = grid.width + widthGap;
                        cy = maxH + heightGap;
                        maxH = Math.max(cy + grid.height, maxH);
                    }
                    else {
                        this.overflow = true;
                        LogUtil.log("FlowLayoutManager:layout height not enough : maxWidth:" + maxWidth + ",maxHeight:" + maxHeight);
                    }
                }
                else {
                    this.setLineX(lineList);
                    lineList.push(grid);
                    if (maxH + grid.height <= maxHeight) {
                        grid.x = 0;
                        grid.y = maxH + heightGap;
                        cx = grid.width + widthGap;
                        cy = maxH + heightGap;
                        maxH = Math.max(cy + grid.height, maxH);
                    }
                    else {
                        this.overflow = true;
                        LogUtil.log("FlowLayoutManager:layout height not enough : maxWidth:" + maxWidth + ",maxHeight:" + maxHeight);
                    }
                }
                this.width = Math.max(this.width, grid.width + grid.x);
            }
            this.setLineX(lineList);
            this.height = maxH;
            if (this.isUpdateHeight) {
                this.target.height = maxH;
            }
            super.layout();
        }
        setLineX(lineList) {
            if (lineList && lineList.length > 0) {
                var last = lineList[lineList.length - 1];
                var dx = MathUtil.int((this.maxWidth - last.x - last.width) / 2);
                for (var k in lineList) {
                    var item = lineList[k];
                    if (item) {
                        item.x += dx;
                    }
                }
            }
            lineList.length = 0;
        }
        updataHeight() {
            this.target.height = this.height;
        }
    }

    class FlowLayout extends Layouts {
        constructor(target) {
            super(target);
            this.maxWidth = 700;
            this.maxHeight = 999999;
            this.widthGap = 0;
            this.heightGap = 0;
            this.overflow = false;
            this.isUpdateHeight = true;
            this.width = 0;
            this.height = 0;
            if (target) {
                this.maxWidth = target.width;
            }
        }
        ;
        layout() {
            this.overflow = false;
            this.width = 0;
            this.height = 0;
            var maxWidth = this.maxWidth;
            var maxHeight = this.maxHeight;
            var widthGap = this.widthGap;
            var heightGap = this.heightGap;
            var sprite = this.target;
            var l = sprite.numChildren;
            var cx = 0;
            var cy = 0;
            var maxH = 0;
            for (var i = 0; i < l; i++) {
                var grid = sprite.getChildAt(i);
                if (cx + grid.width <= maxWidth) {
                    if (maxH + grid.height <= maxHeight) {
                        grid.x = cx;
                        grid.y = cy;
                        cx = cx + grid.width + widthGap;
                        maxH = Math.max(cy + grid.height, maxH);
                    }
                    else {
                        this.overflow = true;
                        LogUtil.log("FlowLayoutManager:layout height not enough : maxWidth:" + maxWidth + ",maxHeight:" + maxHeight);
                    }
                }
                else if (grid.width <= maxWidth) {
                    if (maxH + grid.height <= maxHeight) {
                        grid.x = 0;
                        grid.y = maxH + heightGap;
                        cx = grid.width + widthGap;
                        cy = maxH + heightGap;
                        maxH = Math.max(cy + grid.height, maxH);
                    }
                    else {
                        this.overflow = true;
                        LogUtil.log("FlowLayoutManager:layout height not enough : maxWidth:" + maxWidth + ",maxHeight:" + maxHeight);
                    }
                }
                else {
                    if (maxH + grid.height <= maxHeight) {
                        grid.x = 0;
                        grid.y = maxH + heightGap;
                        cx = grid.width + widthGap;
                        cy = maxH + heightGap;
                        maxH = Math.max(cy + grid.height, maxH);
                    }
                    else {
                        this.overflow = true;
                        LogUtil.log("FlowLayoutManager:layout height not enough : maxWidth:" + maxWidth + ",maxHeight:" + maxHeight);
                    }
                }
                this.width = Math.max(this.width, grid.width + grid.x);
            }
            this.height = maxH;
            if (this.isUpdateHeight) {
                this.target.height = maxH;
            }
            super.layout();
        }
        updataHeight() {
            this.target.height = this.height;
        }
    }

    class GroupView {
        constructor(box, layout = 'ave') {
            this.itemRenderList = {};
            this.box = box;
            for (var index = 0; index < box.numChildren; index++) {
                var item = box.getChildAt(index);
                this.itemRenderList[index] = item.constructor;
                this.itemRenderList[item.name] = item.constructor;
            }
            if (layout == 'flow') {
                this.layouts = new FlowLayout(box);
            }
            else if (layout == 'ave') {
                this.layouts = new AveLayout(box);
            }
            else if (layout == 'center') {
                this.layouts = new CenterLayout(box);
            }
            this.box.on(ViewEvent.VIEW_LAYOUT, this, this.layoutHandler);
        }
        layoutHandler() {
            this.layout();
        }
        getItemRender(i) {
            return this.itemRenderList[i];
        }
        showList() {
            this.box.removeChildren();
            var list = this.data;
            for (var key in list) {
                if (list.hasOwnProperty(key)) {
                    var element = list[key];
                    if (element) {
                        var i = element.itemRenderName;
                        if (!i) {
                            i = 0;
                        }
                        var clas = this.getItemRender(i);
                        if (clas) {
                            var item = new clas();
                            item.mouseEnabled = true;
                            item.dataSource = element;
                            this.box.addChild(item);
                        }
                    }
                }
            }
            if (this.layouts) {
                this.layouts.layout();
            }
        }
        clear() {
            this.data = null;
            this.box.removeChildren();
        }
        addChild(item) {
            this.box.addChild(item);
        }
        setItemList(list) {
            this.clear();
            for (var item of list) {
                this.box.addChild(item);
            }
            this.layouts.layout();
        }
        layout() {
            this.layouts.layout();
        }
        set dataSource(data) {
            this.data = data;
            this.showList();
        }
        get dataSource() {
            return this.data;
        }
    }
    GroupView.FLOW = 'flow';
    GroupView.AVE = 'ave';

    class RecipListView {
        constructor(box, direction = 'h', v = 1) {
            this.itemRenderList = {};
            this.direction = 'h';
            this.v = 0;
            this.mx = 0;
            this.my = 0;
            this.dx = 0;
            this.dy = 0;
            this.cv = 0;
            this.box = box;
            this.direction = direction;
            this.v = this.cv = Math.abs(v);
            box.scrollRect = new Laya.Rectangle(0, 0, box.width, box.height);
            for (var index = 0; index < box.numChildren; index++) {
                var item = box.getChildAt(index);
                this.itemRenderList[index] = item.constructor;
                this.itemRenderList[item.name] = item.constructor;
            }
            this.box.removeChildren();
            this.id = IdUtil.getId();
            this.w = box.width;
            this.h = box.height;
            this.conBox = new Laya.Box();
            this.conBox.width = this.w;
            this.conBox.mouseEnabled = true;
            this.box.addChild(this.conBox);
            this.layouts = new FlowLayout(this.conBox);
            this.layouts.isUpdateHeight = false;
            this.box.on(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            this.box.on(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.box.on(Laya.Event.MOUSE_OUT, this, this.upHandler);
            Laya.timer.callLater(this, this.changeHandler);
        }
        changeHandler() {
            this.box.scrollRect = new Laya.Rectangle(0, 0, this.box.width, this.box.height);
        }
        downHandler() {
            this.box.on(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
            this.mx = this.box.mouseX;
            this.my = this.box.mouseY;
        }
        upHandler() {
            this.box.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
            this.dx = 0;
            this.dy = 0;
        }
        moveHandler() {
            this.dx = this.box.mouseX - this.mx;
            this.dy = this.box.mouseY - this.my;
            this.mx = this.box.mouseX;
            this.my = this.box.mouseY;
        }
        showList() {
            this.conBox.x = 0;
            this.conBox.y = 0;
            this.recoverChildren();
            this.stopRoll();
            var list = this.data;
            for (var key in list) {
                this.showItem(list[key]);
            }
            this.layouts.layout();
            this.startRoll();
        }
        showItem(element) {
            if (element) {
                var i = element.itemRenderName;
                if (!i) {
                    i = 0;
                }
                var clas = this.getItemRender(i);
                if (clas) {
                    var itemName = 'RecipListItem_' + this.id + "_" + element.itemRenderName;
                    var item = PoolUtil.getObject(itemName, clas);
                    item.mouseEnabled = true;
                    item.dataSource = element;
                    this.conBox.addChild(item);
                }
            }
        }
        getItemRender(name) {
            return this.itemRenderList[name];
        }
        setItemRender(name, clas) {
            this.itemRenderList[name] = clas;
        }
        setItemRenderList(list) {
            this.itemRenderList = list;
        }
        clear() {
            this.data = null;
            this.recoverChildren();
        }
        recoverChildren() {
            var l = this.conBox.numChildren;
            if (l > 0) {
                for (var i = 0; i < l; i++) {
                    var item = this.conBox.getChildAt(i);
                    if (item) {
                        PoolUtil.recover(item);
                    }
                }
                this.conBox.removeChildren();
            }
        }
        addChild(item) {
            this.conBox.addChild(item);
        }
        getChildAt(i) {
            return this.conBox.getChildAt(i);
        }
        get numChildren() {
            return this.conBox.numChildren;
        }
        startRoll() {
            Laya.timer.frameLoop(1, this, this.loopsHandler);
        }
        loopsHandler() {
            if (this.conBox.stage == null) {
                this.stopRoll();
                return;
            }
            if (this.conBox.destroyed) {
                this.stopRoll();
                return;
            }
            if (!this.conBox.getStyle()) {
                this.stopRoll();
                return;
            }
            if (this.direction == 'h') {
                if (this.conBox.width <= this.w) {
                    return;
                }
                var tx = -(this.conBox.width - this.w);
                if (this.dx) {
                    this.conBox.x += this.dx;
                }
                else {
                    this.conBox.x += this.cv;
                }
                if (this.conBox.x <= tx) {
                    this.cv = this.v;
                    this.conBox.x = tx;
                }
                else if (this.conBox.x > 0) {
                    this.cv = -this.v;
                    this.conBox.x = 0;
                }
            }
            else {
                if (this.conBox.height <= this.h) {
                    return;
                }
                if (this.dy) {
                    this.conBox.y += this.dy;
                }
                else {
                    this.conBox.y += this.cv;
                }
                var ty = -(this.conBox.height - this.h);
                if (this.conBox.y <= ty) {
                    this.cv = this.v;
                    this.conBox.y = ty;
                }
                else if (this.conBox.y > 0) {
                    this.cv = -this.v;
                    this.conBox.y = 0;
                }
            }
        }
        stopRoll() {
            Laya.timer.clear(this, this.loopsHandler);
        }
        set dataSource(data) {
            this.data = data;
            this.showList();
        }
        get dataSource() {
            return this.data;
        }
    }

    class RollListView {
        constructor(box, direction = 'h', v = 1) {
            this.itemRenderList = {};
            this.direction = 'h';
            this.v = 1;
            this.mx = 0;
            this.my = 0;
            this.dx = 0;
            this.dy = 0;
            this.cv = 0;
            this.box = box;
            this.direction = direction;
            this.v = v;
            box.scrollRect = new Laya.Rectangle(0, 0, box.width, box.height);
            for (var index = 0; index < box.numChildren; index++) {
                var item = box.getChildAt(index);
                this.itemRenderList[index] = item.constructor;
                this.itemRenderList[item.name] = item.constructor;
            }
            this.box.removeChildren();
            this.id = IdUtil.getId();
            this.box.on(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            this.box.on(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.box.on(Laya.Event.MOUSE_OUT, this, this.upHandler);
            Laya.timer.callLater(this, this.changeHandler);
        }
        changeHandler() {
            this.box.scrollRect = new Laya.Rectangle(0, 0, this.box.width, this.box.height);
        }
        downHandler() {
            this.box.on(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
            this.mx = this.box.mouseX;
            this.my = this.box.mouseY;
        }
        upHandler() {
            this.box.off(Laya.Event.MOUSE_MOVE, this, this.moveHandler);
            this.dx = 0;
            this.dy = 0;
        }
        moveHandler() {
            this.dx = this.box.mouseX - this.mx;
            this.dy = this.box.mouseY - this.my;
            this.mx = this.box.mouseX;
            this.my = this.box.mouseY;
        }
        showList() {
            this.recoverChildren();
            var list = this.data;
            for (var key in list) {
                this.showItem(list[key]);
            }
            this.startRoll();
        }
        showItem(element) {
            if (element) {
                var i = element.itemRenderName;
                if (!i) {
                    i = 0;
                }
                var clas = this.getItemRender(i);
                if (clas) {
                    var itemName = 'RollListItem_' + this.id + "_" + element.itemRenderName;
                    var item = PoolUtil.getObject(itemName, clas);
                    item.mouseEnabled = true;
                    item.dataSource = element;
                    this.setLastXY(item);
                    this.box.addChild(item);
                }
            }
        }
        setLastXY(newItem) {
            var l = this.box.numChildren;
            if (l == 0) {
                if (this.direction == 'h') {
                    newItem.x = 0;
                }
                else {
                    newItem.y = 0;
                }
                return;
            }
            var item = this.box.getChildAt(l - 1);
            if (this.direction == 'h') {
                newItem.x = item.x + item.width;
            }
            else {
                newItem.y = item.y + item.height;
            }
        }
        setFristXY(newItem) {
            var l = this.box.numChildren;
            if (l == 0) {
                if (this.direction == 'h') {
                    newItem.x = 0;
                }
                else {
                    newItem.y = 0;
                }
                return;
            }
            var item = this.box.getChildAt(0);
            if (this.direction == 'h') {
                newItem.x = item.x - newItem.width;
            }
            else {
                newItem.y = item.y - newItem.height;
            }
        }
        getItemRender(name) {
            return this.itemRenderList[name];
        }
        setItemRender(name, clas) {
            this.itemRenderList[name] = clas;
        }
        setItemRenderList(list) {
            this.itemRenderList = list;
        }
        clear() {
            this.data = null;
            this.recoverChildren();
        }
        recoverChildren() {
            var l = this.box.numChildren;
            if (l > 0) {
                for (var i = 0; i < l; i++) {
                    var item = this.box.getChildAt(i);
                    if (item) {
                        PoolUtil.recover(item);
                    }
                }
                this.box.removeChildren();
            }
        }
        addChild(item) {
            this.box.addChild(item);
        }
        getChildAt(i) {
            return this.box.getChildAt(i);
        }
        get numChildren() {
            return this.box.numChildren;
        }
        startRoll() {
            if (this.v == 0) {
                return;
            }
            if (this.numChildren <= 1) {
                return;
            }
            Laya.timer.frameLoop(1, this, this.loopHandler);
        }
        stopRoll() {
            Laya.timer.clear(this, this.loopHandler);
        }
        loopHandler() {
            if (this.box.destroyed) {
                this.stopRoll();
                return;
            }
            if (!this.box.getStyle()) {
                this.stopRoll();
                return;
            }
            var l = this.box.numChildren;
            if (this.box.stage == null || l <= 1) {
                this.stopRoll();
                return;
            }
            for (var i = 0; i < l; i++) {
                var item = this.box.getChildAt(i);
                if (item) {
                    if (this.direction == 'h') {
                        this.cv = this.dx || this.v;
                        item.x += this.cv;
                    }
                    else {
                        this.cv = this.dy || this.v;
                        item.y += this.cv;
                    }
                }
            }
            this.dx = 0;
            this.dy = 0;
            this.checkXY();
        }
        checkXY() {
            var l = this.box.numChildren;
            var item = this.box.getChildAt(0);
            if (this.direction == 'h') {
                if (this.cv > 0) {
                    if (item.x > 0) {
                        var last = this.box.getChildAt(l - 1);
                        this.setFristXY(last);
                        this.box.addChildAt(last, 0);
                    }
                }
                else {
                    if (item.x + item.width < 0) {
                        this.setLastXY(item);
                        this.box.addChild(item);
                    }
                }
            }
            else {
                if (this.cv > 0) {
                    if (item.y > 0) {
                        var last = this.box.getChildAt(l - 1);
                        this.setFristXY(last);
                        this.box.addChildAt(last, 0);
                    }
                }
                else {
                    if (item.y + item.height < 0) {
                        this.setLastXY(item);
                        this.box.addChild(item);
                    }
                }
            }
        }
        set dataSource(data) {
            this.data = data;
            this.showList();
        }
        get dataSource() {
            return this.data;
        }
    }

    class RecipsListView {
        constructor(list, v = 1) {
            this.v = 0;
            this.cv = 0;
            this.list = list;
            this.v = v;
        }
        startRoll() {
            Laya.timer.frameLoop(1, this, this.timeHandler);
        }
        stopRoll() {
            Laya.timer.clear(this, this.timeHandler);
        }
        timeHandler() {
            if (!this.list.stage) {
                this.stopRoll();
                return;
            }
            if (!this.list) {
                this.stopRoll();
                return;
            }
            if (!this.list.scrollBar) {
                this.stopRoll();
                return;
            }
            if (this.cv > 0) {
                if (this.list.scrollBar.value >= this.list.scrollBar.max) {
                    this.cv = -this.v;
                }
            }
            else {
                if (this.list.scrollBar.value <= this.list.scrollBar.min) {
                    this.cv = this.v;
                }
            }
            this.list.scrollBar.value += this.cv;
        }
        set dataSource(data) {
            this.list.dataSource = data;
            this.startRoll();
        }
        get dataSource() {
            return this.list.dataSource;
        }
    }

    class EpModel {
        constructor() {
            this.adData = null;
        }
        getAdList(scene) {
            if (this.adData) {
                return this.adData[scene];
            }
            return null;
        }
    }
    EpModel.model = new EpModel();

    class EpVo {
        constructor() {
            this.id = '';
            this.name = '';
            this.gameName = '';
            this.appId = '';
            this.img = '';
            this.anim = '';
            this.path = '';
            this.scene = '';
            this.qrImg = '';
            this.index = 0;
        }
    }

    class EpTool {
        static getAdData(vo) {
            if (!vo) {
                return null;
            }
            var item = {};
            item.vo = vo;
            item.appId = vo.appId;
            item.img_ico = vo.img;
            item.txt_name = vo.name;
            item.txt_gameName = vo.gameName;
            item.mouseEnabled = true;
            if (vo.anim) {
                item.clip_ico = { skin: vo.anim };
                item.img_ico = 'comp/img_blank.png';
            }
            else {
                item.img_ico = vo.img;
            }
            var i = MathUtil.randomInt(1, 2);
            item.img_tag = "ui/img_ad_" + i + ".png";
            if (vo.index % 2 == 1) {
                item.ui_anim = { alpha: 0 };
                item.animType = 0;
            }
            else {
                item.ui_anim = { alpha: 1 };
                item.animType = 1;
            }
            return item;
        }
        static getAdListData(list) {
            var nlist = [];
            if (list) {
                var i = 0;
                for (var vo of list) {
                    vo.index = i;
                    i++;
                    var item = this.getAdData(vo);
                    if (item) {
                        nlist.push(item);
                    }
                }
            }
            return nlist;
        }
        static getList(name) {
            var list1 = EpModel.model.getAdList(name);
            if (list1) {
                return EpTool.getAdListData(list1);
            }
            return [];
        }
        static reAdData(data) {
            var ndata = {};
            var list = data.sceneInfo;
            for (var k in list) {
                var item = list[k];
                var voList = this.reAdItem(item.scene, item.list);
                ndata[item.scene] = voList;
            }
            return ndata;
        }
        static reAdItem(scene, list) {
            var nlist = [];
            for (var svo of list) {
                var vo = new EpVo();
                vo.id = svo.id;
                vo.name = svo.name;
                vo.gameName = svo.gamename;
                vo.appId = svo.appkey;
                vo.img = svo.img;
                vo.anim = svo.qr_img;
                vo.path = svo.path;
                vo.scene = scene;
                vo.qrImg = svo.qr_img;
                nlist.push(vo);
            }
            return nlist;
        }
    }

    class EpViewTool {
        static clickHandler(e) {
            if (this.adController) {
                if (MouseTool.checkClick()) {
                    var target = e.target;
                    if (target.dataSource) {
                        if (target.dataSource.vo) {
                            var vo = target.dataSource.vo;
                            this.adController.dispatchEvent(PlatformEvent.PLATFORM_LINK_GOTO, { appId: vo.appId, path: vo.path, scene: vo.scene, name: vo.name, vo: vo });
                        }
                    }
                }
            }
        }
        static showIcos(c, box, name = '', index = 0) {
            if (box.stage) {
                var list = EpTool.getList(name);
                if (list) {
                    this.showIco(c, box, name, index);
                    TimerUtil.onceTimer(5000, c, () => {
                        this.showIcos(c, box, name, index + 1);
                    });
                }
            }
        }
        static showIco(c, box, name = '', index = 0) {
            if (box.stage) {
                if (box.destroyed) {
                    return;
                }
                var list = EpTool.getList(name);
                if (list) {
                    if (index >= list.length) {
                        index = 0;
                    }
                    var item = list[index];
                    box.dataSource = item;
                    if (!box['_data']) {
                        box['_data'] = true;
                        box.on(Laya.Event.CLICK, this, (e) => { this.clickHandler(e); });
                    }
                }
            }
        }
        static showList(box, name = '') {
            box.dataSource = EpTool.getList(name);
            box.on(Laya.Event.CLICK, this, (e) => { this.clickHandler(e); });
        }
        static showRollList(box, dir, v = 1, name = '') {
            var list = box['_list'];
            if (!box['_list']) {
                list = new RollListView(box, dir, v);
                box.on(Laya.Event.CLICK, this, (e) => { this.clickHandler(e); });
                box['_list'] = list;
            }
            list.dataSource = EpTool.getList(name);
        }
        static showRecipList(box, dir, v = 1, name = '') {
            var list = box['_list'];
            if (!box['_list']) {
                list = new RecipListView(box, dir, v);
                box.on(Laya.Event.CLICK, this, (e) => { this.clickHandler(e); });
                box['_list'] = list;
            }
            list.dataSource = EpTool.getList(name);
        }
        static showRecipsList(box, v = 1, name = '') {
            var list = box['_list'];
            if (!box['_list']) {
                list = new RecipsListView(box, v);
                box.on(Laya.Event.CLICK, this, (e) => { this.clickHandler(e); });
                box['_list'] = list;
            }
            list.dataSource = EpTool.getList(name);
        }
        static showCenterList(box, name = '') {
            var list = new GroupView(box);
            list.dataSource = EpTool.getList(name);
            box.on(Laya.Event.CLICK, this, (e) => { this.clickHandler(e); });
        }
        static showClip(img, name) {
            var imgView = img['_clipView'];
            if (!imgView) {
                img['_clipView'] = imgView = new ClipView(img);
            }
            var list = EpModel.model.getAdList(name);
            if (list && list[0]) {
                var vo = list[0];
                var url = vo.anim || vo.img;
                imgView.load(url);
                img.on(Laya.Event.CLICK, this, (e) => {
                    this.adController.dispatchEvent(PlatformEvent.PLATFORM_LINK_GOTO, { appId: vo.appId, path: vo.path, scene: vo.scene });
                });
            }
        }
        static showBullet(box, name = '') {
            var list = EpTool.getList(name);
        }
        static showAdView(c, viewName, adEvent) {
            function showAd2Handler() {
                c.dispatchEvent(adEvent, { showType: ViewType.OPEN });
            }
            function closeAd2Handler() {
                c.dispatchEvent(adEvent, { showType: ViewType.CLOSE });
            }
            c.addEventListener(ViewEvent.VIWE_OPEN(viewName), c, showAd2Handler);
            c.addEventListener(ViewEvent.VIWE_CLOSE(viewName), c, closeAd2Handler);
        }
        static closeAdView(c, viewName, adEvent) {
            function showAd2Handler() {
                c.dispatchEvent(adEvent, { showType: ViewType.CLOSE });
            }
            function closeAd2Handler() {
                c.dispatchEvent(adEvent, { showType: ViewType.OPEN });
            }
            c.addEventListener(ViewEvent.VIWE_OPEN(viewName), c, showAd2Handler);
            c.addEventListener(ViewEvent.VIWE_CLOSE(viewName), c, closeAd2Handler);
        }
    }

    class EpPage02View extends ui.ep.EpPage02UI {
        constructor() {
            super();
            this.zOrder = 95;
        }
    }

    class EpPage02ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage02View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showList(this.ui.list_ad_1, 'jiesuan');
            EpViewTool.showList(this.ui.list_ad_2, 'jiesuan');
        }
    }

    class EpPage06View extends ui.ep.EpPage06UI {
        constructor() {
            super();
            this.zOrder = 42;
        }
    }

    class EpPage06ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage06View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.showData();
        }
        showData() {
        }
    }

    class EpPage09View extends ui.ep.EpPage09UI {
        constructor() {
            super();
            this.zOrder = 13;
        }
    }

    class EpPage09ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage09View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.box_game.on(Laya.Event.CLICK, this, this.exportHandler);
        }
        exportHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_NATIVE5_VIEW_SHOW, { showType: ViewType.OPEN });
        }
    }

    class EpConfig {
    }
    EpConfig.epPageType = 0;
    EpConfig.bulletList = [
        { name: '主公,有敌情', img: "res/ico/1101.png" },
        { name: '右下角抽兵卡', img: "res/ico/1102.png" },
        { name: '指尖中间攻击最大', img: "res/ico/1103.png" },
        { name: '左下角扩大军营', img: "res/ico/1104.png" },
    ];
    EpConfig.adGame = 0;

    class EpPage10View extends ui.ep.EpPage10UI {
        constructor() {
            super();
            this.zOrder = 13;
        }
    }

    class EpPage10ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage10View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_export.on(Laya.Event.CLICK, this, this.exportHandler);
        }
        exportHandler() {
            if (EpConfig.epPageType == 1) {
                LogUtil.log('EpPage10.qqmini:盒子广告 ---');
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_APPBOX_SHOW);
            }
            else {
                LogUtil.log('EpPage10.Opmini:互推盒子 ---');
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_GAMEBANNER_SHOW);
            }
        }
    }

    class EpItem4View extends ui.ep.EpItem4UI {
        constructor() {
            super();
            this.zOrder = 43;
        }
        set dataSource(v) {
            this._data = v;
            ViewDataTool.setDataSource(this, v);
            if (v) {
                if (v.animType == 0) {
                    this.ani1.play(0, true);
                }
                else {
                    this.ani1.play(30, true);
                }
            }
        }
        get dataSource() {
            return this._data;
        }
    }

    class EpPage11View extends ui.ep.EpPage11UI {
        constructor() {
            super();
            this.zOrder = 60;
        }
    }

    class EpPage11ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = EpPage11View;
            this.viewName = 'EpPage11View';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_close.visible = false;
            this.ui.list_ad_1.itemRender = EpItem4View;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
            TimerUtil.onceTimer(3000, this, this.timerHandler);
        }
        showData() {
            EpViewTool.showRecipsList(this.ui.list_ad_1, 1, 'jiugongge');
        }
        timerHandler() {
            this.ui.btn_close.visible = true;
        }
        closeHandler() {
            this.close();
            if (this.data && this.data.flag) {
                this.dispatchEvent(EpEvent.EP_PAGE15_VIEW_SHOW, { showType: ViewType.OPEN });
            }
        }
    }

    class EpPage12View extends ui.ep.EpPage12UI {
        constructor() {
            super();
        }
    }

    class EpPage12ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = EpPage12View;
            this.viewName = 'EpPage12View';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.btn_next.on(Laya.Event.CLICK, this, this.closeHandler);
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
            this.showCloseEp = ParamUtil.getBool(this.data, 'showCloseEp', false);
        }
        showData() {
            EpViewTool.showRollList(this.ui.list_ad_1, 'h', 1, 'dtlb-10');
            EpViewTool.showRecipsList(this.ui.list_ad_2, 1, 'rmtj-12');
            this.ui.btn_close.visible = false;
            this.ui.btn_next.visible = false;
            TimerUtil.onceTimer(3500, this, this.timer1Handler);
            TimerUtil.onceTimer(1500, this, this.timer2Handler);
        }
        timer1Handler() {
            this.ui.btn_next.visible = true;
        }
        timer2Handler() {
            this.ui.btn_close.visible = true;
        }
        closeHandler() {
            if (this.showCloseEp) {
            }
            this.close();
        }
    }

    class EpPage13View extends ui.ep.EpPage13UI {
        constructor() {
            super();
        }
    }

    class EpPage13ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = EpPage13View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showRecipList(this.ui.list_ad_1, 'v', 1, 'login');
            EpViewTool.showClip(this.ui.img_ad, 'pztg');
        }
    }

    class EpPage14View extends ui.ep.EpPage14UI {
        constructor() {
            super();
            this.zOrder = 42;
        }
    }

    class EpPage14ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = EpPage14View;
            this.viewName = 'EpPage14View';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showRecipList(this.ui.list_ad_1, 'v', 1, 'jiesuan');
        }
    }

    class EpPage15View extends ui.ep.EpPage15UI {
        constructor() {
            super();
            this.zOrder = 51;
        }
    }

    class EpPage15ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage15View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            if (this.data && this.data.y) {
                this.ui.list_ad_1.y = this.data.y;
            }
            if (this.data && this.data.right) {
                this.ui.list_ad_1.right = this.data.right;
            }
            if (this.data && this.data.zorder) {
                this.ui.zOrder = this.data.zorder;
            }
            EpViewTool.showRollList(this.ui.list_ad_1, 'h', -1, 'dtlb-10');
        }
    }

    class EpPage19View extends ui.ep.EpPage19UI {
        constructor() {
            super();
            this.zOrder = 43;
        }
    }

    class EpPage19ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage19View;
            this.viewName = 'EpPage19View';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.btn_next.on(Laya.Event.CLICK, this, this.closeHandler);
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showRecipsList(this.ui.list_ad_2, 1, 'rmtj-14');
            this.ui.btn_close.visible = false;
            this.ui.btn_next.visible = false;
            TimerUtil.onceTimer(3500, this, this.timer1Handler);
            TimerUtil.onceTimer(1500, this, this.timer2Handler);
            this.showCloseEp = ParamUtil.getBool(this.data, 'showCloseEp', false);
        }
        timer1Handler() {
            this.ui.btn_next.visible = true;
        }
        timer2Handler() {
            this.ui.btn_close.visible = true;
        }
        closeHandler() {
            if (this.showCloseEp) {
            }
            this.close();
        }
    }

    class EpPage1View extends ui.ep.EpPage1UI {
        constructor() {
            super();
            this.zOrder = 110;
        }
    }

    class EpPage1ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage1View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.list_ad_1.scrollBar.visible = false;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showRecipsList(this.ui.list_ad_1, 1, 'tjqw-12');
        }
    }

    class EpPage2View extends ui.ep.EpPage2UI {
        constructor() {
            super();
            this.zOrder = 95;
        }
    }

    class EpPage2ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage2View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showRollList(this.ui.list_ad_1, 'v', 1, 'jiesuan');
            EpViewTool.showRollList(this.ui.list_ad_2, 'v', -1, 'jiesuan');
        }
    }

    class EpPage3View extends ui.ep.EpPage3UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class EpPage3ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage3View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showRollList(this.ui.list_ad_2, 'h', 1, 'all');
        }
    }

    class EpPage4View extends ui.ep.EpPage4UI {
        constructor() {
            super();
        }
    }

    class EpPage4ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage4View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
            var time = ParamUtil.getInt(this.data, 'time', 0);
            if (time) {
                TimerUtil.onceTimer(time, this, this.timerHandler);
                this.ui.img_ad.visible = false;
            }
        }
        showData() {
        }
        timerHandler() {
            this.ui.img_ad.visible = true;
        }
    }

    class EpPage5View extends ui.ep.EpPage5UI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class EpPage5ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage5View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showIcos(this, this.ui.ico_1, 'lunbo', 0);
            this.ui.ico_1.ani1.play();
        }
    }

    class EpPage6View extends ui.ep.EpPage6UI {
        constructor() {
            super();
            this.zOrder = 95;
        }
    }

    class EpPage6ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage6View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showIcos(this, this.ui.ico_1, 'lunbo', 0);
            this.ui.ico_1.ani1.play();
        }
    }

    class EpItem2View extends ui.ep.EpItem2UI {
        constructor() {
            super();
        }
    }

    class EpPage7View extends ui.ep.EpPage7UI {
        constructor() {
            super();
        }
    }

    class EpPage7ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage7View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            var list1 = this.getEplist();
            var list2 = this.getEplist();
            this.list = list1.concat(list2);
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            this.showBullet();
        }
        showBullet() {
            if (this.list.length > 0) {
                var vo = this.list.shift();
                var item = new EpItem2View();
                item.x = 720;
                item.y = MathUtil.randomInt(200, 800);
                item.dataSource = vo;
                this.ui.addChild(item);
                TweenUtil.to(this, item, { x: -300 }, 8000, Laya.Ease.linearIn, this.campHandler, [item]);
                item.on(Laya.Event.CLICK, this, this.clickHandler, [vo]);
                TimerUtil.onceTimer(500, this, this.showBullet);
            }
        }
        campHandler(item) {
            item.removeSelf();
        }
        clickHandler(vo) {
            if (vo.appId) {
                this.dispatchEvent(PlatformEvent.PLATFORM_LINK_GOTO, { appId: vo.appId, path: vo.path, scene: vo.scene });
            }
        }
        getEplist() {
            var list1 = EpConfig.bulletList;
            var nlist = [];
            for (var k in list1) {
                var svo = list1[k];
                var vo = new EpVo();
                vo.name = svo.name;
                vo.img = svo.img;
                nlist.push(vo);
            }
            nlist = EpTool.getAdListData(nlist);
            var list = EpTool.getList('danmu-4');
            return nlist.concat(list);
        }
    }

    class EpPage8View extends ui.ep.EpPage8UI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class EpPage8ViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = EpPage8View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showIcos(this, this.ui.ico_1, 'lunbo', 0);
        }
    }

    class EpPage9View extends ui.ep.EpPage9UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class EpPage9ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = EpPage9View;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.box_close.on(Laya.Event.CLICK, this, this.close);
            this.addEventListener(EpEvent.EP_DATA_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            EpViewTool.showRecipList(this.ui.list_ad_2, 'v', 1, 'all');
        }
    }

    class EpController extends Controller {
        constructor() {
            super();
        }
        start() {
            super.start();
            EpViewTool.adController = this;
            ViewManager.register(EpEvent.EP_PAGE1_VIEW_SHOW, this, EpPage1ViewController);
            ViewManager.register(EpEvent.EP_PAGE2_VIEW_SHOW, this, EpPage2ViewController);
            ViewManager.register(EpEvent.EP_PAGE3_VIEW_SHOW, this, EpPage3ViewController);
            ViewManager.register(EpEvent.EP_PAGE4_VIEW_SHOW, this, EpPage4ViewController);
            ViewManager.register(EpEvent.EP_PAGE5_VIEW_SHOW, this, EpPage5ViewController);
            ViewManager.register(EpEvent.EP_PAGE6_VIEW_SHOW, this, EpPage6ViewController);
            ViewManager.register(EpEvent.EP_PAGE7_VIEW_SHOW, this, EpPage7ViewController);
            ViewManager.register(EpEvent.EP_PAGE8_VIEW_SHOW, this, EpPage8ViewController);
            ViewManager.register(EpEvent.EP_PAGE9_VIEW_SHOW, this, EpPage9ViewController);
            ViewManager.register(EpEvent.EP_PAGE02_VIEW_SHOW, this, EpPage02ViewController);
            ViewManager.register(EpEvent.EP_PAGE09_VIEW_SHOW, this, EpPage09ViewController);
            ViewManager.register(EpEvent.EP_PAGE10_VIEW_SHOW, this, EpPage10ViewController);
            ViewManager.register(EpEvent.EP_PAGE11_VIEW_SHOW, this, EpPage11ViewController);
            ViewManager.register(EpEvent.EP_PAGE12_VIEW_SHOW, this, EpPage12ViewController);
            ViewManager.register(EpEvent.EP_PAGE13_VIEW_SHOW, this, EpPage13ViewController);
            ViewManager.register(EpEvent.EP_PAGE14_VIEW_SHOW, this, EpPage14ViewController);
            ViewManager.register(EpEvent.EP_PAGE15_VIEW_SHOW, this, EpPage15ViewController);
            ViewManager.register(EpEvent.EP_PAGE06_VIEW_SHOW, this, EpPage06ViewController);
            ViewManager.register(EpEvent.EP_PAGE19_VIEW_SHOW, this, EpPage19ViewController);
        }
    }

    class GoodsLvConfig {
        static getLvData(cid) {
            return this.list[cid];
        }
        static getLvNum(cid, lv) {
            var data = this.list[cid];
            if (data) {
                return data[lv];
            }
            return 0;
        }
    }
    GoodsLvConfig.list = {
        20010102: [0, 150, 250, 350, 450, 550, 650, 750, 850, 950, 1150, 1250, 1350, 1450, 1550, 1650, 1750, 1850, 1950, 2050, 2150, 2250, 2350, 2450, 2550, 2650, 2750, 2850, 2950, 3050, 3150, 3250, 3350, 3450, 3550, 3650, 3750, 3850, 3950, 4050, 4150, 4250, 4350, 4450, 4550, 4650, 4750, 4850, 4950, 5050,
            5150, 5250, 5350, 5450, 5550, 5650, 5750, 5850, 5950, 6050, 6150, 6250, 6350, 6450, 6550, 6650, 6750, 6850, 6950, 7050, 7150, 7250, 7350, 7450, 7550, 7650, 7750, 7850, 7950, 8050, 8150, 8250, 8350, 8450, 8550, 8650, 8750, 8850, 8950, 9050, 9150, 9250, 9350,
            9450, 9550, 9650, 9750, 9850, 9950, 10050, 10150, 10250, 10350, 10450, 10550, 10650, 10750, 10850, 10950, 11050, 11150, 11250, 11350, 11450, 11550, 11650, 11750, 11850, 11950, 12050, 12150, 12250, 12350, 12450, 12550, 12650, 12750, 12850, 12950, 13050,
            13150, 13250, 13350, 13450, 13550, 13650, 13750, 13850, 13950, 14050, 14150, 14250, 14350, 14450, 14550, 14650, 14750, 14850, 14950, 15050, 15150, 15250, 15350, 15450, 15550, 15650, 15750, 15850, 15950, 16050, 16150, 16250, 16350, 16450, 16550, 16650,
            16750, 16850, 16950, 17050, 17150, 17250, 17350, 17450, 17550, 17650, 17750, 17850, 17950, 18050, 18150, 18250, 18350, 18450, 18550, 18650, 18750, 18850, 18950, 19050, 19150, 19250, 19350, 19450, 19550, 19650, 19750, 19850, 19950],
    };

    class GoodsNumMaxConfig {
        static getHangNumMax(lv) {
            return 50 + lv * 5;
        }
    }

    class GoodsTool {
        static getNum(cid) {
            return GoodsModel.model.getGoodsNum(cid);
        }
        static getLv(cid) {
            return GoodsModel.model.getGoodsLv(cid);
        }
        static addGoods(co) {
            var cid = ParamUtil.getInt(co, 'cid');
            var num = ParamUtil.getInt(co, 'num');
            var single = GoodsVoBuilder.getGoodsSingle(cid);
            if (single) {
                var vo = GoodsModel.model.getGoodsByCid(cid);
                if (!vo) {
                    vo = GoodsVoBuilder.getGoodsVo(cid);
                    vo.num = num;
                }
                else {
                    vo.num = vo.num + num;
                }
                this.setMaxNum(vo);
                if (vo.numMax && vo.num > vo.numMax) {
                    vo.num = vo.numMax;
                }
                this.checkLv(vo);
                if (co.hasOwnProperty('count')) {
                    vo.count = co.count;
                }
                GoodsModel.model.addGoods(vo);
                return vo;
            }
            var list = GoodsModel.model.getGoodsList(cid);
            if (list && list.length) {
                for (var vo of list) {
                    var cnum = num + vo.num;
                    if (vo.numMax == 0) {
                        vo.num = cnum;
                        return vo;
                    }
                    else if (cnum <= vo.numMax) {
                        vo.num = cnum;
                        return vo;
                    }
                    else {
                        vo.num = vo.numMax;
                        num = cnum - vo.numMax;
                    }
                }
            }
            while (num > 0) {
                var vo = GoodsVoBuilder.getGoodsVo(cid);
                if (co.hasOwnProperty('count')) {
                    vo.count = co.count;
                }
                var cnum = num + vo.num;
                if (vo.numMax == 0) {
                    vo.num = cnum;
                    GoodsModel.model.addGoods(vo);
                    return vo;
                }
                else if (cnum <= vo.numMax) {
                    vo.num = cnum;
                    GoodsModel.model.addGoods(vo);
                    return vo;
                }
                else {
                    vo.num = vo.numMax;
                    num = cnum - vo.numMax;
                    GoodsModel.model.addGoods(vo);
                }
            }
        }
        static checkLv(vo) {
            var lvCo = GoodsLvConfig.getLvData(vo.cid);
            if (lvCo) {
                var exp = lvCo[vo.lv];
                if (vo.num >= exp) {
                    vo.lv++;
                    vo.num -= exp;
                    this.checkLv(vo);
                    GoodsModel.model.lvList.push(vo);
                }
            }
        }
        static addGoodsList(list) {
            for (var co of list) {
                this.addGoods(co);
            }
        }
        static randomGoodsList(list, num) {
            var tweight = 0;
            var nlist = [];
            var glist = [];
            for (var k in list) {
                var co = list[k];
                if (!co.weight) {
                    glist.push(co);
                }
                else {
                    tweight += co.weight;
                    co.cweight = tweight;
                    nlist.push(co);
                }
            }
            for (var i = 0; i < num; i++) {
                var n = MathUtil.randomInt(0, tweight);
                var vo = this.randomGoodsItem(nlist, n);
                if (vo) {
                    glist.push(vo);
                }
            }
            return glist;
        }
        static randomGoodsItem(list, cw) {
            for (var vo of list) {
                if (cw <= vo.cweight) {
                    return vo;
                }
            }
            return null;
        }
        static subGoods(cid, num) {
            if (num < 0) {
                num = -num;
            }
            if (this.checkGoods(cid, num)) {
                var single = GoodsVoBuilder.getGoodsSingle(cid);
                if (single) {
                    var vo = GoodsModel.model.getGoodsByCid(cid);
                    if (vo) {
                        vo.num = vo.num - num;
                        if (vo.num < 0) {
                            vo.num = 0;
                        }
                    }
                    return;
                }
                var list = GoodsModel.model.getGoodsList(cid);
                if (list && list.length) {
                    for (var vo of list) {
                        if (vo.num == num) {
                            vo.num -= num;
                            GoodsModel.model.removeGoods(vo.id);
                            return true;
                        }
                        else if (vo.num > num) {
                            vo.num -= num;
                            return true;
                        }
                        else {
                            num -= vo.num;
                            GoodsModel.model.removeGoods(vo.id);
                        }
                    }
                }
            }
            return false;
        }
        static subGoodsList(list) {
            if (list && list.length > 0) {
                if (this.checkGoodsList(list)) {
                    for (var co of list) {
                        this.subGoods(co.cid, co.num);
                    }
                }
            }
        }
        static checkGoods(cid, num) {
            if (num < 0) {
                num = -num;
            }
            var tnum = GoodsModel.model.getGoodsNum(cid);
            if (tnum >= num) {
                return true;
            }
            return false;
        }
        static checkGoodsList(list) {
            if (list && list.length > 0) {
                for (var co of list) {
                    if (this.checkGoods(co.cid, co.num) == false) {
                        return false;
                    }
                }
            }
            return true;
        }
        static checkHasLib(list, lib = 1) {
            for (var co of list) {
                var clib = GoodsVoBuilder.getGoodsLib(co.cid);
                if (clib == lib) {
                    return true;
                }
            }
            return false;
        }
        static checkUpdateLib(data, lib = 1) {
            if (!data) {
                return true;
            }
            if (!data.list) {
                return true;
            }
            if (GoodsTool.checkHasLib(data.list, lib)) {
                return true;
            }
            return false;
        }
        static getChildLoc(vo, type = 0, stype = 0, ttype = 0) {
            var child = vo.child;
            for (var k in child) {
                var cVo = child[k];
                if (type == 0 || cVo.type == type) {
                    if (stype == 0 || cVo.stype == stype) {
                        if (ttype == 0 || cVo.ttype == ttype) {
                            if (cVo.loc) {
                                return cVo;
                            }
                        }
                    }
                }
            }
            return null;
        }
        static getChildLocs(vo, type = 0, stype = 0, ttype = 0) {
            var list = [];
            var child = vo.child;
            for (var k in child) {
                var cVo = child[k];
                if (type == 0 || cVo.type == type) {
                    if (stype == 0 || cVo.stype == stype) {
                        if (ttype == 0 || cVo.ttype == ttype) {
                            if (cVo.loc) {
                                list.push(cVo);
                            }
                        }
                    }
                }
            }
            return list;
        }
        static setChildLoc(vo, chlidVo, type = 0, stype = 0, ttype = 0) {
            var child = vo.child;
            for (var k in child) {
                var cVo = child[k];
                if (type == 0 || cVo.type == type) {
                    if (stype == 0 || cVo.stype == stype) {
                        if (ttype == 0 || cVo.ttype == ttype) {
                            cVo.loc = 0;
                        }
                    }
                }
            }
            chlidVo.loc = 1;
        }
        static getAddList(list) {
            var nlist = [];
            for (var k in list) {
                var v = list[k];
                if (typeof v == 'number') {
                    nlist.push({ cid: v, num: 1 });
                }
                else if (v.num > 0) {
                    nlist.push(v);
                }
            }
            return nlist;
        }
        static getSubList(list) {
            var nlist = [];
            for (var k in list) {
                var v = ObjectUtil.copy(list[k], {});
                if (v.num < 0) {
                    v.num = -v.num;
                    nlist.push(v);
                }
            }
            return nlist;
        }
        static subParamList(list) {
            var nlist = [];
            for (var k in list) {
                var item = list[k];
                var nitem = ObjectUtil.copy(item);
                if (nitem.num > 0) {
                    nitem.num = -nitem.num;
                }
                nlist.push(nitem);
            }
            return nlist;
        }
        static mergeList(list) {
            var lib = {};
            for (var k in list) {
                var item = list[k];
                var cid = item.cid;
                var num = item.num;
                if (lib[cid]) {
                    lib[cid] += num;
                }
                else {
                    lib[cid] = num;
                }
            }
            var nlist = [];
            for (var k in lib) {
                var cid2 = MathUtil.int(k);
                var num2 = lib[k];
                nlist.push({ cid: cid2, num: num2 });
            }
            return nlist;
        }
        static multList(list, num = 1) {
            if (num == 0) {
                return [];
            }
            if (num == 1) {
                return list;
            }
            var nlist = [];
            for (var k in list) {
                var vo = list[k];
                var cvo = ObjectUtil.copy(vo, {});
                cvo.num *= num;
                nlist.push(cvo);
            }
            return nlist;
        }
        static setMaxNum(goods) {
            if (goods.cid == GoodsAttrType.ATTR_PHY) {
                var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
                var max = GoodsNumMaxConfig.getHangNumMax(lv);
                goods.numMax = max;
            }
        }
    }

    class GoodsCardFloatView extends ui.goods.GoodsCardFloatUI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class GoodsCardFloatViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = GoodsCardFloatView;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var vo = ParamUtil.getObject(this.data, 'vo');
            var sx = ParamUtil.getInt(this.data, 'sx', 0);
            var sy = ParamUtil.getInt(this.data, 'sy', 0);
            var tx = ParamUtil.getInt(this.data, 'tx', 0);
            var ty = ParamUtil.getInt(this.data, 'ty', 0);
            var scale = ParamUtil.getInt(this.data, 'scale', 0.6);
            this.ui.dataSource = GoodsViewTool.getGoodsData(vo);
            this.ui.x = sx;
            this.ui.y = sy;
            this.ui.scaleX = scale;
            this.ui.scaleY = scale;
            TweenUtil.to(this, this.ui, { x: tx, y: ty }, 1000, Laya.Ease.quadOut, this.endHander);
        }
        endHander() {
            this.close();
        }
    }

    class GoodsDataController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.addEventListener(GoodsEvent.GOODS_ADD_REQUEST, this, this.addHandler);
            this.addEventListener(GoodsEvent.GOODS_SUB_REQUEST, this, this.subHandler);
            this.addEventListener(GoodsEvent.GOODS_SET_REQUEST, this, this.setHandler);
            this.addEventListener(GoodsEvent.GOODS_LOC_SET_REQUEST, this, this.locHandler);
            this.addEventListener(GoodsEvent.GOODS_CHILD_ADD_REQUEST, this, this.childAddHandler);
            this.addEventListener(GoodsEvent.GOODS_CHILD_LOC_SET_REQUEST, this, this.childLocHandler);
            this.addEventListener(GoodsEvent.GOODS_CHILD_LOC_SET_REQUEST, this, this.childLocHandler);
            this.addEventListener(GoodsEvent.GOODS_ATTR_SET_REQUEST, this, this.setAttrHandler);
            GoodsModel.model.init();
        }
        addHandler(data) {
            GoodsTool.addGoodsList(data.list);
            GoodsModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_RESPONSE);
            this.dispatchEvent(GoodsEvent.GOODS_LIST_RESPONSE, data);
            this.checkLv();
            this.checkShowGetView(data);
        }
        subHandler(data) {
            GoodsTool.subGoodsList(data.list);
            GoodsModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_SUB_RESPONSE);
            var list = GoodsTool.subParamList(data.list);
            this.dispatchEvent(GoodsEvent.GOODS_LIST_RESPONSE, { list: list });
        }
        setHandler(data) {
            var subList = GoodsTool.getSubList(data.list);
            if (GoodsTool.checkGoodsList(subList) == false) {
                return;
            }
            var addList = GoodsTool.getAddList(data.list);
            GoodsTool.subGoodsList(subList);
            GoodsTool.addGoodsList(addList);
            GoodsModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_SET_RESPONSE);
            this.dispatchEvent(GoodsEvent.GOODS_LIST_RESPONSE, data);
            this.checkLv();
            this.checkShowGetView(data);
        }
        childAddHandler(data) {
            var id = data.id;
            var childVo = data.childVo;
            var gvo = GoodsModel.model.getGoods(id);
            if (gvo) {
                gvo.addChild(childVo);
            }
            GoodsModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_CHILD_ADD_RESPONSE);
            this.dispatchEvent(GoodsEvent.GOODS_LIST_RESPONSE, { list: [] });
        }
        childRemoveHandler(data) {
            var id = data.id;
            var childId = data.childId;
            var vo = GoodsModel.model.getGoods(id);
            if (vo) {
                vo.removeChild(childId);
            }
            GoodsModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_CHILD_REMOVE_RESPONSE);
            this.dispatchEvent(GoodsEvent.GOODS_LIST_RESPONSE, { list: [] });
        }
        locHandler(data) {
            var id = data.id;
            var loc = ParamUtil.getInt(data, 'loc', 1);
            var vo = GoodsModel.model.getGoods(id);
            if (vo) {
                this.unLoc(vo.type, vo.stype, vo.ttype, loc);
                vo.loc = loc;
                GoodsModel.model.saveData();
                this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_RESPONSE);
                this.dispatchEvent(GoodsEvent.GOODS_LIST_RESPONSE, { list: [] });
                if (vo.type == 30 && vo.stype == 9) {
                }
                else {
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_OK, text: "装备成功!" });
                }
            }
        }
        unLoc(type, stype, ttype, loc = -1) {
            var list = GoodsModel.model.getGoodsByType(type, stype, ttype);
            for (var k in list) {
                var vo = list[k];
                if (loc == -1 || vo.loc == loc) {
                    vo.loc = 0;
                }
            }
        }
        childLocHandler(data) {
            var vo = data.vo;
            var childVo = data.childVo;
            var type = ParamUtil.getInt(data, 'type', 0);
            var stype = ParamUtil.getInt(data, 'stype', 0);
            var ttype = ParamUtil.getInt(data, 'ttype', 0);
            GoodsTool.setChildLoc(vo, childVo, type, stype, ttype);
            GoodsModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_CHILD_LOC_SET_RESPONSE);
            this.dispatchEvent(GoodsEvent.GOODS_LIST_RESPONSE, { list: [] });
        }
        setAttrHandler(data) {
            var cid = data.cid;
            var vo = GoodsModel.model.getGoodsByCid(cid);
            if (vo) {
                vo.lv = ParamUtil.getInt(data, 'lv', vo.lv);
                vo.count = ParamUtil.getInt(data, 'count', vo.count);
                vo.isNew = ParamUtil.getBool(data, 'isNew', vo.isNew);
                vo.isUnlock = ParamUtil.getBool(data, 'isUnlock', vo.isUnlock);
                GoodsModel.model.saveData();
            }
            this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_RESPONSE);
        }
        checkLv() {
            var list = GoodsModel.model.lvList;
            if (list.length > 0) {
                GoodsModel.model.lvList = [];
                for (var k in list) {
                    var vo = list[k];
                    this.dispatchEvent(GoodsEvent.GOODS_LV_CHANGE, { vo: vo });
                    this.dispatchEvent(GoodsEvent.GOODS_LV_CHANGED(vo.cid), { vo: vo });
                }
            }
        }
        checkShowGetView(data) {
            var showView = ParamUtil.getBool(data, 'showView', true);
            if (showView) {
                this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, data);
            }
        }
    }

    class GoodsGet1View extends ui.goods.GoodsGet1UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsItem1View extends ui.goods.GoodsItem1UI {
        constructor() {
            super();
        }
    }

    class GoodsGet1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGet1View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
            this.showbtn();
        }
        showGoods(co, i = 0) {
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class GoodsGet2View extends ui.goods.GoodsGet2UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGet2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGet2View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
        }
        showGoods(co, i = 0) {
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showBtnHandler() {
            var cid = this.data.list[0].cid;
            var goodsVo = GoodsVoBuilder.getGoodsVo(cid);
            if (goodsVo.type == 20) {
                this.ui.btn_share.visible = true;
                this.ui.btn_ok.x = 0;
            }
            else {
                this.ui.btn_ok.centerX = 0;
                this.ui.btn_share.visible = false;
            }
        }
    }

    class GoodsGet3View extends ui.goods.GoodsGet3UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGet3ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGet3View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
            this.showbtn();
        }
        showGoods(co, i = 0) {
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class GoodsGet4View extends ui.goods.GoodsGet4UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGet4ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGet4View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
        }
        showGoods(co, i = 0) {
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showBtnHandler() {
            var cid = this.data.list[0].cid;
            var goodsVo = GoodsVoBuilder.getGoodsVo(cid);
            if (goodsVo.type == 20) {
                this.ui.btn_share.visible = true;
                this.ui.btn_ok.x = 0;
            }
            else {
                this.ui.btn_ok.centerX = 0;
                this.ui.btn_share.visible = false;
            }
        }
    }

    class GoodsGet5View extends ui.goods.GoodsGet5UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGet5ViewController extends DialogViewController {
        constructor() {
            super();
            this.btnEnble = true;
            this.viewClass = GoodsGet5View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            if (AdTool.checkRate('wzsy', true)) {
                this.ui.btn_ok.bottom = 38;
                this.btnEnble = false;
                TimerUtil.onceTimer(1400, this, () => {
                    this.showBtn();
                    this.btnEnble = true;
                });
            }
            else {
                this.ui.btn_ok.bottom = 240;
            }
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
        }
        showGoods(co, i = 0) {
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            if (this.btnEnble) {
                this.close();
                var list = this.data.list;
                this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
            }
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showBtn() {
            this.ui.btn_ok.bottom = 240;
        }
    }

    class GoodsGet6View extends ui.goods.GoodsGet6UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGet6ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGet6View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            this.isShowInsert = ParamUtil.getBool(this.data, 'isShowInsert', false);
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
            this.showbtn();
        }
        showGoods(co, i = 0) {
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            if (this.isShowInsert) {
                this.dispatchEvent(GoodsEvent.GOODS_CLOSE_CLICK);
            }
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            if (this.isShowInsert) {
                this.dispatchEvent(GoodsEvent.GOODS_CLOSE_CLICK);
            }
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class GoodsGet7View extends ui.goods.GoodsGet7UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGet7ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGet7View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            if (AdModel.model.isShieldCity == false) {
                this.ui.img_ad.visible = false;
                this.ui.txt_double.x = 31;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.txt_double.x = 62;
            }
            this.isShowInsert = ParamUtil.getBool(this.data, 'isShowInsert', false);
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
            this.showbtn();
        }
        showGoods(co, i = 0) {
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            if (this.isShowInsert) {
                this.dispatchEvent(GoodsEvent.GOODS_CLOSE_CLICK);
            }
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            if (this.isShowInsert) {
                this.dispatchEvent(GoodsEvent.GOODS_CLOSE_CLICK);
            }
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showbtn() {
            this.ui.btn_ok.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_ok.visible = true;
                });
            }
            else {
                this.ui.btn_ok.visible = true;
            }
        }
    }

    class GoodsGet8View extends ui.goods.GoodsGet8UI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGet8ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGet8View;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
        }
        showGoods(co, i = 0) {
            this.showBtnHandler();
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showBtnHandler() {
            var cid = this.data.list[0].cid;
            var goodsVo = GoodsVoBuilder.getGoodsVo(cid);
            if (goodsVo.type == 20) {
                this.ui.btn_share.visible = true;
                this.ui.btn_ok.x = 0;
            }
            else {
                this.ui.btn_ok.centerX = 0;
                this.ui.btn_share.visible = false;
            }
        }
    }

    class GoodsGetView extends ui.goods.GoodsGetUI {
        constructor() {
            super();
            this.zOrder = 99;
        }
    }

    class GoodsGetViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsGetView;
            this.viewName = 'GoodsGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_ok.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.btn_share.on(Laya.Event.CLICK, this, this.addDoubleHandler);
            }
            var list = this.data.list;
            for (var i = 0; i < list.length; i++) {
                var co = list[i];
                this.showGoods(co, i);
            }
            this.showAnim();
        }
        showGoods(co, i = 0) {
            this.showBtnHandler();
            var goodsView = new GoodsItem1View();
            goodsView.dataSource = GoodsViewTool.getGoodsRewardData(co);
            goodsView.x = i * 105;
            goodsView.alpha = 0;
            this.ui.box_list.addChild(goodsView);
            if (this.data.rewardType == 1) {
                this.ui.img_box.visible = false;
            }
            else {
                this.ui.img_box.visible = true;
                this.ui.img_box.skin = GoodsConfig.getSegmentIcoUrl(this.data.rewardType);
            }
        }
        showAnim(i = 0) {
            this.ui.txt_double.disabled = false;
            var goodsView = this.ui.box_list.getChildAt(i);
            if (goodsView) {
                TweenUtil.to(this, goodsView, { alpha: 1 }, 400);
            }
            i++;
            if (i <= this.ui.box_list.numChildren - 1) {
                TimerUtil.onceTimer(200, this, this.showAnim, [i]);
            }
        }
        closeHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_GET_SHOW, { list: list, showType: 2 });
        }
        addDoubleHandler() {
            AdTool.videoAdShow(this, this.doubleHandler, 'doubleGet');
        }
        doubleHandler() {
            this.close();
            var list = this.data.list;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list, showType: 2 });
        }
        showBtnHandler() {
            var cid = this.data.list[0].cid;
            var goodsVo = GoodsVoBuilder.getGoodsVo(cid);
            if (goodsVo.type == 20) {
                this.ui.btn_share.visible = true;
                this.ui.btn_ok.x = 0;
            }
            else {
                this.ui.btn_ok.centerX = 0;
                this.ui.btn_share.visible = false;
            }
        }
    }

    class GoodsLvUpView extends ui.goods.GoodsLvUpUI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class GoodsLvUpViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GoodsLvUpView;
            this.viewName = 'GoodsLvUpView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.box_close.on(Laya.Event.CLICK, this, this.close);
            }
            this.lvLabel1 = new BitmapLabelView("font/white.json", 0.6, this.ui.txt_lv);
            this.lvLabel2 = new BitmapLabelView("font/white.json", 0.8, this.ui.txt_nextLv);
            this.showHandler();
        }
        showHandler() {
            this.lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.lvLabel1.text = '' + (this.lv - 1);
            this.lvLabel2.text = '' + (this.lv);
            this.ui.txt_hp1.text = '' + (700 + (this.lv - 1) * 120);
            this.ui.txt_hp2.text = '+' + ((700 + (this.lv - 1 + 1) * 120) - (700 + (this.lv - 1) * 120));
            this.ui.txt_integral1.text = '' + (25 + (this.lv - 1) * 3);
            this.ui.txt_integral2.text = '+' + ((25 + (this.lv - 1 + 1) * 3) - (25 + (this.lv - 1) * 3));
            this.ui.txt_trophy1.text = '' + (20 + (this.lv - 1) * 2);
            this.ui.txt_trophy2.text = '+' + ((20 + (this.lv - 1 + 1) * 2) - (20 + (this.lv - 1) * 2));
        }
    }

    class GoodsMoneyViewController extends ViewController {
        constructor() {
            super();
            this.cid = 3;
            this.viewClass = Laya.Sprite;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.zOrder = 102;
            }
            var num = ParamUtil.getInt(this.data, 'num', 20);
            this.cid = ParamUtil.getInt(this.data, 'cid', GoodsAttrType.ATTR_TONG);
            for (var i = 0; i < num; i++) {
                var img = new Laya.Image();
                img.skin = GoodsConfig.getIconUrl(this.cid);
                this.ui.addChild(img);
                var sx = this.ui.stage.width / 2;
                var sy = 400;
                var sr = Math.random() * 360;
                var tx = Math.random() * 500 - 250 + sx;
                var ty = Math.random() * 500 - 250 + sy;
                var tr = Math.random() * 360;
                img.x = sx;
                img.y = sy;
                img.anchorX = 0.5;
                img.anchorY = 0.5;
                img.width = 50;
                img.height = 50;
                TweenUtil.to(this, img, { x: tx, y: ty }, 1000, Laya.Ease.quadOut, this.moveHander, [img]);
            }
            SoundTool.playSound('money');
            TimerUtil.onceTimer(1500, this, this.endHander);
        }
        moveHander(img) {
            if (this.cid == GoodsAttrType.ATTR_JIN) {
                var tx = Laya.stage.width - 450;
                var ty = 40;
            }
            else if (this.cid == GoodsAttrType.ATTR_EXP) {
                var tx = 100;
                var ty = 40;
            }
            else if (this.cid == GoodsAttrType.ATTR_TONG) {
                var tx = Laya.stage.width - 650;
                var ty = 40;
            }
            else if (this.cid == GoodsAttrType.ATTR_PHY) {
                var tx = Laya.stage.width - 850;
                var ty = 40;
            }
            else if (this.cid == GoodsAttrType.ATTR_INTEGRA) {
                var tx = Laya.stage.width - 850;
                var ty = 40;
            }
            TweenUtil.to(this, img, { x: tx, y: ty, }, 500, Laya.Ease.quadInOut);
        }
        endHander() {
            this.close();
        }
    }

    class GoodsController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.startChild(new GoodsDataController());
            ViewManager.register(GoodsEvent.GOODS_MONEY_VIEW_SHOW, this, GoodsMoneyViewController);
            ViewManager.register(GoodsEvent.GOODS_LV_UP_VIEW_SHOW, this, GoodsLvUpViewController);
            ViewManager.register(GoodsEvent.GOODS_CARD_FLOAT_VIEW_SHOW, this, GoodsCardFloatViewController);
            this.addEventListener(GoodsEvent.GOODS_LV_CHANGED(GoodsAttrType.ATTR_EXP), this, this.unlockHandler);
            this.addEventListener(GoodsEvent.GOODS_GET_VIEW_SHOW, this, this.goodGetHandler);
            this.addEventListener(GoodsEvent.GOODS_GET_SHOW, this, this.getHandler);
        }
        getHandler(data) {
            var showView = ParamUtil.getBool(data, 'showView', true);
            if (showView) {
                var showType = ParamUtil.getInt(data, 'showType', 1);
                var title = ParamUtil.getString(data, 'title', '');
                var list = GoodsTool.getAddList(data.list);
                var isShowInsert = ParamUtil.getBool(data, 'isShowInsert', false);
                var rewardType = ParamUtil.getNumber(data, 'rewardType', 1);
                if (list && list.length) {
                    if (showType == 1) {
                        this.dispatchEvent(GoodsEvent.GOODS_GET_VIEW_SHOW, { showType: ViewType.NEW, list: list, title: title, rewardType: rewardType, isShowInsert: isShowInsert });
                    }
                    else {
                        for (var k in list) {
                            var co = list[k];
                            if (co.cid == GoodsAttrType.ATTR_TONG) {
                                this.dispatchEvent(GoodsEvent.GOODS_MONEY_VIEW_SHOW, { cid: co.cid, num: 20, showType: ViewType.NEW });
                            }
                            else if (co.cid == GoodsAttrType.ATTR_JIN) {
                                this.dispatchEvent(GoodsEvent.GOODS_MONEY_VIEW_SHOW, { cid: co.cid, num: 20, showType: ViewType.NEW });
                            }
                            else if (co.cid == GoodsAttrType.ATTR_EXP) {
                                this.dispatchEvent(GoodsEvent.GOODS_MONEY_VIEW_SHOW, { cid: co.cid, num: 20, showType: ViewType.NEW });
                            }
                            else if (co.cid == GoodsAttrType.ATTR_PHY) {
                                this.dispatchEvent(GoodsEvent.GOODS_MONEY_VIEW_SHOW, { cid: co.cid, num: 20, showType: ViewType.NEW });
                            }
                            else if (co.cid == GoodsAttrType.ATTR_MEDAL) {
                                this.dispatchEvent(GoodsEvent.GOODS_MONEY_VIEW_SHOW, { cid: co.cid, num: 20, showType: ViewType.NEW });
                            }
                            else if (co.cid == GoodsAttrType.ATTR_INTEGRA) {
                                this.dispatchEvent(GoodsEvent.GOODS_MONEY_VIEW_SHOW, { cid: co.cid, num: 20, showType: ViewType.NEW });
                            }
                            else {
                            }
                        }
                    }
                }
            }
        }
        unlockHandler(data) {
            this.dispatchEvent(GoodsEvent.GOODS_LV_UP_VIEW_SHOW);
        }
        goodGetHandler(data) {
            if (GoodsConfig.goodGetType == 1) {
                ViewManager.show(this, GoodsGet1ViewController, data);
            }
            else if (GoodsConfig.goodGetType == 2) {
                ViewManager.show(this, GoodsGet2ViewController, data);
            }
            else if (GoodsConfig.goodGetType == 3) {
                ViewManager.show(this, GoodsGet3ViewController, data);
            }
            else if (GoodsConfig.goodGetType == 4) {
                ViewManager.show(this, GoodsGet4ViewController, data);
            }
            else if (GoodsConfig.goodGetType == 5) {
                ViewManager.show(this, GoodsGet5ViewController, data);
            }
            else if (GoodsConfig.goodGetType == 6) {
                ViewManager.show(this, GoodsGet6ViewController, data);
            }
            else if (GoodsConfig.goodGetType == 7) {
                ViewManager.show(this, GoodsGet7ViewController, data);
            }
            else if (GoodsConfig.goodGetType == 8) {
                ViewManager.show(this, GoodsGet8ViewController, data);
            }
            else {
                ViewManager.show(this, GoodsGetViewController, data);
            }
        }
    }

    class GuideEvent {
    }
    GuideEvent.GUIDE_ARROW_VIEW_SHOW = 'GUIDE_ARROW_VIEW_SHOW';
    GuideEvent.GUIDE_DIALOG_VIEW_SHOW = 'GUIDE_DIALOG_VIEW_SHOW';
    GuideEvent.GUIDE_BATTLE_VIEW_SHOW = 'GUIDE_BATTLE_VIEW_SHOW';
    GuideEvent.GUIDE_BATTLE_AIM_VIEW_SHOW = 'GUIDE_BATTLE_AIM_VIEW_SHOW';
    GuideEvent.GUIDE_BATTLE_ATT_VIEW_SHOW = 'GUIDE_BATTLE_ATT_VIEW_SHOW';
    GuideEvent.GUIDE_BATTLE_SKILL_VIEW_SHOW = 'GUIDE_BATTLE_SKILL_VIEW_SHOW';
    GuideEvent.GUIDE_INIT_COMPLETE = 'GUIDE_INIT_COMPLETE';
    GuideEvent.GUIDE_STEP_NEXT = 'GUIDE_STEP_NEXT';
    GuideEvent.GUIDE_STEP_TRIGGER = 'GUIDE_STEP_TRIGGER';
    GuideEvent.GUIDE_STEP_COMPLETE = 'GUIDE_STEP_COMPLETE';
    GuideEvent.GUIDE_STEP_END = 'GUIDE_STEP_END';
    GuideEvent.GUIDE_STEP_GOTO = 'GUIDE_STEP_GOTO';
    GuideEvent.GUIDE_STEP_CHANGE = 'GUIDE_STEP_CHANGE';
    GuideEvent.GUIDE_STEP_STOP = 'GUIDE_STEP_STOP';
    GuideEvent.GUIDE_STATE_END = 'GUIDE_STATE_END';

    class PropUtil {
        static getInt(data, def = 0) {
            if (data === undefined) {
                return def;
            }
            if (!data) {
                return 0;
            }
            return parseInt(data);
        }
        static getNumber(data, def = 0) {
            if (data === undefined) {
                return def;
            }
            if (!data) {
                return 0;
            }
            return parseFloat(data);
        }
        static getString(data, def = '') {
            if (data === undefined) {
                return def;
            }
            return data.toString();
        }
        static getBool(data, def = false) {
            if (data === undefined) {
                return def;
            }
            if (data == 'true') {
                return true;
            }
            if (data == 'false') {
                return false;
            }
            if (data == '0') {
                return false;
            }
            if (data) {
                return true;
            }
            else {
                return false;
            }
        }
        static getObject(data, def = null) {
            if (data === undefined) {
                return def;
            }
            return data;
        }
        static getNum(data, def = "") {
            if (!data) {
                return def;
            }
            return "" + data;
        }
        static argsUnshift(args, data) {
            if (!args) {
                args = [];
            }
            args.unshift(data);
            return args;
        }
        static argsPush(args, data) {
            if (!args) {
                args = [];
            }
            args.unshift(data);
            return args;
        }
        static isEmpty(data) {
            if (!data) {
                return true;
            }
            if (data == "0") {
                return true;
            }
            if (data instanceof Array) {
                if (data.length == 0) {
                    return true;
                }
            }
            return false;
        }
        static equals(a, b) {
            return a == b;
        }
    }

    class GuideModel {
        constructor() {
            this.groupId = 0;
            this.type = '';
            this.index = 0;
        }
        static get model() {
            return ModelManager.getModel('GuideModel', GuideModel);
        }
        saveData() {
            var data = {};
            data.groupId = GuideModel.model.groupId;
            StorageModel.model.setData("guide", data);
        }
        loadData() {
            var data = StorageModel.model.getData("guide");
            if (data) {
                GuideModel.model.groupId = PropUtil.getInt(data.groupId);
            }
            return data;
        }
    }

    class GuideDialogConfig {
    }
    GuideDialogConfig.dialogList0 = [
        { img: 'ui/img_UM_ui_guide_1.png', type: 1, x: 203, text: '又来一个菜鸟！什么都别说，什么都别问，按我说的做！' },
    ];
    GuideDialogConfig.dialogList1 = [
        { img: 'ui/img_UM_ui_guide_2.png', type: 1, x: 203, text: '不想被干掉的话，赶快去招几个步兵，数量越多越好！' },
    ];
    GuideDialogConfig.dialogList2 = [
        { img: 'ui/img_UM_ui_guide_3.png', type: 1, x: 203, text: '学的挺快啊，不过接下来可要动真格的了，击败前面的敌人！' },
    ];
    GuideDialogConfig.dialogList3 = [
        { img: 'ui/img_UM_ui_guide_4.png', type: 1, x: 203, text: '干得不错，既然如此，相信击败所有敌人难不倒你吧？' },
    ];
    GuideDialogConfig.dialogList4 = [
        { img: 'ui/img_UM_ui_guide_5.png', type: 1, x: 88, text: '太棒了！你真是个天才！以后就做我的搭档吧，一起升级打怪！' },
    ];

    class GuideConfig {
    }
    GuideConfig.lists = [
        { type: 'page_guide', exeEvent: 'GUIDE_DIALOG_VIEW_SHOW', exeData: { showType: 'open', list: GuideDialogConfig.dialogList0 }, nextEvent: ViewEvent.VIWE_CLOSE('GuideDialogView') },
        { type: 'page_guide', exeEvent: 'GOODS_SET_REQUEST', exeData: { showType: 2, list: [{ cid: 20010114, num: 100 }] } },
        { type: 'page_guide', exeEvent: 'SEGMENT_LV_UP_VIEW_SHOW', exeData: {} },
        { type: 'page_guide', viewName: 'SegmentLvUpView', targetName: 'img_goto', nameType: 'name', maskLayer: 'auto' },
        { type: 'page_guide', viewName: 'SegmentView', targetName: 'segm_0', nameType: 'guideName', maskLayer: 'auto' },
        { type: 'page_guide', viewName: 'GoodsGetView', targetName: 'btn_ok', nameType: 'name', maskLayer: 'auto' },
        { type: 'page_guide', viewName: 'SegmentView', targetName: 'box_close', nameType: 'name', maskLayer: 'auto' },
        { type: 'page_guide_2', exeEvent: 'GUIDE_DIALOG_VIEW_SHOW', exeData: { showType: 'open', list: GuideDialogConfig.dialogList1 }, nextEvent: ViewEvent.VIWE_CLOSE('GuideDialogView') },
        { type: 'page_guide_2', viewName: 'PageView', targetName: 'box_loc', nameType: 'name', maskLayer: 'auto', isShowGlobal: true },
        { type: 'page_guide_2', viewName: 'PageView', targetName: 'ui_start', nameType: 'name', maskLayer: 'auto', isShowGlobal: true },
        { type: 'match_guide', exeEvent: 'BATTLE_START_TRY_HERO_VIEW_SHOW', exeData: { showType: 'close' } },
        { type: 'match_guide', exeEvent: 'BATTLE_LOAD_VIEW_SHOW', exeData: { cid: 1, battleType: 1, isShowBtn: false, isBattle: false }, nextEvent: ViewEvent.VIWE_CLOSE('BattleLoadView') },
        { type: 'match_guide', exeEvent: 'GUIDE_DIALOG_VIEW_SHOW', exeData: { showType: 'open', list: GuideDialogConfig.dialogList2 }, nextEvent: ViewEvent.VIWE_CLOSE('GuideDialogView') },
        { type: 'match_guide', exeEvent: 'BATTLE_START', exeData: { cid: 1, battleType: 1, list1: [30011001, 30011002, 30011003, 30011004, 30011005], list2: [30011006, 30011007, 30011008, 30011009, 30011010] } },
        { type: 'battle_guide', nextEvent: 'SCENE_BEGAIN_CAMERA_COMPLETE' },
        { type: 'battle_guide', exeEvent: 'GUIDE_BATTLE_VIEW_SHOW', exeData: { showType: 'open' }, nextEvent: ViewEvent.VIWE_CLOSE('GuideBattleView') },
        { type: 'battle_guide', exeEvent: 'GUIDE_BATTLE_AIM_VIEW_SHOW', exeData: { showType: 'open' }, nextEvent: ViewEvent.VIWE_CLOSE('GuideBattleAimView') },
        { type: 'battle_guide', exeEvent: 'GUIDE_BATTLE_ATT_VIEW_SHOW', exeData: { showType: 'open' }, nextEvent: ViewEvent.VIWE_CLOSE('GuideBattleAttView') },
        { type: 'battle_guide', exeEvent: 'GUIDE_BATTLE_SKILL_VIEW_SHOW', exeData: { showType: 'open' }, nextEvent: ViewEvent.VIWE_CLOSE('GuideBattleSkillView') },
        { type: 'battle_guide', exeEvent: 'GUIDE_DIALOG_VIEW_SHOW', exeData: { showType: 'open', list: GuideDialogConfig.dialogList3 }, nextEvent: ViewEvent.VIWE_CLOSE('GuideDialogView') },
        { type: 'battle_over_guide', nextEvent: ViewEvent.VIWE_OPENED('SegmentView') },
        { type: 'battle_over_guide', exeEvent: 'GUIDE_DIALOG_VIEW_SHOW', exeData: { showType: 'open', list: GuideDialogConfig.dialogList4 }, nextEvent: ViewEvent.VIWE_CLOSE('GuideDialogView') },
        { type: 'battle_over_guide', viewName: 'SegmentView', targetName: 'segm_1', nameType: 'guideName', maskLayer: 'auto' },
        { type: 'battle_over_guide', viewName: 'GoodsGetView', targetName: 'btn_ok', nameType: 'name', maskLayer: 'auto' },
        { type: 'battle_over_guide', viewName: 'SegmentView', targetName: 'box_close', nameType: 'name', maskLayer: 'auto' },
        { type: 'page_guide_3', viewName: 'PageView', targetName: 'img_right', nameType: 'name', maskLayer: 'auto', isShowGlobal: true },
        { type: 'page_guide_3', viewName: 'PageView', targetName: 'box_loc', nameType: 'name', maskLayer: 'auto', isShowGlobal: true },
        { type: 'page_guide_3', viewName: 'PageView', targetName: 'img_hero', nameType: 'name', maskLayer: 'auto', isShowGlobal: true },
        { type: 'page_guide_3', viewName: 'HeroView', targetName: 'box_gift', nameType: 'name', maskLayer: 'auto' },
        { type: 'page_guide_3', viewName: 'HeroLvUpTipView', targetName: 'img_lv', nameType: 'name', maskLayer: 'auto' },
        { type: 'page_guide_3', viewName: 'HeroView', targetName: 'ui_up', nameType: 'name', maskLayer: 'auto', visible: false },
        { type: 'page_guide_3', viewName: 'HeroLvUpAnimView', targetName: 'box_get', nameType: 'name', maskLayer: 'auto', visible: false },
        { type: 'page_guide_4', exeEvent: 'PLATFORM_ADDICO_SHOW', exeData: {} },
    ];

    class GuideVo {
        constructor() {
            this.id = 0;
            this.groupId = 0;
            this.type = '';
            this.index = 1;
            this.viewName = '';
            this.targetName = '';
            this.childName = '';
            this.nameType = '';
            this.anim = 'ani1';
            this.dir = -1;
            this.visible = true;
            this.isShowGlobal = false;
            this.slideTargetName = '';
            this.triggerEvent = '';
            this.exeEvent = '';
            this.nextEvent = '';
            this.checkEvent = '';
            this.maskLayer = null;
        }
    }

    class GuideVoBuild {
        static getGroupId(type) {
            return this.groupIdTypeMap[type];
        }
        static getGroupType(id) {
            return this.groupIdTypeMap[id];
        }
        static getGuideVo(type, index) {
            var ti = type + '@' + index;
            return this.grideList[ti];
        }
        static initData() {
            var list = GuideConfig.lists;
            var type = '';
            var index = 1;
            var groupId = 1;
            var id = 1;
            for (var k in list) {
                var item = list[k];
                var vo = new GuideVo();
                vo.id = id++;
                vo.groupId = groupId;
                ObjectUtil.copy(item, vo);
                if (type != vo.type) {
                    type = vo.type;
                    this.groupIdTypeMap[vo.type] = groupId;
                    this.groupIdTypeMap[groupId] = vo.type;
                    groupId++;
                    index = 1;
                    vo.index = 1;
                }
                else {
                    index++;
                    vo.index = index;
                }
                var ti = vo.type + '@' + vo.index;
                this.grideList[ti] = vo;
            }
        }
    }
    GuideVoBuild.grideList = {};
    GuideVoBuild.groupIdTypeMap = {};

    class GuideTool {
        static getGuideTargetView(view, nameType, targetName, childName = null) {
            if (nameType == 'guideName') {
                return this.getGuideByName(view, targetName, childName);
            }
            else {
                return DisplayUtil.getChildByNames(view, targetName);
            }
        }
        static getGuideByName(view, guideName, childName = null) {
            if (!view) {
                return null;
            }
            var b1 = this.checkGuideName(view, guideName);
            if (b1) {
                if (childName) {
                    return DisplayUtil.getChildByName(view, childName);
                }
                else {
                    return view;
                }
            }
            if (view instanceof Laya.Node) {
                var l = view.numChildren;
                for (var i = 0; i < l; i++) {
                    var child = view.getChildAt(i);
                    var citem = this.getGuideByName(child, guideName, childName);
                    if (citem) {
                        return citem;
                    }
                }
            }
            return null;
        }
        static checkGuideName(view, guideName) {
            if (view) {
                if (view.guideName == guideName) {
                    return true;
                }
                if (view.dataSource && view.dataSource.guideName == guideName) {
                    return true;
                }
            }
            return false;
        }
    }

    class GuideArrowView extends ui.guide.GuideArrowUI {
        constructor() {
            super();
            this.zOrder = 901;
        }
    }

    class GuideArrowViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = GuideArrowView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.outPoint = new Laya.Point();
            this.ui.visible = false;
            this.containerView = this.data.containerView;
            this.vo = this.data.vo;
            TimerUtil.onceTimer(100, this, this.findTargetView);
        }
        findTargetView() {
            if (this.vo) {
                var target = GuideTool.getGuideTargetView(this.containerView, this.vo.nameType, this.vo.targetName, this.vo.childName);
                if (target) {
                    this.targetView = target;
                    this.addGuideEvent();
                }
                else {
                    TimerUtil.onceTimer(1000, this, this.findTargetView);
                }
            }
        }
        addGuideEvent() {
            if (this.vo.triggerEvent == 'CLICK') {
                this.targetView.on(Laya.Event.CLICK, this, this.triggerHandler);
            }
            else if (this.vo.triggerEvent == 'MOUSE_DOWN') {
                this.targetView.on(Laya.Event.MOUSE_DOWN, this, this.triggerHandler);
            }
            else if (this.vo.triggerEvent == 'MOUSE_MOVE') {
                this.targetView.on(Laya.Event.MOUSE_MOVE, this, this.triggerHandler);
            }
            else if (this.vo.triggerEvent) {
                this.addEventListener(this.vo.triggerEvent, this, this.triggerHandler);
            }
            else {
                this.targetView.on(Laya.Event.CLICK, this, this.triggerHandler);
            }
            this.showArrow();
        }
        triggerHandler() {
            this.dispatchEvent(GuideEvent.GUIDE_STEP_TRIGGER, { type: this.vo.type, index: this.vo.index });
            this.stop();
        }
        showArrow() {
            this.vo = this.data.vo;
            if (this.targetView) {
                if (this.vo.slideTargetName) {
                    TimerUtil.loopTimer(1100, this, this.showSlide);
                    TimerUtil.loopTimer(200, this, this.checkSlide);
                    this.showSlide();
                }
                else {
                    TimerUtil.loopFrame(1, this, this.showClick);
                    this.showClick();
                }
            }
            if (this.anim) {
                this.anim.stop();
            }
            if (this.vo.anim) {
                this.anim = this.ui[this.vo.anim];
                if (this.anim) {
                    this.anim.play(0, true);
                }
            }
            this.showMask(this.targetView);
        }
        showClick() {
            if (this.targetView instanceof Laya.Sprite) {
                this.showClick2D(this.targetView);
            }
            else if (this.targetView instanceof Laya.Sprite3D) {
                this.showClick3D(this.targetView);
            }
        }
        showClick2D(target) {
            if (target['guide_disable']) {
                this.ui.visible = false;
                return;
            }
            if (target.stage == null) {
                this.ui.visible = false;
                return;
            }
            if (target.visible == false) {
                this.ui.visible = false;
                return;
            }
            if (target.destroyed) {
                this.ui.visible = false;
                return;
            }
            if (target['disabled']) {
                this.ui.visible = false;
                return;
            }
            this.ui.visible = this.vo.visible;
            var point = this.getXy2D(target);
            this.ui.x = point.x - target.pivotX;
            this.ui.y = point.y - target.pivotY;
            if (this.vo.dir > 0) {
                this.ui.rotation = this.vo.dir;
            }
            else {
                var gxyy = point.gy;
                if (gxyy < Laya.stage.height * 0.7) {
                    this.ui.rotation = 180;
                }
                else {
                    this.ui.rotation = 0;
                }
            }
            this.showMaskXY();
        }
        showClick3D(target) {
            if (target['guide_disable']) {
                this.ui.visible = false;
                return;
            }
            if (target.scene == null) {
                this.ui.visible = false;
                return;
            }
            if (!this.ui.getStyle()) {
                this.ui.visible = false;
                return;
            }
            var scene = target.scene;
            var view = scene.parent;
            if (this.ui.parent != view) {
                this.ui.zOrder = view.zOrder;
                view.addChild(this.ui);
            }
            if (this.camera == null) {
                this.camera = DisplayUtil.getChildByClass(scene, Laya.Camera);
            }
            if (!this.camera) {
                this.ui.visible = false;
                return;
            }
            this.ui.visible = this.vo.visible;
            var v4 = this.getXy3D(target);
            this.ui.x = v4.x;
            this.ui.y = v4.y;
            if (this.vo.dir) {
                this.ui.rotation = this.vo.dir;
            }
            else {
                var gxyy = this.ui.y;
                if (gxyy < Laya.stage.height * 0.7) {
                    this.ui.rotation = 180;
                }
                else {
                    this.ui.rotation = 0;
                }
            }
        }
        showSlide() {
            this.targetView = GuideTool.getGuideTargetView(this.containerView, this.vo.nameType, this.vo.targetName, this.vo.childName);
            if (this.targetView instanceof Laya.Sprite) {
                this.showSlide2D(this.targetView);
            }
            else if (this.targetView instanceof Laya.Sprite3D) {
                this.showSlide3D(this.targetView);
            }
            else {
                this.ui.visible = false;
            }
        }
        checkSlide() {
            if (this.targetView instanceof Laya.Sprite) {
                this.checkSlide2D(this.targetView);
            }
            else if (this.targetView instanceof Laya.Sprite3D) {
                this.checkSlide3D(this.targetView);
            }
            else {
                this.ui.visible = false;
            }
        }
        showSlide2D(target) {
            if (!target) {
                this.ui.visible = false;
                return;
            }
            if (target.stage == null) {
                this.ui.visible = false;
                return;
            }
            if (target.visible == false) {
                this.ui.visible = false;
                return;
            }
            this.slideTargetView2D = GuideTool.getGuideTargetView(this.containerView, this.vo.nameType, this.vo.slideTargetName, this.vo.childName);
            if (!this.slideTargetView2D) {
                this.ui.visible = false;
                return;
            }
            this.ui.ani1.stop();
            this.slideStart2D();
        }
        slideStart2D() {
            var target = this.targetView;
            if (target.stage == null) {
                this.ui.visible = false;
                return;
            }
            if (target.visible == false) {
                this.ui.visible = false;
                return;
            }
            if (target.destroyed) {
                this.ui.visible = false;
                return;
            }
            var fromPoint = this.getXy2D(target);
            this.ui.x = fromPoint.x;
            this.ui.y = fromPoint.y;
            var toPoint = this.getXy2D(this.slideTargetView2D);
            TweenUtil.to(this, this.ui, { x: toPoint.x, y: toPoint.y }, 1000, Laya.Ease.quadInOut);
        }
        checkSlide2D(target) {
            if (target.stage == null) {
                this.ui.visible = false;
                return;
            }
            if (target.visible == false) {
                this.ui.visible = false;
                return;
            }
        }
        showSlide3D(target) {
            if (target == null) {
                this.ui.visible = false;
                return;
            }
            if (target['guide_disable']) {
                this.ui.visible = false;
                return;
            }
            if (target.scene == null) {
                this.ui.visible = false;
                return;
            }
            if (target.destroyed) {
                this.ui.visible = false;
                return;
            }
            var scene = target.scene;
            var view = scene.parent;
            if (this.ui.parent != view) {
                this.ui.zOrder = view.zOrder;
                view.addChild(this.ui);
            }
            if (this.camera == null) {
                this.camera = DisplayUtil.getChildByClass(scene, Laya.Camera);
            }
            if (!this.camera) {
                this.ui.visible = false;
                return;
            }
            this.slideTargetView3D = GuideTool.getGuideTargetView(this.containerView, this.vo.nameType, this.vo.slideTargetName, this.vo.childName);
            if (!this.slideTargetView3D) {
                this.ui.visible = false;
                return;
            }
            this.ui.visible = true;
            this.ui.ani1.stop();
            this.slideStart3D();
        }
        slideStart3D() {
            var target = this.targetView;
            if (target.scene == null) {
                this.ui.visible = false;
                return;
            }
            var fromPoint = this.getXy3D(target);
            this.ui.x = fromPoint.x;
            this.ui.y = fromPoint.y;
            var toPoint = this.getXy3D(this.slideTargetView3D);
            TweenUtil.to(this, this.ui, { x: toPoint.x, y: toPoint.y }, 1000, Laya.Ease.quadInOut);
        }
        checkSlide3D(target) {
            if (!target) {
                this.ui.visible = false;
                return;
            }
            if (target.scene == null) {
                this.ui.visible = false;
                return;
            }
        }
        getXy2D(target) {
            var view = this.containerView;
            var gxy = target.localToGlobal(new Laya.Point(target.pivotX + (target.width) / 2, target.pivotY + (target.height) / 2));
            var xy = view.globalToLocal(gxy);
            var tx = xy.x;
            var ty = xy.y;
            return { x: tx, y: ty, gx: gxy.x, gy: gxy.y };
        }
        getXy3D(target) {
            var x = target.transform.localPositionX;
            var y = target.transform.localPositionY;
            var z = target.transform.localPositionZ;
            var monV4 = Display3DUtil.worldToViewportPoint(this.camera, x, y, z);
            this.outPoint.x = monV4.x;
            this.outPoint.y = monV4.y;
            if (this.ui.parent instanceof Laya.Sprite) {
                var p = this.ui.parent.globalToLocal(this.outPoint);
                return p;
            }
            return this.outPoint;
        }
        showMask(target) {
            if (this.vo.maskLayer) {
                if (this.vo.maskLayer == 'auto') {
                    if (target) {
                        this.showMaskArea(-target.width / 2, -target.height / 2, target.width, target.height);
                    }
                }
                else {
                    this.showMaskArea(this.vo.maskLayer[0], this.vo.maskLayer[1], this.vo.maskLayer[2], this.vo.maskLayer[3]);
                }
            }
        }
        showMaskArea(x, y, w, h) {
            if (!this.maskBox) {
                var sw = Laya.stage.width;
                var sh = Laya.stage.height;
                this.maskBox = new Laya.Box();
                this.maskBox.alpha = 0.6;
                this.maskBox.zOrder = 900;
                this.maskBox.graphics.clear();
                this.maskBox.graphics.drawRect(-sw, -sh, sw * 2 + w, sh + y, "#000");
                this.maskBox.graphics.drawRect(-sw, y, sw + x, h, "#000");
                this.maskBox.graphics.drawRect(x + w, y, sw * 2 - x - w, h, "#000");
                this.maskBox.graphics.drawRect(-sw, y + h, sw * 2 + w, sh, "#000");
                var hitArea = new Laya.HitArea();
                hitArea.hit.drawRect(-sw, -sh, sw * 2 + w, sh * 2 + h, "#000");
                hitArea.unHit.drawRect(x, y, w, h, "#000");
                this.maskBox.hitArea = hitArea;
                this.maskBox.mouseEnabled = true;
                this.maskBox.on(Laya.Event.CLICK, this, () => { });
                this.parentView.addChild(this.maskBox);
            }
        }
        showMaskXY() {
            if (this.maskBox) {
                this.maskBox.x = this.ui.x;
                this.maskBox.y = this.ui.y;
            }
        }
        close() {
            if (this.maskBox) {
                this.maskBox.removeSelf();
            }
            if (this.targetView) {
                this.targetView.off(Laya.Event.CLICK, this, this.triggerHandler);
            }
            super.close();
        }
    }

    class GuideBattleAimView extends ui.guide.GuideBattleAimUI {
        constructor() {
            super();
            this.zOrder = 903;
        }
    }

    class GuideBattleAimViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GuideBattleAimView;
            this.viewName = 'GuideBattleAimView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.on(Laya.Event.CLICK, this, this.close);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_AIM_CHANGE, this, this.close);
        }
    }

    class GuideBattleAttView extends ui.guide.GuideBattleAttUI {
        constructor() {
            super();
            this.zOrder = 903;
        }
    }

    class GuideBattleAttViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GuideBattleAttView;
            this.viewName = 'GuideBattleAttView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.on(Laya.Event.CLICK, this, this.close);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_ATT, this, this.close);
        }
    }

    class GuideBattleSkillView extends ui.guide.GuideBattleSkillUI {
        constructor() {
            super();
            this.zOrder = 903;
        }
    }

    class GuideBattleSkillViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GuideBattleSkillView;
            this.viewName = 'GuideBattleSkillView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.on(Laya.Event.CLICK, this, this.close);
        }
    }

    class GuideBattleView extends ui.guide.GuideBattleUI {
        constructor() {
            super();
            this.zOrder = 903;
        }
    }

    class GuideBattleViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GuideBattleView;
            this.viewName = 'GuideBattleView';
            this.closeAnim = null;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.on(Laya.Event.CLICK, this, this.close);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_MOVE, this, this.close);
        }
    }

    class GuideDialogView extends ui.guide.GuideDialogUI {
        constructor() {
            super();
            this.zOrder = 902;
        }
    }

    class GuideDialogViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = GuideDialogView;
            this.viewName = 'GuideDialogView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.on(Laya.Event.CLICK, this, this.clickHandler);
            this.list = this.data.list;
            this.ui.box_info.visible = false;
            this.showNext();
        }
        clickHandler() {
            this.showNext();
        }
        showNext() {
            if (this.list && this.list.length > 0) {
                var data = this.list.shift();
                if (data.type == 1) {
                    this.showLeft(data.img, data.text, data.x);
                }
                else {
                    this.showRight(data.img, data.text, data.x);
                }
                this.ui.img_info.skin = data.img;
            }
            else {
                this.close();
            }
        }
        showLeft(img, text, x) {
            this.ui.img_guider.x = -900;
            this.ui.img_info.skin = img;
            TweenUtil.to(this, this.ui.img_guider, { x: x }, 500, Laya.Ease.quadOut, this.comHandler);
        }
        showRight(img, text, x) {
            this.ui.img_guider.x = 900;
            this.ui.img_info.skin = img;
            TweenUtil.to(this, this.ui.img_guider, { x: x }, 500, Laya.Ease.quadOut, this.comHandler);
        }
        comHandler() {
            TimerUtil.onceTimer(300, this, () => {
                this.ui.box_info.visible = true;
            });
        }
    }

    class CallbackUtil {
        static call(c, eventName, eventData, callback) {
            if (!eventData) {
                eventData = {};
            }
            eventData.caller = c;
            eventData.callback = callback;
            c.dispatchEvent(eventName, eventData);
        }
        static callback(e, data) {
            if (e && e.caller && e.callback != null) {
                var fun = e.callback;
                fun.call(e.caller, data);
            }
        }
    }

    class GuideStepController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.addEventListener(GuideEvent.GUIDE_STEP_TRIGGER, this, this.triggerHandler);
            this.addEventListener(GuideEvent.GUIDE_STEP_STOP, this, this.stopGuide);
            this.startGuide();
        }
        startGuide() {
            var type = GuideModel.model.type;
            var index = GuideModel.model.index;
            this.vo = GuideVoBuild.getGuideVo(type, index);
            GuideModel.model.vo = this.vo;
            if (this.vo) {
                if (this.vo.exeEvent) {
                    TimerUtil.callLater(this, this.exeGuideEventHandler);
                }
                if (this.vo.nextEvent) {
                    this.onceEventListener(this.vo.nextEvent, this, this.nextHandler);
                }
                if (this.vo.viewName) {
                    this.viewName = this.vo.viewName;
                    var view = ViewManager.getView(this.viewName);
                    if (view) {
                        this.view = view.view;
                        this.showGuideArrow();
                    }
                    this.addEventListener(ViewEvent.VIWE_OPENED(this.viewName), this, this.viewOpenHandler);
                    this.addEventListener(ViewEvent.VIWE_CLOSED(this.viewName), this, this.viewCloseHandler);
                }
                if (this.vo.checkEvent) {
                    CallbackUtil.call(this, this.vo.checkEvent, this.vo.checkData, this.checkHandler);
                }
            }
            this.dispatchEvent(GuideEvent.GUIDE_STEP_CHANGE);
        }
        checkHandler(data) {
            if (data && data.check) {
                TimerUtil.callLater(this, this.nextHandler);
            }
        }
        stopGuide() {
            this.closeGuideArrow();
            this.stop();
        }
        viewOpenHandler(data) {
            this.closeGuideArrow();
            var target = data.target;
            if (target) {
                this.view = target.view;
                this.showGuideArrow();
            }
        }
        viewCloseHandler(data) {
            this.closeGuideArrow();
        }
        exeGuideEventHandler() {
            this.dispatchEvent(this.vo.exeEvent, this.vo.exeData);
            if (this.vo.nextEvent) {
            }
            else if (this.vo.viewName) {
            }
            else {
                this.nextHandler();
            }
        }
        nextHandler() {
            this.dispatchEvent(GuideEvent.GUIDE_STEP_TRIGGER, { type: this.vo.type, index: this.vo.index });
        }
        triggerHandler(data) {
            if (data.type == GuideModel.model.type && data.index == GuideModel.model.index) {
                this.nextGuide(GuideModel.model.type, GuideModel.model.index);
            }
        }
        nextGuide(type, index) {
            LogUtil.log("nextGuide:" + type + ',index:' + index);
            this.checkGuideEnd(type, GuideModel.model.index + 1);
        }
        checkGuideEnd(type, index) {
            LogTool.log('GuideStepController.checkGuideEnd:' + this.vo.id);
            this.dispatchEvent(GuideEvent.GUIDE_STEP_COMPLETE, { id: this.vo.id });
            var vo = GuideVoBuild.getGuideVo(type, index);
            if (vo == null) {
                LogUtil.log("endGuide:" + type + ',index:' + index);
                this.dispatchEvent(GuideEvent.GUIDE_STEP_END);
            }
            else {
                LogUtil.log("nextGuide:" + type + ',index:' + index);
                this.dispatchEvent(GuideEvent.GUIDE_STEP_NEXT);
            }
        }
        showGuideArrow() {
            if (this.vo.isShowGlobal) {
                this.dispatchEvent(GuideEvent.GUIDE_ARROW_VIEW_SHOW, { showType: ViewType.OPEN, containerView: this.view, vo: this.vo });
            }
            else {
                this.dispatchEvent(GuideEvent.GUIDE_ARROW_VIEW_SHOW, { showType: ViewType.OPEN, parentView: this.view, containerView: this.view, vo: this.vo });
            }
        }
        closeGuideArrow() {
            this.dispatchEvent(GuideEvent.GUIDE_ARROW_VIEW_SHOW, { showType: ViewType.CLOSE });
        }
    }

    class GuideController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            GuideVoBuild.initData();
            ViewManager.register(GuideEvent.GUIDE_ARROW_VIEW_SHOW, this, GuideArrowViewController);
            ViewManager.register(GuideEvent.GUIDE_DIALOG_VIEW_SHOW, this, GuideDialogViewController);
            ViewManager.register(GuideEvent.GUIDE_BATTLE_VIEW_SHOW, this, GuideBattleViewController);
            ViewManager.register(GuideEvent.GUIDE_BATTLE_AIM_VIEW_SHOW, this, GuideBattleAimViewController);
            ViewManager.register(GuideEvent.GUIDE_BATTLE_ATT_VIEW_SHOW, this, GuideBattleAttViewController);
            ViewManager.register(GuideEvent.GUIDE_BATTLE_SKILL_VIEW_SHOW, this, GuideBattleSkillViewController);
            this.addEventListener(GuideEvent.GUIDE_STEP_NEXT, this, this.nextHandler);
            this.addEventListener(GuideEvent.GUIDE_STEP_END, this, this.arrowEndHandler);
            this.addEventListener(GuideEvent.GUIDE_STEP_GOTO, this, this.gotoHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            GuideModel.model.loadData();
            var groupId = GuideModel.model.groupId;
            if (groupId == 0) {
                groupId = 1;
            }
            if (groupId >= 0) {
                this.showGuide(groupId);
            }
            this.dispatchEvent(GuideEvent.GUIDE_INIT_COMPLETE);
        }
        nextHandler(data) {
            GuideModel.model.index++;
            this.guideStarts();
        }
        gotoHandler(data) {
            var groupId = data.groupId;
            if (groupId > 0) {
                this.showGuide(groupId);
            }
        }
        arrowEndHandler(data) {
            this.showGuide(GuideModel.model.groupId + 1);
        }
        showGuide(groupId) {
            var type = GuideVoBuild.getGroupType(groupId);
            if (type) {
                this.saveData(groupId);
                this.guideStart(groupId);
            }
            else {
                GuideModel.model.vo = null;
                this.saveData(-1);
                this.dispatchEvent(GuideEvent.GUIDE_STEP_STOP);
                this.dispatchEvent(GuideEvent.GUIDE_STATE_END);
            }
        }
        guideStart(groupId) {
            var type = GuideVoBuild.getGroupType(groupId);
            GuideModel.model.type = type;
            GuideModel.model.index = 1;
            this.guideStarts();
        }
        guideStarts() {
            LogUtil.log("guideStart:" + GuideModel.model.type);
            this.dispatchEvent(GuideEvent.GUIDE_STEP_STOP);
            this.startChild(new GuideStepController());
        }
        saveData(guide) {
            GuideModel.model.groupId = guide;
            GuideModel.model.saveData();
        }
    }

    class HangConfig {
        static getMax(lv) {
            return GoodsNumMaxConfig.getHangNumMax(lv);
        }
    }
    HangConfig.time = 6 * 60;
    HangConfig.rewardList = [{ cid: 20010102, num: 1 }];

    class HangModel {
        constructor() {
            this.rewardTs = 0;
        }
        static get model() {
            return ModelManager.getModel('HangModel', HangModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.rewardTs = this.rewardTs;
            StorageModel.model.setData("hang", data);
        }
        loadData() {
            var data = StorageModel.model.getData("hang");
            this.rewardTs = ParamUtil.getNumber(data, 'rewardTs', 0);
        }
    }

    class HangController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            HangModel.model.init();
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            TimerUtil.loopTimer(HangConfig.time * 1000, this, this.timerHandler);
        }
        initHandler() {
            if (HangModel.model.rewardTs == 0) {
                HangModel.model.rewardTs = TimeUtil.getTimestamp();
                return;
            }
            var num = MathUtil.int((TimeUtil.getTimestamp() - HangModel.model.rewardTs) / HangConfig.time);
            var addNum = 0;
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var max = HangConfig.getMax(lv);
            var cnum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_PHY);
            if (cnum + num > max) {
                addNum = max - cnum;
            }
            else {
                addNum = num;
            }
            addNum = MathUtil.int(addNum);
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: GoodsAttrType.ATTR_PHY, num: addNum }], showView: false });
            HangModel.model.rewardTs = TimeUtil.getTimestamp();
            HangModel.model.saveData();
        }
        timerHandler() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var max = HangConfig.getMax(lv);
            var cnum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_PHY);
            if (cnum + 1 > max) {
                return;
            }
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: GoodsAttrType.ATTR_PHY, num: 1 }], showView: false });
            HangModel.model.rewardTs = TimeUtil.getTimestamp();
            HangModel.model.saveData();
        }
    }

    class HeroEvent {
    }
    HeroEvent.HERO_VIEW_SHOW = 'HERO_VIEW_SHOW';
    HeroEvent.HERO_LV_UP_ANIM_VIEW_SHOW = 'HERO_LV_UP_ANIM_VIEW_SHOW';
    HeroEvent.HERO_LV_UP_TIP_VIEW_SHOW = 'HERO_LV_UP_TIP_VIEW_SHOW';
    HeroEvent.HERO_LV_UP_REQUEST = 'HERO_LV_UP_REQUEST';
    HeroEvent.HERO_LV_UP_RESPONSE = 'HERO_LV_UP_RESPONSE';
    HeroEvent.HERO_UNLOCK_TIP_VIEW_SHOW = 'HERO_UNLOCK_TIP_VIEW_SHOW';
    HeroEvent.HERO_NEW_UNLOCK_TIP_VIEW_SHOW = 'HERO_NEW_UNLOCK_TIP_VIEW_SHOW';

    class HeroModel {
        constructor() {
            this.heroTipsIco = true;
            this.lv = 1;
            this.maxTriphyNum = 0;
            this.giftAdNum = 0;
        }
        static get model() {
            return ModelManager.getModel('HeroModel', HeroModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.lv = this.lv;
            data.heroTipsIco = this.heroTipsIco;
            data.maxTriphyNum = this.maxTriphyNum;
            data.giftAdNum = this.giftAdNum;
            StorageModel.model.setData("HeroModel", data);
        }
        loadData() {
            var data = StorageModel.model.getData("HeroModel");
            this.lv = ParamUtil.getNumber(data, 'lv', 1);
            ;
            this.heroTipsIco = ParamUtil.getBool(data, 'heroTipsIco', true);
            this.maxTriphyNum = ParamUtil.getNumber(data, 'maxTriphyNum', 0);
            this.giftAdNum = ParamUtil.getNumber(data, 'giftAdNum', 0);
        }
    }

    class HeroLvUpAnimView extends ui.hero.HeroLvUpAnimUI {
        constructor() {
            super();
            this.zOrder = 58;
        }
    }

    class HeroLvUpAnimViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = HeroLvUpAnimView;
            this.viewName = 'HeroLvUpAnimView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.isEnd = true;
            this.epLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.ui_aim.txt_ep);
            this.lvLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.ui_aim.txt_lv2);
            this.ui.ui_aim.box_close.on(Laya.Event.CLICK, this, this.getRewardHandler);
            this.ui.ui_aim.box_get.on(Laya.Event.CLICK, this, this.gameHandler);
            this.showHandler();
        }
        showHandler() {
            this.ui.ui_aim.ui_card.txt_lv.text = '' + this.data.vo.lv;
            this.ui.ui_aim.ui_card.txt_name.text = this.data.vo.name;
            this.ui.ui_aim.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.data.vo.cid);
            this.ui.ui_aim.txt_lv.text = '等级' + this.data.vo.lv;
            var hp = HeroTool.getUnitHp(this.data.vo.cid);
            this.ui.ui_aim.txt_hp1.text = '' + SceneUnitHprConfig.getHp(hp, this.data.vo.lv - 1);
            this.ui.ui_aim.txt_hp2.text = '+' + (SceneUnitHprConfig.getHp(hp, this.data.vo.lv) - (SceneUnitHprConfig.getHp(hp, this.data.vo.lv - 1)));
            var att = GoodsListConfig.getVo(this.data.vo.cid);
            this.ui.ui_aim.txt_att1.text = '' + SceneUnitAttConfig.getAtt(att.attShow, this.data.vo.lv - 1);
            this.ui.ui_aim.txt_att2.text = '+' + (SceneUnitAttConfig.getAtt(att.attShow, this.data.vo.lv) - (SceneUnitAttConfig.getAtt(att.attShow, this.data.vo.lv - 1)));
            this.ui.ui_aim.ui_get.txt_tong.text = '' + this.data.num;
            this.ui.ui_aim.txt_tong.text = '' + this.data.num;
            if (this.data.vo.quality == 0) {
                this.ui.ui_aim.txt_card.text = GoodsModel.model.getGoodsNum(this.data.vo.cid) + '/' + (this.data.vo.lv + 1) * 20;
            }
            else if (this.data.vo.quality == 1) {
                this.ui.ui_aim.txt_card.text = GoodsModel.model.getGoodsNum(this.data.vo.cid) + '/' + (this.data.vo.lv + 1) * 5;
            }
            else {
                this.ui.ui_aim.txt_card.text = GoodsModel.model.getGoodsNum(this.data.vo.cid) + '/' + (this.data.vo.lv + 1) * 1;
            }
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var exp = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_EXP);
            var expMax = GoodsLvConfig.getLvNum(GoodsAttrType.ATTR_EXP, lv);
            this.ui.ui_aim.img_head.skin = PlayerModel.model.ico;
            this.ui.ui_aim.txt_name.text = PlayerModel.model.name;
            this.lvLabel.text = '' + lv;
            this.epLabel.text = exp + '/' + expMax;
            ProgressBarViewTool.setRectBarValue(this.ui.ui_aim.bar_exp, exp / expMax);
        }
        gameHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: this.data.vo.id });
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.data.num }] });
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            TimerUtil.onceTimer(1300, this, () => {
                this.close();
                this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: 1, isTry: false });
            });
        }
        getRewardHandler() {
            if (this.isEnd == true) {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_EXP, num: this.data.num }] });
                TimerUtil.onceTimer(1300, this, () => {
                    this.close();
                });
                this.isEnd = false;
            }
        }
    }

    class HeroLvUpTipView extends ui.hero.HeroLvUpTipUI {
        constructor() {
            super();
            this.zOrder = 55;
        }
    }

    class HeroLvUpTipViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = HeroLvUpTipView;
            this.viewName = 'HeroLvUpTipView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.box_no.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_lv.on(Laya.Event.CLICK, this, this.gotoLvHandler);
            this.hero = this.data.vo;
            this.showHandler();
        }
        showHandler() {
            this.ui.txt_name.text = this.hero.name;
            this.ui.ui_card.txt_name.text = this.hero.name;
            this.ui.ui_card.txt_lv.text = '' + this.hero.lv;
            this.ui.ui_card.img_ico.skin = GoodsViewTool.getImgUrl(this.hero.cid);
            if (this.hero.quality == 0) {
                this.ui.txt_quality.text = '普通';
                this.ui.txt_card.text = GoodsModel.model.getGoodsNum(this.data.vo.cid) + '/' + (this.data.vo.lv + 1) * 20;
            }
            else if (this.hero.quality == 1) {
                this.ui.txt_quality.text = '稀有';
                this.ui.txt_card.text = GoodsModel.model.getGoodsNum(this.data.vo.cid) + '/' + (this.data.vo.lv + 1) * 5;
            }
            else {
                this.ui.txt_quality.text = '史诗';
                this.ui.txt_card.text = GoodsModel.model.getGoodsNum(this.data.vo.cid) + '/' + (this.data.vo.lv + 1) * 1;
            }
        }
        gotoLvHandler() {
            this.close();
            this.dispatchEvent(HeroEvent.HERO_VIEW_SHOW, { showType: ViewType.OPEN, index: 0, isSkipHero: true, heroVo: this.hero, isShowHand: true });
        }
    }

    class HeroUnlockTip1View extends ui.hero.HeroUnlockTip1UI {
        constructor() {
            super();
            this.zOrder = 51;
        }
    }

    class HeroUnlockTip1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = HeroUnlockTip1View;
            this.viewName = 'HeroUnlockTipView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.img_battle.on(Laya.Event.CLICK, this, this.battleAgainHandler);
            this.ui.img_ad.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_use.on(Laya.Event.CLICK, this, this.useNowHandler);
            this.ui.img_go.on(Laya.Event.CLICK, this, this.adEnhancedUseHandler);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_go.visible = false;
            this.heroVo = HeroTool.getFirstByUnlock();
            if (this.heroVo) {
                this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(this.heroVo.cid);
                var skillVo = HeroTool.getSkillVo(this.heroVo.cid);
                var gunVo = HeroTool.getGunVo(this.heroVo.cid);
                this.ui.ui_up.txt_name.text = skillVo.name;
                this.ui.ui_up.txt_info.text = skillVo.info;
                this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
                this.ui.ui_down.txt_name.text = gunVo.name;
                this.ui.ui_down.txt_info.text = gunVo.info;
                this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
                var unlockTriNum = GoodsListConfig.getVo(this.heroVo.cid).triphyNum;
                var maxTriNum = SegmentModel.model.maxTriphyNum;
                this.progress = (1 - (unlockTriNum - maxTriNum) / unlockTriNum);
                this.ui.txt_info.text = MathUtil.int(this.progress * 100) + '%';
                ProgressBarViewTool.setRectBarValue(this.ui.img_bar, this.progress);
                this.showRoleHandler();
                this.showBtnHandler();
            }
        }
        showRoleHandler() {
            this.goods3D.showRole(this.heroVo.cid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        showBtnHandler() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var triphyNum = 20 + (lv - 1) * 2;
            var unlockNum = GoodsListConfig.getVo(this.heroVo.cid).triphyNum;
            var playerCupNum = SegmentModel.model.maxTriphyNum;
            var n = (unlockNum - playerCupNum) / triphyNum;
            if (MathUtil.int(this.progress) >= 1) {
                this.ui.img_use.visible = true;
                this.ui.img_go.visible = true;
                this.ui.img_battle.visible = false;
                this.ui.img_ad.visible = false;
                this.ui.txt_unlock.text = '（成功解锁，可以使用）';
                this.ui.txt_tip.text = '直接强化到三级';
            }
            else {
                this.ui.img_use.visible = false;
                this.ui.img_go.visible = false;
                this.ui.img_battle.visible = true;
                this.ui.img_ad.visible = true;
                this.ui.txt_unlock.text = '（再战' + MathUtil.int(n) + '场可成功解锁）';
                this.ui.txt_tip.text = '马上获得新英雄';
            }
        }
        battleAgainHandler() {
            this.close();
            this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: 1, isTry: false });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.unlockHeroHandler, 'unlockHero');
        }
        unlockHeroHandler() {
            this.ui.txt_info.text = '100%';
            this.progress = 1;
            this.showBtnHandler();
            ProgressBarViewTool.setRectBarValue(this.ui.img_bar, 1);
            if (this.heroVo) {
                this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: this.heroVo.cid, isUnlock: true });
            }
        }
        useNowHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: this.heroVo.id });
            TimerUtil.onceTimer(1000, this, () => {
                this.close();
                this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: 1, isTry: false });
            });
        }
        adEnhancedUseHandler() {
            AdTool.videoAdShow(this, this.enhancedUseHandler, 'enhancedUseHero');
        }
        enhancedUseHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: this.heroVo.id });
            this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: this.heroVo.cid, lv: 3 });
            TimerUtil.onceTimer(1000, this, () => {
                this.close();
                this.dispatchEvent(BattleEvent.BATTLE_LOAD_VIEW_SHOW, { cid: 1, battleType: 1, isTry: false });
            });
        }
    }

    class HeroUnlockTipView extends ui.hero.HeroUnlockTipUI {
        constructor() {
            super();
            this.zOrder = 51;
        }
    }

    class HeroUnlockTipViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = HeroUnlockTipView;
            this.viewName = 'HeroUnlockTipView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.img_ok.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_go.on(Laya.Event.CLICK, this, this.goHeroHandler);
            this.ui.img_ad.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_go.visible = false;
            this.heroVo = HeroTool.getFirstByUnlock();
            if (this.heroVo) {
                this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(this.heroVo.cid);
                var skillVo = HeroTool.getSkillVo(this.heroVo.cid);
                var gunVo = HeroTool.getGunVo(this.heroVo.cid);
                this.ui.ui_up.txt_name.text = skillVo.name;
                this.ui.ui_up.txt_info.text = skillVo.info;
                this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
                this.ui.ui_down.txt_name.text = gunVo.name;
                this.ui.ui_down.txt_info.text = gunVo.info;
                this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
                var unlockTriNum = GoodsListConfig.getVo(this.heroVo.cid).triphyNum;
                var maxTriNum = SegmentModel.model.maxTriphyNum;
                var progress = (1 - (unlockTriNum - maxTriNum) / unlockTriNum);
                this.ui.txt_info.text = MathUtil.int(progress * 100) + '%';
                ProgressBarViewTool.setRectBarValue(this.ui.img_bar, progress);
                this.showRoleHandler();
            }
        }
        showRoleHandler() {
            this.goods3D.showRole(this.heroVo.cid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        adHandler() {
            AdTool.videoAdShow(this, this.unlockHeroHandler, 'unlockHero');
        }
        unlockHeroHandler() {
            this.ui.img_go.visible = true;
            this.ui.img_ad.visible = false;
            this.ui.txt_info.text = '100%';
            ProgressBarViewTool.setRectBarValue(this.ui.img_bar, 1);
            if (this.heroVo) {
                this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: this.heroVo.cid, isUnlock: true });
            }
        }
        goHeroHandler() {
            this.close();
            this.dispatchEvent(HeroEvent.HERO_VIEW_SHOW, { showType: ViewType.OPEN, index: 0, isSkipHero: true, heroVo: this.heroVo, isShowHand: false });
        }
    }

    class HeroView extends ui.hero.HeroUI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class HeroViewController extends DialogViewController {
        constructor() {
            super();
            this.index = 0;
            this.selectHero = null;
            this.giftHero = null;
            this.v = 0;
            this.selectIndex = -1;
            this.viewClass = HeroView;
            this.viewName = 'HeroView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.zOrder = ParamUtil.getInt(this.data, 'zOrder', this.ui.zOrder);
            this.parentView.addChild(this.ui);
            this.isShowHand = ParamUtil.getBool(this.data, 'isShowHand', false);
            this.tongLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_tong);
            this.jinLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_jin);
            this.ui.box_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.img_left.on(Laya.Event.CLICK, this, this.leftHandler);
            this.ui.img_right.on(Laya.Event.CLICK, this, this.rightHandler);
            this.ui.box_loc.on(Laya.Event.CLICK, this, this.locHeroHandler);
            this.ui.box_ad.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.ui_up.on(Laya.Event.CLICK, this, this.lvUpHandler);
            this.ui.img_tong.on(Laya.Event.CLICK, this, this.tongHandler);
            this.ui.img_jin.on(Laya.Event.CLICK, this, this.jinHandler);
            this.ui.box_gift.on(Laya.Event.CLICK, this, this.adGiftHandler);
            this.ui.list_hero.scrollBar.visible = false;
            this.ui.list_hero.on(Laya.Event.CLICK, this, this.changeHeroHandler);
            this.addEventListener(GoodsEvent.GOODS_LOC_SET_REQUEST, this, this.setPlayerHandler);
            this.addEventListener(HeroEvent.HERO_LV_UP_RESPONSE, this, this.lvUpShowHandler);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showInfoHandler);
            this.addEventListener(GoodsEvent.GOODS_ATTR_SET_REQUEST, this, this.showInfoHandler);
            this.addEventListener(BattleEvent.BATTLE_LOAD_START, this, this.close);
            if (this.isShowHand == true) {
                this.ui.ui_hand.visible = true;
            }
            else {
                this.ui.ui_hand.visible = false;
            }
            if (this.data.isSkipHero == true) {
                this.skipRoleHandler();
            }
            else {
                this.showRoleHandler();
            }
            if (HeroModel.model.giftAdNum == 0) {
                this.ui.ui_gift.img_ad.visible = false;
                this.ui.ui_gift.img_lv.x = 17;
            }
            else {
                if (AdTool.checkVideoIco('ys_jili')) {
                    this.ui.ui_gift.img_lv.x = 27;
                    this.ui.ui_gift.img_ad.visible = true;
                }
                else {
                    this.ui.ui_gift.img_ad.visible = false;
                    this.ui.ui_gift.img_lv.x = 17;
                }
            }
            this.showInfoHandler();
            this.lvUpShowHandler();
            TimerUtil.onceTimer(10000, this, this.closeBtnHandler);
        }
        closeHandler() {
            this.close();
            this.dispatchEvent(PageEvent.PAGE_VIEW_REFRESH);
        }
        showList() {
            var heroList = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            var nlist = [];
            var index = 0;
            var ys_jili = AdTool.checkVideoIco('ys_jili');
            for (var k in heroList) {
                var heroVo = heroList[k];
                var data = {};
                data.txt_name = heroVo.name;
                data.txt_lv = heroVo.lv;
                data.img_ico = GoodsViewTool.getImgUrl(heroVo.cid);
                data.img_bg = null;
                if (heroVo.triphyNum <= SegmentModel.model.maxTriphyNum || heroVo.isUnlock) {
                    data.img_mask = { visible: false };
                    data.txt_lock = { visible: false };
                    data.img_ad = { visible: false };
                    data.img_ad2 = { visible: false };
                    data.img_bg = { vo: heroVo };
                    if (heroVo.isNew) {
                        data.img_isNew = { visible: true };
                    }
                    else {
                        data.img_isNew = { visible: false };
                    }
                }
                else {
                    if (index == 0) {
                        data.img_ad = { visible: true, vo: heroVo };
                        if (ys_jili) {
                            data.img_ad2 = { visible: true };
                        }
                        else {
                            data.img_ad2 = { visible: false };
                        }
                        index++;
                    }
                    else {
                        data.img_ad = { visible: false };
                        data.img_ad2 = { visible: false };
                    }
                    data.img_mask = { visible: true };
                    data.txt_lock = { visible: true, text: '奖杯' + GoodsListConfig.getVo(heroVo.cid).triphyNum };
                    data.img_isNew = { visible: false };
                }
                nlist.push(data);
            }
            this.ui.list_hero.dataSource = nlist;
            this.ui.list_hero.selectEnable = false;
        }
        showInfoHandler() {
            this.tongLabel.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG);
            this.jinLabel.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN);
            this.ui.img_name.skin = GoodsConfig.getNameIcoUrl(this.selectHero.cid);
            this.ui.txt_info.text = GoodsListConfig.getVo(this.selectHero.cid).info;
            this.ui.txt_info1.text = '解锁条件：' + GoodsListConfig.getVo(this.selectHero.cid).unlockInfo;
            var skillVo = HeroTool.getSkillVo(this.selectHero.cid);
            this.ui.img_skill.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
            this.ui.txt_skill.text = skillVo.name;
            var gunVo = HeroTool.getGunVo(this.selectHero.cid);
            this.ui.img_gun.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
            if (this.selectHero.quality == 0) {
                this.ui.img_quality.skin = 'ui/img_UM_hero_pz_1.png';
            }
            else if (this.selectHero.quality == 1) {
                this.ui.img_quality.skin = 'ui/img_UM_hero_pz_2.png';
            }
            else {
                this.ui.img_quality.skin = 'ui/img_UM_hero_pz_3.png';
            }
            if (this.selectHero.location == 'att') {
                this.ui.img_att.skin = 'ui/img_UM_hero_lx_1.png';
            }
            else if (this.selectHero.location == 'defense') {
                this.ui.img_att.skin = 'ui/img_UM_hero_lx_3.png';
            }
            else {
                this.ui.img_att.skin = 'ui/img_UM_hero_lx_2.png';
            }
            this.showGift();
            this.showList();
            this.checkLocShow(this.selectHero);
            this.lvUpShowHandler();
        }
        closeBtnHandler() {
            this.ui.ui_change.visible = false;
        }
        showGift() {
            var num = 0;
            if (this.giftHero) {
                this.ui.ui_gift.img_hero.skin = GoodsViewTool.getIcoUrl(this.giftHero.cid);
                if (this.giftHero.quality == 0) {
                    num = 60;
                }
                else if (this.giftHero.quality == 1) {
                    num = 20;
                }
                else {
                    num = 5;
                }
                this.ui.ui_gift.txt_num.text = 'x' + num;
            }
        }
        showRoleHandler() {
            var goods = GoodsModel.model.getFirstByType(30, 9, 1, 1);
            if (goods) {
                BattleModel.model.playerCid = goods.cid;
                this.selectHero = goods;
                this.giftHero = goods;
                this.checkLocShow(goods);
                this.index = HeroTool.getHeroIndex(goods.cid);
            }
            this.goods3D.showRole(BattleModel.model.playerCid, 0, 0, 0, -0.2, 0.2, -1, 1.15, 0, -15);
        }
        skipRoleHandler() {
            var goods = this.data.heroVo;
            if (goods) {
                this.selectHero = goods;
                this.giftHero = goods;
                this.checkLocShow(goods);
                this.index = HeroTool.getHeroIndex(goods.cid);
                this.goods3D.showRole(goods.cid, 0, 0, 0, -0.2, 0.2, -1, 1.15, 0, -15);
            }
        }
        lvUpShowHandler() {
            if (this.selectHero) {
                this.ui.txt_lv.text = '' + this.selectHero.lv;
                var skillVo = HeroTool.getSkillVo(this.selectHero.cid);
                if (skillVo) {
                    this.ui.txt_cooling.text = MathUtil.int(skillVo.attCd / 1000) + '.00s';
                }
                var gunVo = HeroTool.getGunVo(this.selectHero.cid);
                if (gunVo) {
                    this.ui.txt_range.text = gunVo.attDis + 'm';
                    this.ui.txt_gun.text = gunVo.name;
                }
                var hp = HeroTool.getUnitHp(this.selectHero.cid);
                this.ui.txt_hp.text = '' + SceneUnitHprConfig.getHp(hp, this.selectHero.lv);
                this.ui.txt_hp1.text = '' + SceneUnitHprConfig.getHp(hp, this.selectHero.lv + 1);
                var att = GoodsListConfig.getVo(this.selectHero.cid);
                this.ui.txt_att.text = '' + SceneUnitAttConfig.getAtt(att.attShow, this.selectHero.lv);
                this.ui.txt_att1.text = '' + SceneUnitAttConfig.getAtt(att.attShow, this.selectHero.lv + 1);
                if (this.selectHero.quality == 0) {
                    this.ui.ui_up.txt_tong.text = '' + (this.selectHero.lv + 1) * HeroConfig.tongNumNormal;
                    this.ui.txt_total.text = GoodsModel.model.getGoodsNum(this.selectHero.cid) + '/' + (this.selectHero.lv + 1) * 20;
                    this.v = GoodsModel.model.getGoodsNum(this.selectHero.cid) / ((this.selectHero.lv + 1) * 20);
                }
                else if (this.selectHero.quality == 1) {
                    this.ui.ui_up.txt_tong.text = '' + (this.selectHero.lv + 1) * HeroConfig.tongNumRare;
                    this.ui.txt_total.text = GoodsModel.model.getGoodsNum(this.selectHero.cid) + '/' + (this.selectHero.lv + 1) * 5;
                    this.v = GoodsModel.model.getGoodsNum(this.selectHero.cid) / ((this.selectHero.lv + 1) * 5);
                }
                else {
                    this.ui.ui_up.txt_tong.text = '' + (this.selectHero.lv + 1) * HeroConfig.tongNumEpic;
                    this.ui.txt_total.text = GoodsModel.model.getGoodsNum(this.selectHero.cid) + '/' + (this.selectHero.lv + 1) * 1;
                    this.v = GoodsModel.model.getGoodsNum(this.selectHero.cid) / ((this.selectHero.lv + 1) * 1);
                }
                ProgressBarViewTool.setRectBarValue(this.ui.img_bar, this.v);
            }
        }
        changeHeroHandler(e) {
            if (MouseTool.checkClick(e, 'img_bg')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.index = HeroTool.getHeroIndex(vo.cid);
                    this.selectIndex = this.index;
                    this.setPlayerHandler();
                    this.setGiftHandler();
                    this.lvUpShowHandler();
                    this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: vo.cid, isNew: false });
                }
            }
            if (MouseTool.checkClick(e, 'img_ad')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.unlockHero = vo;
                    AdTool.videoAdShow(this, this.adUnlockHandler, 'unlockHero');
                }
            }
            this.ui.list_hero.selectedIndex = this.selectIndex;
        }
        adUnlockHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: this.unlockHero.cid, isUnlock: true });
        }
        lvUpHandler() {
            var hero = this.selectHero;
            if (hero) {
                this.dispatchEvent(HeroEvent.HERO_LV_UP_REQUEST, { vo: hero });
            }
        }
        leftHandler() {
            this.index--;
            if (this.index < 0) {
                this.index = GoodsConfig.heroMaxIndex;
            }
            this.setPlayerHandler();
            this.lvUpShowHandler();
        }
        rightHandler() {
            this.index++;
            if (this.index > GoodsConfig.heroMaxIndex) {
                this.index = 0;
            }
            this.setPlayerHandler();
            this.lvUpShowHandler();
        }
        setGiftHandler() {
            if (this.selectHero) {
                this.giftHero = this.selectHero;
            }
        }
        setPlayerHandler() {
            var heroList = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            this.selectHero = heroList[this.index];
            if (this.selectHero) {
                this.checkLocShow(this.selectHero);
                this.goods3D.showRole(this.selectHero.cid, 0, 0, 0, -0.2, 0.2, -1, 1.15, 0, -15);
                this.showInfoHandler();
            }
        }
        locHeroHandler() {
            if (this.selectHero) {
                BattleModel.model.playerCid = this.selectHero.cid;
                this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: this.selectHero.id });
                this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '成功派遣' + GoodsListConfig.getVo(this.selectHero.cid).name + '出战' });
            }
        }
        checkLocShow(selectHero) {
            if (selectHero.loc == 1) {
                this.ui.box_loc.visible = false;
                this.ui.box_noLoc.visible = true;
            }
            else {
                this.ui.box_loc.visible = true;
                this.ui.box_noLoc.visible = false;
            }
            if (selectHero.triphyNum <= SegmentModel.model.maxTriphyNum || selectHero.isUnlock) {
                this.ui.img_lock.visible = false;
                this.ui.box_ad.visible = false;
                this.ui.txt_info1.visible = false;
            }
            else {
                this.ui.box_loc.visible = false;
                this.ui.box_noLoc.visible = false;
                this.ui.img_lock.visible = true;
                this.ui.box_ad.visible = true;
                this.ui.txt_info1.visible = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.tryHandler, '');
        }
        tryHandler() {
            BattleModel.model.playerCid = this.selectHero.cid;
        }
        tongHandler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(0)] });
        }
        jinHandler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
        }
        adGiftHandler() {
            if (HeroModel.model.giftAdNum == 0) {
                this.giveGift();
            }
            else {
                AdTool.videoAdShow(this, this.giveGift, 'giveHeroGift');
            }
        }
        giveGift() {
            var num = 0;
            if (this.giftHero.quality == 0) {
                num = 60;
            }
            else if (this.giftHero.quality == 1) {
                num = 20;
            }
            else {
                num = 5;
            }
            if (AdTool.checkVideoIco('ys_jili')) {
                this.ui.ui_gift.img_lv.x = 27;
                this.ui.ui_gift.img_ad.visible = true;
            }
            else {
                this.ui.ui_gift.img_ad.visible = false;
                this.ui.ui_gift.img_lv.x = 17;
            }
            HeroModel.model.giftAdNum++;
            HeroModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { showType: 2, list: [{ cid: this.giftHero.cid, num: num }] });
        }
        testHandler() {
            var heroVo = HeroTool.getFirstByUnlock();
            if (heroVo) {
                this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: heroVo.cid, isUnlock: true });
            }
        }
    }

    class HeroNewUnlockTipView extends ui.hero.HeroNewUnlockTipUI {
        constructor() {
            super();
            this.zOrder = 52;
        }
    }

    class HeroNewUnlockTipViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = HeroNewUnlockTipView;
            this.viewName = 'HeroNewUnlockTipView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.ui.img_ok.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_go.on(Laya.Event.CLICK, this, this.goHandler);
            this.heroVo = this.data.heroVo;
            if (this.heroVo) {
                this.ui.ui_left.img_hero.skin = GoodsConfig.getTryIcoUrl(this.heroVo.cid);
                var skillVo = HeroTool.getSkillVo(this.heroVo.cid);
                var gunVo = HeroTool.getGunVo(this.heroVo.cid);
                this.ui.ui_up.txt_name.text = skillVo.name;
                this.ui.ui_up.txt_info.text = skillVo.info;
                this.ui.ui_up.img_ico.skin = GoodsConfig.getSkillIcoUrl(skillVo.ico, "white");
                this.ui.ui_down.txt_name.text = gunVo.name;
                this.ui.ui_down.txt_info.text = gunVo.info;
                this.ui.ui_down.img_ico.skin = GoodsConfig.getGunIcoUrl(gunVo.ico);
                this.showRoleHandler();
            }
        }
        showRoleHandler() {
            this.goods3D.showRole(this.heroVo.cid, 0, 0, 0, 0.95, 0, -0.9, 1.15, 0, -15);
        }
        goHandler() {
            this.close();
            this.dispatchEvent(HeroEvent.HERO_VIEW_SHOW, { showType: ViewType.OPEN, index: 0, isSkipHero: true, heroVo: this.heroVo, isShowHand: false, zOrder: 55 });
        }
    }

    class HeroController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            HeroModel.model.init();
            ViewManager.register(HeroEvent.HERO_VIEW_SHOW, this, HeroViewController);
            ViewManager.register(HeroEvent.HERO_LV_UP_ANIM_VIEW_SHOW, this, HeroLvUpAnimViewController);
            ViewManager.register(HeroEvent.HERO_LV_UP_TIP_VIEW_SHOW, this, HeroLvUpTipViewController);
            ViewManager.register(HeroEvent.HERO_NEW_UNLOCK_TIP_VIEW_SHOW, this, HeroNewUnlockTipViewController);
            this.addEventListener(HeroEvent.HERO_UNLOCK_TIP_VIEW_SHOW, this, this.unlockHandler);
            this.addEventListener(HeroEvent.HERO_LV_UP_REQUEST, this, this.heroUpHandler);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.isShowTip);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.isLvUpTip);
            this.addEventListener(GoodsEvent.GOODS_ATTR_SET_REQUEST, this, this.isLvUpTip);
            this.addEventListener(GoodsEvent.GOODS_ATTR_SET_REQUEST, this, this.isShowTip);
            this.addEventListener(BattleEvent.BATTLE_SETTLE_COMPLETE, this, this.settleHandler);
            this.isShowTip();
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            var list = HeroConfig.heroList;
            for (var k in list) {
                var cid = list[k];
                var heroVo = GoodsModel.model.getGoodsByCid(cid);
                if (heroVo) {
                    if (heroVo.isUnlock == false) {
                        if (heroVo.triphyNum <= SegmentModel.model.maxTriphyNum) {
                            this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: heroVo.cid, isUnlock: true });
                        }
                    }
                }
            }
        }
        heroUpHandler(data) {
            var hero = data.vo;
            var tongNum = 0;
            var cardHeroNum = 0;
            var expNum = 0;
            if (hero.quality == 0) {
                tongNum = (hero.lv + 1) * HeroConfig.tongNumNormal;
                cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumNormal;
                expNum = (hero.lv + 1) * HeroConfig.expNumNormal;
            }
            else if (hero.quality == 1) {
                tongNum = (hero.lv + 1) * HeroConfig.tongNumRare;
                cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumRare;
                expNum = (hero.lv + 1) * HeroConfig.expNumRare;
            }
            else {
                tongNum = (hero.lv + 1) * HeroConfig.tongNumEpic;
                cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumEpic;
                expNum = (hero.lv + 1) * HeroConfig.expNumEpic;
            }
            if (hero.triphyNum <= SegmentModel.model.maxTriphyNum || hero.isUnlock) {
                if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG) >= tongNum && hero.lv <= HeroConfig.lvMax && GoodsModel.model.getGoodsNum(hero.cid) >= cardHeroNum) {
                    this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TONG, num: tongNum }] });
                    this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: hero.cid, num: cardHeroNum }] });
                    this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: hero.cid, lv: hero.lv + 1 });
                    this.dispatchEvent(HeroEvent.HERO_LV_UP_RESPONSE);
                    this.dispatchEvent(HeroEvent.HERO_LV_UP_ANIM_VIEW_SHOW, { vo: hero, num: expNum });
                }
                else {
                    if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG) < tongNum) {
                        this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(0)] });
                        return;
                    }
                    if (GoodsModel.model.getGoodsNum(hero.cid) < cardHeroNum) {
                        this.dispatchEvent(ShopEvent.SHOP_MALL_VIEW_SHOW, { showType: ViewType.OPEN });
                        return;
                    }
                }
            }
            else {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "未解锁哦!" });
            }
        }
        isLvUpTip(data) {
            var heroVo = this.checkPopup();
            var isPopup = false;
            for (var k in data.list) {
                var goods = data.list[k];
                if (GoodsListConfig.getVo(goods.cid).type == 30 && BattleModel.model.isLvUpTip == true) {
                    isPopup = true;
                }
                else {
                    isPopup = false;
                }
            }
            if (heroVo && isPopup == true && heroVo.triphyNum <= SegmentModel.model.maxTriphyNum) {
                this.dispatchEvent(HeroEvent.HERO_LV_UP_TIP_VIEW_SHOW, { showType: ViewType.OPEN, vo: heroVo });
            }
            else {
                this.dispatchEvent(HeroEvent.HERO_LV_UP_TIP_VIEW_SHOW, { showType: ViewType.CLOSE });
            }
        }
        isShowTip() {
            HeroModel.model.heroTipsIco = this.checkIsLvUp();
            HeroModel.model.saveData();
        }
        checkIsLvUp() {
            var tongNum = 0;
            var cardHeroNum = 0;
            var goodsVo = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            for (var k in goodsVo) {
                var hero = goodsVo[k];
                if (hero.quality == 0) {
                    tongNum = (hero.lv + 1) * HeroConfig.tongNumNormal;
                    cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumNormal;
                }
                else if (hero.quality == 1) {
                    tongNum = (hero.lv + 1) * HeroConfig.tongNumRare;
                    cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumRare;
                }
                else {
                    tongNum = (hero.lv + 1) * HeroConfig.tongNumEpic;
                    cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumEpic;
                }
                if (hero.triphyNum <= SegmentModel.model.maxTriphyNum || hero.isUnlock) {
                    if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG) >= tongNum && hero.lv <= HeroConfig.lvMax && GoodsModel.model.getGoodsNum(hero.cid) >= cardHeroNum) {
                        return true;
                    }
                }
            }
            return false;
        }
        checkPopup() {
            var cardHeroNum = 0;
            var goodsVo = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            for (var k in goodsVo) {
                var hero = goodsVo[k];
                if (hero.quality == 0) {
                    cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumNormal;
                }
                else if (hero.quality == 1) {
                    cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumRare;
                }
                else {
                    cardHeroNum = (hero.lv + 1) * HeroConfig.cardNumEpic;
                }
                if (GoodsModel.model.getGoodsNum(hero.cid) >= cardHeroNum) {
                    return hero;
                }
            }
            return null;
        }
        settleHandler() {
            var hero = HeroTool.getFirstByUnlock();
            var gameTime = BattleModel.model.victoryNum + BattleModel.model.defeatNum;
            if (hero && gameTime > 1) {
                this.dispatchEvent(HeroEvent.HERO_UNLOCK_TIP_VIEW_SHOW);
            }
            if (gameTime > 1) {
                var list = HeroConfig.heroList;
                for (var k in list) {
                    var cid = list[k];
                    var heroVo = GoodsModel.model.getGoodsByCid(cid);
                    if (heroVo) {
                        if (heroVo.isUnlock == false) {
                            if (heroVo.triphyNum <= SegmentModel.model.maxTriphyNum) {
                                this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: heroVo.cid, isUnlock: true });
                                this.dispatchEvent(CommonEvent.QUEUE_EVENT_ADD, { eventName: HeroEvent.HERO_NEW_UNLOCK_TIP_VIEW_SHOW, data: { heroVo: heroVo }, exitEvent: ViewEvent.VIWE_CLOSE('HeroNewUnlockTipView') });
                            }
                        }
                    }
                }
            }
        }
        unlockHandler(data) {
            if (HeroConfig.unlockTipType == 1) {
                ViewManager.show(this, HeroUnlockTip1ViewController, data);
            }
            else {
                ViewManager.show(this, HeroUnlockTipViewController, data);
            }
        }
    }

    class FontMaterial extends Laya.UnlitMaterial {
        constructor() {
            super(...arguments);
            this.fontWidth = 0;
            this.fontHeight = 0;
            this.fontX = 0;
            this.fontY = 0;
            this.offX = 0;
            this.offY = 0;
            this.scaleWH = 1;
        }
    }

    class TextSprite3D extends Laya.Sprite3D {
        constructor(name) {
            super();
            this.scaleWH = 1;
            this.text = new Laya.MeshSprite3D(Laya.PrimitiveMesh.createPlane(1, 1), name);
            this.text.transform.localPositionX = 0.5;
            this.text.transform.localPositionZ = 0.5;
            this.addChild(this.text);
        }
        set material(m) {
            this.text.meshRenderer.material = m;
        }
        set width(w) {
            this.text.transform.localScaleX = w;
            this.text.transform.localPositionX = w / 2;
        }
        get width() {
            return this.text.transform.localScaleX;
        }
        set height(h) {
            this.transform.localScaleZ = h;
            this.text.transform.localPositionZ = h / 2;
        }
        get height() {
            return this.text.transform.localScaleZ;
        }
        set x(v) {
            this.transform.localPositionX = v;
        }
        get x() {
            return this.transform.localPositionX;
        }
        set y(v) {
            this.transform.localPositionZ = v;
        }
        get y() {
            return this.transform.localPositionZ;
        }
    }

    class BitmapFonts3D {
        constructor() {
            this.completes = [];
            this.textureMap = {};
            this.isLoaded = false;
            this.imgLib = {};
        }
        static loadFont(url, complete) {
            var font = this.lib[url];
            if (!font) {
                font = new BitmapFonts3D();
                this.lib[url] = font;
            }
            font.load(url, complete);
        }
        static getFont(url) {
            return this.lib[url];
        }
        load(url, complete) {
            if (this.isLoaded) {
                if (complete) {
                    complete.run();
                }
                return;
            }
            if (complete) {
                this.completes.push(complete);
            }
            if (this.url) {
                return;
            }
            this.url = url;
            Laya.loader.load(url, HandlerUtil.create(this, this.jsonCompHandeler), null, Laya.Loader.JSON);
        }
        jsonCompHandeler(data) {
            this.data = data;
            var pngurl = this.url.replace('.fnt', '.png');
            pngurl = pngurl.replace('.json', '.png');
            Laya.loader.load(pngurl, HandlerUtil.create(this, this.loadCompHandeler), null, Laya.Loader.IMAGE);
        }
        loadCompHandeler(img) {
            this.isLoaded = true;
            this.texture = img.bitmap;
            for (var fun of this.completes) {
                if (fun) {
                    fun.run();
                }
            }
            this.completes = [];
        }
        getTextTexture(text) {
            if (text == "/") {
                text = "╱";
            }
            else if (text == ":") {
                text = "：";
            }
            else if (text == "\\") {
                text = "╲";
            }
            if (this.textureMap[text] == 'null') {
                return null;
            }
            if (this.textureMap[text]) {
                return this.textureMap[text];
            }
            if (!this.texture) {
                return null;
            }
            if (!this.data) {
                return null;
            }
            if (!this.data.frames) {
                return null;
            }
            var list = this.data.frames;
            if (!list[text]) {
                return null;
            }
            var co = list[text];
            if (!co) {
                this.textureMap[text] = 'null';
                return null;
            }
            var material = new FontMaterial();
            material.albedoIntensity = 1;
            material.renderMode = 2;
            material.fontWidth = co.w;
            material.fontHeight = co.h;
            material.fontX = co.x;
            material.fontY = co.y;
            material.offX = co.offX;
            material.offY = co.offY;
            material.scaleWH = material.fontWidth / material.fontHeight;
            material.albedoTexture = this.texture;
            material.tilingOffsetX = co.w / this.texture.width;
            material.tilingOffsetY = co.h / this.texture.height;
            material.tilingOffsetZ = co.x / this.texture.width;
            material.tilingOffsetW = 1 - material.tilingOffsetY - co.y / this.texture.height;
            this.textureMap[text] = material;
            return material;
        }
        getImage(text) {
            var imgList = this.getImageList(text);
            if (imgList.length > 0) {
                return imgList.pop();
            }
            var tt = this.getTextTexture(text);
            if (tt) {
                var img = new TextSprite3D();
                img.material = tt;
                img.width = tt.scaleWH;
                img.name = text;
                return img;
            }
            else if (text == ' ') {
                var img = new TextSprite3D();
                img.name = text;
                return img;
            }
            return null;
        }
        getImageList(text) {
            var list = this.imgLib[text];
            if (!list) {
                list = this.imgLib[text] = [];
            }
            return list;
        }
        recoverImage(img) {
            if (img) {
                var imgList = this.getImageList(img.name);
                imgList.push(img);
            }
        }
    }
    BitmapFonts3D.lib = {};

    class BrowserParamTool {
        static getParams() {
            if (!this.param) {
                var url = this.getUrlParam();
                if (url) {
                    this.param = {};
                    if (url) {
                        url = decodeURIComponent(url);
                        var urlw = url.replace(/\?/g, "&");
                        var list = urlw.split('&');
                        for (var item of list) {
                            var prm = item.split('=');
                            var k = prm[0];
                            var v = prm[1];
                            this.param[k] = v;
                        }
                    }
                }
            }
            return this.param;
        }
        static getParam(name) {
            var param = this.getParams();
            if (param && param.hasOwnProperty(name)) {
                return param[name];
            }
            return undefined;
        }
        static getParamDefault(name, def = undefined) {
            var v = this.getParam(name);
            if (v === undefined) {
                return def;
            }
            return v;
        }
        static getParamString(name) {
            return this.getParam(name);
        }
        static getParamInt(name) {
            return MathUtil.int(this.getParam(name));
        }
        static getParamNumber(name) {
            return MathUtil.number(this.getParam(name));
        }
        static getParamBool(name) {
            return MathUtil.bool(this.getParam(name));
        }
        static checkAgent(type) {
            if (Laya.Browser.userAgent) {
                return Laya.Browser.userAgent.indexOf(type) > -1;
            }
            return false;
        }
        static hideUrlParam() {
            if (window && window.location && window.location.search) {
                this.urlParam = window.location.search;
                if (typeof localStorage != "undefined") {
                    localStorage.setItem('urlParam', this.urlParam);
                }
                if (typeof history != "undefined") {
                    history.replaceState({}, null, 'index.html');
                }
            }
            else if (typeof localStorage != "undefined") {
                this.urlParam = localStorage.getItem("urlParam");
            }
            if (!this.urlParam) {
                this.urlParam = '';
            }
        }
        static getUrlParam() {
            if (this.urlParam) {
                return this.urlParam;
            }
            else if (window && window.location && window.location.search) {
                return window.location.search;
            }
            return '';
        }
    }
    BrowserParamTool.urlParam = '';

    class MainConfig {
    }
    MainConfig.clientConfig = null;
    MainConfig.basePath = '';
    MainConfig.ver = '';
    MainConfig.versionUrl = '';
    MainConfig.divice = '';
    MainConfig.os = '';
    MainConfig.soft = '';
    MainConfig.platform = '';
    MainConfig.channel = '';
    MainConfig.entry = '';

    class MainTool {
        static initParam() {
            LogTool.log("userAgent:" + Laya.Browser.userAgent);
            var clientConfig = window['clientConfig'];
            if (typeof clientConfig != "undefined") {
                MainConfig.clientConfig = clientConfig;
                MainConfig.ver = ParamUtil.getString(clientConfig, 'ver', '');
                MainConfig.basePath = ParamUtil.getString(clientConfig, 'basePath', MainConfig.basePath);
                MainConfig.versionUrl = ParamUtil.getString(clientConfig, 'versionUrl', MainConfig.versionUrl);
                MainConfig.platform = ParamUtil.getString(clientConfig, 'platform', MainConfig.platform);
                SoundConfig.soundFormat = ParamUtil.getString(clientConfig, 'soundFormat', SoundConfig.soundFormat);
                LogTool.log('平台名' + MainConfig.platform);
                if (MainConfig.basePath) {
                    Laya.URL.basePath = MainConfig.basePath;
                }
            }
            MainConfig.platform = BrowserParamTool.getParamDefault('platform', MainConfig.platform);
            MainConfig.channel = BrowserParamTool.getParamDefault('channel', MainConfig.channel);
            MainConfig.entry = BrowserParamTool.getParamDefault('entry', MainConfig.entry);
            var ver = BrowserParamTool.getParamDefault('ver', MainConfig.ver);
            if (ver) {
                MainConfig.ver = ver;
            }
            if (!MainConfig.ver) {
                MainConfig.ver = 't' + TimeUtil.getTimestamp();
            }
            LogTool.log("basePath:" + Laya.URL.basePath);
            var br = Laya.Browser;
            if (br.onPC) {
                MainConfig.divice = 'pc';
                MainConfig.os = 'win';
            }
            if (BrowserParamTool.checkAgent('Windows')) {
                MainConfig.divice = 'pc';
                MainConfig.os = 'win';
            }
            if (br.onAndroid) {
                MainConfig.divice = 'android';
                MainConfig.os = 'android';
            }
            if (br.onMac) {
                MainConfig.divice = 'imac';
                MainConfig.os = 'mac';
            }
            if (br.onWP) {
                MainConfig.divice = 'wp';
                MainConfig.os = 'wp';
            }
            if (br.onIPhone) {
                MainConfig.divice = 'iphone';
                MainConfig.os = 'ios';
            }
            if (br.onIPad) {
                MainConfig.divice = 'ipad';
                MainConfig.os = 'ios';
            }
            if (br.onQQBrowser) {
                MainConfig.soft = 'qq_browser';
            }
            if (br.onMQQBrowser) {
                MainConfig.soft = 'qq_m_browser';
            }
            if (br.onSafari) {
                MainConfig.soft = 'safari';
            }
            if (br.onFirefox) {
                MainConfig.soft = 'firefox';
            }
            if (br.onEdge) {
                MainConfig.soft = 'edge';
            }
            if (br.onIE) {
                MainConfig.soft = 'ie';
            }
        }
        static getVersionUrl() {
            if (!MainConfig.versionUrl) {
                return 'version.json?ver=' + MainConfig.ver;
            }
            return MainConfig.versionUrl;
        }
        static getClientParam(k, def = null) {
            return ParamUtil.getObject(MainConfig.clientConfig, k, def);
        }
    }

    class LoadingConfig {
    }
    LoadingConfig.packageList = null;
    LoadingConfig.loadList = [
        { url: "res/atlas/comp.atlas", type: 'atlas' },
        { url: "res/atlas/ui.atlas", type: 'atlas' },
    ];
    LoadingConfig.loadScene = [
        'scene/LayaScene_unit/Conventional/role_1.lh',
    ];
    LoadingConfig.preloadList = [
        'scene/LayaScene_scene_1/Conventional/scene_1.ls',
    ];
    LoadingConfig.soundList = [
        '1', '2', '3', '4', '5', '6', '7', '8', '9', '10',
    ];

    class LoadingEvent {
    }
    LoadingEvent.LOADING_START = 'LOADING_START';
    LoadingEvent.LOADING_COMPLETE = 'LOADING_COMPLETE';
    LoadingEvent.LOADING_PACKAGE_START = 'LOADING_PACKAGE_START';
    LoadingEvent.LOADING_PACKAGE_COMPLETE = 'LOADING_PACKAGE_COMPLETE';
    LoadingEvent.LOADING_PACKAGE_PROGRESS = 'LOADING_PACKAGE_PROGRESS';
    LoadingEvent.LOADING_PACKAGE_FAIL = 'LOADING_PACKAGE_FAIL';
    LoadingEvent.LOADING_LOGIN_VIEW_SHOW = 'LOADING_LOGIN_VIEW_SHOW';
    LoadingEvent.LOADING_LOGIN_PROGRESS = 'LOADING_LOGIN_PROGRESS';
    LoadingEvent.LOADING_LOGIN_COMPLETE = 'LOADING_LOGIN_COMPLETE';
    LoadingEvent.LOADING_OFFLINE_VIEW_SHOW = 'LOADING_OFFLINE_VIEW_SHOW';

    class LoadingLoginView extends ui.loading.LoadingLoginUI {
        constructor() {
            super();
            this.zOrder = 100;
        }
    }

    class LoadingLoginViewController extends DialogViewController {
        constructor() {
            super();
            this.pro = 20;
            this.proMax = 1000;
            this.viewClass = LoadingLoginView;
            this.modalAlpha = 1;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.txt_load.text = "";
            this.loadPackageHandler();
        }
        loadPackageHandler() {
            LoadingConfig.packageList = ParamUtil.getObject(MainConfig.clientConfig, 'packageList', LoadingConfig.packageList);
            if (LoadingConfig.packageList && LoadingConfig.packageList.length > 0) {
                this.addEventListener(LoadingEvent.LOADING_PACKAGE_COMPLETE, this, this.loadList);
                this.addEventListener(LoadingEvent.LOADING_PACKAGE_PROGRESS, this, this.progressHandler);
                this.dispatchEvent(LoadingEvent.LOADING_PACKAGE_START, { list: LoadingConfig.packageList });
            }
            else {
                this.loadList();
            }
        }
        progressHandler(data) {
            this.ui.txt_load.text = "正在加载" + data.name + ":" + MathUtil.int(data.progress * 100) + "%";
            ProgressBarViewTool.setRectBarValue(this.ui.img_act, data.progress);
        }
        loadList() {
            Laya.loader.load(LoadingConfig.loadList, HandlerUtil.create(this, this.loadSceneHandler), HandlerUtil.create(this, this.pageProgressHandler));
        }
        pageProgressHandler(v) {
            this.ui.txt_load.text = MathUtil.int(v * 100) + "%";
            ProgressBarViewTool.setRectBarValue(this.ui.img_act, v);
        }
        loadSceneHandler() {
            this.preloadList = ObjectUtil.copy(LoadingConfig.loadScene, []);
            this.startLoadPre();
            TimerUtil.loopFrame(1, this, this.showTextHandler);
        }
        startLoadPre() {
            if (this.preloadList && this.preloadList.length > 0) {
                var url = this.preloadList.shift();
                LoaderUtil.load3D(url, null, this, this.startLoadPre);
            }
            else {
                this.compHandler();
            }
        }
        showTextHandler() {
            this.pro += MathUtil.randomInt(1, 10);
            this.ui.txt_load.text = this.pro + "%";
            ProgressBarViewTool.setRectBarValue(this.ui.img_act, this.pro / this.proMax);
        }
        compHandler() {
            this.closeHandler();
        }
        closeHandler() {
            this.dispatchEvent(LoadingEvent.LOADING_LOGIN_PROGRESS, { progress: 1 });
            this.dispatchEvent(LoadingEvent.LOADING_LOGIN_COMPLETE);
            this.close();
        }
    }

    class LoadingOfflineView extends ui.loading.LoadingOfflineUI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class LoadingOfflineViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = LoadingOfflineView;
            this.openAnim = null;
            this.closeAnim = ViewAnimTool.getViewAnim('UpOut');
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
        }
    }

    class LoadingController extends Controller {
        constructor() {
            super();
            this.preloadList = [];
        }
        run() {
            super.run();
            this.addEventListener(MainEvent.MAIN_INIT_START, this, this.startHandler);
            ViewManager.register(LoadingEvent.LOADING_LOGIN_VIEW_SHOW, this, LoadingLoginViewController);
            ViewManager.register(LoadingEvent.LOADING_OFFLINE_VIEW_SHOW, this, LoadingOfflineViewController);
        }
        startHandler() {
            var url = MainTool.getVersionUrl();
            LogTool.log("VerURL:" + url);
            if (url) {
                LoaderUtil.loads(url, this, this.loadLineHandler);
            }
            else {
                this.loadLineHandler({});
            }
        }
        loadLineHandler(data) {
            if (data) {
                var url = MainTool.getVersionUrl();
                Laya.ResourceVersion.enable(url, HandlerUtil.create(this, this.onVersionLoaded), Laya.ResourceVersion.FILENAME_VERSION);
            }
            else {
                this.dispatchEvent(LoadingEvent.LOADING_OFFLINE_VIEW_SHOW);
            }
        }
        onVersionLoaded() {
            Laya.AtlasInfoManager.enable("fileconfig.json", HandlerUtil.create(this, this.onConfigLoaded));
        }
        onConfigLoaded() {
            this.addEventListener(LoadingEvent.LOADING_LOGIN_COMPLETE, this, this.compHandler);
            this.dispatchEvent(LoadingEvent.LOADING_LOGIN_VIEW_SHOW, { showType: ViewType.OPEN });
        }
        compHandler() {
            this.dispatchEvent(MainEvent.MAIN_INIT_COMPLETE);
            this.preloadHandler();
        }
        preloadHandler() {
            this.preloadList = ObjectUtil.copy(LoadingConfig.preloadList, []);
            this.startLoadPre();
            this.startLoadFont();
        }
        startLoadPre() {
            if (this.preloadList && this.preloadList.length > 0) {
                var url = this.preloadList.shift();
                Laya.loader.create(url, HandlerUtil.create(this, this.startLoadPreHandler));
            }
        }
        loadSound() {
            this.soundList = ObjectUtil.copy(LoadingConfig.soundList, []);
            this.startLoadSound();
        }
        startLoadSound() {
            if (this.soundList && this.soundList.length > 0) {
                var url = this.soundList.shift();
                SoundTool.playSound(url);
                TimerUtil.onceTimer(1000, this, this.startLoadSound);
            }
        }
        startLoadPreHandler() {
            TimerUtil.onceTimer(1000, this, this.startLoadPre);
        }
        startLoadFont() {
            BitmapFonts3D.loadFont("font/white.json");
        }
    }

    class OnlineConfig {
        static getItemData(day) {
            return this.list[day];
        }
    }
    OnlineConfig.onlineType = 0;
    OnlineConfig.onlineButton = 0;
    OnlineConfig.list = {
        0: { time: 1 * 60, num: 0, reward: { cid: 20010003, num: 100 } },
        1: { time: 5 * 60, num: 1, reward: { cid: 20010003, num: 200 } },
        2: { time: 10 * 60, num: 2, reward: { cid: 20010003, num: 300 } },
        3: { time: 15 * 60, num: 3, reward: { cid: 20010003, num: 300 } },
        4: { time: 20 * 60, num: 4, reward: { cid: 20010003, num: 300 } },
        5: { time: 30 * 60, num: 5, reward: { cid: 20010003, num: 500 } },
        6: { time: 45 * 60, num: 6, reward: { cid: 20010003, num: 500 } },
        7: { time: 60 * 60, num: 7, reward: { cid: 20010003, num: 1000 } },
    };

    class OnlineEvent {
    }
    OnlineEvent.ONLINE_VIEW_SHOW = 'ONLINE_VIEW_SHOW';
    OnlineEvent.ONLINE_REWARD_REQUEST = 'ONLINE_REWARD_REQUEST';
    OnlineEvent.ONLINE_REWARD_RESPONSE = 'ONLINE_REWARD_RESPONSE';
    OnlineEvent.ONLINE_REWARD_CHANGE = 'ONLINE_REWARD_CHANGE';
    OnlineEvent.ONLINE_CLOSE_CLICK = 'ONLINE_CLOSE_CLICK';

    class OnlineModel {
        constructor() {
            this.rewardNum = 0;
            this.loginTs = 0;
            this.gameTime = 0;
            this.stateChange = false;
            this.adNum = 0;
        }
        static get model() {
            return ModelManager.getModel('OnlineModel', OnlineModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            var list = [];
            data.list = list;
            data.rewardNum = this.rewardNum;
            data.loginTime = this.loginTs;
            data.gameTime = this.gameTime;
            data.adNum = this.adNum;
            StorageModel.model.setData("online", data);
        }
        loadData() {
            var data = StorageModel.model.getData("online");
            this.loginTs = ParamUtil.getNumber(data, 'loginTime', 0);
            this.rewardNum = ParamUtil.getInt(data, 'rewardNum', 0);
            this.gameTime = ParamUtil.getInt(data, 'gameTime', 0);
            this.adNum = ParamUtil.getNumber(data, 'adNum', 0);
        }
    }

    class OnlineVo {
        constructor() {
            this.cid = 0;
            this.num = 0;
            this.time = 0;
            this.reward = {};
        }
    }

    class OnlineVoBuilder {
        static getLineVo(cid) {
            var item = OnlineConfig.list[cid];
            if (!item) {
                return null;
            }
            var vo = new OnlineVo();
            vo.cid = MathUtil.int(cid);
            ObjectUtil.copy(item, vo);
            return vo;
        }
    }

    class OnlineTool {
        static checkFinish() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var rewardNum = OnlineModel.model.rewardNum;
            for (var k in list) {
                var vo = list[k];
                var num = vo.num;
                if (num < rewardNum) {
                }
                else if (gameTime >= vo.time) {
                    return true;
                }
                else {
                }
            }
            return false;
        }
    }

    class Online1View extends ui.online.Online1UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class Online1ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = Online1View;
            this.viewName = 'OnlineView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneRewardHandler);
            this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_RESPONSE, this, this.showList);
            this.ui.list_1.scrollBar.visible = false;
            this.showbtn1();
            TimerUtil.loopTimer(1000, this, this.showTimeHandler);
            this.showList();
        }
        showTimeHandler() {
            if (OnlineModel.model.rewardNum >= 8) {
                TimerUtil.stopTimer(this, this.showTimeHandler);
                this.ui.txt_total.text = '';
                return;
            }
            var gameTime = OnlineModel.model.gameTime;
            this.ui.txt_total.text = '已累计在线时长  ' + TimeFormatUtil.formatTime(gameTime);
        }
        showList() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var nlist = [];
            var rewardNum = OnlineModel.model.rewardNum;
            var index = -1;
            var i = 0;
            for (var k in list) {
                var vo = OnlineVoBuilder.getLineVo(k);
                var data = {};
                var num = vo.num;
                var reward = vo.reward;
                data.txt_time = MathUtil.int(vo.time / 60) + "分钟";
                data.txt_num = "金币x" + reward.num;
                if (num < rewardNum) {
                    data.box_has = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_bg2 = { visible: false };
                }
                else if (gameTime >= vo.time) {
                    data.box_has = { visible: true };
                    data.img_state = { visible: false };
                    data.img_state1 = { visible: false };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                    data.img_bg2 = { visible: true };
                    if (index == -1) {
                        index = i;
                    }
                }
                else {
                    data.box_has = { visible: false };
                    data.img_bg2 = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                }
                nlist.push(data);
                i++;
            }
            this.ui.list_1.dataSource = nlist;
            if (index >= 0) {
                this.ui.list_1.scrollBar.value = 264 * index;
            }
            this.showBtn();
        }
        showBtn() {
            var btnshow = OnlineTool.checkFinish();
            if (btnshow) {
                this.ui.btn_get.disabled = false;
                this.ui.box_get.disabled = false;
            }
            else {
                this.ui.btn_get.disabled = true;
                this.ui.box_get.disabled = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoRewardHandler, 'doubleGet');
        }
        getOneRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 2 });
        }
        showbtn1() {
            this.ui.btn_close.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_close.visible = true;
                });
            }
            else {
                this.ui.btn_close.visible = true;
            }
        }
    }

    class Online2View extends ui.online.Online2UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class Online2ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = Online2View;
            this.viewName = 'OnlineView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneRewardHandler);
            this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_RESPONSE, this, this.showList);
            this.ui.list_1.scrollBar.visible = false;
            TimerUtil.loopTimer(1000, this, this.showTimeHandler);
            this.showList();
        }
        showTimeHandler() {
            if (OnlineModel.model.rewardNum >= 8) {
                TimerUtil.stopTimer(this, this.showTimeHandler);
                this.ui.txt_total.text = '';
                return;
            }
            var gameTime = OnlineModel.model.gameTime;
            this.ui.txt_total.text = '已累计在线时长  ' + TimeFormatUtil.formatTime(gameTime);
        }
        showList() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var nlist = [];
            var rewardNum = OnlineModel.model.rewardNum;
            var index = -1;
            var i = 0;
            for (var k in list) {
                var vo = OnlineVoBuilder.getLineVo(k);
                var data = {};
                var num = vo.num;
                var reward = vo.reward;
                data.txt_time = MathUtil.int(vo.time / 60) + "分钟";
                data.txt_num = "金币x" + reward.num;
                if (num < rewardNum) {
                    data.box_has = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_bg2 = { visible: false };
                }
                else if (gameTime >= vo.time) {
                    data.box_has = { visible: true };
                    data.img_state = { visible: false };
                    data.img_state1 = { visible: false };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                    data.img_bg2 = { visible: true };
                    if (index == -1) {
                        index = i;
                    }
                }
                else {
                    data.box_has = { visible: false };
                    data.img_bg2 = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                }
                nlist.push(data);
                i++;
            }
            this.ui.list_1.dataSource = nlist;
            if (index >= 0) {
                this.ui.list_1.scrollBar.value = 264 * index;
            }
            this.showBtn();
        }
        showBtn() {
            var btnshow = OnlineTool.checkFinish();
            if (btnshow) {
                this.ui.btn_get.disabled = false;
                this.ui.box_get.disabled = false;
            }
            else {
                this.ui.btn_get.disabled = true;
                this.ui.box_get.disabled = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoRewardHandler, 'doubleGet');
        }
        getOneRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 2 });
        }
    }

    class Online3View extends ui.online.Online3UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class Online3ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = Online3View;
            this.viewName = 'OnlineView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneRewardHandler);
            this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_RESPONSE, this, this.showList);
            this.ui.list_1.scrollBar.visible = false;
            this.showbtn1();
            TimerUtil.loopTimer(1000, this, this.showTimeHandler);
            this.showList();
        }
        showTimeHandler() {
            if (OnlineModel.model.rewardNum >= 8) {
                TimerUtil.stopTimer(this, this.showTimeHandler);
                this.ui.txt_total.text = '';
                return;
            }
            var gameTime = OnlineModel.model.gameTime;
            this.ui.txt_total.text = '已累计在线时长  ' + TimeFormatUtil.formatTime(gameTime);
        }
        showList() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var nlist = [];
            var rewardNum = OnlineModel.model.rewardNum;
            var index = -1;
            var i = 0;
            for (var k in list) {
                var vo = OnlineVoBuilder.getLineVo(k);
                var data = {};
                var num = vo.num;
                var reward = vo.reward;
                data.txt_time = MathUtil.int(vo.time / 60) + "分钟";
                data.txt_num = "金币x" + reward.num;
                if (num < rewardNum) {
                    data.box_has = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_bg2 = { visible: false };
                }
                else if (gameTime >= vo.time) {
                    data.box_has = { visible: true };
                    data.img_state = { visible: false };
                    data.img_state1 = { visible: false };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                    data.img_bg2 = { visible: true };
                    if (index == -1) {
                        index = i;
                    }
                }
                else {
                    data.box_has = { visible: false };
                    data.img_bg2 = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                }
                nlist.push(data);
                i++;
            }
            this.ui.list_1.dataSource = nlist;
            if (index >= 0) {
                this.ui.list_1.scrollBar.value = 264 * index;
            }
            this.showBtn();
        }
        showBtn() {
            var btnshow = OnlineTool.checkFinish();
            if (btnshow) {
                this.ui.btn_get.disabled = false;
                this.ui.box_get.disabled = false;
            }
            else {
                this.ui.btn_get.disabled = true;
                this.ui.box_get.disabled = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoRewardHandler, 'doubleGet');
        }
        getOneRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 2 });
        }
        showbtn1() {
            this.ui.btn_close.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_close.visible = true;
                });
            }
            else {
                this.ui.btn_close.visible = true;
            }
        }
    }

    class Online4View extends ui.online.Online4UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class Online4ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = Online4View;
            this.viewName = 'OnlineView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneRewardHandler);
            this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_RESPONSE, this, this.showList);
            this.ui.list_1.scrollBar.visible = false;
            TimerUtil.loopTimer(1000, this, this.showTimeHandler);
            this.showList();
        }
        showTimeHandler() {
            if (OnlineModel.model.rewardNum >= 8) {
                TimerUtil.stopTimer(this, this.showTimeHandler);
                this.ui.txt_total.text = '';
                return;
            }
            var gameTime = OnlineModel.model.gameTime;
            this.ui.txt_total.text = '已累计在线时长  ' + TimeFormatUtil.formatTime(gameTime);
        }
        showList() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var nlist = [];
            var rewardNum = OnlineModel.model.rewardNum;
            var index = -1;
            var i = 0;
            for (var k in list) {
                var vo = OnlineVoBuilder.getLineVo(k);
                var data = {};
                var num = vo.num;
                var reward = vo.reward;
                data.txt_time = MathUtil.int(vo.time / 60) + "分钟";
                data.txt_num = "金币x" + reward.num;
                if (num < rewardNum) {
                    data.box_has = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_bg2 = { visible: false };
                }
                else if (gameTime >= vo.time) {
                    data.box_has = { visible: true };
                    data.img_state = { visible: false };
                    data.img_state1 = { visible: false };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                    data.img_bg2 = { visible: true };
                    if (index == -1) {
                        index = i;
                    }
                }
                else {
                    data.box_has = { visible: false };
                    data.img_bg2 = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                }
                nlist.push(data);
                i++;
            }
            this.ui.list_1.dataSource = nlist;
            if (index >= 0) {
                this.ui.list_1.scrollBar.value = 264 * index;
            }
            this.showBtn();
        }
        showBtn() {
            var btnshow = OnlineTool.checkFinish();
            if (btnshow) {
                this.ui.btn_get.disabled = false;
                this.ui.box_get.disabled = false;
            }
            else {
                this.ui.btn_get.disabled = true;
                this.ui.box_get.disabled = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoRewardHandler, 'doubleGet');
        }
        getOneRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 2 });
        }
    }

    class Online5View extends ui.online.Online5UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class Online5ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = Online5View;
            this.viewName = 'OnlineView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneRewardHandler);
            this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_RESPONSE, this, this.showList);
            this.ui.list_1.scrollBar.visible = false;
            this.showbtn1();
            TimerUtil.loopTimer(1000, this, this.showTimeHandler);
            this.showList();
        }
        showTimeHandler() {
            if (OnlineModel.model.rewardNum >= 8) {
                TimerUtil.stopTimer(this, this.showTimeHandler);
                this.ui.txt_total.text = '';
                return;
            }
            var gameTime = OnlineModel.model.gameTime;
            this.ui.txt_total.text = '已累计在线时长  ' + TimeFormatUtil.formatTime(gameTime);
        }
        showList() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var nlist = [];
            var rewardNum = OnlineModel.model.rewardNum;
            var index = -1;
            var i = 0;
            for (var k in list) {
                var vo = OnlineVoBuilder.getLineVo(k);
                var data = {};
                var num = vo.num;
                var reward = vo.reward;
                data.txt_time = MathUtil.int(vo.time / 60) + "分钟";
                data.txt_num = "金币x" + reward.num;
                if (num < rewardNum) {
                    data.box_has = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_bg2 = { visible: false };
                }
                else if (gameTime >= vo.time) {
                    data.box_has = { visible: true };
                    data.img_state = { visible: false };
                    data.img_state1 = { visible: false };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                    data.img_bg2 = { visible: true };
                    if (index == -1) {
                        index = i;
                    }
                }
                else {
                    data.box_has = { visible: false };
                    data.img_bg2 = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                }
                nlist.push(data);
                i++;
            }
            this.ui.list_1.dataSource = nlist;
            if (index >= 0) {
                this.ui.list_1.scrollBar.value = 264 * index;
            }
            this.showBtn();
        }
        showBtn() {
            var btnshow = OnlineTool.checkFinish();
            if (btnshow) {
                this.ui.btn_get.disabled = false;
                this.ui.box_get.disabled = false;
            }
            else {
                this.ui.btn_get.disabled = true;
                this.ui.box_get.disabled = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoRewardHandler, 'doubleGet');
        }
        getOneRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 2 });
        }
        showbtn1() {
            this.ui.btn_close.visible = false;
            this.ui.btn_get.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_close.visible = true;
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_close.visible = true;
                this.ui.btn_get.visible = true;
            }
        }
    }

    class Online6View extends ui.online.Online6UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class Online6ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = Online6View;
            this.viewName = 'OnlineView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneRewardHandler);
            this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_RESPONSE, this, this.showList);
            this.ui.list_1.scrollBar.visible = false;
            this.showbtn1();
            TimerUtil.loopTimer(1000, this, this.showTimeHandler);
            this.showList();
        }
        showTimeHandler() {
            if (OnlineModel.model.rewardNum >= 8) {
                TimerUtil.stopTimer(this, this.showTimeHandler);
                this.ui.txt_total.text = '';
                return;
            }
            var gameTime = OnlineModel.model.gameTime;
            this.ui.txt_total.text = '已累计在线时长  ' + TimeFormatUtil.formatTime(gameTime);
        }
        showList() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var nlist = [];
            var rewardNum = OnlineModel.model.rewardNum;
            var index = -1;
            var i = 0;
            for (var k in list) {
                var vo = OnlineVoBuilder.getLineVo(k);
                var data = {};
                var num = vo.num;
                var reward = vo.reward;
                data.txt_time = MathUtil.int(vo.time / 60) + "分钟";
                data.txt_num = "金币x" + reward.num;
                if (num < rewardNum) {
                    data.box_has = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_bg2 = { visible: false };
                }
                else if (gameTime >= vo.time) {
                    data.box_has = { visible: true };
                    data.img_state = { visible: false };
                    data.img_state1 = { visible: false };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                    data.img_bg2 = { visible: true };
                    if (index == -1) {
                        index = i;
                    }
                }
                else {
                    data.box_has = { visible: false };
                    data.img_bg2 = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                }
                nlist.push(data);
                i++;
            }
            this.ui.list_1.dataSource = nlist;
            if (index >= 0) {
                this.ui.list_1.scrollBar.value = 264 * index;
            }
            this.showBtn();
        }
        showBtn() {
            var btnshow = OnlineTool.checkFinish();
            if (btnshow) {
                this.ui.btn_get.disabled = false;
                this.ui.box_get.disabled = false;
            }
            else {
                this.ui.btn_get.disabled = true;
                this.ui.box_get.disabled = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoRewardHandler, 'doubleGet');
        }
        getOneRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 2 });
        }
        showbtn1() {
            this.ui.btn_close.visible = false;
            this.ui.btn_get.visible = false;
            if (AdModel.model.isShieldCity == false) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_close.visible = true;
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_close.visible = true;
                this.ui.btn_get.visible = true;
            }
        }
        closeHandler() {
            this.close();
            this.dispatchEvent(OnlineEvent.ONLINE_CLOSE_CLICK);
        }
    }

    class OnlineView extends ui.online.OnlineUI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class OnlineViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = OnlineView;
            this.viewName = 'OnlineView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneRewardHandler);
            this.ui.box_get.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_RESPONSE, this, this.showList);
            this.ui.list_1.scrollBar.visible = false;
            TimerUtil.loopTimer(1000, this, this.showTimeHandler);
            this.showList();
        }
        showTimeHandler() {
            if (OnlineModel.model.rewardNum >= 8) {
                TimerUtil.stopTimer(this, this.showTimeHandler);
                this.ui.txt_total.text = '';
                return;
            }
            var gameTime = OnlineModel.model.gameTime;
            this.ui.txt_total.text = '已累计在线时长  ' + TimeFormatUtil.formatTime(gameTime);
        }
        showList() {
            var gameTime = OnlineModel.model.gameTime;
            var list = OnlineConfig.list;
            var nlist = [];
            var rewardNum = OnlineModel.model.rewardNum;
            var index = -1;
            var i = 0;
            for (var k in list) {
                var vo = OnlineVoBuilder.getLineVo(k);
                var data = {};
                var num = vo.num;
                var reward = vo.reward;
                data.txt_time = MathUtil.int(vo.time / 60) + "分钟";
                data.txt_num = "金币x" + reward.num;
                if (num < rewardNum) {
                    data.box_has = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_bg2 = { visible: false };
                }
                else if (gameTime >= vo.time) {
                    data.box_has = { visible: true };
                    data.img_state = { visible: false };
                    data.img_state1 = { visible: false };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                    data.img_bg2 = { visible: true };
                    if (index == -1) {
                        index = i;
                    }
                }
                else {
                    data.box_has = { visible: false };
                    data.img_bg2 = { visible: false };
                    data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_state1 = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                }
                nlist.push(data);
                i++;
            }
            this.ui.list_1.dataSource = nlist;
            if (index >= 0) {
                this.ui.list_1.scrollBar.value = 264 * index;
            }
            this.showBtn();
        }
        showBtn() {
            var btnshow = OnlineTool.checkFinish();
            if (btnshow) {
                this.ui.btn_get.disabled = false;
                this.ui.box_get.disabled = false;
            }
            else {
                this.ui.btn_get.disabled = true;
                this.ui.box_get.disabled = true;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoRewardHandler, 'doubleGet');
        }
        getOneRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoRewardHandler() {
            OnlineModel.model.adNum++;
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_REQUEST, { multiple: 2 });
        }
    }

    class OnlineController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            OnlineModel.model.init();
            this.addEventListener(OnlineEvent.ONLINE_VIEW_SHOW, this, this.onLineHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_REQUEST, this, this.rwHadnler);
            this.initHandler();
        }
        initHandler() {
            var nowTime = TimeUtil.getTimestamp();
            var zero = TimeUtil.getZeroTimestamp();
            this.gameTime = OnlineModel.model.gameTime;
            if (OnlineModel.model.loginTs < zero) {
                OnlineModel.model.loginTs = nowTime;
                OnlineModel.model.rewardNum = 0;
                OnlineModel.model.gameTime = 0;
                OnlineModel.model.adNum = 0;
            }
            OnlineModel.model.saveData();
            TimerUtil.loopTimer(1000, this, this.getTimeHandler);
        }
        getTimeHandler() {
            var num = OnlineModel.model.rewardNum;
            if (num >= 8) {
                TimerUtil.stopTimer(this, this.getTimeHandler);
                return;
            }
            OnlineModel.model.gameTime += 1;
            var data = OnlineConfig.getItemData(num);
            var needTime = data.time;
            if (OnlineModel.model.stateChange == false) {
                if (OnlineModel.model.gameTime >= needTime) {
                    OnlineModel.model.stateChange = true;
                    this.dispatchEvent(OnlineEvent.ONLINE_REWARD_CHANGE);
                }
            }
            if (OnlineModel.model.gameTime % 60 == 0) {
                OnlineModel.model.saveData();
            }
        }
        rwHadnler(data) {
            var vo = OnlineVoBuilder.getLineVo(OnlineModel.model.rewardNum);
            OnlineModel.model.rewardNum++;
            LogTool.log('vo.reward:' + JSONUtil.stringify(data.multiple));
            OnlineModel.model.stateChange = false;
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { showType: 2, list: [{ cid: vo.reward.cid, num: vo.reward.num * data.multiple }] });
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_CHANGE);
            this.dispatchEvent(OnlineEvent.ONLINE_REWARD_RESPONSE);
            OnlineModel.model.saveData();
        }
        onLineHandler(data) {
            if (OnlineConfig.onlineType == 1) {
                ViewManager.show(this, Online1ViewController, data);
            }
            else if (OnlineConfig.onlineType == 2) {
                ViewManager.show(this, Online2ViewController, data);
            }
            else if (OnlineConfig.onlineType == 3) {
                ViewManager.show(this, Online3ViewController, data);
            }
            else if (OnlineConfig.onlineType == 4) {
                ViewManager.show(this, Online4ViewController, data);
            }
            else if (OnlineConfig.onlineType == 5) {
                ViewManager.show(this, Online5ViewController, data);
            }
            else if (OnlineConfig.onlineType == 6) {
                ViewManager.show(this, Online6ViewController, data);
            }
            else {
                ViewManager.show(this, OnlineViewController, data);
            }
        }
    }

    class GoodsBoxConfig {
        static getCard(cardType, triphyNum) {
            var normalCardList = [];
            var rareCardList = [];
            var epicCardList = [];
            for (var k in this.normalCardList) {
                if (triphyNum >= this.normalCardList[k].triphyNum) {
                    normalCardList.push(this.normalCardList[k]);
                }
            }
            for (var k in this.rareCardList) {
                if (triphyNum >= this.rareCardList[k].triphyNum) {
                    rareCardList.push(this.rareCardList[k]);
                }
            }
            for (var k in this.epicCardList) {
                if (triphyNum >= this.epicCardList[k].triphyNum) {
                    epicCardList.push(this.epicCardList[k]);
                }
            }
            if (cardType == 0) {
                if (normalCardList.length > 0) {
                    return RandomUtil.randomItem(normalCardList);
                }
                else {
                    return null;
                }
            }
            else if (cardType == 1) {
                if (rareCardList.length > 0) {
                    return RandomUtil.randomItem(rareCardList);
                }
                else {
                    return null;
                }
            }
            else {
                if (epicCardList.length > 0) {
                    return RandomUtil.randomItem(epicCardList);
                }
                else {
                    return null;
                }
            }
        }
        static getRewad(rewardList, diceList, triphyNum) {
            var reward = RandomUtil.randomWeight(diceList, 1);
            for (var i = 0; i < reward[0].num; i++) {
                var card = this.getCard(reward[0].cardType, triphyNum);
                if (card) {
                    rewardList.push(card);
                }
            }
        }
        static getBronzeBox(triphyNum) {
            var rewardList = [];
            var tong = RandomUtil.randomWeight(this.diceList1, 1);
            rewardList.push(tong[0]);
            this.getRewad(rewardList, this.diceList2, triphyNum);
            this.getRewad(rewardList, this.diceList3, triphyNum);
            return rewardList;
        }
        static getGoldBox(triphyNum) {
            var rewardList = [];
            var tong = RandomUtil.randomWeight(this.diceList4, 1);
            rewardList.push(tong[0]);
            this.getRewad(rewardList, this.diceList5, triphyNum);
            this.getRewad(rewardList, this.diceList6, triphyNum);
            this.getRewad(rewardList, this.diceList7, triphyNum);
            return rewardList;
        }
        static getMasonryBox(triphyNum) {
            var rewardList = [];
            var tong = RandomUtil.randomWeight(this.diceList8, 1);
            rewardList.push(tong[0]);
            this.getRewad(rewardList, this.diceList9, triphyNum);
            this.getRewad(rewardList, this.diceList10, triphyNum);
            this.getRewad(rewardList, this.diceList11, triphyNum);
            this.getRewad(rewardList, this.diceList12, triphyNum);
            return rewardList;
        }
        static geLegendBox(triphyNum) {
            var rewardList = [];
            var tong = RandomUtil.randomWeight(this.diceList13, 1);
            rewardList.push(tong[0]);
            this.getRewad(rewardList, this.diceList14, triphyNum);
            this.getRewad(rewardList, this.diceList15, triphyNum);
            this.getRewad(rewardList, this.diceList16, triphyNum);
            this.getRewad(rewardList, this.diceList17, triphyNum);
            return rewardList;
        }
        static getRainbowBox(triphyNum) {
            var rewardList = [];
            var tong = RandomUtil.randomWeight(this.diceList18, 1);
            rewardList.push(tong[0]);
            this.getRewad(rewardList, this.diceList19, triphyNum);
            this.getRewad(rewardList, this.diceList20, triphyNum);
            this.getRewad(rewardList, this.diceList21, triphyNum);
            this.getRewad(rewardList, this.diceList22, triphyNum);
            return rewardList;
        }
    }
    GoodsBoxConfig.normalCardList = [
        { cid: 30011001, num: 1, triphyNum: 100 },
        { cid: 30011002, num: 1, triphyNum: 160 },
        { cid: 30011003, num: 1, triphyNum: 120 },
        { cid: 30011005, num: 1, triphyNum: 200 },
        { cid: 30011006, num: 1, triphyNum: 400 },
        { cid: 30011007, num: 1, triphyNum: 500 },
        { cid: 30011008, num: 1, triphyNum: 600 }
    ];
    GoodsBoxConfig.rareCardList = [
        { cid: 30011004, num: 1, triphyNum: 300 },
        { cid: 30011009, num: 1, triphyNum: 700 }
    ];
    GoodsBoxConfig.epicCardList = [
        { cid: 30011010, num: 1, triphyNum: 800 }
    ];
    GoodsBoxConfig.diceList1 = [
        { cid: 20010003, num: 500, weight: 75 },
        { cid: 20010003, num: 1000, weight: 20 },
        { cid: 20010003, num: 2000, weight: 4 },
        { cid: 20010003, num: 3000, weight: 1 },
    ];
    GoodsBoxConfig.diceList2 = [
        { cardType: 0, num: 10, weight: 75 },
        { cardType: 0, num: 20, weight: 20 },
        { cardType: 0, num: 40, weight: 4 },
        { cardType: 0, num: 80, weight: 1 },
    ];
    GoodsBoxConfig.diceList3 = [
        { cardType: 0, num: 20, weight: 75 },
        { cardType: 0, num: 40, weight: 20 },
        { cardType: 1, num: 5, weight: 4 },
        { cardType: 1, num: 10, weight: 1 },
    ];
    GoodsBoxConfig.diceList4 = [
        { cid: 20010003, num: 500, weight: 8 },
        { cid: 20010003, num: 1000, weight: 60 },
        { cid: 20010003, num: 2000, weight: 30 },
        { cid: 20010003, num: 3000, weight: 2 },
    ];
    GoodsBoxConfig.diceList5 = [
        { cardType: 0, num: 10, weight: 8 },
        { cardType: 0, num: 20, weight: 60 },
        { cardType: 0, num: 40, weight: 30 },
        { cardType: 0, num: 80, weight: 2 },
    ];
    GoodsBoxConfig.diceList6 = [
        { cardType: 0, num: 20, weight: 8 },
        { cardType: 0, num: 40, weight: 60 },
        { cardType: 1, num: 5, weight: 30 },
        { cardType: 1, num: 10, weight: 2 },
    ];
    GoodsBoxConfig.diceList7 = [
        { cardType: 1, num: 20, weight: 75 },
        { cardType: 1, num: 40, weight: 20 },
        { cardType: 2, num: 1, weight: 4 },
        { cardType: 2, num: 2, weight: 1 },
    ];
    GoodsBoxConfig.diceList8 = [
        { cid: 20010003, num: 500, weight: 2 },
        { cid: 20010003, num: 1000, weight: 8 },
        { cid: 20010003, num: 2000, weight: 60 },
        { cid: 20010003, num: 3000, weight: 30 },
    ];
    GoodsBoxConfig.diceList9 = [
        { cardType: 0, num: 10, weight: 2 },
        { cardType: 0, num: 20, weight: 8 },
        { cardType: 0, num: 40, weight: 60 },
        { cardType: 0, num: 80, weight: 30 },
    ];
    GoodsBoxConfig.diceList10 = [
        { cardType: 0, num: 20, weight: 8 },
        { cardType: 0, num: 40, weight: 60 },
        { cardType: 1, num: 5, weight: 30 },
        { cardType: 1, num: 10, weight: 2 },
    ];
    GoodsBoxConfig.diceList11 = [
        { cardType: 1, num: 20, weight: 75 },
        { cardType: 1, num: 40, weight: 20 },
        { cardType: 2, num: 1, weight: 4 },
        { cardType: 2, num: 2, weight: 1 },
    ];
    GoodsBoxConfig.diceList12 = [
        { cardType: 1, num: 40, weight: 25 },
        { cardType: 2, num: 2, weight: 45 },
        { cardType: 2, num: 4, weight: 25 },
        { cardType: 2, num: 8, weight: 5 },
    ];
    GoodsBoxConfig.diceList13 = [
        { cid: 20010003, num: 2000, weight: 2 },
        { cid: 20010003, num: 3000, weight: 8 },
        { cid: 20010003, num: 5000, weight: 60 },
        { cid: 20010003, num: 10000, weight: 30 },
    ];
    GoodsBoxConfig.diceList14 = [
        { cardType: 0, num: 20, weight: 2 },
        { cardType: 0, num: 40, weight: 8 },
        { cardType: 0, num: 80, weight: 60 },
        { cardType: 0, num: 16, weight: 30 },
    ];
    GoodsBoxConfig.diceList15 = [
        { cardType: 0, num: 40, weight: 2 },
        { cardType: 0, num: 80, weight: 8 },
        { cardType: 1, num: 10, weight: 60 },
        { cardType: 1, num: 20, weight: 30 },
    ];
    GoodsBoxConfig.diceList16 = [
        { cardType: 1, num: 40, weight: 8 },
        { cardType: 1, num: 80, weight: 60 },
        { cardType: 2, num: 2, weight: 30 },
        { cardType: 2, num: 4, weight: 2 },
    ];
    GoodsBoxConfig.diceList17 = [
        { cardType: 1, num: 80, weight: 25 },
        { cardType: 2, num: 4, weight: 45 },
        { cardType: 2, num: 8, weight: 25 },
        { cardType: 2, num: 16, weight: 5 },
    ];
    GoodsBoxConfig.diceList18 = [
        { cid: 20010003, num: 3000, weight: 2 },
        { cid: 20010003, num: 5000, weight: 8 },
        { cid: 20010003, num: 10000, weight: 60 },
        { cid: 20010003, num: 15000, weight: 30 },
    ];
    GoodsBoxConfig.diceList19 = [
        { cardType: 0, num: 40, weight: 2 },
        { cardType: 0, num: 80, weight: 8 },
        { cardType: 0, num: 16, weight: 60 },
        { cardType: 0, num: 32, weight: 30 },
    ];
    GoodsBoxConfig.diceList20 = [
        { cardType: 0, num: 80, weight: 2 },
        { cardType: 0, num: 160, weight: 8 },
        { cardType: 1, num: 20, weight: 60 },
        { cardType: 1, num: 40, weight: 30 },
    ];
    GoodsBoxConfig.diceList21 = [
        { cardType: 1, num: 80, weight: 8 },
        { cardType: 1, num: 160, weight: 60 },
        { cardType: 2, num: 4, weight: 30 },
        { cardType: 2, num: 8, weight: 2 },
    ];
    GoodsBoxConfig.diceList22 = [
        { cardType: 1, num: 16, weight: 25 },
        { cardType: 2, num: 8, weight: 45 },
        { cardType: 2, num: 16, weight: 25 },
        { cardType: 2, num: 32, weight: 5 },
    ];

    class LeadEvent {
    }
    LeadEvent.LEAD_VIEW_SHOW = 'LEAD_VIEW_SHOW';
    LeadEvent.LEAD_UP_VIEW_SHOW = 'LEAD_UP_VIEW_SHOW';
    LeadEvent.LEAD_REWARD_REQUEST = 'LEAD_REWARD_REQUEST';
    LeadEvent.LEAD_REWARD_RESPONSE = 'LEAD_REWARD_RESPONSE';
    LeadEvent.LEAD_UP_REWARD_REQUEST = 'LEAD_UP_REWARD_REQUEST';
    LeadEvent.LEAD_UP_REWARD_RESPONSE = 'LEAD_UP_REWARD_RESPONSE';
    LeadEvent.LEAD_LIST_REQUEST = 'LEAD_LIST_REQUEST';
    LeadEvent.LEAD_LIST_RESPONSE = 'LEAD_LIST_RESPONSE';
    LeadEvent.LEAD_LIST_END = 'LEAD_LIST_END';
    LeadEvent.LEAD_PROSS_STOP = 'LEAD_PROSS_STOP';

    class PageCollectionView extends ui.page.PageCollectionUI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class PageCollectionViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageCollectionView;
            this.viewName = 'PageCollectionView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_scale.scale(PageConfig.pageScale, PageConfig.pageScale);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
        }
        okHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_ADD_MINI_VIEW);
        }
    }

    class PageGoldGunGetView extends ui.page.PageGoldGunGetUI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class PageGoldGunGetViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageGoldGunGetView;
            this.viewName = 'PageGoldGunGetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_use.on(Laya.Event.CLICK, this, this.adHandler);
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
                this.ui.img_bg.on(Laya.Event.CLICK, this, this.ad2Handler);
            }
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showDataHandler);
            this.showDataHandler();
        }
        showDataHandler() {
            this.vo = PageConfig.getGoldGun(PageModel.model.goldGunIndex);
            if (this.vo) {
                var co = this.vo.goods[0];
                var goodsVo = GoodsVoBuilder.getGoodsVo(co.cid);
                this.selectGoods = goodsVo;
                ProgressBarViewTool.setRectBarValue(this.ui.bar_ad, PageModel.model.goldGunNum / this.vo.num);
                this.ui.txt_tt.text = '观看' + (this.vo.num - PageModel.model.goldGunNum) + '个广告可领取奖励';
                this.ui.txt_bar.text = '' + MathUtil.int(PageModel.model.goldGunNum / this.vo.num * 100) + '%';
                if (this.selectGoods.type == 20) {
                    this.ui.box_money.visible = true;
                    this.ui.box_gun.visible = false;
                    this.ui.txt_info.text = '金币: ' + this.vo.goods[1].num;
                    this.ui.txt_info2.text = '钻石: ' + this.vo.goods[0].num;
                }
                else {
                    this.ui.box_money.visible = false;
                    this.ui.box_gun.visible = true;
                    this.elementVo = SceneVoBuilder.getElementVo(this.selectGoods.cid);
                    this.ui.txt_name.text = '' + this.selectGoods.name;
                    this.ui.img_1.skin = GoodsViewTool.getImgUrl(this.elementVo.cid);
                    this.ui.txt_att.text = "伤害: " + this.elementVo.att;
                    this.ui.txt_ctype.text = "类型: " + GoodsConfig.getCtypeText(this.elementVo.ctype);
                    this.ui.txt_quality.text = "品质: " + GoodsConfig.getQualityName(this.selectGoods.quality);
                    this.ui.txt_attBulletMax.text = "弹容: " + MathUtil.int(this.elementVo.attBulletMax);
                    this.ui.txt_attCd.text = "射速: " + MathUtil.number(this.elementVo.attCd / 1000) + "秒";
                    this.ui.txt_attAcc.text = "精度: " + MathUtil.number(this.elementVo.attAcc);
                    this.ui.txt_attBulletTime.text = '换弹: ' + MathUtil.number(this.elementVo.attBulletTime / 1000) + "秒";
                }
                this.nextGoldGunShow();
            }
            this.dispatchEvent(PageEvent.PAGE_GOLD_GUN_TYPE, { vo: this.vo });
        }
        nextGoldGunShow() {
            if (PageModel.model.goldGunIndex >= PageConfig.goldGunMax) {
                this.ui.box_next_gun.visible = false;
                this.ui.box_next_money.visible = false;
            }
            else {
                var index = PageModel.model.goldGunIndex + 1;
                var vo = PageConfig.getGoldGun(index);
                var goodsvo = GoodsVoBuilder.getGoodsVo(vo.goods[0].cid);
                if (goodsvo.type == 20) {
                    this.ui.box_next_money.visible = true;
                    this.ui.box_next_gun.visible = false;
                    this.ui.txt_num.text = '' + vo.goods[1].num;
                    this.ui.txt_num2.text = '' + vo.goods[0].num;
                }
                else {
                    this.ui.box_next_money.visible = false;
                    this.ui.box_next_gun.visible = true;
                    this.elementVo = SceneVoBuilder.getElementVo(vo.goods[0].cid);
                    this.ui.img_ico.skin = GoodsViewTool.getIcoUrl(goodsvo.cid);
                    ;
                    this.ui.txt_name2.text = goodsvo.name;
                    this.ui.txt_att2.text = '伤害: ' + this.elementVo.att;
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.videoHandler);
        }
        videoHandler() {
            PageModel.model.goldGunNum++;
            if (PageModel.model.goldGunNum >= this.vo.num) {
                PageModel.model.goldGunNum = 0;
                PageModel.model.goldGunIndex++;
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: this.vo.goods });
            }
            PageModel.model.saveData();
            this.showDataHandler();
            if (PageModel.model.goldGunIndex > PageConfig.goldGunMax) {
                this.close();
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageReward1View extends ui.page.PageReward1UI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class PageReward1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageReward1View;
            this.viewName = 'PageRewardView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.label = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_num);
            this.vo = this.data.list[0];
            this.ui.img_ad1.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_no.on(Laya.Event.CLICK, this, this.close);
            this.showDataHandler();
            this.showbtn();
            this.showBtnState();
        }
        showbtn() {
            this.ui.img_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_no.visible = true;
                });
            }
            else {
                this.ui.img_no.visible = true;
            }
        }
        showBtnState() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
        }
        showDataHandler() {
            this.checkIco();
            this.ui.img_ico.skin = this.vo.ico;
            this.ui.img_ico2.skin = GoodsConfig.getSegmentIcoUrl(this.vo.cid);
            this.showTextHandler();
        }
        showTextHandler() {
            if (this.vo.cid == 0) {
                this.label.text = '黄金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 1) {
                this.label.text = '白金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 2) {
                this.label.text = '史诗宝箱购买次数x' + this.vo.num;
            }
            else {
                this.label.text = this.vo.num;
            }
        }
        adHandler() {
            LogTool.log('666666666666666666666666666666666666666666666666666666666');
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.videoHandler();
            }
            else {
                AdTool.videoAdShow(this, this.videoHandler, 'supply@' + this.vo.cid);
            }
        }
        videoHandler() {
            if (this.vo.cid == 20010001) {
                PageModel.model.jinAdNum++;
            }
            if (this.vo.cid == 20010003) {
                PageModel.model.tongAdNum++;
            }
            if (this.vo.cid == 20010107) {
                PageModel.model.phyAdNum++;
            }
            PageModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: this.vo.cid, num: this.vo.num }] });
            this.close();
        }
        checkIco() {
            if (!this.vo.ico) {
                var vo = GoodsConfig.getGoodsByCid(this.vo.cid);
                this.vo.ico = vo.ico;
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageReward2View extends ui.page.PageReward2UI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class PageReward2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageReward2View;
            this.viewName = 'PageRewardView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.label = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_num);
            this.vo = this.data.list[0];
            this.ui.btn_ad.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_no.on(Laya.Event.CLICK, this, this.close);
            this.showDataHandler();
            this.showBtnState();
        }
        showBtnState() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
        }
        showDataHandler() {
            this.checkIco();
            this.ui.img_ico.skin = this.vo.ico;
            this.ui.img_ico2.skin = GoodsConfig.getSegmentIcoUrl(this.vo.cid);
            this.showTextHandler();
        }
        showTextHandler() {
            if (this.vo.cid == 0) {
                this.label.text = '黄金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 1) {
                this.label.text = '白金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 2) {
                this.label.text = '史诗宝箱购买次数x' + this.vo.num;
            }
            else {
                this.label.text = this.vo.num;
            }
        }
        adHandler() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.videoHandler();
            }
            else {
                AdTool.videoAdShow(this, this.videoHandler, 'supply@' + this.vo.cid);
            }
        }
        videoHandler() {
            if (this.vo.cid == 20010001) {
                PageModel.model.jinAdNum++;
            }
            if (this.vo.cid == 20010003) {
                PageModel.model.tongAdNum++;
            }
            if (this.vo.cid == 20010107) {
                PageModel.model.phyAdNum++;
            }
            PageModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: this.vo.cid, num: this.vo.num }] });
            this.close();
        }
        checkIco() {
            if (!this.vo.ico) {
                var vo = GoodsConfig.getGoodsByCid(this.vo.cid);
                this.vo.ico = vo.ico;
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageReward3View extends ui.page.PageReward3UI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class PageReward3ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageReward3View;
            this.viewName = 'PageRewardView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.label = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_num);
            this.vo = this.data.list[0];
            this.ui.img_ad1.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_no.on(Laya.Event.CLICK, this, this.close);
            this.showDataHandler();
            this.showbtn();
            this.showBtnState();
        }
        showbtn() {
            this.ui.img_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_no.visible = true;
                });
            }
            else {
                this.ui.img_no.visible = true;
            }
        }
        showBtnState() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
        }
        showDataHandler() {
            this.checkIco();
            this.ui.img_ico.skin = this.vo.ico;
            this.ui.img_ico2.skin = GoodsConfig.getSegmentIcoUrl(this.vo.cid);
            this.showTextHandler();
        }
        showTextHandler() {
            if (this.vo.cid == 0) {
                this.label.text = '黄金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 1) {
                this.label.text = '白金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 2) {
                this.label.text = '史诗宝箱购买次数x' + this.vo.num;
            }
            else {
                this.label.text = this.vo.num;
            }
        }
        adHandler() {
            LogTool.log('666666666666666666666666666666666666666666666666666666666');
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.videoHandler();
            }
            else {
                AdTool.videoAdShow(this, this.videoHandler, 'supply@' + this.vo.cid);
            }
        }
        videoHandler() {
            if (this.vo.cid == 20010001) {
                PageModel.model.jinAdNum++;
            }
            if (this.vo.cid == 20010003) {
                PageModel.model.tongAdNum++;
            }
            if (this.vo.cid == 20010107) {
                PageModel.model.phyAdNum++;
            }
            PageModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: this.vo.cid, num: this.vo.num }] });
            this.close();
        }
        checkIco() {
            if (!this.vo.ico) {
                var vo = GoodsConfig.getGoodsByCid(this.vo.cid);
                this.vo.ico = vo.ico;
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageReward4View extends ui.page.PageReward4UI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class PageReward4ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageReward4View;
            this.viewName = 'PageRewardView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.label = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_num);
            this.vo = this.data.list[0];
            this.ui.img_ad1.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_no.on(Laya.Event.CLICK, this, this.close);
            this.showDataHandler();
            this.showbtn();
            this.showBtnState();
        }
        showbtn() {
            this.ui.img_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_no.visible = true;
                });
            }
            else {
                this.ui.img_no.visible = true;
            }
        }
        showBtnState() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
        }
        showDataHandler() {
            this.checkIco();
            this.ui.img_ico.skin = this.vo.ico;
            this.ui.img_ico2.skin = GoodsConfig.getSegmentIcoUrl(this.vo.cid);
            this.showTextHandler();
        }
        showTextHandler() {
            if (this.vo.cid == 0) {
                this.label.text = '黄金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 1) {
                this.label.text = '白金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 2) {
                this.label.text = '史诗宝箱购买次数x' + this.vo.num;
            }
            else {
                this.label.text = this.vo.num;
            }
        }
        adHandler() {
            LogTool.log('666666666666666666666666666666666666666666666666666666666');
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.videoHandler();
            }
            else {
                AdTool.videoAdShow(this, this.videoHandler, 'supply@' + this.vo.cid);
            }
        }
        videoHandler() {
            if (this.vo.cid == 20010001) {
                PageModel.model.jinAdNum++;
            }
            if (this.vo.cid == 20010003) {
                PageModel.model.tongAdNum++;
            }
            if (this.vo.cid == 20010107) {
                PageModel.model.phyAdNum++;
            }
            PageModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: this.vo.cid, num: this.vo.num }] });
            this.close();
        }
        checkIco() {
            if (!this.vo.ico) {
                var vo = GoodsConfig.getGoodsByCid(this.vo.cid);
                this.vo.ico = vo.ico;
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageReward5View extends ui.page.PageReward5UI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class PageReward5ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageReward5View;
            this.viewName = 'PageRewardView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.label = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_num);
            this.vo = this.data.list[0];
            this.ui.img_ad1.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_no.on(Laya.Event.CLICK, this, this.close);
            this.showDataHandler();
            this.showbtn();
            this.showBtnState();
        }
        showbtn() {
            this.ui.img_no.visible = false;
            if (AdModel.model.isShieldCity == false) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_no.visible = true;
                });
            }
            else {
                this.ui.img_no.visible = true;
            }
        }
        showBtnState() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
        }
        showDataHandler() {
            this.checkIco();
            this.ui.img_ico.skin = this.vo.ico;
            this.ui.img_ico2.skin = GoodsConfig.getSegmentIcoUrl(this.vo.cid);
            this.showTextHandler();
        }
        showTextHandler() {
            if (this.vo.cid == 0) {
                this.label.text = '黄金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 1) {
                this.label.text = '白金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 2) {
                this.label.text = '史诗宝箱购买次数x' + this.vo.num;
            }
            else {
                this.label.text = this.vo.num;
            }
        }
        adHandler() {
            LogTool.log('666666666666666666666666666666666666666666666666666666666');
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.videoHandler();
            }
            else {
                AdTool.videoAdShow(this, this.videoHandler, 'supply@' + this.vo.cid);
            }
        }
        videoHandler() {
            if (this.vo.cid == 20010001) {
                PageModel.model.jinAdNum++;
            }
            if (this.vo.cid == 20010003) {
                PageModel.model.tongAdNum++;
            }
            if (this.vo.cid == 20010107) {
                PageModel.model.phyAdNum++;
            }
            PageModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: this.vo.cid, num: this.vo.num }] });
            this.close();
        }
        checkIco() {
            if (!this.vo.ico) {
                var vo = GoodsConfig.getGoodsByCid(this.vo.cid);
                this.vo.ico = vo.ico;
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageReward6View extends ui.page.PageReward6UI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class PageReward6ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageReward6View;
            this.viewName = 'PageRewardView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.label = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_num);
            this.vo = this.data.list[0];
            this.ui.img_ad1.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_no.on(Laya.Event.CLICK, this, this.close);
            if (AdModel.model.isShieldCity == false) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
            this.showDataHandler();
            this.showbtn();
            this.showBtnState();
        }
        showbtn() {
            this.ui.img_no.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_no.visible = true;
                });
            }
            else {
                this.ui.img_no.visible = true;
            }
        }
        showBtnState() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
        }
        showDataHandler() {
            this.checkIco();
            this.ui.img_ico.skin = this.vo.ico;
            this.ui.img_ico2.skin = GoodsConfig.getSegmentIcoUrl(this.vo.cid);
            this.showTextHandler();
        }
        showTextHandler() {
            if (this.vo.cid == 0) {
                this.label.text = '黄金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 1) {
                this.label.text = '白金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 2) {
                this.label.text = '史诗宝箱购买次数x' + this.vo.num;
            }
            else {
                this.label.text = this.vo.num;
            }
        }
        adHandler() {
            LogTool.log('666666666666666666666666666666666666666666666666666666666');
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.videoHandler();
            }
            else {
                AdTool.videoAdShow(this, this.videoHandler, 'supply@' + this.vo.cid);
            }
        }
        videoHandler() {
            if (this.vo.cid == 20010001) {
                PageModel.model.jinAdNum++;
            }
            if (this.vo.cid == 20010003) {
                PageModel.model.tongAdNum++;
            }
            if (this.vo.cid == 20010107) {
                PageModel.model.phyAdNum++;
            }
            PageModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: this.vo.cid, num: this.vo.num }] });
            this.close();
        }
        checkIco() {
            if (!this.vo.ico) {
                var vo = GoodsConfig.getGoodsByCid(this.vo.cid);
                this.vo.ico = vo.ico;
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageRewardView extends ui.page.PageRewardUI {
        constructor() {
            super();
            this.zOrder = 90;
        }
    }

    class PageRewardViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageRewardView;
            this.viewName = 'PageRewardView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.label = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_num);
            this.vo = this.data.list[0];
            this.ui.btn_ad.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_no.on(Laya.Event.CLICK, this, this.close);
            this.showDataHandler();
            this.showBtnState();
        }
        showBtnState() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.ui.img_ad.visible = false;
                this.ui.img_free.x = 58;
            }
            else {
                this.ui.img_ad.visible = true;
                this.ui.img_free.x = 92;
            }
        }
        showDataHandler() {
            this.checkIco();
            this.ui.img_ico.skin = this.vo.ico;
            this.ui.img_ico2.skin = GoodsConfig.getSegmentIcoUrl(this.vo.cid);
            this.showTextHandler();
        }
        showTextHandler() {
            if (this.vo.cid == 0) {
                this.label.text = '黄金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 1) {
                this.label.text = '白金宝箱购买次数x' + this.vo.num;
            }
            else if (this.vo.cid == 2) {
                this.label.text = '史诗宝箱购买次数x' + this.vo.num;
            }
            else {
                this.label.text = this.vo.num;
            }
        }
        adHandler() {
            if (this.vo.cid == 20010001 && PageModel.model.jinAdNum == 0 || this.vo.cid == 20010003 && PageModel.model.tongAdNum == 0 || this.vo.cid == 20010107 && PageModel.model.phyAdNum == 0) {
                this.videoHandler();
            }
            else {
                AdTool.videoAdShow(this, this.videoHandler, 'supply@' + this.vo.cid);
            }
        }
        videoHandler() {
            if (this.vo.cid == 20010001) {
                PageModel.model.jinAdNum++;
            }
            if (this.vo.cid == 20010003) {
                PageModel.model.tongAdNum++;
            }
            if (this.vo.cid == 20010107) {
                PageModel.model.phyAdNum++;
            }
            PageModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: this.vo.cid, num: this.vo.num }] });
            this.close();
        }
        checkIco() {
            if (!this.vo.ico) {
                var vo = GoodsConfig.getGoodsByCid(this.vo.cid);
                this.vo.ico = vo.ico;
            }
        }
        ad2Handler() {
            var rate = AdModel.model.getRate('shipin');
            if (RandomUtil.randomHit(rate)) {
                AdTool.videoAdShow(this, null);
            }
        }
    }

    class PageShareView extends ui.page.PageShareUI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class PageShareViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PageShareView;
            this.viewName = 'PageShareView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_scale.scale(PageConfig.pageScale, PageConfig.pageScale);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
        }
        okHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_SHOW);
        }
    }

    class LotteryEvent {
    }
    LotteryEvent.LOTTERY_VIEW_SHOW = 'LOTTERY_VIEW_SHOW';

    class PlayerEvent {
    }
    PlayerEvent.PLAYER_INFO_REQUEST = 'PLAYER_INFO_REQUEST';
    PlayerEvent.PLAYER_INFO_RESPONSE = 'PLAYER_INFO_RESPONSE';
    PlayerEvent.PLAYER_INFO_SET = 'PLAYER_INFO_SET';
    PlayerEvent.PLAYER_INFO_CHANGE = 'PLAYER_INFO_CHANGE';
    PlayerEvent.PLAYER_NAME_SET = 'PLAYER_NAME_SET';
    PlayerEvent.PLAYER_SET_VIEW_SHOW = 'PLAYER_SET_VIEW_SHOW';

    class RankEvent {
    }
    RankEvent.RANK_VIEW_SHOW = 'RANK_VIEW_SHOW';
    RankEvent.RANK_UP_VIEW_SHOW = 'RANK_UP_VIEW_SHOW';

    class SegmentEvent {
    }
    SegmentEvent.SEGMENT_VIEW_SHOW = 'SEGMENT_VIEW_SHOW';
    SegmentEvent.SEGMENT_LV_UP_VIEW_SHOW = 'SEGMENT_LV_UP_VIEW_SHOW';
    SegmentEvent.SEGMENT_TRIPHY_NUM_CHANGE = 'SEGMENT_TRIPHY_NUM_CHANGE';
    SegmentEvent.SEGMENT_LUCKY_BOX_VIEW_SHOW = 'SEGMENT_LUCKY_BOX_VIEW_SHOW';
    SegmentEvent.SEGMENT_LUCKY_BOX_VIEW_REFRESH = 'SEGMENT_LUCKY_BOX_VIEW_REFRESH';
    SegmentEvent.SEGMENT_REWARD_REPORT = 'SEGMENT_REWARD_REPORT';

    class SegmentConfig {
    }
    SegmentConfig.rewardList = [
        { name: '青铜Ⅲ', lv: 1, segment: 1, index: 1, unlockTroNum: 100, goods: { cid: 30011001, num: 1, goodsType: 'card' }, img: 'res/segment/1_3.png', isPopup: false },
        { name: '青铜Ⅲ', lv: 1.2, segment: 1, index: 2, unlockTroNum: 120, goods: { cid: 30011003, num: 30, goodsType: 'card' }, img: 'res/segment/1_3.png', isPopup: false },
        { name: '青铜Ⅲ', lv: 1.4, segment: 1, index: 3, unlockTroNum: 140, goods: { cid: 3001, num: 1, goodsType: 'box' }, img: 'res/segment/1_3.png', isPopup: false },
        { name: '青铜Ⅲ', lv: 1.6, segment: 1, index: 4, unlockTroNum: 160, goods: { cid: 30011002, num: 30, goodsType: 'card' }, img: 'res/segment/1_3.png', isPopup: true },
        { name: '青铜Ⅲ', lv: 1.8, segment: 1, index: 5, unlockTroNum: 180, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/1_3.png', isPopup: false },
        { name: '青铜Ⅱ', lv: 2, segment: 2, index: 6, unlockTroNum: 200, goods: { cid: 30011005, num: 1, goodsType: 'card' }, img: 'res/segment/1_2.png', isPopup: true },
        { name: '青铜Ⅱ', lv: 2.2, segment: 2, index: 7, unlockTroNum: 220, goods: { cid: 20010003, num: 2000, goodsType: 'tong' }, img: 'res/segment/1_2.png', isPopup: false },
        { name: '青铜Ⅱ', lv: 2.4, segment: 2, index: 8, unlockTroNum: 240, goods: { cid: 3001, num: 1, goodsType: 'box' }, img: 'res/segment/1_2.png', isPopup: false },
        { name: '青铜Ⅱ', lv: 2.6, segment: 2, index: 9, unlockTroNum: 260, goods: { cid: 30011001, num: 80, goodsType: 'card' }, img: 'res/segment/1_2.png', isPopup: true },
        { name: '青铜Ⅱ', lv: 2.8, segment: 2, index: 10, unlockTroNum: 280, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/1_2.png', isPopup: false },
        { name: '青铜Ⅰ', lv: 3, segment: 3, index: 11, unlockTroNum: 300, goods: { cid: 30011004, num: 1, goodsType: 'card' }, img: 'res/segment/1_1.png', isPopup: true },
        { name: '青铜Ⅰ', lv: 3.2, segment: 3, index: 12, unlockTroNum: 320, goods: { cid: 20010003, num: 3000, goodsType: 'tong' }, img: 'res/segment/1_1.png', isPopup: false },
        { name: '青铜Ⅰ', lv: 3.4, segment: 3, index: 13, unlockTroNum: 340, goods: { cid: 3001, num: 1, goodsType: 'box' }, img: 'res/segment/1_1.png', isPopup: false },
        { name: '青铜Ⅰ', lv: 3.6, segment: 3, index: 14, unlockTroNum: 360, goods: { cid: 30011003, num: 80, goodsType: 'card' }, img: 'res/segment/1_1.png', isPopup: true },
        { name: '青铜Ⅰ', lv: 3.8, segment: 3, index: 15, unlockTroNum: 380, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/1_1.png', isPopup: false },
        { name: '白银Ⅲ', lv: 4, segment: 4, index: 16, unlockTroNum: 400, goods: { cid: 30011006, num: 1, goodsType: 'card' }, img: 'res/segment/2_3.png', isPopup: true },
        { name: '白银Ⅲ', lv: 4.2, segment: 4, index: 17, unlockTroNum: 420, goods: { cid: 20010001, num: 300, goodsType: 'jin' }, img: 'res/segment/2_3.png', isPopup: false },
        { name: '白银Ⅲ', lv: 4.4, segment: 4, index: 18, unlockTroNum: 440, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/2_3.png', isPopup: false },
        { name: '白银Ⅲ', lv: 4.6, segment: 4, index: 19, unlockTroNum: 460, goods: { cid: 30011002, num: 80, goodsType: 'card' }, img: 'res/segment/2_3.png', isPopup: true },
        { name: '白银Ⅲ', lv: 4.8, segment: 4, index: 20, unlockTroNum: 480, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/2_3.png', isPopup: false },
        { name: '白银Ⅱ', lv: 5, segment: 5, index: 21, unlockTroNum: 500, goods: { cid: 30011007, num: 1, goodsType: 'card' }, img: 'res/segment/2_2.png', isPopup: true },
        { name: '白银Ⅱ', lv: 5.2, segment: 5, index: 22, unlockTroNum: 520, goods: { cid: 20010001, num: 300, goodsType: 'jin' }, img: 'res/segment/2_2.png', isPopup: false },
        { name: '白银Ⅱ', lv: 5.4, segment: 5, index: 23, unlockTroNum: 540, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/2_2.png', isPopup: false },
        { name: '白银Ⅱ', lv: 5.6, segment: 5, index: 24, unlockTroNum: 560, goods: { cid: 30011005, num: 80, goodsType: 'card' }, img: 'res/segment/2_2.png', isPopup: true },
        { name: '白银Ⅱ', lv: 5.8, segment: 5, index: 25, unlockTroNum: 580, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/2_2.png', isPopup: false },
        { name: '白银Ⅰ', lv: 6, segment: 6, index: 26, unlockTroNum: 600, goods: { cid: 30011008, num: 1, goodsType: 'card' }, img: 'res/segment/2_1.png', isPopup: true },
        { name: '白银Ⅰ', lv: 6.2, segment: 6, index: 27, unlockTroNum: 620, goods: { cid: 20010001, num: 300, goodsType: 'jin' }, img: 'res/segment/2_1.png', isPopup: false },
        { name: '白银Ⅰ', lv: 6.4, segment: 6, index: 28, unlockTroNum: 640, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/2_1.png', isPopup: false },
        { name: '白银Ⅰ', lv: 6.6, segment: 6, index: 29, unlockTroNum: 660, goods: { cid: 30011004, num: 20, goodsType: 'card' }, img: 'res/segment/2_1.png', isPopup: true },
        { name: '白银Ⅰ', lv: 6.8, segment: 6, index: 30, unlockTroNum: 680, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/2_1.png', isPopup: false },
        { name: '黄金Ⅳ', lv: 7, segment: 7, index: 31, unlockTroNum: 700, goods: { cid: 30011009, num: 1, goodsType: 'card' }, img: 'res/segment/3_4.png', isPopup: true },
        { name: '黄金Ⅳ', lv: 7.2, segment: 7, index: 32, unlockTroNum: 720, goods: { cid: 20010003, num: 5000, goodsType: 'tong' }, img: 'res/segment/3_4.png', isPopup: false },
        { name: '黄金Ⅳ', lv: 7.4, segment: 7, index: 33, unlockTroNum: 740, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/3_4.png', isPopup: false },
        { name: '黄金Ⅳ', lv: 7.6, segment: 7, index: 34, unlockTroNum: 760, goods: { cid: 30011006, num: 80, goodsType: 'card' }, img: 'res/segment/3_4.png', isPopup: true },
        { name: '黄金Ⅳ', lv: 7.8, segment: 7, index: 35, unlockTroNum: 780, goods: { cid: 30011001, num: 120, goodsType: 'card' }, img: 'res/segment/3_4.png', isPopup: true },
        { name: '黄金Ⅲ', lv: 8, segment: 8, index: 36, unlockTroNum: 800, goods: { cid: 30011010, num: 1, goodsType: 'card' }, img: 'res/segment/3_3.png', isPopup: true },
        { name: '黄金Ⅲ', lv: 8.2, segment: 8, index: 37, unlockTroNum: 820, goods: { cid: 20010003, num: 5000, goodsType: 'tong' }, img: 'res/segment/3_3.png', isPopup: false },
        { name: '黄金Ⅲ', lv: 8.4, segment: 8, index: 38, unlockTroNum: 840, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/3_3.png', isPopup: false },
        { name: '黄金Ⅲ', lv: 8.6, segment: 8, index: 39, unlockTroNum: 860, goods: { cid: 30011007, num: 80, goodsType: 'card' }, img: 'res/segment/3_3.png', isPopup: true },
        { name: '黄金Ⅲ', lv: 8.8, segment: 8, index: 40, unlockTroNum: 880, goods: { cid: 30011003, num: 120, goodsType: 'card' }, img: 'res/segment/3_3.png', isPopup: true },
        { name: '黄金Ⅱ', lv: 9, segment: 9, index: 41, unlockTroNum: 900, goods: { cid: 30011011, num: 1, goodsType: 'card' }, img: 'res/segment/3_2.png', isPopup: true },
        { name: '黄金Ⅱ', lv: 9.2, segment: 9, index: 42, unlockTroNum: 920, goods: { cid: 20010003, num: 5000, goodsType: 'tong' }, img: 'res/segment/3_2.png', isPopup: false },
        { name: '黄金Ⅱ', lv: 9.4, segment: 9, index: 43, unlockTroNum: 940, goods: { cid: 3002, num: 1, goodsType: 'box' }, img: 'res/segment/3_2.png', isPopup: false },
        { name: '黄金Ⅱ', lv: 9.6, segment: 9, index: 44, unlockTroNum: 960, goods: { cid: 30011008, num: 80, goodsType: 'card' }, img: 'res/segment/3_2.png', isPopup: true },
        { name: '黄金Ⅱ', lv: 9.8, segment: 9, index: 45, unlockTroNum: 980, goods: { cid: 30011002, num: 120, goodsType: 'card' }, img: 'res/segment/3_2.png', isPopup: true },
        { name: '黄金Ⅰ', lv: 10, segment: 10, index: 46, unlockTroNum: 1000, goods: { cid: 30011012, num: 1, goodsType: 'card' }, img: 'res/segment/3_1.png', isPopup: true },
        { name: '黄金Ⅰ', lv: 10.2, segment: 10, index: 47, unlockTroNum: 1020, goods: { cid: 20010001, num: 600, goodsType: 'jin' }, img: 'res/segment/3_1.png', isPopup: false },
        { name: '黄金Ⅰ', lv: 10.4, segment: 10, index: 48, unlockTroNum: 1040, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/3_1.png', isPopup: false },
        { name: '黄金Ⅰ', lv: 10.6, segment: 10, index: 49, unlockTroNum: 1060, goods: { cid: 30011009, num: 20, goodsType: 'card' }, img: 'res/segment/3_1.png', isPopup: true },
        { name: '黄金Ⅰ', lv: 10.8, segment: 10, index: 50, unlockTroNum: 1080, goods: { cid: 30011005, num: 120, goodsType: 'card' }, img: 'res/segment/3_1.png', isPopup: true },
        { name: '铂金Ⅳ', lv: 11, segment: 11, index: 51, unlockTroNum: 1100, goods: { cid: 30011013, num: 1, goodsType: 'card' }, img: 'res/segment/4_4.png', isPopup: true },
        { name: '铂金Ⅳ', lv: 11.2, segment: 11, index: 52, unlockTroNum: 1120, goods: { cid: 20010001, num: 600, goodsType: 'jin' }, img: 'res/segment/4_4.png', isPopup: false },
        { name: '铂金Ⅳ', lv: 11.4, segment: 11, index: 53, unlockTroNum: 1140, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/4_4.png', isPopup: false },
        { name: '铂金Ⅳ', lv: 11.6, segment: 11, index: 54, unlockTroNum: 1160, goods: { cid: 30011010, num: 4, goodsType: 'card' }, img: 'res/segment/4_4.png', isPopup: true },
        { name: '铂金Ⅳ', lv: 11.8, segment: 11, index: 55, unlockTroNum: 1180, goods: { cid: 30011004, num: 30, goodsType: 'card' }, img: 'res/segment/4_4.png', isPopup: true },
        { name: '铂金Ⅲ', lv: 12, segment: 12, index: 56, unlockTroNum: 1200, goods: { cid: 30011014, num: 1, goodsType: 'card' }, img: 'res/segment/4_3.png', isPopup: true },
        { name: '铂金Ⅲ', lv: 12.2, segment: 12, index: 57, unlockTroNum: 1220, goods: { cid: 20010001, num: 600, goodsType: 'jin' }, img: 'res/segment/4_3.png', isPopup: false },
        { name: '铂金Ⅲ', lv: 12.4, segment: 12, index: 58, unlockTroNum: 1240, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/4_3.png', isPopup: false },
        { name: '铂金Ⅲ', lv: 12.6, segment: 12, index: 59, unlockTroNum: 1260, goods: { cid: 30011011, num: 20, goodsType: 'card' }, img: 'res/segment/4_3.png', isPopup: true },
        { name: '铂金Ⅲ', lv: 12.8, segment: 12, index: 60, unlockTroNum: 1280, goods: { cid: 30011006, num: 120, goodsType: 'card' }, img: 'res/segment/4_3.png', isPopup: true },
        { name: '铂金Ⅱ', lv: 1, segment: 13, index: 61, unlockTroNum: 1300, goods: { cid: 30011015, num: 1, goodsType: 'card' }, img: 'res/segment/4_2.png', isPopup: true },
        { name: '铂金Ⅱ', lv: 13.2, segment: 13, index: 62, unlockTroNum: 1320, goods: { cid: 20010003, num: 8000, goodsType: 'tong' }, img: 'res/segment/4_2.png', isPopup: false },
        { name: '铂金Ⅱ', lv: 13.4, segment: 13, index: 63, unlockTroNum: 1340, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/4_2.png', isPopup: false },
        { name: '铂金Ⅱ', lv: 13.6, segment: 13, index: 64, unlockTroNum: 1360, goods: { cid: 30011012, num: 20, goodsType: 'card' }, img: 'res/segment/4_2.png', isPopup: true },
        { name: '铂金Ⅱ', lv: 13.8, segment: 13, index: 65, unlockTroNum: 1380, goods: { cid: 30011007, num: 120, goodsType: 'card' }, img: 'res/segment/4_2.png', isPopup: true },
        { name: '铂金Ⅰ', lv: 14, segment: 14, index: 66, unlockTroNum: 1400, goods: { cid: 30011016, num: 1, goodsType: 'card' }, img: 'res/segment/4_1.png', isPopup: true },
        { name: '铂金Ⅰ', lv: 14.2, segment: 14, index: 67, unlockTroNum: 1420, goods: { cid: 20010003, num: 8000, goodsType: 'tong' }, img: 'res/segment/4_1.png', isPopup: false },
        { name: '铂金Ⅰ', lv: 14.4, segment: 14, index: 68, unlockTroNum: 1440, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/4_1.png', isPopup: false },
        { name: '铂金Ⅰ', lv: 14.6, segment: 14, index: 69, unlockTroNum: 1460, goods: { cid: 30011013, num: 20, goodsType: 'card' }, img: 'res/segment/4_1.png', isPopup: true },
        { name: '铂金Ⅰ', lv: 14.8, segment: 14, index: 70, unlockTroNum: 1480, goods: { cid: 30011008, num: 120, goodsType: 'card' }, img: 'res/segment/4_1.png', isPopup: true },
        { name: '钻石Ⅴ', lv: 15, segment: 15, index: 71, unlockTroNum: 1500, goods: { cid: 30011017, num: 1, goodsType: 'card' }, img: 'res/segment/5_5.png', isPopup: true },
        { name: '钻石Ⅴ', lv: 15.2, segment: 15, index: 72, unlockTroNum: 1520, goods: { cid: 20010003, num: 8000, goodsType: 'tong' }, img: 'res/segment/5_5.png', isPopup: false },
        { name: '钻石Ⅴ', lv: 15.4, segment: 15, index: 73, unlockTroNum: 1540, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/5_5.png', isPopup: false },
        { name: '钻石Ⅴ', lv: 15.6, segment: 15, index: 74, unlockTroNum: 1560, goods: { cid: 30011014, num: 4, goodsType: 'card' }, img: 'res/segment/5_5.png', isPopup: true },
        { name: '钻石Ⅴ', lv: 15.8, segment: 15, index: 75, unlockTroNum: 1580, goods: { cid: 30011009, num: 30, goodsType: 'card' }, img: 'res/segment/5_5.png', isPopup: true },
        { name: '钻石Ⅳ', lv: 16, segment: 16, index: 76, unlockTroNum: 1600, goods: { cid: 30011004, num: 20, goodsType: 'card' }, img: 'res/segment/5_4.png', isPopup: true },
        { name: '钻石Ⅳ', lv: 16.2, segment: 16, index: 77, unlockTroNum: 1620, goods: { cid: 20010001, num: 800, goodsType: 'jin' }, img: 'res/segment/5_4.png', isPopup: false },
        { name: '钻石Ⅳ', lv: 16.4, segment: 16, index: 78, unlockTroNum: 1640, goods: { cid: 20010003, num: 12000, goodsType: 'tong' }, img: 'res/segment/5_4.png', isPopup: false },
        { name: '钻石Ⅳ', lv: 16.6, segment: 16, index: 79, unlockTroNum: 1660, goods: { cid: 30011015, num: 4, goodsType: 'card' }, img: 'res/segment/5_4.png', isPopup: true },
        { name: '钻石Ⅳ', lv: 16.8, segment: 16, index: 80, unlockTroNum: 1680, goods: { cid: 30011010, num: 6, goodsType: 'card' }, img: 'res/segment/5_4.png', isPopup: true },
        { name: '钻石Ⅲ', lv: 17, segment: 17, index: 81, unlockTroNum: 1700, goods: { cid: 30011009, num: 20, goodsType: 'card' }, img: 'res/segment/5_3.png', isPopup: true },
        { name: '钻石Ⅲ', lv: 17.2, segment: 17, index: 82, unlockTroNum: 1720, goods: { cid: 20010001, num: 800, goodsType: 'jin' }, img: 'res/segment/5_3.png', isPopup: false },
        { name: '钻石Ⅲ', lv: 17.4, segment: 17, index: 83, unlockTroNum: 1740, goods: { cid: 20010003, num: 12000, goodsType: 'tong' }, img: 'res/segment/5_3.png', isPopup: false },
        { name: '钻石Ⅲ', lv: 17.6, segment: 17, index: 84, unlockTroNum: 1760, goods: { cid: 30011016, num: 4, goodsType: 'card' }, img: 'res/segment/5_3.png', isPopup: true },
        { name: '钻石Ⅲ', lv: 17.8, segment: 17, index: 85, unlockTroNum: 1780, goods: { cid: 30011011, num: 6, goodsType: 'card' }, img: 'res/segment/5_3.png', isPopup: true },
        { name: '钻石Ⅱ', lv: 18, segment: 18, index: 86, unlockTroNum: 1800, goods: { cid: 30011010, num: 4, goodsType: 'card' }, img: 'res/segment/5_2.png', isPopup: true },
        { name: '钻石Ⅱ', lv: 18.2, segment: 18, index: 87, unlockTroNum: 1820, goods: { cid: 20010001, num: 800, goodsType: 'jin' }, img: 'res/segment/5_2.png', isPopup: false },
        { name: '钻石Ⅱ', lv: 18.4, segment: 18, index: 88, unlockTroNum: 1840, goods: { cid: 20010003, num: 12000, goodsType: 'tong' }, img: 'res/segment/5_2.png', isPopup: false },
        { name: '钻石Ⅱ', lv: 18.6, segment: 18, index: 89, unlockTroNum: 1860, goods: { cid: 30011017, num: 4, goodsType: 'card' }, img: 'res/segment/5_2.png', isPopup: true },
        { name: '钻石Ⅱ', lv: 18.8, segment: 18, index: 90, unlockTroNum: 1880, goods: { cid: 30011012, num: 30, goodsType: 'card' }, img: 'res/segment/5_2.png', isPopup: true },
        { name: '钻石Ⅰ', lv: 19, segment: 19, index: 91, unlockTroNum: 1900, goods: { cid: 30011011, num: 20, goodsType: 'card' }, img: 'res/segment/5_1.png', isPopup: true },
        { name: '钻石Ⅰ', lv: 19.2, segment: 19, index: 92, unlockTroNum: 1920, goods: { cid: 20010003, num: 15000, goodsType: 'tong' }, img: 'res/segment/5_1.png', isPopup: false },
        { name: '钻石Ⅰ', lv: 19.4, segment: 19, index: 93, unlockTroNum: 1940, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/5_1.png', isPopup: false },
        { name: '钻石Ⅰ', lv: 19.6, segment: 19, index: 94, unlockTroNum: 1960, goods: { cid: 3004, num: 1, goodsType: 'box' }, img: 'res/segment/5_1.png', isPopup: false },
        { name: '钻石Ⅰ', lv: 19.8, segment: 19, index: 95, unlockTroNum: 1980, goods: { cid: 30011013, num: 30, goodsType: 'card' }, img: 'res/segment/5_1.png', isPopup: true },
        { name: '至尊Ⅴ', lv: 20, segment: 20, index: 96, unlockTroNum: 2000, goods: { cid: 30011012, num: 20, goodsType: 'card' }, img: 'res/segment/6_5.png', isPopup: true },
        { name: '至尊Ⅴ', lv: 20.2, segment: 20, index: 97, unlockTroNum: 2020, goods: { cid: 20010003, num: 15000, goodsType: 'tong' }, img: 'res/segment/6_5.png', isPopup: false },
        { name: '至尊Ⅴ', lv: 20.4, segment: 20, index: 98, unlockTroNum: 2040, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/6_5.png', isPopup: false },
        { name: '至尊Ⅴ', lv: 20.6, segment: 20, index: 99, unlockTroNum: 2060, goods: { cid: 3004, num: 1, goodsType: 'box' }, img: 'res/segment/6_5.png', isPopup: false },
        { name: '至尊Ⅴ', lv: 20.8, segment: 20, index: 100, unlockTroNum: 2080, goods: { cid: 30011014, num: 6, goodsType: 'card' }, img: 'res/segment/6_5.png', isPopup: true },
        { name: '至尊Ⅳ', lv: 21, segment: 21, index: 101, unlockTroNum: 2100, goods: { cid: 30011013, num: 20, goodsType: 'card' }, img: 'res/segment/6_4.png', isPopup: true },
        { name: '至尊Ⅳ', lv: 21.2, segment: 21, index: 102, unlockTroNum: 2120, goods: { cid: 20010003, num: 15000, goodsType: 'tong' }, img: 'res/segment/6_4.png', isPopup: false },
        { name: '至尊Ⅳ', lv: 21.4, segment: 21, index: 103, unlockTroNum: 2140, goods: { cid: 3003, num: 1, goodsType: 'box' }, img: 'res/segment/6_4.png', isPopup: false },
        { name: '至尊Ⅳ', lv: 21.6, segment: 21, index: 104, unlockTroNum: 2160, goods: { cid: 3004, num: 1, goodsType: 'box' }, img: 'res/segment/6_4.png', isPopup: false },
        { name: '至尊Ⅳ', lv: 21.8, segment: 21, index: 105, unlockTroNum: 2180, goods: { cid: 30011015, num: 6, goodsType: 'card' }, img: 'res/segment/6_4.png', isPopup: true },
        { name: '至尊Ⅲ', lv: 22, segment: 22, index: 106, unlockTroNum: 2200, goods: { cid: 30011014, num: 4, goodsType: 'card' }, img: 'res/segment/6_3.png', isPopup: true },
        { name: '至尊Ⅲ', lv: 22.2, segment: 22, index: 107, unlockTroNum: 2220, goods: { cid: 3004, num: 1, goodsType: 'box' }, img: 'res/segment/6_3.png', isPopup: false },
        { name: '至尊Ⅲ', lv: 22.4, segment: 22, index: 108, unlockTroNum: 2240, goods: { cid: 20010003, num: 20000, goodsType: 'tong' }, img: 'res/segment/6_3.png', isPopup: false },
        { name: '至尊Ⅲ', lv: 22.6, segment: 22, index: 109, unlockTroNum: 2260, goods: { cid: 30011004, num: 30, goodsType: 'card' }, img: 'res/segment/6_3.png', isPopup: true },
        { name: '至尊Ⅲ', lv: 22.8, segment: 22, index: 110, unlockTroNum: 2280, goods: { cid: 30011016, num: 6, goodsType: 'card' }, img: 'res/segment/6_3.png', isPopup: true },
        { name: '至尊Ⅱ', lv: 23, segment: 23, index: 111, unlockTroNum: 2300, goods: { cid: 30011015, num: 4, goodsType: 'card' }, img: 'res/segment/6_2.png', isPopup: true },
        { name: '至尊Ⅱ', lv: 23.2, segment: 23, index: 112, unlockTroNum: 2320, goods: { cid: 3004, num: 1, goodsType: 'box' }, img: 'res/segment/6_2.png', isPopup: false },
        { name: '至尊Ⅱ', lv: 23.4, segment: 23, index: 113, unlockTroNum: 2340, goods: { cid: 20010003, num: 20000, goodsType: 'tong' }, img: 'res/segment/6_2.png', isPopup: false },
        { name: '至尊Ⅱ', lv: 23.6, segment: 23, index: 114, unlockTroNum: 2360, goods: { cid: 30011009, num: 30, goodsType: 'card' }, img: 'res/segment/6_2.png', isPopup: true },
        { name: '至尊Ⅱ', lv: 23.8, segment: 23, index: 115, unlockTroNum: 2380, goods: { cid: 30011017, num: 6, goodsType: 'card' }, img: 'res/segment/6_2.png', isPopup: true },
        { name: '至尊Ⅰ', lv: 24, segment: 24, index: 116, unlockTroNum: 2400, goods: { cid: 30011016, num: 4, goodsType: 'card' }, img: 'res/segment/6_1.png', isPopup: true },
        { name: '至尊Ⅰ', lv: 24.2, segment: 24, index: 117, unlockTroNum: 2420, goods: { cid: 3004, num: 1, goodsType: 'box' }, img: 'res/segment/6_1.png', isPopup: false },
        { name: '至尊Ⅰ', lv: 24.4, segment: 24, index: 118, unlockTroNum: 2440, goods: { cid: 20010003, num: 20000, goodsType: 'tong' }, img: 'res/segment/6_1.png', isPopup: false },
        { name: '至尊Ⅰ', lv: 24.6, segment: 24, index: 119, unlockTroNum: 2460, goods: { cid: 30011010, num: 6, goodsType: 'card' }, img: 'res/segment/6_1.png', isPopup: true },
        { name: '至尊Ⅰ', lv: 24.8, segment: 24, index: 120, unlockTroNum: 2480, goods: { cid: 30011004, num: 45, goodsType: 'card' }, img: 'res/segment/6_1.png', isPopup: true },
        { name: '王者Ⅵ', lv: 25, segment: 25, index: 121, unlockTroNum: 2500, goods: { cid: 30011017, num: 6, goodsType: 'card' }, img: 'res/segment/7_6.png', isPopup: true },
        { name: '王者Ⅵ', lv: 25.2, segment: 25, index: 122, unlockTroNum: 2520, goods: { cid: 30011009, num: 45, goodsType: 'card' }, img: 'res/segment/7_6.png', isPopup: true },
        { name: '王者Ⅵ', lv: 25.4, segment: 25, index: 123, unlockTroNum: 2540, goods: { cid: 30011010, num: 6, goodsType: 'card' }, img: 'res/segment/7_6.png', isPopup: true },
        { name: '王者Ⅵ', lv: 25.6, segment: 25, index: 124, unlockTroNum: 2560, goods: { cid: 30011011, num: 45, goodsType: 'card' }, img: 'res/segment/7_6.png', isPopup: true },
        { name: '王者Ⅵ', lv: 25.8, segment: 25, index: 125, unlockTroNum: 2580, goods: { cid: 30011012, num: 45, goodsType: 'card' }, img: 'res/segment/7_6.png', isPopup: true },
        { name: '王者Ⅴ', lv: 26, segment: 26, index: 126, unlockTroNum: 2600, goods: { cid: 30011013, num: 45, goodsType: 'card' }, img: 'res/segment/7_5.png', isPopup: true },
        { name: '王者Ⅴ', lv: 26.2, segment: 26, index: 127, unlockTroNum: 2620, goods: { cid: 30011014, num: 6, goodsType: 'card' }, img: 'res/segment/7_5.png', isPopup: true },
        { name: '王者Ⅴ', lv: 26.4, segment: 26, index: 128, unlockTroNum: 2640, goods: { cid: 30011015, num: 6, goodsType: 'card' }, img: 'res/segment/7_5.png', isPopup: true },
        { name: '王者Ⅴ', lv: 26.6, segment: 26, index: 129, unlockTroNum: 2660, goods: { cid: 30011016, num: 6, goodsType: 'card' }, img: 'res/segment/7_5.png', isPopup: true },
        { name: '王者Ⅴ', lv: 26.8, segment: 26, index: 130, unlockTroNum: 2680, goods: { cid: 30011017, num: 6, goodsType: 'card' }, img: 'res/segment/7_5.png', isPopup: true },
        { name: '王者Ⅳ', lv: 27, segment: 27, index: 131, unlockTroNum: 2700, goods: { cid: 3005, num: 1, goodsType: 'box' }, img: 'res/segment/7_4.png', isPopup: false },
        { name: '王者Ⅳ', lv: 27.2, segment: 27, index: 132, unlockTroNum: 2720, goods: { cid: 30011001, num: 300, goodsType: 'card' }, img: 'res/segment/7_4.png', isPopup: true },
        { name: '王者Ⅳ', lv: 27.4, segment: 27, index: 133, unlockTroNum: 2740, goods: { cid: 30011007, num: 300, goodsType: 'card' }, img: 'res/segment/7_4.png', isPopup: true },
        { name: '王者Ⅳ', lv: 27.6, segment: 27, index: 134, unlockTroNum: 2760, goods: { cid: 30011011, num: 75, goodsType: 'card' }, img: 'res/segment/7_4.png', isPopup: true },
        { name: '王者Ⅳ', lv: 27.8, segment: 27, index: 135, unlockTroNum: 2780, goods: { cid: 30011010, num: 10, goodsType: 'card' }, img: 'res/segment/7_4.png', isPopup: true },
        { name: '王者Ⅲ', lv: 28, segment: 28, index: 136, unlockTroNum: 2800, goods: { cid: 3005, num: 1, goodsType: 'box' }, img: 'res/segment/7_3.png', isPopup: false },
        { name: '王者Ⅲ', lv: 28.2, segment: 28, index: 137, unlockTroNum: 2820, goods: { cid: 30011003, num: 300, goodsType: 'card' }, img: 'res/segment/7_3.png', isPopup: true },
        { name: '王者Ⅲ', lv: 28.4, segment: 28, index: 138, unlockTroNum: 2840, goods: { cid: 30011008, num: 300, goodsType: 'card' }, img: 'res/segment/7_3.png', isPopup: true },
        { name: '王者Ⅲ', lv: 28.6, segment: 28, index: 139, unlockTroNum: 2860, goods: { cid: 30011012, num: 75, goodsType: 'card' }, img: 'res/segment/7_3.png', isPopup: true },
        { name: '王者Ⅲ', lv: 28.8, segment: 28, index: 140, unlockTroNum: 2880, goods: { cid: 30011014, num: 10, goodsType: 'card' }, img: 'res/segment/7_3.png', isPopup: true },
        { name: '王者Ⅱ', lv: 29, segment: 29, index: 141, unlockTroNum: 2900, goods: { cid: 3005, num: 1, goodsType: 'box' }, img: 'res/segment/7_2.png', isPopup: false },
        { name: '王者Ⅱ', lv: 29.2, segment: 29, index: 142, unlockTroNum: 2920, goods: { cid: 30011002, num: 300, goodsType: 'card' }, img: 'res/segment/7_2.png', isPopup: true },
        { name: '王者Ⅱ', lv: 29.4, segment: 29, index: 143, unlockTroNum: 2940, goods: { cid: 30011004, num: 75, goodsType: 'card' }, img: 'res/segment/7_2.png', isPopup: true },
        { name: '王者Ⅱ', lv: 29.6, segment: 29, index: 144, unlockTroNum: 2960, goods: { cid: 30011013, num: 75, goodsType: 'card' }, img: 'res/segment/7_2.png', isPopup: true },
        { name: '王者Ⅱ', lv: 29.8, segment: 29, index: 145, unlockTroNum: 2980, goods: { cid: 30011015, num: 10, goodsType: 'card' }, img: 'res/segment/7_2.png', isPopup: true },
        { name: '王者Ⅰ', lv: 30, segment: 30, index: 146, unlockTroNum: 3000, goods: { cid: 30011006, num: 300, goodsType: 'card' }, img: 'res/segment/7_1.png', isPopup: true },
        { name: '王者Ⅰ', lv: 30.2, segment: 30, index: 147, unlockTroNum: 3020, goods: { cid: 30011005, num: 300, goodsType: 'card' }, img: 'res/segment/7_1.png', isPopup: true },
        { name: '王者Ⅰ', lv: 30.4, segment: 30, index: 148, unlockTroNum: 3040, goods: { cid: 30011009, num: 75, goodsType: 'card' }, img: 'res/segment/7_1.png', isPopup: true },
        { name: '王者Ⅰ', lv: 30.6, segment: 30, index: 149, unlockTroNum: 3060, goods: { cid: 30011016, num: 10, goodsType: 'card' }, img: 'res/segment/7_1.png', isPopup: true },
        { name: '王者Ⅰ', lv: 30.8, segment: 30, index: 150, unlockTroNum: 3080, goods: { cid: 30011017, num: 10, goodsType: 'card' }, img: 'res/segment/7_1.png', isPopup: true },
    ];

    class SegmentTool {
        static getSegment(triphyNum) {
            var rewardList = SegmentConfig.rewardList;
            for (var k in rewardList) {
                if (rewardList[k]) {
                    if (rewardList[k].unlockTroNum >= triphyNum) {
                        return rewardList[k].segment;
                    }
                }
            }
            return 1;
        }
        static getSegmentName(segment) {
            var rewardList = SegmentConfig.rewardList;
            for (var k in rewardList) {
                if (rewardList[k]) {
                    if (rewardList[k].segment == segment) {
                        return rewardList[k].name;
                    }
                }
            }
            return '';
        }
        static getSegmentImg(segment) {
            var rewardList = SegmentConfig.rewardList;
            for (var k in rewardList) {
                if (rewardList[k]) {
                    if (rewardList[k].segment == segment) {
                        return rewardList[k].img;
                    }
                }
            }
            return '';
        }
        static getCompeletSegmentVo() {
            var list = SegmentConfig.rewardList;
            for (var k in list) {
                var segmentVo = list[k];
                if (SegmentModel.model.maxTriphyNum >= segmentVo.unlockTroNum) {
                    if (SegmentModel.model.getState(segmentVo.lv) == 3) {
                    }
                    else {
                        return segmentVo;
                    }
                }
            }
            return null;
        }
    }

    class ShopModel {
        constructor() {
            this.target = [];
            this.boxNum = 0;
            this.boxNum1 = 0;
            this.boxTs = 0;
            this.resNum = 0;
            this.resTs = 0;
            this.tongNum = 0;
            this.yinNum = 0;
            this.jinNum = 0;
            this.jinBoxNum1 = 0;
            this.jinBoxNum2 = 0;
            this.jinBoxNum3 = 0;
            this.jinBoxNum4 = 0;
            this.freeTsList = {};
            this.boxRefreshTs = 0;
            this.boxList = [];
            this.shopTipsIco = true;
        }
        static get model() {
            return ModelManager.getModel('ShopModel', ShopModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            data.boxNum = this.boxNum;
            data.boxNum1 = this.boxNum1;
            data.boxTs = this.boxTs;
            data.resNum = this.resNum;
            data.resTs = this.resTs;
            data.tongNum = this.tongNum;
            data.yinNum = this.yinNum;
            data.jinNum = this.jinNum;
            data.jinBoxNum1 = this.jinBoxNum1;
            data.jinBoxNum2 = this.jinBoxNum2;
            data.jinBoxNum3 = this.jinBoxNum3;
            data.jinBoxNum4 = this.jinBoxNum4;
            data.freeTsList = this.freeTsList;
            data.boxRefreshTs = this.boxRefreshTs;
            data.boxList = this.boxList;
            data.shopTipsIco = this.shopTipsIco;
            StorageModel.model.setData("shop", data);
        }
        loadData() {
            var data = StorageModel.model.getData("shop");
            this.boxNum = ParamUtil.getInt(data, 'boxNum', 0);
            this.boxNum1 = ParamUtil.getInt(data, 'boxNum1', 0);
            this.boxTs = ParamUtil.getNumber(data, 'boxTs');
            this.resNum = ParamUtil.getInt(data, 'resNum', 0);
            this.resTs = ParamUtil.getNumber(data, 'resTs');
            this.tongNum = ParamUtil.getNumber(data, 'tongNum');
            this.yinNum = ParamUtil.getNumber(data, 'yinNum');
            this.jinNum = ParamUtil.getNumber(data, 'jinNum');
            this.jinBoxNum1 = ParamUtil.getNumber(data, 'jinBoxNum1');
            this.jinBoxNum2 = ParamUtil.getNumber(data, 'jinBoxNum2');
            this.jinBoxNum3 = ParamUtil.getNumber(data, 'jinBoxNum3');
            this.jinBoxNum4 = ParamUtil.getNumber(data, 'jinBoxNum4');
            this.freeTsList = ParamUtil.getObject(data, 'freeTsList', {});
            this.boxRefreshTs = ParamUtil.getNumber(data, 'boxRefreshTs');
            this.boxList = ParamUtil.getObject(data, 'boxList', []);
            this.shopTipsIco = ParamUtil.getBool(data, 'shopTipsIco', true);
            ;
        }
        setFreeTs(cid, ts) {
            this.freeTsList[cid] = ts;
        }
        getFreeTs(cid) {
            return this.freeTsList[cid];
        }
    }

    class SignEvent {
    }
    SignEvent.SIGN_VIEW_SHOW = 'SIGN_VIEW_SHOW';
    SignEvent.SIGN_REWARD_REQUEST = 'SIGN_REWARD_REQUEST';
    SignEvent.SIGN_REWARD_RESPONSE = 'SIGN_REWARD_RESPONSE';
    SignEvent.SIGN_BTNMOVE_SHOW = 'SIGN_BTNMOVE_SHOW';
    SignEvent.SIGN_CLOSE_CLICK = 'SIGN_CLOSE_CLICK';

    class SignModel {
        constructor() {
            this.rewardTs = 0;
            this.dayNum = 0;
            this.dayType = 0;
            this.tipsIco = true;
        }
        static get model() {
            return ModelManager.getModel('SignModel', SignModel);
        }
        ;
        init() {
            this.loadData();
        }
        saveData() {
            var data = {};
            var list = [];
            data.list = list;
            data.rewardTs = this.rewardTs;
            data.dayNum = this.dayNum;
            data.tipsIco = this.tipsIco;
            data.dayType = this.dayType;
            StorageModel.model.setData("sign", data);
        }
        loadData() {
            var data = StorageModel.model.getData("sign");
            this.rewardTs = ParamUtil.getNumber(data, 'rewardTs', 0);
            this.dayNum = ParamUtil.getInt(data, 'dayNum', 0);
            this.dayType = ParamUtil.getInt(data, 'dayType', 0);
            this.tipsIco = ParamUtil.getBool(data, 'tipsIco', true);
        }
    }

    class TaskEvent {
    }
    TaskEvent.TASK_VIEW_SHOW = 'TASK_VIEW_SHOW';
    TaskEvent.TASK_GETREWARD_REQUEST = 'TASK_GETREWARD_REQUEST';
    TaskEvent.TASK_GETREWARD_RESPONSE = 'TASK_GETREWARD_RESPONSE';
    TaskEvent.TASK_LIST_RESPONSE = 'TASK_LIST_RESPONSE';
    TaskEvent.TASK_GETREWARD_COMPLETE = 'TASK_GETREWARD_COMPLETE';
    TaskEvent.TASK_STATE_CHECK = 'TASK_STATE_CHECK';
    TaskEvent.TASK_RESET_REQUEST = 'TASK_RESET_REQUEST';
    TaskEvent.TASK_RESET_RESPONSE = 'TASK_RESET_RESPONSE';

    class TaskConfig {
    }
    TaskConfig.taskTime = 60 * 60 * 24 * 2;
    TaskConfig.list = {
        500001: { cid: 500001, name: 'threadTask', info: '累计参加任意1场比赛', ico: '500001', type: 'event', cond: 'BATTLE_START', condValue: 1, value: 0, reward: [{ cid: 20010107, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500002: { cid: 500002, name: 'threadTask', info: '累计参加任意3场比赛', ico: '500002', type: 'event', cond: 'BATTLE_START', condValue: 3, value: 0, reward: [{ cid: 20010107, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500003: { cid: 500003, name: 'threadTask', info: '累计参加任意5场比赛', ico: '500003', type: 'event', cond: 'BATTLE_START', condValue: 5, value: 0, reward: [{ cid: 20010107, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500004: { cid: 500004, name: 'threadTask', info: '累计参加任意7场比赛', ico: '500004', type: 'event', cond: 'BATTLE_START', condValue: 7, value: 0, reward: [{ cid: 20010107, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500005: { cid: 500005, name: 'threadTask', info: '累计参加任意9场比赛', ico: '500005', type: 'event', cond: 'BATTLE_START', condValue: 9, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500006: { cid: 500006, name: 'threadTask', info: '累计参加任意12场比赛', ico: '500006', type: 'event', cond: 'BATTLE_START', condValue: 12, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500007: { cid: 500007, name: 'threadTask', info: '累计参加任意15场比赛', ico: '500007', type: 'event', cond: 'BATTLE_START', condValue: 15, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500008: { cid: 500008, name: 'threadTask', info: '累计参加任意18场比赛', ico: '500008', type: 'event', cond: 'BATTLE_START', condValue: 18, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500009: { cid: 500009, name: 'threadTask', info: '累计参加任意21场比赛', ico: '500009', type: 'event', cond: 'BATTLE_START', condValue: 21, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500010: { cid: 500010, name: 'threadTask', info: '累计参加任意24场比赛', ico: '500010', type: 'event', cond: 'BATTLE_START', condValue: 24, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500011: { cid: 500011, name: 'threadTask', info: '累计参加任意27场比赛', ico: '500011', type: 'event', cond: 'BATTLE_START', condValue: 27, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500012: { cid: 500012, name: 'threadTask', info: '累计参加任意30场比赛', ico: '500012', type: 'event', cond: 'BATTLE_START', condValue: 30, value: 0, reward: [{ cid: 20010107, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500013: { cid: 500013, name: 'threadTask', info: '累计击杀1个敌人', ico: '500013', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 1, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500014: { cid: 500014, name: 'threadTask', info: '累计击杀3个敌人', ico: '500014', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 3, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500015: { cid: 500015, name: 'threadTask', info: '累计击杀6个敌人', ico: '500015', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 6, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500016: { cid: 500016, name: 'threadTask', info: '累计击杀10个敌人', ico: '500016', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 10, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500051: { cid: 500051, name: 'threadTask', info: '累计击杀15个敌人', ico: '500051', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 15, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500052: { cid: 500052, name: 'threadTask', info: '累计击杀30个敌人', ico: '500052', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 30, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500053: { cid: 500053, name: 'threadTask', info: '累计击杀40个敌人', ico: '500053', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 40, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500054: { cid: 500054, name: 'threadTask', info: '累计击杀50个敌人', ico: '500054', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 50, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500055: { cid: 500055, name: 'threadTask', info: '累计击杀60个敌人', ico: '500055', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 60, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500056: { cid: 500056, name: 'threadTask', info: '累计击杀70个敌人', ico: '500056', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 70, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500057: { cid: 500057, name: 'threadTask', info: '累计击杀80个敌人', ico: '500057', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 80, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500058: { cid: 500058, name: 'threadTask', info: '累计击杀100个敌人', ico: '500058', type: 'event', cond: 'SCENE_FIGHT_NPC_KILL', condValue: 100, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500017: { cid: 500017, name: 'threadTask', info: '累计战场捡取10金币', ico: '500017', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 10, value: 0, reward: [{ cid: 20010001, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500018: { cid: 500018, name: 'threadTask', info: '累计战场捡取20金币', ico: '500018', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 20, value: 0, reward: [{ cid: 20010001, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500019: { cid: 500019, name: 'threadTask', info: '累计战场捡取60金币', ico: '500019', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 60, value: 0, reward: [{ cid: 20010001, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500020: { cid: 500020, name: 'threadTask', info: '累计战场捡取100金币', ico: '500020', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 100, value: 0, reward: [{ cid: 20010001, num: 5 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500021: { cid: 500021, name: 'threadTask', info: '累计战场捡取160金币', ico: '500021', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 160, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500022: { cid: 500022, name: 'threadTask', info: '累计战场捡取220金币', ico: '500022', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 220, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500023: { cid: 500023, name: 'threadTask', info: '累计战场捡取300金币', ico: '500023', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 300, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500024: { cid: 500024, name: 'threadTask', info: '累计战场捡取400金币', ico: '500024', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 400, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500025: { cid: 500025, name: 'threadTask', info: '累计战场捡取500金币', ico: '500025', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 500, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500026: { cid: 500026, name: 'threadTask', info: '累计战场捡取600金币', ico: '500026', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 600, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500027: { cid: 500027, name: 'threadTask', info: '累计战场捡取700金币', ico: '500027', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 700, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500028: { cid: 500028, name: 'threadTask', info: '累计战场捡取800金币', ico: '500028', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021002', condValue: 800, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500029: { cid: 500029, name: 'threadTask', info: '累计战场捡取2钻石', ico: '500029', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 2, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500030: { cid: 500030, name: 'threadTask', info: '累计战场捡取4钻石', ico: '500030', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 4, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500031: { cid: 500031, name: 'threadTask', info: '累计战场捡取12钻石', ico: '500031', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 12, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500032: { cid: 500032, name: 'threadTask', info: '累计战场捡取20钻石', ico: '500032', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 20, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500033: { cid: 500033, name: 'threadTask', info: '累计战场捡取32钻石', ico: '500033', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 32, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500034: { cid: 500034, name: 'threadTask', info: '累计战场捡取44钻石', ico: '500034', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 44, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500035: { cid: 500035, name: 'threadTask', info: '累计战场捡取60钻石', ico: '500035', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 60, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500036: { cid: 500036, name: 'threadTask', info: '累计战场捡取80钻石', ico: '500036', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 80, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500037: { cid: 500037, name: 'threadTask', info: '累计战场捡取100钻石', ico: '500037', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 100, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500038: { cid: 500038, name: 'threadTask', info: '累计战场捡取120钻石', ico: '500038', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 120, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500039: { cid: 500039, name: 'threadTask', info: '累计战场捡取140钻石', ico: '500039', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 140, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500040: { cid: 500040, name: 'threadTask', info: '累计战场捡取160钻石', ico: '500040', type: 'event', cond: 'SCENE_PLAYER_PICKUP_CONPLETE@30021001', condValue: 160, value: 0, reward: [{ cid: 20010003, num: 500 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500041: { cid: 500041, name: 'threadTask', info: '累计升级任意英雄1次', ico: '500041', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 1, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500042: { cid: 500042, name: 'threadTask', info: '累计升级任意英雄2次', ico: '500042', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 2, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500043: { cid: 500043, name: 'threadTask', info: '累计升级任意英雄3次', ico: '500043', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 3, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500044: { cid: 500044, name: 'threadTask', info: '累计升级任意英雄4次', ico: '500044', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 4, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500045: { cid: 500045, name: 'threadTask', info: '累计升级任意英雄5次', ico: '500045', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 5, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500046: { cid: 500046, name: 'threadTask', info: '累计升级任意英雄6次', ico: '500046', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 6, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500047: { cid: 500047, name: 'threadTask', info: '累计升级任意英雄7次', ico: '500047', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 7, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500048: { cid: 500048, name: 'threadTask', info: '累计升级任意英雄8次', ico: '500048', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 8, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500049: { cid: 500049, name: 'threadTask', info: '累计升级任意英雄9次', ico: '500049', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 9, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500050: { cid: 500050, name: 'threadTask', info: '累计升级任意英雄10次', ico: '500050', type: 'event', cond: 'HERO_LV_UP_RESPONSE', condValue: 10, value: 0, reward: [{ cid: 20010001, num: 10 }, { cid: 20010115, num: 10 }], goEvent: 'HERO_VIEW_SHOW' },
        500059: { cid: 500059, name: 'threadTask', info: '累计消耗5点体力', ico: '500059', type: 'goodsSub', cond: 20010107, condValue: 5, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500060: { cid: 500060, name: 'threadTask', info: '累计消耗10点体力', ico: '500060', type: 'goodsSub', cond: 20010107, condValue: 10, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500061: { cid: 500061, name: 'threadTask', info: '累计消耗15点体力', ico: '500061', type: 'goodsSub', cond: 20010107, condValue: 15, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500062: { cid: 500062, name: 'threadTask', info: '累计消耗20点体力', ico: '500062', type: 'goodsSub', cond: 20010107, condValue: 20, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 5 }], goEvent: 'PAGE_VIEW_SHOW' },
        500063: { cid: 500063, name: 'threadTask', info: '累计消耗30点体力', ico: '500063', type: 'goodsSub', cond: 20010107, condValue: 30, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500064: { cid: 500064, name: 'threadTask', info: '累计消耗40点体力', ico: '500064', type: 'goodsSub', cond: 20010107, condValue: 40, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500065: { cid: 500065, name: 'threadTask', info: '累计消耗60点体力', ico: '500065', type: 'goodsSub', cond: 20010107, condValue: 60, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500066: { cid: 500066, name: 'threadTask', info: '累计消耗80点体力', ico: '500066', type: 'goodsSub', cond: 20010107, condValue: 80, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500067: { cid: 500067, name: 'threadTask', info: '累计消耗100点体力', ico: '500067', type: 'goodsSub', cond: 20010107, condValue: 100, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500068: { cid: 500068, name: 'threadTask', info: '累计消耗120点体力', ico: '500068', type: 'goodsSub', cond: 20010107, condValue: 120, value: 0, reward: [{ cid: 20010003, num: 200 }, { cid: 20010115, num: 10 }], goEvent: 'PAGE_VIEW_SHOW' },
        500069: { cid: 500069, name: 'boxTask1', info: '青铜宝箱', ico: '500069', type: 'goodsAdd', cond: 20010115, condValue: 60, value: 0, reward: [{ cid: 3001, num: 1 },], goEvent: '' },
        500070: { cid: 500070, name: 'boxTask1', info: '黄金宝箱', ico: '500070', type: 'goodsAdd', cond: 20010115, condValue: 90, value: 0, reward: [{ cid: 3002, num: 1 }], goEvent: '' },
        500071: { cid: 500071, name: 'boxTask1', info: '钻石宝箱', ico: '500071', type: 'goodsAdd', cond: 20010115, condValue: 120, value: 0, reward: [{ cid: 3003, num: 1 }], goEvent: '' },
        500072: { cid: 500072, name: 'boxTask2', info: '传说宝箱', ico: '500072', type: 'goodsAdd', cond: 20010115, condValue: 200, value: 0, reward: [{ cid: 3004, num: 1 },], goEvent: '' },
        500073: { cid: 500073, name: 'boxTask2', info: '彩虹宝箱', ico: '500073', type: 'goodsAdd', cond: 20010115, condValue: 300, value: 0, reward: [{ cid: 3005, num: 1 }], goEvent: '' },
    };

    class TaskVo {
        constructor() {
            this.cid = 0;
            this.name = '';
            this.ico = '';
            this.info = '';
            this.type = '';
            this.cond = '';
            this.condValue = 0;
            this.reward = {};
            this.state = 0;
            this.isPopup = false;
            this.progressVaule = 0;
            this.value = 0;
            this.goEvent = '';
            this.goData = {};
            this.showType = 1;
        }
    }

    class TaskVoBuilder {
        static getTaskVo(cid) {
            var item = TaskConfig.list[cid];
            if (!item) {
                return null;
            }
            var vo = new TaskVo();
            ObjectUtil.copy(item, vo);
            return vo;
        }
        static getTaskList() {
            return ArrayUtil.objectToArray(TaskConfig.list);
        }
    }

    class TaskModel {
        constructor() {
            this.list = {};
            this.finishNum = 0;
            this.buildTs = 0;
        }
        static get model() {
            return ModelManager.getModel('TaskModel', TaskModel);
        }
        ;
        init() {
            this.loadData();
        }
        buildTasktList() {
            this.buildTs = TimeUtil.getTimestamp();
            var list = TaskConfig.list;
            var nlist = [];
            for (var k in list) {
                var item = list[k];
                var vo = TaskVoBuilder.getTaskVo(item.cid);
                if (vo) {
                    nlist[vo.cid] = vo;
                }
            }
            this.list = nlist;
            this.saveData();
        }
        getTaskVo(cid) {
            return this.list[cid];
        }
        saveData() {
            var data = {};
            var list = [];
            for (var k in this.list) {
                var vo = this.list[k];
                var item = { cid: vo.cid, value: vo.value, state: vo.state };
                list.push(item);
            }
            data.list = list;
            data.finishNum = this.finishNum;
            data.buildTs = this.buildTs;
            StorageModel.model.setData("TaskModel", data);
        }
        loadData() {
            var data = StorageModel.model.getData("TaskModel");
            this.finishNum = ParamUtil.getInt(data, 'finishNum', 0);
            this.buildTs = ParamUtil.getNumber(data, 'buildTs', TimeUtil.getTimestamp());
            if (data && data.list) {
                var list = data.list;
                var nlist = {};
                for (var k in list) {
                    var item = list[k];
                    var vo = TaskVoBuilder.getTaskVo(item.cid);
                    if (vo) {
                        vo.value = item.value;
                        vo.state = item.state;
                        nlist[vo.cid] = vo;
                    }
                }
                this.list = nlist;
            }
            else {
                this.buildTasktList();
            }
        }
        getNotDeliverNum() {
            if (!this.list) {
                return 0;
            }
            var num = 0;
            for (var k in this.list) {
                var vo = this.list[k];
                if (vo.state < 3) {
                    num++;
                }
            }
            return num;
        }
    }

    class TaskTool {
        static getTaskVo() {
            var list = TaskModel.model.list;
            for (var k in list) {
                var taskVo = list[k];
                if (taskVo.state == 3) {
                }
                else if (taskVo.state <= 2) {
                    return taskVo;
                }
            }
            return null;
        }
        static getCompeletTaskVo() {
            var list = TaskModel.model.list;
            for (var k in list) {
                var taskVo = list[k];
                if (taskVo.state == 2) {
                    return taskVo;
                }
            }
            return null;
        }
        static checkFinish() {
            var vo = this.getCompeletTaskVo();
            if (vo) {
                return true;
            }
            return false;
        }
    }

    class PageTool {
        static getHeroIndex(cid) {
            var index = 0;
            var heroList = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            for (var k in heroList) {
                if (heroList[k].cid != cid) {
                    index++;
                }
                else {
                    return index;
                }
            }
        }
    }

    class PageView extends ui.page.PageUI {
        constructor() {
            super();
            this.zOrder = 9;
        }
    }

    class PageViewController extends PanelViewController {
        constructor() {
            super();
            this.mx = 0;
            this.index = 0;
            this.selectHero = null;
            this.logNum = 0;
            this.viewClass = PageView;
            this.viewName = 'PageView';
            this.openSound = null;
            this.closeSound = null;
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
            }
            this.epLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_ep);
            this.phyLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_phy);
            this.tongLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_tong);
            this.jinLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_jin);
            this.phyTimeLabel = new BitmapLabelView("font/white.json", 0.35, this.ui.txt_phyTime);
            this.jiaLabel = new BitmapLabelView("font/white.json", 0.35, this.ui.txt_jia);
            this.lvLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_lv);
            this.ui.img_shop.on(Laya.Event.CLICK, this, this.showShopHandler);
            this.ui.img_task.on(Laya.Event.CLICK, this, this.showTaskHandler);
            this.ui.img_segment.on(Laya.Event.CLICK, this, this.showSegmentHandler);
            this.ui.img_phy.on(Laya.Event.CLICK, this, this.addHandler);
            this.ui.img_tong.on(Laya.Event.CLICK, this, this.add2Handler);
            this.ui.img_jin.on(Laya.Event.CLICK, this, this.add3Handler);
            this.ui.box_start2.on(Laya.Event.CLICK, this, this.start2Handler);
            this.ui.txt_name.on(Laya.Event.CLICK, this, this.changeNameHandler);
            this.ui.ui_head.on(Laya.Event.CLICK, this, this.headHandler);
            this.ui.img_hero.on(Laya.Event.CLICK, this, this.heroHandler);
            this.ui.ui_start.on(Laya.Event.CLICK, this, this.start2Handler);
            this.ui.box_loc.on(Laya.Event.CLICK, this, this.locHeroHandler);
            this.ui.box_sign.on(Laya.Event.CLICK, this, this.showSigndayHandler);
            this.ui.box_online.on(Laya.Event.CLICK, this, this.showOnlineHandler);
            this.ui.ui_box.on(Laya.Event.CLICK, this, this.getRewardHandler);
            this.ui.ui_gift.on(Laya.Event.CLICK, this, this.getGiftRewardHandler);
            this.ui.img_left.on(Laya.Event.MOUSE_DOWN, this, this.leftHandler1);
            this.addEventListener(StageMouseEvent.STAGE_MOUSE_UP, this, this.stopTrunLeftHandler);
            this.addEventListener(StageMouseEvent.STAGE_MOUSE_OUT, this, this.stopTrunLeftHandler);
            this.ui.img_right.on(Laya.Event.MOUSE_DOWN, this, this.rightHandler1);
            this.addEventListener(StageMouseEvent.STAGE_MOUSE_UP, this, this.stopTrunRightHandler);
            this.addEventListener(StageMouseEvent.STAGE_MOUSE_OUT, this, this.stopTrunRightHandler);
            this.ui.box_scene.on(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            this.ui.box_scene.on(Laya.Event.MOUSE_UP, this, this.upHandler);
            this.ui.box_scene.on(Laya.Event.MOUSE_OUT, this, this.upHandler);
            this.addEventListener(OnlineEvent.ONLINE_REWARD_CHANGE, this, this.showInfoHandler);
            this.addEventListener(PageEvent.PAGE_SIGN_TIP_SHOW, this, this.showInfoHandler);
            this.addEventListener(TaskEvent.TASK_LIST_RESPONSE, this, this.showInfoHandler);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showInfoHandler);
            this.addEventListener(PlayerEvent.PLAYER_INFO_CHANGE, this, this.showInfoHandler);
            this.addEventListener(GoodsEvent.GOODS_LOC_SET_REQUEST, this, this.setPlayerHandler);
            this.addEventListener(PageEvent.PAGE_VIEW_REFRESH, this, this.showInfoHandler);
            this.addEventListener(SegmentEvent.SEGMENT_TRIPHY_NUM_CHANGE, this, this.showInfoHandler);
            this.addEventListener(PageEvent.PAGE_GET_CHEST_RESPONSE, this, this.showInfoHandler);
            this.addEventListener(PageEvent.PAGE_GET_GIFT_RESPONSE, this, this.showInfoHandler);
            this.addEventListener(GoodsEvent.GOODS_ATTR_SET_REQUEST, this, this.showInfoHandler);
            this.addEventListener(PageEvent.PAGE_VOIDE_BTN_SHOW, this, this.refreshVoideBtnHandler);
            SoundTool.playMusic('bgm');
            if (PageConfig.isShowBox) {
                this.ui.ui_box.visible = true;
            }
            else {
                this.ui.ui_box.visible = false;
            }
            this.lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.showInfoHandler();
            TimerUtil.loopTimer(1000, this, this.timeHandler);
            TimerUtil.onceTimer(10000, this, this.closeBtn);
            this.refreshVoideBtnHandler();
        }
        refreshVoideBtnHandler() {
            if (AdTool.checkVideoIco('ys_jili')) {
                this.ui.ui_gift.img_ad.visible = true;
                this.ui.ui_box.img_ad.visible = true;
            }
            else {
                this.ui.ui_gift.img_ad.visible = false;
                this.ui.ui_box.img_ad.visible = false;
            }
        }
        leftHandler() {
            if (this.goods3D.role) {
                TimerUtil.loopFrame(1, this, this.leftTrunHandler);
            }
        }
        stopTrunLeftHandler() {
            TimerUtil.stopTimer(this, this.leftTrunHandler);
        }
        leftTrunHandler() {
            if (this.goods3D.role) {
                this.goods3D.role.transform.localRotationEulerY -= 1;
            }
        }
        closeBtn() {
            this.ui.ui_change.visible = false;
        }
        rightHandler() {
            if (this.goods3D.role) {
                TimerUtil.loopFrame(1, this, this.rightTrunHandler);
            }
        }
        stopTrunRightHandler() {
            TimerUtil.stopTimer(this, this.rightTrunHandler);
        }
        rightTrunHandler() {
            if (this.goods3D.role) {
                this.goods3D.role.transform.localRotationEulerY += 1;
            }
        }
        downHandler() {
            this.mx = this.ui.box_scene.mouseX;
            this.ui.box_scene.on(Laya.Event.MOUSE_MOVE, this, this.mouseMoveHandler);
        }
        upHandler() {
            this.ui.box_scene.off(Laya.Event.MOUSE_MOVE, this, this.mouseMoveHandler);
        }
        mouseMoveHandler() {
            var dx = this.ui.box_scene.mouseX - this.mx;
            this.mx = this.ui.box_scene.mouseX;
            if (dx) {
                this.goods3D.role.transform.localRotationEulerY += dx;
            }
        }
        showRoleHandler() {
            var goods = GoodsModel.model.getFirstByType(30, 9, 1, 1);
            if (goods) {
                BattleModel.model.playerCid = goods.cid;
                this.selectHero = goods;
            }
            else {
                var goods = GoodsModel.model.getGoodsByCid(BattleModel.model.playerCid);
                this.selectHero = goods;
            }
            this.index = PageTool.getHeroIndex(this.selectHero.cid);
            this.checkLocShow(this.selectHero);
            this.ui.txt_info.text = '解锁条件：' + GoodsListConfig.getVo(this.selectHero.cid).unlockInfo;
            this.goods3D.showRole(this.selectHero.cid, 0, 0, 0, -1.1, 0, -0.9, 1.15, 0, -15);
        }
        showInfoHandler() {
            this.lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            this.triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.ui_head.img_head.skin = PlayerModel.model.ico;
            this.ui.txt_name.text = PlayerModel.model.name;
            this.tongLabel.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG);
            this.jinLabel.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN);
            var exp = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_EXP);
            var expMax = GoodsLvConfig.getLvNum(GoodsAttrType.ATTR_EXP, this.lv);
            this.lvLabel.text = '' + this.lv;
            this.epLabel.text = exp + '/' + expMax;
            ProgressBarViewTool.setRectBarValue(this.ui.bar_exp, exp / expMax);
            var phy = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_PHY);
            var phyMax = HangConfig.getMax(this.lv);
            this.phyLabel.text = phy + '/' + phyMax;
            this.jiaLabel.text = '+1';
            var troNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            var segment = SegmentTool.getSegment(troNum);
            this.ui.img_seg.skin = SegmentTool.getSegmentImg(segment);
            this.ui.txt_seg.text = SegmentTool.getSegmentName(segment);
            if (PageConfig.isShowName) {
                this.ui.txt_name.text = PlayerModel.model.name;
            }
            else {
                this.ui.txt_name.text = '';
            }
            this.ui.ui_hero.visible = HeroModel.model.heroTipsIco;
            this.ui.ui_shop.visible = ShopModel.model.shopTipsIco;
            this.ui.ui_sign.visible = SignModel.model.tipsIco;
            this.ui.ui_online.visible = OnlineTool.checkFinish();
            this.ui.ui_task.visible = TaskTool.checkFinish();
            this.ui.ui_segment.visible = SegmentModel.model.tipsIco;
            if (PageConfig.isShowGift) {
                this.showGift();
            }
            else {
                this.ui.ui_gift.visible = false;
            }
            if (PageConfig.isShowBox) {
                this.showChest();
            }
            else {
                this.ui.ui_box.visible = false;
            }
            this.showRoleHandler();
        }
        showGift() {
            var giftNum = PageModel.model.giftNum;
            var gift;
            if (giftNum < PageConfig.GiftMax) {
                gift = PageConfig.getGift(giftNum);
            }
            else {
                gift = PageConfig.getGift(9);
            }
            this.ui.ui_gift.img_hero.skin = GoodsViewTool.getIcoUrl(gift.goods.cid);
            this.ui.ui_gift.txt_num.text = 'x' + gift.goods.num;
            if (giftNum >= PageConfig.GiftMax) {
                this.ui.ui_gift.visible = false;
            }
        }
        getGiftRewardHandler() {
            var giftNum = PageModel.model.giftNum;
            if (giftNum < PageConfig.GiftMax) {
                var vo = PageConfig.getGift(giftNum);
                this.dispatchEvent(PageEvent.PAGE_GET_GIFT_REQUEST, { vo: vo });
            }
        }
        showChest() {
            var chestNum = PageModel.model.chestNum;
            if (chestNum < PageConfig.ChestMax) {
                var cid = PageConfig.getTreasureChest(chestNum).cid;
            }
            else {
                var cid = PageConfig.getTreasureChest(3).cid;
            }
            if (BattleModel.model.victoryNum + BattleModel.model.defeatNum >= 1) {
                this.ui.ui_box.visible = true;
                this.ui.ui_box.img_box.skin = GoodsConfig.getSegmentIcoUrl(cid);
            }
            if (chestNum >= PageConfig.ChestMax) {
                this.ui.ui_box.visible = false;
            }
        }
        timeHandler() {
            var t = MathUtil.int(HangConfig.time - (TimeUtil.getTimestamp() - HangModel.model.rewardTs));
            if (t < 0) {
                t = 0;
            }
            this.phyTimeLabel.text = TimeFormatUtil.formatTime(t);
        }
        startHandler() {
            if (GoodsCostTool.checkCost(GoodsAttrType.ATTR_PHY, BattleConfig.phy) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "体力不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
                return;
            }
            this.dispatchEvent(PageEvent.PAGE_BATTLE_START);
        }
        start2Handler() {
            this.dispatchEvent(BattleEvent.BATTLE_START_TRY_HERO_VIEW_SHOW, { battleType: 1 });
        }
        start3Handler() {
            this.dispatchEvent(BattleEvent.BATTLE_START_TRY_HERO_VIEW_SHOW, { battleType: 1 });
        }
        start4Handler() {
            this.dispatchEvent(BattleEvent.BATTLE_START_TRY_HERO_VIEW_SHOW, { battleType: 1 });
        }
        showSigndayHandler() {
            this.dispatchEvent(SignEvent.SIGN_VIEW_SHOW);
            LogTool.log('签到');
        }
        showOnlineHandler() {
            LogTool.log('在线奖励');
            this.dispatchEvent(OnlineEvent.ONLINE_VIEW_SHOW);
        }
        showLotteryHandler() {
            this.dispatchEvent(LotteryEvent.LOTTERY_VIEW_SHOW);
        }
        showEquipHandler() {
        }
        showShopHandler() {
            this.dispatchEvent(ShopEvent.SHOP_MALL_VIEW_SHOW);
        }
        showSegmentHandler() {
            this.dispatchEvent(SegmentEvent.SEGMENT_VIEW_SHOW);
        }
        changeNameHandler() {
            this.dispatchEvent(PlayerEvent.PLAYER_SET_VIEW_SHOW);
        }
        showTaskHandler() {
            this.dispatchEvent(TaskEvent.TASK_VIEW_SHOW);
        }
        showRankHandler() {
            this.dispatchEvent(RankEvent.RANK_VIEW_SHOW);
        }
        headHandler() {
            this.dispatchEvent(PlayerEvent.PLAYER_SET_VIEW_SHOW);
        }
        heroHandler() {
            this.dispatchEvent(HeroEvent.HERO_VIEW_SHOW, { index: this.index, lv: this.lv, triphyNum: this.triphyNum, isSkipHero: false });
        }
        leftHandler1() {
            this.index--;
            if (this.index < 0) {
                this.index = GoodsConfig.heroMaxIndex;
            }
            this.setPlayerHandler();
        }
        rightHandler1() {
            this.index++;
            if (this.index > GoodsConfig.heroMaxIndex) {
                this.index = 0;
            }
            this.setPlayerHandler();
        }
        setPlayerHandler() {
            var heroList = GoodsModel.model.getGoodsByType(30, 9, 1, -1);
            this.selectHero = heroList[this.index];
            if (this.selectHero) {
                this.checkLocShow(this.selectHero);
                this.goods3D.showRole(this.selectHero.cid, 0, 0, 0, -1.1, 0, -0.9, 1.15, 0, -15);
                this.ui.txt_info.text = '解锁条件：' + GoodsListConfig.getVo(this.selectHero.cid).unlockInfo;
            }
        }
        locHeroHandler() {
            if (this.selectHero) {
                this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: this.selectHero.id });
                BattleModel.model.playerCid = this.selectHero.cid;
                this.dispatchEvent(BattleEvent.BATTLE_TEXT_TIP_VIEW_SHOW, { text: '成功派遣' + GoodsListConfig.getVo(this.selectHero.cid).name + '出战' });
            }
        }
        checkLocShow(selectHero) {
            if (selectHero.loc == 1) {
                this.ui.box_loc.visible = false;
                this.ui.box_noLoc.visible = true;
            }
            else {
                this.ui.box_loc.visible = true;
                this.ui.box_noLoc.visible = false;
            }
            if (selectHero.triphyNum <= SegmentModel.model.maxTriphyNum || selectHero.isUnlock) {
                this.ui.img_lock.visible = false;
                this.ui.txt_info.visible = false;
            }
            else {
                this.ui.box_loc.visible = false;
                this.ui.box_noLoc.visible = false;
                this.ui.img_lock.visible = true;
                this.ui.txt_info.visible = true;
            }
        }
        addHandler() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            var phyMax = HangConfig.getMax(lv);
            if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_PHY) >= phyMax) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "体力值已满" });
                return;
            }
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(2)] });
        }
        add2Handler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(0)] });
        }
        add3Handler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
        }
        goldGunHandler() {
        }
        shareHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_JIN, num: 300 }, { cid: GoodsAttrType.ATTR_TONG, num: 2000 }] });
        }
        getRewardHandler() {
            var chestNum = PageModel.model.chestNum;
            if (chestNum < PageConfig.ChestMax) {
                var vo = PageConfig.getTreasureChest(chestNum);
                this.dispatchEvent(PageEvent.PAGE_GET_CHEST_REQUEST, { vo: vo });
            }
        }
        testHandler() {
            this.logNum++;
            if (this.logNum >= 10) {
                this.dispatchEvent(CommonEvent.LOG_VIEW_SHOW);
            }
            NativeTool.showFeedAd({ type: 1 });
        }
        close() {
            super.close();
            this.goods3D.close();
        }
    }

    class PageController extends Controller {
        constructor() {
            super();
            this.reward = [];
            this.cid = 0;
        }
        run() {
            super.run();
            PageModel.model.init();
            ViewManager.register(PageEvent.PAGE_VIEW_SHOW, this, PageViewController);
            ViewManager.register(PageEvent.PAGE_GOLD_GUN_GET_SHOW, this, PageGoldGunGetViewController);
            ViewManager.register(PageEvent.PAGE_COLLECTION_VIEW_SHOW, this, PageCollectionViewController);
            ViewManager.register(PageEvent.PAGE_SHARE_VIEW_SHOW, this, PageShareViewController);
            this.addEventListener(PageEvent.PAGE_REWARD_VIEW_SHOW, this, this.rewardHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(PageEvent.PAGE_BATTLE_START, this, this.startBatleHandler);
            this.addEventListener(BattleEvent.BATTLE_STATE_START, this, this.battleStartHanler);
            this.addEventListener(BattleEvent.BATTLE_STATE_END, this, this.battleEndHandler);
            this.addEventListener(PageEvent.PAGE_GET_CHEST_REQUEST, this, this.adHandler);
            this.addEventListener(PageEvent.PAGE_GET_GIFT_REQUEST, this, this.adGiftHandler);
            PageModel.model.gameTs = TimeUtil.getTimestamp();
        }
        initHandler(data) {
            PageModel.model.startGameTs = TimeUtil.getTimestamp();
            PageModel.model.gameNum++;
            PageModel.model.saveData();
            this.dispatchEvent(PageEvent.PAGE_VIEW_SHOW, { showType: ViewType.OPEN });
            this.showViewHandler();
        }
        showViewHandler() {
        }
        startBatleHandler(data) {
            var cid = MathUtil.randomInt(1, 2);
            this.dispatchEvent(BattleEvent.BATTLE_READY_VIEW_SHOW, { cid: cid, battleType: PageModel.model.battleType });
        }
        battleStartHanler() {
            this.dispatchEvent(PageEvent.PAGE_VIEW_SHOW, { showType: ViewType.CLOSE });
        }
        battleEndHandler(data) {
            this.dispatchEvent(SceneEvent.SCENE_BATTLE_VIEW_SHOW, { showType: ViewType.CLOSE });
            this.dispatchEvent(BattleEvent.BATTLE_VIEW_SHOW, { showType: ViewType.CLOSE });
            this.dispatchEvent(PageEvent.PAGE_VIEW_SHOW, { showType: ViewType.OPEN });
            this.dispatchEvent(LeadEvent.LEAD_VIEW_SHOW);
        }
        rewardHandler(data) {
            if (PageConfig.pageRewardType == 1) {
                ViewManager.show(this, PageReward1ViewController, data);
            }
            else if (PageConfig.pageRewardType == 2) {
                ViewManager.show(this, PageReward2ViewController, data);
            }
            else if (PageConfig.pageRewardType == 3) {
                ViewManager.show(this, PageReward3ViewController, data);
            }
            else if (PageConfig.pageRewardType == 4) {
                ViewManager.show(this, PageReward4ViewController, data);
            }
            else if (PageConfig.pageRewardType == 5) {
                ViewManager.show(this, PageReward5ViewController, data);
            }
            else if (PageConfig.pageRewardType == 6) {
                ViewManager.show(this, PageReward6ViewController, data);
            }
            else {
                ViewManager.show(this, PageRewardViewController, data);
            }
        }
        getChestHandler() {
            PageModel.model.chestNum += 1;
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: this.reward, rewardType: this.cid });
            this.dispatchEvent(PageEvent.PAGE_GET_CHEST_RESPONSE);
            PageModel.model.saveData();
        }
        adHandler(data) {
            if (data) {
                this.reward = [];
                if (data.vo.cid == 3002) {
                    this.reward = GoodsBoxConfig.getGoldBox(SegmentModel.model.maxTriphyNum);
                    this.reward = GoodsTool.mergeList(this.reward);
                }
                else if (data.vo.cid == 3003) {
                    this.reward = GoodsBoxConfig.getMasonryBox(SegmentModel.model.maxTriphyNum);
                    this.reward = GoodsTool.mergeList(this.reward);
                }
                else if (data.vo.cid == 3004) {
                    this.reward = GoodsBoxConfig.geLegendBox(SegmentModel.model.maxTriphyNum);
                    this.reward = GoodsTool.mergeList(this.reward);
                }
                else if (data.vo.cid == 3005) {
                    this.reward = GoodsBoxConfig.getRainbowBox(SegmentModel.model.maxTriphyNum);
                    this.reward = GoodsTool.mergeList(this.reward);
                }
                this.cid = data.vo.cid;
                AdTool.videoAdShow(this, this.getChestHandler, 'addbox');
            }
        }
        GiftHandler() {
            PageModel.model.giftNum += 1;
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [this.vo.goods], rewardType: 1, isShowInsert: true });
            this.dispatchEvent(PageEvent.PAGE_GET_GIFT_RESPONSE);
            PageModel.model.saveData();
        }
        adGiftHandler(data) {
            if (data) {
                var gift = data.vo;
                if (SegmentModel.model.maxTriphyNum >= gift.unlockTroNum) {
                    this.vo = gift;
                    AdTool.videoAdShow(this, this.GiftHandler, "addGift");
                }
                else {
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "未达到杯数!" });
                }
            }
        }
    }

    class CheckShowController extends Controller {
        constructor(viewEvent, eventData = null, openList = null, preventList = null) {
            super();
            this.list = {};
            this.indexList = {};
            this.dataList = {};
            this.viewEvent = viewEvent;
            this.eventData = eventData;
            for (var k in openList) {
                this.regOpenView(openList[k]);
            }
            for (var k in preventList) {
                this.regPreventView(preventList[k]);
            }
        }
        regOpenView(viewName, data = null, index = 1) {
            this.indexList[viewName] = index;
            this.dataList[viewName] = data;
            this.addEventListener(ViewEvent.VIWE_OPEN(viewName), this, this.openHandler);
            this.addEventListener(ViewEvent.VIWE_CLOSE(viewName), this, this.closeHandler);
            var view = ViewManager.getView(viewName);
            if (view) {
                this.openHandler({ viewName: viewName });
            }
        }
        offOpenView(viewName) {
            delete this.indexList[viewName];
            delete this.dataList[viewName];
            this.removeEventListener(ViewEvent.VIWE_OPEN(viewName), this, this.openHandler);
            this.removeEventListener(ViewEvent.VIWE_CLOSE(viewName), this, this.closeHandler);
        }
        regPreventView(viewName, index = 2) {
            this.indexList[viewName] = index;
            this.addEventListener(ViewEvent.VIWE_OPEN(viewName), this, this.preventHandler);
            this.addEventListener(ViewEvent.VIWE_CLOSE(viewName), this, this.repreventHandler);
            var view = ViewManager.getView(viewName);
            if (view) {
                this.preventHandler({ viewName: viewName });
            }
        }
        offPreventView(viewName) {
            delete this.indexList[viewName];
            this.removeEventListener(ViewEvent.VIWE_OPEN(viewName), this, this.preventHandler);
            this.removeEventListener(ViewEvent.VIWE_CLOSE(viewName), this, this.repreventHandler);
        }
        openHandler(data) {
            var index = this.indexList[data.viewName];
            this.openView(data.viewName, this.dataList[data.viewName], index);
        }
        closeHandler(data) {
            this.closeView(data.viewName);
        }
        preventHandler(data) {
            var index = this.indexList[data.viewName];
            this.preventView(data.viewName, index);
        }
        repreventHandler(data) {
            this.unpreventView(data.viewName);
        }
        openView(viewName, data = null, index = 1) {
            this.list[viewName] = { viewName: viewName, data: data, type: 'open', index: index };
            this.checkView();
        }
        closeView(viewName) {
            this.removeView(viewName);
            this.checkView();
        }
        preventView(viewName, index = 2) {
            this.list[viewName] = { viewName: viewName, type: 'close', index: index };
            this.checkView();
        }
        unpreventView(viewName) {
            this.removeView(viewName);
            this.checkView();
        }
        removeView(viewName) {
            delete this.list[viewName];
        }
        checkView() {
            TimerUtil.onceTimer(60, this, this.checkViewHandler);
        }
        checkViewHandler() {
            var citem = null;
            for (var k in this.list) {
                var item = this.list[k];
                if (citem == null) {
                    citem = item;
                }
                else if (item.index > citem.index) {
                    citem = item;
                }
            }
            if (citem && citem.type == 'open') {
                this.showEvent(k, citem.data);
            }
            else {
                this.closeEvent();
            }
        }
        showEvent(viewName, edata = null) {
            var data = ObjectUtil.copy(this.eventData, {});
            data.showType = ViewType.OPEN;
            data = ObjectUtil.copy(this.dataList[viewName], data);
            this.dispatchEvent(this.viewEvent, data);
        }
        closeEvent() {
            var data = ObjectUtil.copy(this.eventData, {});
            data.showType = ViewType.CLOSE;
            this.dispatchEvent(this.viewEvent, data);
        }
    }

    class PlatformModel {
        constructor() {
            this.addDesktopFinish = false;
            this.addMiniFinish = false;
            this.hasAdVideo = false;
            this.adVoideTime = 0;
            this.hasAdAppBox = false;
            this.shareTime = 0;
            this.shareNum = 0;
            this.shareTs = 0;
            this.hasRecorder = false;
            this.adVideoId = '';
            this.adInserId = '';
            this.adRandomId = '';
            this.adAppBoxId = '';
            this.adBlockId = '';
            this.adVideoViewName = '';
            this.isAddIco = false;
            this.isShowFollow = false;
            this.isShowFollowIco = false;
            this.isAddMini = false;
            this.openId = '';
            this.province = '';
            this.city = '';
            this.channel_id = '';
            this.channelType = '';
            this.privacyNum = 0;
        }
        saveData() {
            var data = {};
            data.isAddIco = this.isAddIco;
            data.shareTs = this.shareTs;
            data.shareNum = this.shareNum;
            data.channel_id = this.channel_id;
            data.privacyNum = this.privacyNum;
            data.isAddMini = this.isAddMini;
            StorageModel.model.setData("platform", data);
        }
        loadData() {
            var data = StorageModel.model.getData("platform");
            if (data) {
                ObjectUtil.copy(data, this);
            }
            this.privacyNum = ParamUtil.getNumber(data, 'privacyNum', 0);
            this.openId = this.getOpenId();
        }
        getOpenId() {
            var id = StorageModel.model.getData("openid");
            if (!id) {
                id = TimeUtil.getTime() + "" + Math.ceil(Math.random() * 10000);
                StorageModel.model.setData("openid", id);
            }
            return id;
        }
    }
    PlatformModel.model = new PlatformModel();

    class PlatformConfig {
    }
    PlatformConfig.gameName = '玩具兵大作战';
    PlatformConfig.platformType = 0;
    PlatformConfig.shareImageURL = [
        'https://mmocgame.qpic.cn/wechatgame/on1u8OJiaGR6e2y0pPlB8U2YO2L1yNCBzGn5iaRvp7WQBlrLj27gjcR2BVp7tIIr9c/0',
        'https://mmocgame.qpic.cn/wechatgame/on1u8OJiaGR5nmnzpyuU7DyiatSnibaOTfDhFlzz8BxQibgnFmfwDsGWAxY4ZqGJocl9/0',
        'https://mmocgame.qpic.cn/wechatgame/on1u8OJiaGR7ZlE7FK1pEeR87u3HZa25QXIaVuKfB7ibA6eTRnFVqKIvxIMSWe3Wb5/0'
    ];
    PlatformConfig.shareText = [];
    PlatformConfig.loadingImage = './ui/img_loading.jpg';
    PlatformConfig.followReward = [{ cid: 30042101, num: 1 }, { cid: 30041102, num: 1 }];
    PlatformConfig.followReward1 = [{ cid: 30041121, num: 1, hp: 600, attpro: 0.06 }, { cid: 30041221, num: 1, hp: 1600, hppro: 0.06 }];
    PlatformConfig.addMiniReward = [{ cid: 20010001, num: 200 }, { cid: 20010003, num: 2000 }];
    PlatformConfig.addPageReward = [{ cid: 20010001, num: 200 }, { cid: 20010003, num: 2000 }];
    PlatformConfig.shareReward = [{ cid: 20010003, num: 2000 }, { cid: 20010001, num: 100 }, { cid: 30011001, num: 40 }];
    PlatformConfig.content = "深圳市探娱互动科学文化有限公司隐私政策\n\
    生效日期：2021-05-30\n\
    用户在使用深圳探娱所提供的移动游戏产品及服务过程中：\n\
    1、游戏产品为用户提供账号一键注册或快速注册等功能，使用该功能时，系统将帮助用户向游戏服务器发送一条请求短信，并依当地电信运营商标准收取基本短信息通信费，不会产生任何额外费用。为了发送上述短信，深圳探娱需要收集您的手机号码，并获取发送短信权限。\n\
    2、为了更好地帮助用户获取游戏活动等相关信息，安装了深圳探娱相关游戏产品，游戏服务器将不定期向用户推送信息，通常每日不会超过三条、每月不会超过30条，且内容均是该游戏相关信息。\n\
    3、为了用户之间交流方便，深圳探娱部分游戏产品自带语音聊天功能，安装该类型游戏产品后，将启动用户的移动设备的录音权限，以实现语言聊天的功能，该功能仅用于用户之间互动。\n\
    4、为了方便用户将游戏画面分享给其他用户，深圳探娱部分游戏产品自带截图保存和分享功能，在用户再次确认后，将有权访问用户的照片、媒体内容和文件，该功能仅用于用户将自己的游戏画面进行分享。\n\
    5、为了方便用户找到附近在玩同样游戏的其他用户，深圳探娱部分游戏产品自带定位功能，在用户再次确认后，将有权使用网络获取用户大概位置或使用GPS获取用户精确位置。\n\
    6、为了方便用户将自己的真实头像上传到游戏中，深圳探娱部分游戏产品自带照相功能，在用户再次确认后将有权使用用户移动设备的摄像头进行照相或者录制视频。\n\
    7、为了加快游戏运行速度，节约用户流量，深圳探娱部分游戏产品需要对用户移动设备的外部存储空间进行读取。\n\
    8、为了识别用户设备，保障网络运营安全，深圳探娱部分游戏产品需要收集用户移动设备的国际移动设备识别码（IMEI）。\n\
    9、用户可以拒绝提供上述权限，仍可继续使用深圳探娱所提供的移动游戏产品，但是在这种情况下，用户将可能无法使用产品的部分功能，无法完成产品的某些任务，无法实现和其他玩家的某些互动，在游戏体验和收益上落后于其他用户，另外对用户安全保障存在一定影响。\n\
    更多详细服务内容可详见下文《隐私政策》相关条款。\n\
    深圳市探娱互动科学文化有限公司（以下简称“我们”）尊重并保护所有使用服务用户的个人隐私权。您在使用我们的服务时，我们可能会收集和使用您的相关信息。但我们将以高度的勤勉、审慎义务对待这些信息。 深圳探娱深知个人信息对您的重要性，并会尽全力保护您的个人信息安全可靠。我们致力于维持您对我们的信任，恪守以下原则，保护您的个人信息：权责一致原则、目的明确原则、选择同意原则、最少够用原则、确保安全原则、主体参与原则、公开透明原则等。\n\
    请注意！深圳探娱可能适时对本协议进行修改与更新，您同意将随时留意查看本协议的最新版本。请在使用我们的产品（或服务）前，仔细阅读并了解本《隐私政策》，以确保对本《隐私政策》的最新版本始终保持了解。\n\
    1.适用范围2.信息使用3.信息披露4.订阅及自动续订说明5. 信息存储6.信息安全7.信息管理8.个人信息保护9.修订和通知10.独立第三方11.如何联系我们\n\
    1.适用范围\n\
    a) 在您使用我们网络服务，或访问我们平台网页时，我们自动接收并记录的您的浏览器和计算机上及其他移动终端设备的信息，包括但不限于您的IP地址、地址位置信息、浏览器的类型、使用的语言、访问日期和时间、通讯账户、通讯时长、软硬件特征信息及您需求的网页记录等数据；\n\
    b) 您在注册账户时填写、提供或上传的姓名、个人昵称、身份证号、手机号、QQ号、微信、或其他社交网站信息、个人头像、分享的照片。\n\
    c) 您在使用探娱互动提供的服务时，可能提供的您的家庭地址、个人兴趣爱好及其他个人隐私。\n\
    d) 我们通过合法途径从商业伙伴处取得的用户个人数据。\n\
    f) 在我们为您提供游戏服务的时候，我们会通过嵌入第三方SDK（广东天宸网络科技有限公司、广东欢太科技有限公司、北京字节跳动科技有限公司、深圳市腾讯科技有限公司、北京热云科技有限公司、华为软件技术有限公司）收集读取您电话状态、网络状态、硬件型号、设备MAC地址、操作系统类型及版本、设备识别码（IMSI/IMEI/android ID/IDFA/OPENUDID/GUID/IDFV/OAID）信息，达到精准广告推送/个性化服务。\n\
    2.信息使用\n\
    a) 我们不会向任何无关第三方提供、出售、出租、分享或交易您的个人信息，除非事先得到您的许可，或该第三方和我们（含我们关联公司）单独或共同为您提供服务，且在该服务结束后，其将被禁止访问包括其以前能够访问的所有这些资料。\n\
    b) 我们亦不允许任何第三方以任何手段收集、编辑、出售或者无偿传播您的个人信息。任何我们平台用户如从事上述活动，一经发现，我司有权立即终止与该用户的服务协议。\n\
    c) 我们使用您的信息，包括游戏日志信息，例如登录日志，物品日志，游戏对局日志，交友日志等，会用于身份认证、安全防范、反诈骗检测、客户安全服务、存档备份、商业分析等。\n\
    d) 为服务用户的目的，我们可能通过使用您的个人信息，向您提供您感兴趣的信息，包括但不限于向您提供个性化需求、发送新产品和服务广告、资讯信息、邀请您参加我们的服务调查，或者与我司合作伙伴共享信息以便他们向您发送有关其产品和服务的信息（注：与合作伙伴共享您的信息需要您的事先同意）。\n\
    e)为您提供游戏用户认证服务，当我们为您提供认证服务，以便我们根据法律法规为认证用户提供认证服务时，您需要向我们提供您的姓名和身份证号信息。您完成用户认证后可享受更好地的游戏服务，否则无法进行游戏体验和充值，数据同步等。\n\
    3.信息披露\n\
    在如下情况下，我们将依据您的个人意愿或法律的规定全部或部分的披露您的个人信息：\n\
    a) 经您事先同意，向第三方披露；\n\
    b) 为提供您所要求的产品和服务，而必须和第三方分享您的个人信息；\n\
    c) 根据法律的有关规定，或者行政或司法机构的要求，向第三方或者行政、司法机构披露； \n\
    d) 如您出现违反中国有关法律、法规或者我们服务协议或相关规则的情况，需要向第三方披露；\n\
    e) 如您是适格的知识产权投诉人并已提起投诉，应被投诉人要求，向被投诉人披露，以便双方处理可能的权利纠纷；\n\
    f) 在我们平台上创建的某一交易中或我们发生合并、收购、资产转让或其他合作等，如交易或合作任何一方履行或部分履行了交易义务并提出信息披露请求的，我们有权决定向该用户提供其交易对方的联络方式等必要信息，以促成交易的完成或纠纷的解决。\n\
    g) 其它我们根据法律、法规或者政策认为合适的披露。\n\
    4.订阅及自动续订说明\n\
    a）付款将在确认购买时向iTunes帐户收取。\n\
    b）订阅自动续订，除非自动续订在当前期限结束前至少24小时关闭。\n\
    c）账户将在本期结束前的24小时内收取续费费用，并确定续约费用。\n\
    d）订购可由用户管理，购买后可通过转到用户的帐户设置关闭自动续订。\n\
    e）免费试用期的任何未使用部分（如果提供）在用户购买该出版物的订阅时将被没收。\n\
    5. 信息存储\n\
    我们会遵守法律法规的规定，将您的个人信息存储在安全的服务器设备或其他安全系统更高的数据库或设备中，我们会为您的信息提供相应的安全保障，以防止信息的丢失、不当使用、未经授权访问或披露。为确保网站正常运转，我们会在您的计算机或移动设备上存储名为Cookie的小数据文件。Cookie通常包含标识符、站点名称以及一些号码和字符。Cookie有助于我们辨认您作为我们的注册用户的身份，或保存您向我们提供有关您的喜好或其他有助于我们辨认您作为我们的注册用户的身份，或保存您向我们提供有关您的喜好或其他信息了解您使用服务进行什么活动、或哪些服务或服务最受欢迎；及有助于我们根据您的信息，向您提供与您相关的广告而非进行普遍的广告投放。 我们不会将Cookie用于本政策所述目的之外的任何用途。您可根据自己的偏好通过浏览器或其他方式设置管理或删除Cookie。\n\
    6. 信息安全\n\
    a) 我们账号均有安全保护功能，亦请您妥善保管您的用户名及密码信息。我们将通过对用户密码进行加密等安全措施确保您的信息不丢失，不被滥用和变造。尽管有前述安全措施，但同时也请您注意在信息网络上不存在“完善的安全措施”。\n\
    b) 在使用我们网络服务进行网上交易时，您不可避免的要向交易对方或潜在的交易对方披露自己的个人信息，如联络方式或者邮政地址。请您妥善保护自己的个人信息，仅在必要的情形下向他人提供。如您发现自己的个人信息泄密，尤其是我们用户名及密码发生泄露，请您立即联络我们客服，以便我们采取相应措施。 \n\
    7.信息管理\n\
    a) 我们鼓励您更新和修改您的个人信息以使其更准确有效。我们将采取适当的技术手段或提供提交申请的联系渠道，尽可能保证您正常访问、更新和更正自己的个人信息。您可以在使用我们的服务过程中对您的个人信息，含注册信息及其他个人信息，按我们的指引进行信息管理（包含：访问、更新），具体的信息管理范围及管理方式取决于您使用的具体服务。\n\
    b) 若我们为实现服务功能或为活动所需向您收集、使用您的信息时，您发现我们违反约定错误收集、使用您的信息的，您可以通过本隐私政策中载明的我们的客服联系方式向我们反馈，我们将按您的要求对信息予以处理。\n\
    c）若您访问、管理您的个人信息时，我们将会对您的身份进行认证，已确保账户安全，您需按我们的指引向我们提供您的身份信息，若您提供的信息验证不成功的，我们将会很遗憾地告知您可能无法对您要求的个人信息进行管理。\n\
    d）我们将尽最大的技术努力满足您对个人信息的管理，但若因技术原因或法律监管要求，可能会无法满足您所有的要求，您可以通过本隐私政策中载明的客服联系方式将问题反馈我们，以便我们改进技术，更好地为您提供服务。\n\
    e) 若您对个人信息需要管理或对我们对您的个人信息管理有疑问的，您可以通过我们的客服进行问题反馈及沟通解决，我们将尽快审核并给予您答复。\n\
    f) 我们向您提供账号注销的途径。在符合我们的服务条款约定条件及国家相关法律法规规定的情况下，您可以在游戏的“个人中心”页面点击“账号注销”；您也可以选择通过本协议中“如何联系我们”章节所列的反馈渠道联系我们，我们将尽快为您作出解答。\n\
    g) 我们将根据用户同意《隐私协议》后，主动弹出相关的权限申请，权限包括：存储、使用语音；用户可以根据自身的需求进行相关的权限授权。\n\
    8.个人信息保护\n\
    a) 我们会采取一切合理可行的措施，保护您的个人信息。例如，我们使用SSL/hash对您的数据进行加密保护；如我们与第三方分享您的信息，我们将会采用加密、脱敏及其他去标识化处理等手段保障您的信息安全。\n\
    b） 我们为保护信息采取的其他安全措施,我们通过建立数据分类分级制度、数据安全管理规范、数据安全开发规范来管理规范信息的存储和使用。我们通过信息接触者保密协议、监控和审计机制来对数据进行全面安全控制。\n\
    c） 我们仅允许有必要知晓这些信息的深圳探娱工作人员、合作伙伴访问您的信息，同时要求可能接触到您的信息的所有人员履行相应的保密义务。如果未能履行这些义务，可能会被追究法律责任或被中止与深圳探娱的合作关系。\n\
    d） 我们会采取一切合理可行的措施，确保未收集无关的个人信息。我们只会在您第一次使用我们的产品或服务时，同意我们的产品或服务收集个人信息之后，注销账号之前保留您的个人信息，除非法律法规明确要求我们保留更长的期限。\n\
    e） 互联网并非绝对安全的环境，而且电子邮件、即时通讯、及与其他深圳探娱用户的交流方式并未加密，除非我们明确要求，我们强烈建议您不要通过此类方式发送个人信息。请使用复杂密码，协助我们保证您的账号安全。如果我们明确要求您在提交特定服务需求时，使用电子邮件等方式发送个人信息，我们将按照本隐私政策的要求，采取合理可行的措施，保护您发送的个人信息。\n\
    f） 互联网环境并非百分之百安全，我们将尽力确保或担保您发送给我们的任何信息的安全性。如果我们的物理、技术、或管理防护设施遭到破坏，导致信息被非授权访问、公开披露、篡改、或毁坏，导致您的合法权益受损，我们将承担相应的法律责任。   \n\
    g）在不幸发生个人信息安全事件后，我们将采取必要措施以阻止安全事件扩大，并以推送通知、公告等形式告知您。  \n\
    h) 我们产品、网站和服务主要面向成人。深圳探娱遵从国家政策，如果没有父母和监护人的同意，未成年人/儿童不得创建自己的用户账号。 对于经父母或监护人同意而收集未成年人/儿童个人信息的情况，我们只会在受到法律的允许、父母或监护人明确同意或者保护未成年人/儿童所必要的情况下使用或公开披露此信息。我们在收集和处理不满14周岁的儿童的个人信息时，还将遵守《隐私政策（儿童适用）》。我们非常重视对未成年人信息的保护。\n\
    9.修订和通知\n\
    为了给您提供更好的服务，我们可能会根据探娱服务的更新情况及法律法规的相关要求适时修订本隐私政策的条款，该等修改构成本政策的一部分。我们会在本页面的显著位置公布改动信息。在该种情况下，若您继续使用我们的服务，即表示同意受经修订的本隐私政策的约束。\n\
    10.独立第三方\n\
    我们的产品或服务可能接入第三方插件、链接到第三方网站或者允许您将我们产品或服务的部分内容分享到第三方网站或者应用（上述第三方统称“独立第三方”）。不同于前文您使用第三方账号登录我们的产品或服务的情况，本条款情形下我们将不会和独立第三方分享您提供给我们的个人信息，但是独立第三方可能单独收集、使用、储存和分享您的个人信息。请您知悉，该等情形下独立第三方对您的个人信息的单独收集、使用、储存和分享行为将适用该独立第三方自己的隐私政策而不是本隐私政策。请您仔细阅读该等隐私政策，如果您对其存在疑问，您可以选择不使用独立第三方提供的服务或者功能。我们将不会为独立第三方对您的个人数据收集、使用、储存和分享行为及其后果承担任何责任。 \n\
    我们接入的独立第三方列表，以及独立第三方收集的信息、开启的权限和相关的目的，（请点击查阅《第三方SDK目录》）。\n\
    11.如何联系我们\n\
    我们设立了个人信息保护专职部门，将按照本政策保护您的个人信息。如您有关于网络信息安全的投诉和举报，或您对于本政策、探娱的隐私措施、您的信息的相关权益有任何问题、意见或建议，请与探娱的个人信息保护工作人员联系，可发送邮件至bd@tanyu.mobi或写信至以下地址：深圳市南山区高新南一道9-6号深圳市探娱互动科学文化有限公司个人信息保护专员（收）；邮编：518000。 一般情况下，我们将在收到您的问题、意见或建议，并验证您的用户身份后的十五个工作日内予以回复。如您不满意我们的回复，还可以向消费者权益保护部门投诉或向有管辖权的法院提起诉讼。 \n\
    深圳探娱隐私政策（儿童适用） \n\
    对于不满十四周岁的未成年人（简称“儿童”），我们收集和处理其个人信息除适用《深圳探娱隐私政策》的规定外，还会遵守下列条款。如果下列条款\n\
    《深圳探娱隐私政策》不一致，以下列条款的规定为准：\n\
    1、我们的儿童个人信息保护负责人的联系方式为bd@tanyu.mobi，儿童监护人可以通过该联系方式主动和我们联系，行使下列条款授予儿童监护人的权利。\n\
    2、我们收集、使用、转移、披露儿童个人信息前，将通过儿童监护人为儿童注册账号时留存的监护人本人联系方式提前通知儿童监护人，并只有获得其同意后才对儿童信息进行收集、使用、转移、披露。\n\
    3、儿童监护人收到上述通知后，可以拒绝，如果监护人拒绝我们按照《深圳探娱隐私政策》收集、使用、转移、披露儿童个人信息，我们将不会对儿童信息进行收集、使用、转移、披露，但是，这可能意味着儿童无法完整使用我们产品的部分功能。如果监护人拒绝我们使用的儿童个人信息是运行我们产品所必须的基本信息（儿童的姓名、身份证号码、移动设备号码、设备识别码），儿童将完全无法使用我们的产品。\n\
    4、我们工作人员访问儿童个人信息，应当经过儿童个人信息保护负责人或者其授权的管理人员审批，记录访问情况，并采取技术措施，避免违法复制、下载儿童个人信息。   \n\
    5、儿童监护人代表儿童行使《深圳探娱隐私政策》下儿童本人享有的一切权利，包括《深圳探娱隐私政策》第五条规定的访问、控制、删除儿童个人信息、改变儿童信息授权同意的范围，以及注销儿童的深圳探娱账号。   \n\
    6、儿童监护人可以撤回对我方收集、使用、转移、披露儿童个人信息的授权，但是这可能意味着儿童无法完整使用我们产品的部分功能。如果监护人撤回授权的儿童个人信息是运行我们产品所必须的基本信息（儿童的姓名、身份证号码、移动设备号码、设备识别码），儿童将完全无法使用我们的产品。\n\
    7、我们向第三方转移儿童个人信息的，将会自行或者委托第三方机构进行安全评估。\n\
    8、我们如果停止运营产品或服务，会立即停止收集儿童个人信息的活动，删除我们持有的儿童个人信息，并将停止运营的通知及时告知儿童监护人。";

    class PlatformTool {
        static initParam() {
            PlatformConfig.loadingImage = ParamUtil.getString(MainConfig.clientConfig, 'loadingImage', PlatformConfig.loadingImage);
            console.log('PlatformConfig.loadingImage:' + PlatformConfig.loadingImage);
            if (BrowserParamTool.checkAgent('LayaAirIDE') || BrowserParamTool.getParam('verType') == 'debug') {
                MainConfig.platform = 'fw';
                MainConfig.channel = 'fw';
                MainConfig.soft = 'debug';
                MainConfig.entry = 'debug';
                MainConfig.divice = 'debug';
            }
        }
        static getShareText() {
            return ArrayUtil.randomItem(PlatformConfig.shareText);
        }
        static getShareImageURL() {
            return ArrayUtil.randomItem(PlatformConfig.shareImageURL);
        }
        static getShareObject() {
            return {
                channel: 'article',
                title: PlatformTool.getShareText(),
                imageUrl: PlatformTool.getShareImageURL(),
            };
        }
        static getRewardType() {
            var list = [];
            if (list.length == 0) {
                return '';
            }
            var type = ArrayUtil.randomItem(list);
            return type;
        }
        static compareVersion(v1, v2) {
            v1 = v1.split('.');
            v2 = v2.split('.');
            const len = Math.max(v1.length, v2.length);
            while (v1.length < len) {
                v1.push('0');
            }
            while (v2.length < len) {
                v2.push('0');
            }
            for (let i = 0; i < len; i++) {
                const num1 = parseInt(v1[i]);
                const num2 = parseInt(v2[i]);
                if (num1 > num2) {
                    return 1;
                }
                else if (num1 < num2) {
                    return -1;
                }
            }
            return 0;
        }
    }

    class PlatrormLoadingView extends Laya.Image {
        constructor() {
            super();
            this.loadImage(PlatformConfig.loadingImage);
            this.sizeGrid = "1000,0,100,0";
            this.top = this.left = this.right = this.bottom = 0;
        }
        static show() {
            if (!this.img) {
                this.img = new PlatrormLoadingView();
            }
            Laya.stage.addChild(this.img);
        }
        static close() {
            if (this.img) {
                this.img.removeSelf();
                this.img = null;
            }
        }
    }

    class OpminiConfig {
        static getNative(type) {
            if (this.nativeids[type]) {
                return this.nativeids[type];
            }
            return this.nativeid;
        }
    }
    OpminiConfig.appid = '30677541';
    OpminiConfig.videoid = '414252';
    OpminiConfig.bannerid = '414240';
    OpminiConfig.insertid = '414241';
    OpminiConfig.portalid = '414253';
    OpminiConfig.nativeid = ' 414251';
    OpminiConfig.nativeids = {
        'ad': '414251',
        'ico': '414243',
        'banner': '414243'
    };
    OpminiConfig.gameId = 734;
    OpminiConfig.version = '1.0.0';

    class BdminiConfig {
    }
    BdminiConfig.appid = '23595230';
    BdminiConfig.appsid = 'ae1cbdfc';
    BdminiConfig.videoid = '7402330';
    BdminiConfig.bannerid = '';
    BdminiConfig.sceneDesk = '1230000000000000';
    BdminiConfig.version = '1.1.0';

    class BdminiModel {
        constructor() {
            this.hasVideoAd = false;
            this.recorderEnd = false;
            this.state = 0;
            this.videoShareComplete = false;
        }
        static getApi() {
            if (typeof swan == "undefined") {
                return null;
            }
            else {
                return swan;
            }
        }
    }
    BdminiModel.model = new BdminiModel();

    class BdminiController extends Controller {
        constructor() {
            super();
            this.videoPlaying = false;
        }
        run() {
            super.run();
            this.api = BdminiModel.getApi();
            this.vo = BdminiModel.model;
            BattleConfig.endType = 1;
            BattleConfig.defeatType = 1;
            BattleConfig.victoryType = 1;
            PlatrormLoadingView.show();
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_SHOW, this, this.shareHandler);
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_VIDEO_SHOW, this, this.shareVideoHandler);
            this.addEventListener(PlatformEvent.PLATFORM_RECORDER_START, this, this.recorderStartHandler);
            this.addEventListener(PlatformEvent.PLATFORM_RECORDER_STOP, this, this.recorderStopHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            LogTool.log("Bdmini.init()");
            let data = this.api.getSystemInfoSync();
            LogTool.log('手机品牌信息：' + data.brand);
            PlatrormLoadingView.close();
            this.initViedoAd();
            this.initBannerAd();
            this.initShare();
            this.initDesktop();
            this.initRecorder();
            this.initAuti();
        }
        initShare() {
            this.api.onShareAppMessage(function () {
                return PlatformTool.getShareObject();
            });
        }
        shareHandler() {
            this.api.shareAppMessage(PlatformTool.getShareObject());
            Laya.timer.once(3000, this, this.sharCompleteHandler);
        }
        initViedoAdEvent() {
        }
        sharCompleteHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_COMPLETE);
            this.dispatchEvent(AdEvent.AD_SHARE_SUCCESS);
        }
        showRewardView(taskCid = 0) {
            var type = PlatformTool.getRewardType();
            if (type == 'share') {
            }
            else if (type == 'adVideo') {
                this.checkVideoLoad();
            }
        }
        initViedoAd() {
            if (!BdminiConfig.videoid || !this.api.createRewardedVideoAd) {
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                return null;
            }
            if (!this.rewardedVideoAd) {
                let example = {
                    adUnitId: BdminiConfig.videoid,
                    appSid: BdminiConfig.appsid
                };
                let rewardedVideoAd = this.api.createRewardedVideoAd(example);
                rewardedVideoAd.load();
                rewardedVideoAd.onLoad(() => {
                    LogTool.log('激励视频加载成功');
                    PlatformModel.model.hasAdVideo = true;
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_LOAD);
                });
                rewardedVideoAd.onError((err) => {
                    PlatformModel.model.hasAdVideo = false;
                    SoundTool.setPause('video', false);
                    LogTool.log('激励视频错误:' + BdminiConfig.videoid + JSONUtil.stringify(err));
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                });
                rewardedVideoAd.onClose((res) => {
                    LogTool.log('激励视频关闭');
                    SoundTool.setPause('video', false);
                    this.videoPlaying = false;
                    if (res && res.isEnded) {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                    }
                    else {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                    }
                    rewardedVideoAd.load();
                });
                this.rewardedVideoAd = rewardedVideoAd;
            }
            this.initViedoAdEvent();
            return this.rewardedVideoAd;
        }
        checkVideoLoad() {
            let rewardedVideoAd = this.rewardedVideoAd;
            if (PlatformModel.model.hasAdVideo) {
                this.showVideoStartHandler();
            }
            else if (rewardedVideoAd) {
                rewardedVideoAd.load();
                this.onceEventListener(PlatformEvent.PLATFORM_AD_VIDEO_LOAD, this, this.showVideoStartHandler);
            }
        }
        showVideoStartHandler() {
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            let rewardedVideoAd = this.initViedoAd();
            SoundTool.setPause('video', true);
            rewardedVideoAd.show();
            this.videoPlaying = true;
        }
        shareCompHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareFailHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
        }
        videoPlayTimeHanlder() {
            this.videoPlaying = false;
        }
        initBannerAd() {
            if (OpminiConfig.bannerid) {
                LogTool.log("bdmini.initBanner");
                var showList = [];
                var preventList = [];
                this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
                this.startChild(this.checkShowBanner);
            }
        }
        bannerViewHandler(data) {
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBanner();
            }
            else {
                this.showBanner();
            }
        }
        showBanner() {
            if (!BdminiConfig.bannerid) {
                return;
            }
            if (this.bannerAd) {
                LogTool.log("showBanner-has");
                this.bannerAd.show();
                return;
            }
            LogTool.log("showBanner-load");
            var bannerid = BdminiConfig.bannerid;
            var appid = BdminiConfig.appsid;
            let info = this.api.getSystemInfoSync();
            let screenHeight = info.screenHeight;
            let screenWidth = info.screenWidth;
            LogTool.log("showBanner-show:id:" + bannerid + ',w:' + screenWidth + ',h:' + screenHeight);
            let bannerAd = this.api.createBannerAd({
                adUnitId: bannerid,
                appSid: appid,
                style: {
                    left: (screenWidth - 300) / 2,
                    height: 90,
                    top: screenHeight - 110,
                    width: 200,
                }
            });
            bannerAd.onLoad((res) => {
                LogTool.log("showBanner-onLoad");
                bannerAd.show();
            });
            bannerAd.onResize((res) => {
                LogTool.log("showBanner-onResize:w" + res.width + ',h:' + res.height + ',rh:' + bannerAd.style.realHeight);
                bannerAd.style.top = screenHeight - bannerAd.style.realHeight - 10;
            });
            bannerAd.onError((res) => {
                LogTool.log("showBanner-onError:" + res.errCode + ",msg:" + res.errMsg);
            });
            this.bannerAd = bannerAd;
        }
        closeBanner() {
            LogTool.log("showBanner-close");
            if (this.bannerAd) {
                this.bannerAd.hide();
            }
        }
        initDesktop() {
            var res = this.api.getLaunchOptionsSync();
            LogTool.log("initDesktop:" + res.scene);
            if (res.scene == BdminiConfig.sceneDesk) {
                PlatformModel.model.addDesktopFinish = true;
            }
        }
        initRecorder() {
        }
        battleStartHandler() {
            LogTool.log("bdmini:battleStartHandler");
            if (SceneModel.model.vo.state == 1) {
                this.vo.videoPath = null;
                this.vo.recorderEnd = false;
                if (this.api.getVideoRecorderManager) {
                    LogTool.log("bdmini:StartHandler");
                    this.recorderStartHandler();
                }
            }
        }
        recorderStartHandler() {
            LogTool.log("bdmini:recorderStartHandler");
            this.vo.videoPath = null;
            this.vo.recorderEnd = false;
            this.vo.state = 1;
            this.vo.videoShareComplete = false;
            const recorder = this.api.getVideoRecorderManager();
            this.recorder = recorder;
            recorder.onStart(res => {
                LogTool.log('录屏开始');
                this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_STATE_VIEW_SHOW, { showType: ViewType.OPEN });
                this.recorderTime = TimeUtil.getTime();
            });
            recorder.onStop(res => {
                LogTool.log('录屏结束:' + res.videoPath);
                this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_STATE_VIEW_SHOW, { showType: ViewType.CLOSE });
                this.vo.videoPath = res.videoPath;
                this.recorderStop();
            });
            recorder.start({
                microphoneEnabled: false,
                duration: 120
            });
        }
        recorderStopHandler() {
            LogTool.log('录屏:手动停止');
            this.vo.recorderEnd = true;
            if (this.recorder) {
                this.recorder.stop();
                this.recorderStop();
            }
        }
        recorderBattleStop(data) {
            LogTool.log('录屏:战斗结束:点击确定按钮');
            this.vo.recorderEnd = true;
            if (this.recorder) {
                this.recorder.stop();
            }
            this.recorderStop();
        }
        recorderStop() {
            Laya.timer.clear(this, this.recorderStartHandler);
            if (this.vo.recorderEnd) {
                this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_BTN_VIEW_SHOW, { showType: ViewType.CLOSE });
            }
            LogTool.log('录屏结束:显示分享:' + this.vo.recorderEnd + " , videoPath:" + this.vo.videoPath);
            if (this.vo.recorderEnd && this.vo.videoPath) {
            }
        }
        shareVideoHandler() {
            LogTool.log('分享录屏:' + this.vo.videoPath);
            var videoPath = this.vo.videoPath;
            if (videoPath) {
                this.api.shareVideo({
                    videoPath: videoPath,
                    title: PlatformTool.getShareText(),
                    success: () => {
                        LogTool.log('分享成功！');
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_VIDEO_COMPLETE);
                    },
                    fail: (e) => {
                        LogTool.log('分享失败！');
                        this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { type: PromptType.PROMPT_WARNING, text: "分享失败" });
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_VIDEO_FAIL);
                    }
                });
            }
            else {
                LogTool.log('没有录制视频');
            }
        }
        initAuti(callback = null) {
            if (!Laya.Browser.onIOS && this.api.getAntiAddiction) {
                LogTool.log('bdmini_pay:getAntiAddiction');
                let api = this.api.getAntiAddiction();
                api.onAntiAddiction((data) => {
                    var state = data.state;
                    var msg = data.msg;
                    console.log("state: ", state);
                    console.log("msg: ", msg);
                    if (callback) {
                        callback(state, msg);
                    }
                });
            }
        }
    }

    class Base64Util {
        static encode(text) {
            var Base64 = window['Base64'];
            return Base64.encode(text);
        }
        static decode(text) {
            var Base64 = window['Base64'];
            return Base64.decode(text);
        }
    }

    class NetTool {
        static request(url, data = null, method = 'GET', caller = null, fun = null, errfun = null) {
            this.requests(url, data, method, 'JSON', caller, fun, errfun);
        }
        static requests(url, data = null, method = 'GET', resultType = 'JSON', caller = null, fun = null, errfun = null) {
            var jdata = null;
            if (method == 'get' || method == 'GET') {
                url = this.getRequestUrl(url, data);
            }
            else {
            }
            jdata = this.getDataString(data);
            var xhr = new Laya.HttpRequest();
            xhr.http.timeout = 60000;
            xhr.http.withCredentials = true;
            xhr.once(Laya.Event.COMPLETE, this, completeHandler);
            xhr.once(Laya.Event.ERROR, this, errorHandler);
            xhr.send(url, jdata, method, "text");
            LogTool.log("net:request>:" + url + "?" + JSONUtil.stringify(jdata));
            this.requestList.push(xhr);
            function completeHandler(rdata) {
                ArrayUtil.remove(this.requestList, xhr);
                var jdata;
                if (resultType == 'JSON') {
                    jdata = JSONUtil.parse(rdata);
                    LogTool.log("net:response<:" + resultType + ",url" + url + "?" + rdata);
                }
                else if (resultType == 'BASE64') {
                    jdata = Base64Util.decode(rdata);
                    LogTool.log("net:response<:" + resultType + ",url" + url + "?" + edata);
                }
                else if (resultType == 'BASE64&JSON') {
                    var edata = Base64Util.decode(rdata);
                    LogTool.log("net:response<:" + resultType + ",url" + url + "?" + edata);
                    jdata = JSONUtil.parse(edata);
                }
                else {
                    jdata = rdata;
                    LogTool.log("net:response<:" + resultType + ",url" + url + "?" + rdata);
                }
                if (fun) {
                    fun.call(caller, jdata, data);
                }
            }
            function errorHandler(err) {
                ArrayUtil.remove(this.requestList, xhr);
                if (errfun) {
                    errfun.call(caller, err, data);
                }
            }
        }
        static getDataString(data) {
            if (!data) {
                return '';
            }
            var st = '';
            for (var key in data) {
                var element = data[key];
                st += key + '=' + element + '&';
            }
            return st;
        }
        static getRequestUrl(url, data = null) {
            if (!data) {
                return url;
            }
            if (url.indexOf('?') >= 0) {
                return url + '&' + this.getDataString(data);
            }
            else {
                return url + '?' + this.getDataString(data);
            }
        }
    }
    NetTool.requestList = [];

    class CsjConfig {
    }
    CsjConfig.gameId = 481;
    CsjConfig.version = '1.0.0';

    class CsjController extends Controller {
        constructor() {
            super();
            this.rateKey = [];
            this.ckey = '';
        }
        run() {
            super.run();
            PageConfig.pageScale = 0.8;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.showVideoAdHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsterHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_RANDOM_SHOW, this, this.showRandomHandler);
            this.addEventListener(NativeEvent.NATIVE_CALL_RESPONSE("videoAdComplete"), this, this.videoAdComplete);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            this.initSDK();
        }
        initParam() {
            this.initInsertAd();
            this.initBannerAd();
            this.initSplashAd();
            this.initLog();
        }
        videoAdComplete() {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        initBannerAd() {
            if (AdModel.model.isShieldCity) {
                return;
            }
            LogTool.log("csj.initBanner");
            var showList = ['LotteryView', 'BattleModesView', 'OnlineView', 'SignDayView', 'PageGoldGunGetView', 'GoodsGetView', 'TalentView',
                'ShopBuyView', 'PageShareView', 'PageCollectionView', 'AlertView', 'BattleResurrecView', 'BattleMatchView', 'BattleMatch5View'];
            var preventList = ['TalentResultView', 'GoodsExhView', 'BattleGetVipView'];
            this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
            this.startChild(this.checkShowBanner);
        }
        bannerViewHandler(data) {
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBanner();
            }
            else {
                this.showBanner();
            }
        }
        showBanner() {
            LogTool.log("bannerAdShow.show");
            NativeTool.showBannerAd();
            this.eventLog("bannerAdShow");
        }
        closeBanner() {
            NativeTool.closeBannerAd();
        }
        showVideoAdHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            LogTool.log('csj.激励广告');
            NativeTool.showVideoAd();
            this.eventLog("videoAdShow");
        }
        initInsertAd() {
        }
        showOrAdHandler() {
            LogTool.log('csj.showInsterHandler');
            TimerUtil.onceTimer(500, this, this.showInsterHandler);
        }
        showInsterHandler(data) {
            if (AdModel.model.isShieldCity) {
                return;
            }
            var list = ['BattleVictoryView', 'BattleDefeatView',];
            for (var view of list) {
                PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
                NativeTool.showInsterAd();
                this.eventLog("insterAdShow");
            }
        }
        showRandomHandler(data) {
            PlatformModel.model.adRandomId = ParamUtil.getString(data, 'id', '');
        }
        initLog() {
        }
        eventLog(name, type = '') {
            var eventType = this.getEventType(name, type);
            LogTool.log('eventLog.' + name + ',type:' + type + ',eventType:' + eventType);
            NativeTool.callNative("eventLog", { adName: name, adType: type, eventType: eventType });
        }
        getEventType(name, type = '') {
            if (type) {
                var nt = name + "_" + type;
            }
            else {
                var nt = name;
            }
            if (nt == 'bannerAdShow') {
                return 'event_1';
            }
            else if (nt == 'insterAdShow') {
                return 'event_2';
            }
            else if (nt == 'videoAdShow') {
                return 'event_3';
            }
            else if (nt == 'splashAdShow') {
                return 'event_4';
            }
        }
        initSplashAd() {
            if (AdModel.model.isShieldCity) {
                return;
            }
            LogTool.log('csj.开屏广告.init');
            NativeTool.showSplashAd();
            this.eventLog("splashAdShow");
        }
        initSDK() {
            this.getPinbi();
        }
        getPinbi() {
            var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/isPinbi';
            NetTool.request(url, { gameId: CsjConfig.gameId }, 'get', this, this.getCityHandler);
        }
        getCityHandler(data) {
            LogTool.log('csj.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            LogTool.log('csj.isShieldCity:' + AdModel.model.isShieldCity);
            this.getAdRate();
        }
        getAdRate() {
            if (this.rateKey.length > 0) {
                this.ckey = this.rateKey.shift();
                var data1 = { gameId: CsjConfig.gameId, version: CsjConfig.version, openId: 10000, key: this.ckey };
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/adrate';
                NetTool.request(url, data1, 'get', this, this.getAdRateHandler);
            }
            else {
                this.initParam();
            }
        }
        getAdRateHandler(data) {
            LogTool.log('csj.getAdRate:' + this.ckey + ':' + JSONUtil.stringify(data));
            AdModel.model.setRate(this.ckey, data.rate);
            this.getAdRate();
        }
    }

    class SjController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adShowHandler);
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_SHOW, this, this.shareShowHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            PageConfig.isShowBox = false;
            PageConfig.isShowGift = false;
            BattleConfig.isShowAd = false;
            BattleConfig.isShowTaskList = false;
        }
        adShowHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareShowHandler() {
            if (MainConfig.entry == 'android_app') {
                this.shareNatice();
            }
            else if (MainConfig.entry == 'ios_app') {
                this.shareNatice();
            }
            else {
                this.shareCopy();
            }
        }
        shareNatice() {
            if (NativeTool.available()) {
            }
            else {
                this.shareCopy();
            }
        }
        shareCopy() {
        }
    }

    class ViewTool {
        static synchView(viewName, c, adEvent, data = null) {
            function showHandler() {
                var datas = data || {};
                datas.showType = ViewType.OPEN;
                c.dispatchEvent(adEvent, datas);
            }
            function closeHandler() {
                var datas = data || {};
                datas.showType = ViewType.CLOSE;
                c.dispatchEvent(adEvent, datas);
            }
            c.addEventListener(ViewEvent.VIWE_OPEN(viewName), c, showHandler);
            c.addEventListener(ViewEvent.VIWE_CLOSE(viewName), c, closeHandler);
            if (ViewManager.getView(viewName)) {
                showHandler();
            }
            else {
                closeHandler();
            }
        }
        static contraryView(viewName, c, adEvent, data = null) {
            function showHandler() {
                var datas = data || {};
                datas.showType = ViewType.CLOSE;
                c.dispatchEvent(adEvent, datas);
            }
            function closeHandler() {
                var datas = data || {};
                datas.showType = ViewType.OPEN;
                c.dispatchEvent(adEvent, datas);
            }
            c.addEventListener(ViewEvent.VIWE_OPEN(viewName), c, showHandler);
            c.addEventListener(ViewEvent.VIWE_CLOSE(viewName), c, closeHandler);
            if (ViewManager.getView(viewName)) {
                closeHandler();
            }
            else {
                showHandler();
            }
        }
    }

    class MzminiConfig {
    }
    MzminiConfig.appid = '';
    MzminiConfig.videoid = 'mB024rbG';
    MzminiConfig.bannerid = 'Gx0QKDdX';
    MzminiConfig.insertid = 'RYjkPYZl';
    MzminiConfig.version = '1.0.0';

    class MzminiModel {
        constructor() {
        }
        static getApi() {
            if (typeof qg == "undefined") {
                return null;
            }
            else {
                return qg;
            }
        }
    }
    MzminiModel.model = new MzminiModel();

    class MzminiController extends Controller {
        constructor() {
            super();
            this.adViewTime = 0;
            this.bannerTs = 0;
        }
        run() {
            super.run();
            this.api = MzminiModel.getApi();
            this.vo = MzminiModel.model;
            PageConfig.pageScale = 0.8;
            BattleConfig.endType = 1;
            BattleConfig.defeatType = 1;
            BattleConfig.victoryType = 1;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsertAd);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            this.initViedoAd();
            this.initRemordAd();
            this.initBannerAd();
        }
        initViedoAd() {
            if (!MzminiConfig.videoid) {
                return null;
            }
            if (!this.rewardedVideoAd) {
                let example = {
                    posId: MzminiConfig.videoid,
                    adUnitId: MzminiConfig.videoid,
                };
                let rewardedVideoAd = this.api.createRewardedVideoAd(example);
                rewardedVideoAd.load();
                rewardedVideoAd.onLoad(() => {
                    PlatformModel.model.hasAdVideo = true;
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_LOAD);
                });
                rewardedVideoAd.onError((err) => {
                    PlatformModel.model.hasAdVideo = false;
                    LogTool.log('mzmini.激励视频错误:' + JSONUtil.stringify(err));
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                });
                rewardedVideoAd.onClose((res) => {
                    LogTool.log('mzmini.激励视频关闭');
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                    rewardedVideoAd.load();
                    SoundTool.setPause('adView', false);
                });
                this.rewardedVideoAd = rewardedVideoAd;
            }
            return this.rewardedVideoAd;
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            let rewardedVideoAd = this.initViedoAd();
            if (rewardedVideoAd && PlatformModel.model.hasAdVideo) {
                LogTool.log('mzmini.存在视频111:' + PlatformModel.model.hasAdVideo + rewardedVideoAd);
                if (TimeUtil.getTimestamp() - this.adViewTime <= 10) {
                    LogTool.log('mzmini.调用激励视频频率过高');
                    this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "暂无广告" });
                }
                else {
                    LogTool.log('mzmini.激励视频播放');
                    rewardedVideoAd.show();
                }
                this.adViewTime = TimeUtil.getTimestamp();
                SoundTool.setPause('adView', true);
            }
            else {
                this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "暂无广告" });
            }
        }
        initBannerAd() {
            if (MzminiConfig.bannerid) {
                LogTool.log("mzmini.initBanner.初始化banner");
                var showList = ['LotteryView', 'BattleModesView', 'OnlineView', 'SignDayView', 'PageGoldGunGetView', 'GoodsGetView', 'TalentView',
                    'ShopBuyView', 'PageShareView', 'PageCollectionView', 'AlertView', 'BattleResurrecView', 'BattleMatchView', 'BattleMatch5View'];
                var preventList = ['TalentResultView', 'GoodsExhView', 'BattleGetVipView'];
                this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
                this.startChild(this.checkShowBanner);
            }
        }
        bannerViewHandler(data) {
            this.barrerData = data;
            TimerUtil.onceTimer(100, this, this.showbannerHandler);
        }
        showbannerHandler() {
            if (this.barrerData && this.barrerData.showType == ViewType.CLOSE) {
                LogTool.log("mzmini.showbannerHandler.closeBanner");
                this.closeBanner();
            }
            else {
                LogTool.log("mzmini.showbannerHandler.showBanner");
                this.showBanner();
            }
        }
        initShowBanner(isShow = false) {
            if (!MzminiConfig.bannerid) {
                return;
            }
            if (this.bannerAd) {
                this.stopBanner();
            }
            var bannerid = MzminiConfig.bannerid;
            let info = this.api.getSystemInfoSync();
            let screenHeight = info.screenHeight;
            let screenWidth = info.screenWidth;
            LogTool.log("mzmini.showBannerHandler-bannerid:" + bannerid + ',h:' + screenHeight + ',w:' + screenWidth);
            let bannerAd = this.api.createBannerAd({
                adUnitId: bannerid,
                style: {
                    left: (screenWidth - 900) / 2,
                    top: screenHeight - 600,
                    width: 900,
                    height: 600,
                }
            });
            bannerAd.onResize((res) => {
                LogTool.log("mzmini.showBanner-onResize:w" + res.width + ',h:' + res.height);
                bannerAd.style.top = screenHeight - res.height;
                bannerAd.style.left = ((screenWidth - 900) / 2) + 60;
                bannerAd.style.width = res.width;
                bannerAd.style.height = res.height;
            });
            bannerAd.onError(res => {
                LogTool.log("mzmini.banner加载错误:" + JSONUtil.stringify(res));
                bannerAd.hide();
                bannerAd.destroy();
                this.bannerAd = null;
            });
            if (isShow) {
                LogTool.log("mzmini.banner显示:-");
                bannerAd.show();
            }
            this.bannerAd = bannerAd;
        }
        showBanner() {
            LogTool.log("mzmini.showBanner");
            var ts = TimeUtil.getTimestamp();
            if (!this.bannerAd) {
                this.bannerTs = ts;
                this.initShowBanner(true);
            }
            else if (this.bannerAd) {
                LogTool.log("mzmini.banner显示:-" + this.bannerAd.width + ',h:' + this.bannerAd.height);
                this.bannerAd.show();
            }
        }
        closeBanner() {
            LogTool.log("mzmini.closeBanner");
            if (this.bannerAd) {
                this.bannerAd.hide();
            }
        }
        stopBanner() {
            LogTool.log("mzmini.stopBanner");
            if (this.bannerAd) {
                this.bannerAd.hide();
                this.bannerAd.destroy();
                this.bannerAd = null;
            }
        }
        showInsertAd(data) {
            LogTool.log("mzmini.showInsertAd");
            PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
            if (!MzminiConfig.insertid) {
                return;
            }
            if (this.api.createInsertAd) {
                LogTool.log('mzmini.插屏 showInsertAd' + MzminiConfig.insertid);
                if (this.interstitialAd) {
                    this.interstitialAd.destroy();
                }
                this.interstitialAd = this.api.createInsertAd({
                    adUnitId: MzminiConfig.insertid,
                });
                this.interstitialAd.onLoad(() => {
                    LogTool.log('mzmini.插屏 广告加载成功');
                    this.interstitialAd.show();
                });
                this.interstitialAd.onError((err) => {
                    LogTool.log('mzmini.插屏 广告加载失败:' + JSONUtil.stringify(err));
                });
                this.interstitialAd.load();
            }
        }
        initRemordAd() {
            this.addEventListener(ViewEvent.VIWE_OPEN("BattleDefeatView"), this, this.showInsertAd);
            this.addEventListener(ViewEvent.VIWE_OPEN("BattleVictoryView"), this, this.showInsertAd);
            this.addEventListener(ViewEvent.VIWE_OPEN("BattleEndView"), this, this.showInsertAd);
        }
        gotoHandler(data) {
            LogTool.log('mzmini.gotoLinkHandler:' + data.appId);
            this.api.navigateToMiniGame({
                pkgName: data.appId,
                success: function () {
                    LogTool.log("mzmini.跳转成功");
                },
                fail: function (res) {
                    LogTool.log("mzmini.跳转失败" + JSON.stringify(res));
                }
            });
        }
        initEpView() {
            LogTool.log("mzmini.导出界面");
            ViewTool.synchView('PageView', this, EpEvent.EP_PAGE09_VIEW_SHOW);
            this.statusChangeAdHandler();
        }
        statusChangeAdHandler() {
            this.dispatchEvent(EpEvent.EP_PAGE09_VIEW_SHOW, { showType: ViewType.OPEN });
        }
    }

    class SignConfig {
        static getDayData(day, type) {
            if (type == 1) {
                return this.list1[day];
            }
            else {
                return this.list[day];
            }
        }
    }
    SignConfig.signType = 0;
    SignConfig.list = {
        1: { day: 1, name: 'day1', reward: { cid: 20010001, num: 100 } },
        2: { day: 2, name: 'day2', reward: { cid: 30011002, num: 100, count: 0 } },
        3: { day: 3, name: 'day3', reward: { cid: 20010001, num: 300 } },
        4: { day: 4, name: 'day4', reward: { cid: 30011003, num: 200 } },
        5: { day: 5, name: 'day5', reward: { cid: 20010001, num: 500 } },
        6: { day: 6, name: 'day6', reward: { cid: 30011001, num: 300 } },
        7: { day: 7, name: 'day7', reward: { cid: 30011010, num: 15, count: 0 } },
    };
    SignConfig.list1 = {
        1: { day: 1, name: 'day1', reward: { cid: 20010003, num: 2000 } },
        2: { day: 2, name: 'day2', reward: { cid: 20010001, num: 300 } },
        3: { day: 3, name: 'day3', reward: { cid: 20010003, num: 5000 } },
        4: { day: 4, name: 'day4', reward: { cid: 1, num: 1 } },
        5: { day: 5, name: 'day5', reward: { cid: 20010003, num: 10000 } },
        6: { day: 6, name: 'day6', reward: { cid: 2, num: 1 } },
        7: { day: 7, name: 'day7', reward: { cid: 20010001, num: 800 } },
    };

    class OpminiModel {
        constructor() {
        }
        static getApi() {
            if (typeof qg == "undefined") {
                return null;
            }
            else {
                return qg;
            }
        }
    }
    OpminiModel.model = new OpminiModel();

    class OpminiAddIcoController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = OpminiModel.getApi();
            this.vo = OpminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_ADDICO_SHOW, this, this.addicoHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_END, this, this.initAddIcoHandler);
            this.initAddIco();
        }
        initAddIco() {
            LogTool.log("opmini:initAddIco");
            if ('hasShortcutInstalled' in this.api && 'installShortcut' in this.api) {
                this.api.hasShortcutInstalled({
                    success: (res) => {
                        LogTool.log("opmini:hasShortcutInstalled:" + res);
                        if (res) {
                        }
                        else {
                            LogTool.log('桌面还未添加图标');
                            this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_VIEW_SHOW, { showType: ViewType.OPEN });
                            this.addIcoEvent();
                        }
                    },
                    fail: (err) => { },
                });
            }
        }
        addIcoEvent() {
            this.addEventListener(ViewEvent.VIWE_OPEN('PageView'), this, this.initAddIco);
            this.addEventListener(ViewEvent.VIWE_CLOSE('PageView'), this, this.statusChangeicoHandler);
        }
        statusChangeicoHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_VIEW_SHOW, { showType: ViewType.CLOSE });
        }
        initAddIcoHandler() {
            LogTool.log("vvmini:initAddIco-游戏结束");
            if (this.api.hasShortcutInstalled) {
                this.api.hasShortcutInstalled({
                    success: (res) => {
                        LogTool.log("vvmini:hasShortcutInstalled:" + res);
                        if (res) {
                        }
                        else {
                            LogTool.log('桌面还未添加图标');
                            this.addicoHandler();
                        }
                    },
                    fail: (err) => { },
                });
            }
        }
        addicoHandler() {
            LogTool.log("opmini.addico");
            if ('installShortcut' in this.api) {
                this.api.installShortcut({
                    success: (res) => {
                        LogTool.log("opmini.addico.success:" + JSONUtil.stringify(res));
                        TimerUtil.onceTimer(600, this, this.addicoCompHandler);
                    },
                    fail: (err) => {
                        LogTool.log("opmini.addico:" + JSONUtil.stringify(err));
                    }
                });
            }
        }
        addicoCompHandler() {
            this.api.hasShortcutInstalled({
                success: (res) => {
                    LogTool.log("opmini:hasShortcutInstalled:" + res);
                    if (res) {
                        LogTool.log("opmini.addico:success:" + JSONUtil.stringify(res));
                        PlatformModel.model.isAddIco = true;
                        PlatformModel.model.saveData();
                        this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_COMPLETE);
                        this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_OK, text: "添加成功" });
                    }
                }
            });
        }
    }

    class AdNativeVo {
        constructor() {
            this.type = '';
            this.nativeId = '';
            this.nativeURL = '';
            this.nativeTitle = '';
            this.nativeContent = '';
            this.nativeIco = '';
            this.nativeLogoUrl = '';
            this.startTs = 0;
            this.useLib = {};
        }
    }

    class OpminiNativeAdController extends Controller {
        constructor(data) {
            super();
            this.refreshTime = 0;
            this.isClickClose = false;
            this.isStops = false;
            this.data = data;
            this.id = ParamUtil.getString(this.data, "id", this.id);
            this.pid = "" + IdUtil.getId();
        }
        run() {
            super.run();
            this.api = OpminiModel.getApi();
            this.viewName = this.data.viewName;
            this.nativeid = OpminiConfig.getNative(this.data.type);
            this.ui = this.data.ui;
            this.ico = this.data.ico;
            this.image = this.data.image;
            this.title = this.data.title;
            this.content = this.data.content;
            this.refreshTime = ParamUtil.getInt(this.data, 'refreshTime');
            this.clickList = this.data.clickList;
            this.showHandler = this.data.showHandler;
            this.closeHandler = this.data.closeHandler;
            this.isClickClose = ParamUtil.getBool(this.data, "isClickClose", false);
            if (this.ui) {
                this.ui.visible = false;
            }
            if (this.ico) {
                this.ico.visible = false;
                this.ico.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.image) {
                this.image.visible = false;
                this.image.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.title) {
                this.title.visible = false;
                this.title.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.content) {
                this.content.visible = false;
                this.content.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.clickList) {
                for (var k in this.clickList) {
                    var clickBox = this.clickList[k];
                    clickBox.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
                }
            }
            LogTool.log('opmini.原生广告.closeHandlers.1');
            this.addEventListener(ViewEvent.VIWE_CLOSE(this.viewName), this, this.closeHandlers);
            this.addEventListener(AdEvent.AD_NATIVE_CLICK, this, this.clickNativeAdHandler);
            this.addEventListener(AdEvent.AD_NATIVE_CLICKED(this.viewName), this, this.clickNativeAdHandler);
            this.loadNativeAd();
        }
        closeHandlers() {
            if (this.isStops == false) {
                this.isStops = true;
                LogTool.log('opmini.原生广告.closeHandlers:' + this.viewName + '');
                this.showAd();
                this.callStop();
                this.stopNatived();
                this.stop();
                this.vo = null;
            }
        }
        loadNativeAd() {
            if (AdModel.model.isShieldCity) {
                if (TimeUtil.getTimestamp() - PageModel.model.gameTs < 60) {
                    LogTool.log('opmini.原生广告:' + this.viewName + ' timte < 60');
                    LogTool.log('opmini.原生广告.closeHandlers.2');
                    this.closeHandlers();
                    return;
                }
            }
            var vo = AdModel.model.getNativeAd(this.nativeid);
            if (vo) {
                this.vo = vo;
                this.nativeAd = vo.nativeAd;
                this.loadComplete();
            }
            else {
                this.startLoadNativeAd();
            }
        }
        startLoadNativeAd() {
            LogTool.log('opmini.原生广告开始载.startLoadNativeAd:' + this.viewName);
            this.nativeAd = this.api.createNativeAd({
                adUnitId: this.nativeid
            });
            this.nativeAd.onLoad((res) => {
                LogTool.log('opmini.原生广告加载成功:' + JSONUtil.stringify(res));
                var list = res.adList;
                if (PropUtil.isEmpty(list) == false) {
                    var item = list[0];
                    var vo = new AdNativeVo();
                    vo.nativeId = item.adId;
                    vo.nativeURL = item.imgUrlList[0];
                    vo.nativeTitle = item.title;
                    vo.nativeContent = item.desc;
                    vo.nativeIco = item.icon;
                    vo.nativeLogoUrl = item.logoUrl;
                    vo.nativeAd = this.nativeAd;
                    this.vo = vo;
                    AdModel.model.addNativeAd(this.nativeid, this.vo);
                    this.loadComplete();
                }
            });
            this.nativeAd.onError((res) => {
                LogTool.log('opmini.原生广告加载失败:' + JSONUtil.stringify(res));
                LogTool.log('opmini.原生广告.closeHandlers.3');
                this.closeHandlers();
            });
            this.nativeAd.load();
        }
        loadComplete() {
            if (this.vo) {
                AdModel.model.addNativeUse(this.nativeid, this.pid);
            }
            if (this.showHandler) {
                LogTool.log("opmini:showHandler.");
                HandlerUtil.call(this.showHandler, { vo: this.vo });
            }
            this.showAd();
            this.showNativeAdHandler();
            LogTool.log("opmini:loadNativeAd.url:" + this.vo.nativeURL);
            if (this.refreshTime > 0) {
                TimerUtil.onceTimer(this.refreshTime, this, this.reloadHandler);
            }
        }
        reloadHandler() {
            if (this.nativeAd) {
                this.nativeAd.load();
            }
        }
        showNativeAdHandler() {
            if (this.nativeAd) {
                this.nativeAd.reportAdShow({ adId: this.vo.nativeId });
                LogTool.log('opmini.原生广告.reportAdShow:' + this.vo.nativeId);
                this.adShowHandler();
            }
        }
        clickNativeAdHandler() {
            if (this.nativeAd) {
                if (AdModel.model.nativeCanclick == 0) {
                    this.nativeAd.reportAdClick({ adId: this.vo.nativeId });
                    LogTool.log('opmini.原生广告.reportAdClick.nativeId:' + this.vo.nativeId);
                    this.adClickHandler();
                }
            }
            if (this.isClickClose) {
                LogTool.log('opmini.原生广告.closeHandlers.4');
                this.closeHandlers();
            }
        }
        stopNatived() {
            LogTool.log('opmini.原生广告.stopNatived-' + this.nativeid + '_' + this.pid);
            AdModel.model.subNativeUse(this.nativeid, this.pid);
            LogTool.log('opmini.原生广告.stopNatived-hasvo');
            if (AdModel.model.hasNativeUse(this.nativeid) == false) {
                LogTool.log('opmini.原生广告.2' + JSONUtil.stringify(this.nativeAd));
                if (this.nativeAd) {
                    LogTool.log('opmini.原生广告.stopNatived-id:' + this.nativeid);
                    LogTool.log('opmini.原生广告.stopNatived.destroy');
                    this.nativeAd.destroy();
                    AdModel.model.removeNativeAd(this.nativeid);
                    this.nativeAd = null;
                }
            }
        }
        callStop() {
            if (this.closeHandler) {
                LogTool.log("opmini:closeHandler.");
                HandlerUtil.call(this.closeHandler);
            }
        }
        adShowHandler() {
            var data1 = { gameId: OpminiConfig.gameId, type: 'show', adid: this.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readShowHandler);
        }
        readShowHandler() {
        }
        adClickHandler() {
            var data1 = { gameId: OpminiConfig.gameId, type: 'click', adid: this.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readClickHandler);
        }
        readClickHandler() {
        }
        showAd() {
            if (this.vo) {
                if (this.ui) {
                    this.ui.visible = true;
                }
                if (this.ico) {
                    LogTool.log('opmini.原生广告.ico:' + this.vo.nativeIco);
                    this.ico.visible = true;
                    this.ico.skin = this.vo.nativeIco;
                }
                if (this.image) {
                    LogTool.log('opmini.原生广告.image:' + this.vo.nativeURL);
                    this.image.visible = true;
                    this.image.skin = this.vo.nativeURL;
                }
                if (this.title) {
                    LogTool.log('opmini.原生广告.title:' + this.vo.nativeTitle);
                    this.title.visible = true;
                    this.title.text = this.vo.nativeTitle;
                }
                if (this.content) {
                    LogTool.log('opmini.原生广告.content:' + this.vo.nativeContent);
                    this.content.visible = true;
                    this.content.text = this.vo.nativeContent;
                }
            }
            else {
                if (this.ui) {
                    this.ui.visible = false;
                }
                if (this.ico) {
                    this.ico.visible = false;
                }
                if (this.image) {
                    this.image.visible = false;
                }
                if (this.title) {
                    this.image.visible = false;
                }
                if (this.content) {
                    this.content.visible = false;
                }
            }
        }
    }

    class OpminiPortalController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = OpminiModel.getApi();
            this.vo = OpminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_GAMEBANNER_SHOW, this, this.initPortalAdView);
        }
        initPortalAdView() {
            LogTool.log("opmini.互推盒子");
            if (!OpminiConfig.portalid) {
                return null;
            }
            this.gamePortalAd = this.api.createGamePortalAd({
                adUnitId: OpminiConfig.portalid
            });
            this.gamePortalAd.load();
            this.gamePortalAd.onLoad(() => {
                LogTool.log('opmini.互推盒子 广告加载成功');
                this.gamePortalAd.show();
            });
            this.gamePortalAd.onError((err) => {
                LogTool.log('opmini.互推盒子 广告加载失败:' + JSONUtil.stringify(err));
            });
        }
    }

    class OpminiVideoAdController extends Controller {
        constructor() {
            super();
            this.adViewTime = 0;
        }
        run() {
            super.run();
            this.api = OpminiModel.getApi();
            this.vo = OpminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.initViedoAd();
        }
        initViedoAd() {
            if (!OpminiConfig.videoid) {
                return null;
            }
            if (!this.rewardedVideoAd) {
                let example = {
                    posId: OpminiConfig.videoid,
                    adUnitId: OpminiConfig.videoid,
                };
                let rewardedVideoAd = this.api.createRewardedVideoAd(example);
                rewardedVideoAd.load();
                rewardedVideoAd.onLoad(() => {
                    PlatformModel.model.hasAdVideo = true;
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_LOAD);
                });
                rewardedVideoAd.onError((err) => {
                    PlatformModel.model.hasAdVideo = false;
                    LogTool.log('opmini.激励视频错误:' + JSONUtil.stringify(err));
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                });
                rewardedVideoAd.onClose((res) => {
                    LogTool.log('opmini.激励视频关闭');
                    if (res && res.isEnded) {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                    }
                    else {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                    }
                    rewardedVideoAd.load();
                    SoundTool.setPause('adView', false);
                });
                this.rewardedVideoAd = rewardedVideoAd;
            }
            return this.rewardedVideoAd;
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            let rewardedVideoAd = this.initViedoAd();
            if (rewardedVideoAd && PlatformModel.model.hasAdVideo) {
                LogTool.log('opmini.存在视频');
                if (TimeUtil.getTimestamp() - this.adViewTime <= 10) {
                    LogTool.log('调用激励视频频率过高');
                    this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "暂无广告" });
                }
                else {
                    rewardedVideoAd.show();
                }
                this.adViewTime = TimeUtil.getTimestamp();
                SoundTool.setPause('adView', true);
            }
            else {
                this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "暂无广告" });
            }
        }
    }

    class OpminiController extends Controller {
        constructor() {
            super();
            this.rateList = ['yanchi', 'wudian', 'icontime', 'yuansheng'];
        }
        run() {
            super.run();
            this.api = OpminiModel.getApi();
            this.vo = OpminiModel.model;
            this.addEventListener(LoadingEvent.LOADING_LOGIN_PROGRESS, this, this.setLoadingHandler);
            this.addEventListener(PlatformEvent.PLATFORM_EXIT, this, this.exitHandler);
            this.addEventListener(AdEvent.AD_NATIVE_LOAD, this, this.loadNativeAd);
            this.addEventListener(PlatformEvent.PLATFORM_LINK_GOTO, this, this.gotoHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(PlatformEvent.PLATFORM_API_INIT, this, this.initApiHandler);
            this.setLoadingProgress(0);
        }
        initHandler() {
            this.initAd();
            this.initPrivacy();
        }
        initApiHandler() {
            this.initEpView();
            this.startChild(new OpminiVideoAdController());
            this.startChild(new OpminiPortalController());
            this.startChild(new OpminiAddIcoController());
        }
        initParam() {
            this.initNativeAd();
            if (AdModel.model.isShieldCity == false) {
                PlayerConfig.playerType = 1;
                PageConfig.pageRewardType = 1;
                SignConfig.signType = 1;
                GoodsConfig.goodGetType = 1;
                OnlineConfig.onlineType = 1;
                BattleConfig.battleTryType = 1;
                BattleConfig.battleTaskType = 1;
                BattleConfig.victoryType = 1;
                BattleConfig.defeatType = 1;
                CommonConfig.alertType = 1;
                BattleConfig.battleTryTypeTwo = 1;
            }
            else {
                PlayerConfig.playerType = 1;
                PageConfig.pageRewardType = 2;
                SignConfig.signType = 0;
                GoodsConfig.goodGetType = 2;
                OnlineConfig.onlineType = 2;
                BattleConfig.battleTryType = 0;
                BattleConfig.battleTaskType = 2;
                BattleConfig.victoryType = 2;
                BattleConfig.defeatType = 2;
                CommonConfig.alertType = 2;
                BattleConfig.battleTryTypeTwo = 0;
            }
        }
        initPrivacy(data = null) {
            if (PlatformModel.model.privacyNum < 1) {
                this.dispatchEvent(PlatformEvent.PLATFORM_PRIVACY_VIEW);
            }
        }
        setLoadingHandler(data) {
            this.setLoadingProgress(data.progress);
        }
        setLoadingProgress(v) {
            this.api.setLoadingProgress({ progress: v * 100 });
            if (v == 1) {
                this.api.loadingComplete({ complete: (res) => { } });
            }
        }
        initAd() {
            this.api.initAdService({
                appId: OpminiConfig.appid,
                isDebug: false,
                success: (res) => {
                    LogTool.log("opmini.initAdService success");
                    this.initSdk();
                },
                fail: (res) => {
                    LogTool.log("opmini.initAdService fail:" + res.code + res.msg);
                },
                complete: (res) => {
                    LogTool.log("opmini.initAdService complete");
                }
            });
        }
        initNativeAd() {
            this.initNativHandler();
        }
        initNativHandler() {
            var showList = ['PlayerSetView', 'PageRewardView', 'AlertView'];
            var preventList = ['BattleVictoryView', 'BattleDefeatView', 'SegmentLvUpView'];
            this.checkShowAd = new CheckShowController(PlatformEvent.PLATFORM_AD_NATIVE_VIEW_SHOW, { type: 'ad' }, showList, preventList);
            this.startChild(this.checkShowAd);
            var showList3 = ['GoodsGetView', 'OnlineView', 'BattleTaskView', 'BattleVictoryView', 'BattleDefeatView'];
            var preventList3 = ['BattleVictoryView', 'BattleDefeatView', 'SegmentLvUpView'];
            this.checkShowAd3 = new CheckShowController(PlatformEvent.PLATFORM_AD_NATIVE3_VIEW_SHOW, { type: 'ad' }, showList3, preventList3);
            this.startChild(this.checkShowAd3);
            var showList4 = ['BattleVictoryView', 'BattleDefeatView'];
            var preventList4 = ['SegmentLvUpView'];
            this.checkShowAd4 = new CheckShowController(PlatformEvent.PLATFORM_AD_NATIVE4_VIEW_SHOW, { type: 'ad' }, showList4, preventList4);
            this.startChild(this.checkShowAd4);
            this.addEventListener(SceneEvent.SCENE_BEGAIN_CAMERA_COMPLETE, this, this.showNativeIco);
        }
        showNativeIco() {
            this.checkShowIco = new CheckShowController(PlatformEvent.PLATFORM_AD_NATIVE_ICON_VIEW_SHOW, null, [], []);
            this.checkShowIco.regOpenView('BattleView', { type: 'ico', y: 173, right: 1125, zorder: 20, refreshTime: 30000 });
            this.startChild(this.checkShowIco);
        }
        loadNativeAd(data) {
            LogUtil.log("loadNativeAd:opmini");
            if (!this.getChild(data.viewName)) {
                LogUtil.log("loadNativeAd:opmini:startChild");
                this.startChild(new OpminiNativeAdController(data));
            }
        }
        gotoHandler(data) {
            LogTool.log('opmini.gotoLinkHandler:' + data.appId);
            this.api.navigateToMiniGame({
                pkgName: data.appId,
                success: function () {
                    LogTool.log("opmini.跳转成功");
                },
                fail: function (res) {
                    LogTool.log("opmini.跳转失败" + JSON.stringify(res));
                }
            });
        }
        initEpView() {
            LogTool.log("opmini.导出界面");
            ViewTool.synchView('PageView', this, EpEvent.EP_PAGE10_VIEW_SHOW);
            this.statusChangeAdHandler();
        }
        statusChangeAdHandler() {
            this.dispatchEvent(EpEvent.EP_PAGE10_VIEW_SHOW, { showType: ViewType.OPEN });
        }
        initSdk() {
            this.startLogin();
        }
        startLogin() {
            var data = {};
            data.gameId = OpminiConfig.gameId;
            data.version = OpminiConfig.version;
            data.channel_id = PlatformModel.model.channel_id;
            data.openId = PlatformModel.model.openId;
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/login';
            NetTool.request(url, data, 'get', this, this.loginResponseHandler);
        }
        loginResponseHandler(data) {
            EpModel.model.adData = EpTool.reAdData(data);
            this.dispatchEvent(EpEvent.EP_DATA_RESPONSE);
            this.getCity();
        }
        getCity() {
            if (OpminiConfig.gameId) {
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/isPinbi';
                NetTool.request(url, { gameId: OpminiConfig.gameId }, 'get', this, this.getCityHandler);
            }
        }
        getCityHandler(data) {
            LogTool.log('opmini.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            this.getRateAip();
        }
        getRateAip() {
            if (this.rateList.length > 0) {
                var key = this.rateList.shift();
                var data1 = { gameId: OpminiConfig.gameId, version: OpminiConfig.version, key: key };
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/adrate';
                NetTool.request(url, data1, 'get', this, (data) => {
                    AdModel.model.setRate(key, ParamUtil.getInt(data, 'rate'));
                    this.getRateAip();
                });
            }
            else {
                this.dispatchEvent(PlatformEvent.PLATFORM_API_INIT);
                this.initCanclick();
            }
        }
        initCanclick() {
            var data1 = { gameId: OpminiConfig.gameId, type: 'canclick', adid: OpminiConfig.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readCanclickHandler);
        }
        readCanclickHandler(data) {
            if (data) {
                AdModel.model.nativeCanclick = data.code;
            }
            this.initParam();
        }
        exitHandler() {
            this.api.exitApplication({});
        }
    }

    class OppoConfig {
        static getNative(type) {
            if (this.nativeids[type]) {
                return this.nativeids[type];
            }
            return this.nativeids['ad'];
        }
        static getAdProd(type) {
            var c = this.adProb[type];
            if (c) {
                return c;
            }
            return 0.5;
        }
    }
    OppoConfig.videoid = '';
    OppoConfig.bannerid = '';
    OppoConfig.gameId = 490;
    OppoConfig.version = '1.0.0';
    OppoConfig.nativeids = {
        'ad': '306724',
        'banner': '306725'
    };
    OppoConfig.adProb = {
        'levOpen': 0.5,
        'lvUp': 0.3,
        'bossReward': 0.5,
        'offlineReward': 0.3,
        'dropReward': 0.3,
        'reward': 0.3,
    };

    class OppoIcoView extends ui.platform.PlatformOppoIcoUI {
        constructor() {
            super();
            this.zOrder = 10;
        }
    }

    class OppoIcoViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = OppoIcoView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.y = 210;
            this.ui.left = 2;
            LogTool.log('显示更多游戏按钮');
            this.ui.box_ico.on(Laya.Event.CLICK, this, this.clickHandler);
        }
        clickHandler() {
            LogTool.log('oppo.showPlatformView');
            NativeTool.showPlatformView();
        }
    }

    class OppoNativeAdController extends Controller {
        constructor(data) {
            super();
            this.refreshTime = 0;
            this.isClickClose = false;
            this.isStops = false;
            this.data = data;
            this.id = ParamUtil.getString(this.data, "id", this.id);
        }
        run() {
            super.run();
            this.viewName = this.data.viewName;
            this.nativeid = OppoConfig.getNative(this.data.type);
            this.ui = this.data.ui;
            this.ico = this.data.ico;
            this.image = this.data.image;
            this.title = this.data.title;
            this.content = this.data.content;
            this.refreshTime = ParamUtil.getInt(this.data, 'refreshTime');
            this.clickList = this.data.clickList;
            this.showHandler = this.data.showHandler;
            this.closeHandler = this.data.closeHandler;
            this.isClickClose = ParamUtil.getBool(this.data, "isClickClose", false);
            if (this.ui) {
                this.ui.visible = false;
            }
            if (this.ico) {
                LogTool.log('oppo.原生广告.click.ico');
                this.ico.visible = false;
                this.ico.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.image) {
                LogTool.log('oppo.原生广告.click.image');
                this.image.visible = false;
                this.image.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.title) {
                LogTool.log('oppo.原生广告.click.title');
                this.title.visible = false;
                this.title.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.content) {
                LogTool.log('oppo.原生广告.click.content');
                this.content.visible = false;
                this.content.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
            }
            if (this.clickList) {
                for (var k in this.clickList) {
                    LogTool.log('oppo.原生广告.click.clickList');
                    var clickBox = this.clickList[k];
                    clickBox.on(Laya.Event.MOUSE_UP, this, this.clickNativeAdHandler);
                }
            }
            this.addEventListener(ViewEvent.VIWE_CLOSE(this.viewName), this, this.closeHandlers);
            this.addEventListener(AdEvent.AD_NATIVE_CLICK, this, this.clickNativeAdHandler);
            this.loadNativeAd();
        }
        closeHandlers() {
            if (this.isStops == false) {
                this.isStops = true;
                LogTool.log('oppo.原生广告.closeHandlers:' + this.viewName + '');
                this.vo = null;
                this.showAd();
                this.callStop();
                this.stopNatived();
                this.stop();
            }
        }
        loadNativeAd() {
            LogTool.log('oppo.loadNativeAd.isShieldCity' + AdModel.model.isShieldCity);
            LogTool.log('oppo.原生广告开始载' + this.viewName);
            this.addEventListener(NativeEvent.NATIVE_CALL_RESPONSE("nativeAdResponse"), this, this.nativeAdComplete);
            NativeTool.callNative("nativeAdLoad", { id: this.nativeid });
        }
        nativeAdComplete(data) {
            LogTool.log("oppo:nativeAdComplete.url:" + JSONUtil.stringify(data));
            if (data.id == this.nativeid) {
                var vo = new AdNativeVo();
                vo.nativeId = data.id;
                vo.nativeURL = data.img;
                vo.nativeTitle = data.title;
                vo.nativeContent = data.desc;
                vo.nativeIco = data.ico;
                vo.nativeLogoUrl = data.ico;
                this.vo = vo;
                if (this.showHandler) {
                    LogTool.log("oppo:showHandler.");
                    HandlerUtil.call(this.showHandler, { vo: vo });
                }
                this.showAd();
                this.showNativeAdHandler();
                LogTool.log("oppo:loadNativeAd.url:" + this.vo.nativeURL);
            }
        }
        showNativeAdHandler() {
            if (this.vo) {
                LogTool.log('oppo.原生广告.reportAdShow:' + this.vo.nativeId);
                this.adShowHandler();
            }
        }
        clickNativeAdHandler() {
            LogTool.log('oppo.原生广告.clickNativeAdHandler' + this.nativeid);
            if (this.vo) {
                if (AdModel.model.nativeCanclick == 0) {
                    NativeTool.callNative("nativeAdClick", { id: this.nativeid });
                    LogTool.log('oppo.原生广告.reportAdClick.nativeId:' + this.vo.nativeId);
                    this.adClickHandler();
                }
            }
            if (this.isClickClose) {
                this.closeHandlers();
            }
        }
        stopNatived() {
            LogTool.log('oppo.原生广告.stopNatived');
            if (this.vo) {
                NativeTool.callNative("nativeAdClose", { id: this.nativeid });
                this.vo = null;
            }
        }
        callStop() {
            if (this.closeHandler) {
                LogTool.log("oppo:closeHandler.");
                HandlerUtil.call(this.closeHandler);
            }
        }
        adShowHandler() {
            var data1 = { gameId: OppoConfig.gameId, type: 'show', adid: this.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readShowHandler);
        }
        readShowHandler() {
        }
        adClickHandler() {
            LogTool.log('oppo.原生广告.adClickHandler');
            var data1 = { gameId: OppoConfig.gameId, type: 'click', adid: this.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readClickHandler);
        }
        readClickHandler() {
        }
        showAd() {
            if (this.vo) {
                if (this.ui) {
                    this.ui.visible = true;
                }
                if (this.ico) {
                    LogTool.log('oppo.原生广告.ico' + this.vo.nativeIco);
                    this.ico.visible = true;
                    this.ico.skin = this.vo.nativeIco;
                }
                if (this.image) {
                    LogTool.log('oppo.原生广告.image' + this.vo.nativeURL);
                    this.image.visible = true;
                    this.image.skin = this.vo.nativeURL;
                }
                if (this.title) {
                    LogTool.log('oppo.原生广告.title' + this.vo.nativeTitle);
                    this.title.visible = true;
                    this.title.text = this.vo.nativeTitle;
                }
                if (this.content) {
                    LogTool.log('oppo.原生广告.content' + this.vo.nativeContent);
                    this.content.visible = true;
                    this.content.text = this.vo.nativeContent;
                }
            }
            else {
                if (this.ui) {
                    this.ui.visible = false;
                }
                if (this.ico) {
                    this.ico.visible = false;
                }
                if (this.image) {
                    this.image.visible = false;
                }
                if (this.title) {
                    this.image.visible = false;
                }
                if (this.content) {
                    this.content.visible = false;
                }
            }
        }
    }

    class OppoController extends Controller {
        constructor() {
            super();
            this.adNum = 0;
            this.rateList = [];
        }
        run() {
            super.run();
            PageConfig.pageScale = 0.8;
            PageConfig.pageQqShow = true;
            BattleConfig.endType = 1;
            BattleConfig.defeatType = 1;
            BattleConfig.victoryType = 1;
            BattleConfig.battleViewType = 1;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.showVideoAdHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsterHandler);
            this.addEventListener(NativeEvent.NATIVE_CALL_RESPONSE("videoAdComplete"), this, this.videoAdComplete);
            this.addEventListener(AdEvent.AD_NATIVE_LOAD, this, this.loadNativeAd);
            this.addEventListener(PlatformEvent.PLATFORM_EXIT, this, this.exitHandler);
            ViewManager.register(PlatformEvent.PLATFORM_OPPO_ICO_VIEW, this, OppoIcoViewController);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            this.initIco();
            this.initPrivacy();
            this.initLog();
            this.initSdk();
            this.initCanclick();
        }
        initParam() {
            this.initNativeAd();
            this.initNativePageAd();
            if (AdModel.model.isShieldCity == false) {
                BattleConfig.getGunType = 1;
            }
        }
        initPrivacy(data = null) {
            if (PlatformModel.model.privacyNum < 1) {
                this.dispatchEvent(PlatformEvent.PLATFORM_PRIVACY_VIEW);
            }
        }
        initIco(data = null) {
            ViewTool.synchView('PageView', this, PlatformEvent.PLATFORM_OPPO_ICO_VIEW);
        }
        initBannerAd() {
            LogTool.log("oppo.initBanner");
            var showList = ['LotteryView', 'BattleModesView', 'OnlineView', 'SignDayView', 'PageGoldGunGetView', 'GoodsGetView', 'TalentView',
                'ShopBuyView', 'PageShareView', 'PageCollectionView', 'AlertView', 'BattleResurrecView', 'BattleMatchView', 'BattleMatch5View'];
            var preventList = ['TalentResultView', 'GoodsExhView', 'BattleGetVipView'];
            this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
            this.startChild(this.checkShowBanner);
        }
        bannerViewHandler(data) {
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBanner();
            }
            else {
                this.showBanner(data);
            }
        }
        showBanner(data) {
            NativeTool.showBannerAd(data);
            this.eventLog("bannerAdShow");
        }
        closeBanner() {
            NativeTool.closeBannerAd();
        }
        showVideoAdHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            LogTool.log('oppo.showVideoAdHandler.激励广告');
            NativeTool.showVideoAd();
            this.eventLog("videoAdShow", PlatformModel.model.adVideoId);
        }
        videoAdComplete() {
            LogTool.log('oppo.激励广告.奖励');
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        initInsertAd() {
            LogTool.log('oppo.插屏广告.init');
            var list = ['BattleDefeatView', 'BattleVictoryView', 'BattleEndView'];
            for (var view of list) {
                LogTool.log("oppo.initAdInsert:" + view);
                this.addEventListener(ViewEvent.VIWE_OPEN(view), this, this.showOrAdHandler);
            }
        }
        showOrAdHandler() {
            LogTool.log('oppo.showInsterHandler');
            this.adNum++;
            if (this.adNum < 3) {
                return;
            }
            if (this.adNum % 5 == 0) {
                TimerUtil.onceTimer(500, this, this.showInsterHandler);
            }
        }
        showInsterHandler(data) {
            PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
            NativeTool.showFullAd();
            this.eventLog("insterAdShow");
        }
        initNativeAd() {
            LogTool.log('oppo.initNativeAd.原生广告初始化');
            if (AdModel.model.isShieldCity == false) {
                var showList = ['LotteryView', 'BattleModesView', 'OnlineView', 'SignDayView', 'PageGoldGunGetView', 'GoodsGetView', 'TalentView',
                    'ShopBuyView', 'PageShareView', 'PageCollectionView', 'AlertView', 'BattleMatchView', 'BattleMatch5View'];
                var preventList = ['TalentResultView', 'GoodsExhView', 'BattleGetVipView'];
                this.checkShowAd = new CheckShowController(PlatformEvent.PLATFORM_AD_NATIVE1_VIEW_SHOW, null, showList, preventList);
                this.checkShowAd.regOpenView('BattleResurrecView', { type: 'banner', zorder: 21 });
                this.startChild(this.checkShowAd);
            }
            this.checkShowAd2 = new CheckShowController(PlatformEvent.PLATFORM_AD_NATIVE_VIEW_SHOW, null, [], ['BattleResurrecView', 'AlertView']);
            this.checkShowAd2.regOpenView('BattleView', { type: 'ad', zorder: 20, right: 1 });
            this.startChild(this.checkShowAd2);
        }
        initNativePageAd() {
            ViewTool.synchView('BattleGetVipView', this, PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { type: 'ad', time: 1000 });
            ViewTool.synchView('OnlineView', this, PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { type: 'ad', time: 1000 });
            ViewTool.synchView('SignDayView', this, PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { type: 'ad', time: 1000 });
            ViewTool.synchView('PageGoldGunGetView', this, PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { type: 'ad', time: 1000 });
            ViewTool.synchView('GoodsGetView', this, PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { type: 'ad', time: 1000 });
            if (AdModel.model.isShieldCity == false) {
                ViewTool.synchView('BattleGetGunView', this, PlatformEvent.PLATFORM_AD_NATIVE2_VIEW_SHOW, { type: 'ad', zOrder: 30 });
            }
            this.addEventListener(BattleEvent.BATTLE_CLOSE_CLICK, this, this.showNativeHandler);
        }
        loadNativeAd(data) {
            if (!this.getChild(data.viewName)) {
                LogUtil.log("loadNativeAd:oppo:startChild");
                this.startChild(new OppoNativeAdController(data));
            }
        }
        showNativeHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { time: 500, type: 'ad', zOrder: 901 });
        }
        initSdk() {
            this.startLogin();
        }
        startLogin() {
            var data = {};
            data.gameId = OppoConfig.gameId;
            data.version = OppoConfig.version;
            data.channel_id = PlatformModel.model.channel_id;
            data.openId = PlatformModel.model.openId;
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/login';
            NetTool.request(url, data, 'get', this, this.loginResponseHandler);
        }
        loginResponseHandler(data) {
            EpModel.model.adData = EpTool.reAdData(data);
            this.dispatchEvent(EpEvent.EP_DATA_RESPONSE);
            this.getCity();
        }
        getCity() {
            if (OppoConfig.gameId) {
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/isPinbi';
                NetTool.request(url, { gameId: OppoConfig.gameId }, 'get', this, this.getCityHandler);
            }
        }
        getCityHandler(data) {
            LogTool.log('oppo.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            this.getRateAip();
            this.initParam();
        }
        getRateAip() {
            if (this.rateList.length > 0) {
                var key = this.rateList.shift();
                var data1 = { gameId: OppoConfig.gameId, version: OppoConfig.version, key: key };
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/adrate';
                NetTool.request(url, data1, 'get', this, (data) => {
                    AdModel.model.setRate(key, ParamUtil.getInt(data, 'rate'));
                    this.getRateAip();
                });
            }
            else {
            }
        }
        initCanclick() {
            LogTool.log('oppo.initCanclick');
            var data1 = { gameId: OppoConfig.gameId, type: 'canclick', adid: OppoConfig.nativeids };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readCanclickHandler);
        }
        readCanclickHandler(data) {
            LogTool.log('oppo.readCanclickHandler.1');
            if (data) {
                LogTool.log('oppo.readCanclickHandler.2');
                AdModel.model.nativeCanclick = data.code;
            }
        }
        initLog() {
            this.addEventListener(ViewEvent.VIWE_OPEN("BattleDefeatView"), this, this.logHandler);
        }
        logHandler() {
            this.eventLog("battle_defeat");
        }
        eventLog(name, type = '') {
            var eventType = this.getEventType(name, type);
            NativeTool.callNative("eventLog", { adName: name, adType: type, eventType: eventType });
        }
        getEventType(name, type = '') {
            if (type) {
                var nt = name + "_" + type;
            }
            else {
                var nt = name;
            }
            if (nt == 'bannerAdShow') {
                return 'event_1';
            }
            else if (nt == 'videoAdShow_battle_revive') {
                return 'event_2';
            }
            else if (nt == 'videoAdShow_battle_skill') {
                return 'event_3';
            }
            else if (nt == 'videoAdShow_goods_lvup') {
                return 'event_4';
            }
            else if (nt == 'videoAdShow_goods_unlock') {
                return 'event_5';
            }
            else if (nt == 'videoAdShow_phy_reward') {
                return 'event_6';
            }
            else if (nt == 'videoAdShow_task_deliver') {
                return 'event_7';
            }
            else if (nt == 'videoAdShow_task_sign') {
                return 'event_8';
            }
            else if (nt == 'videoAdShow_taks_quicken') {
                return 'event_9';
            }
            else if (nt == 'battle_defeat') {
                return 'event_11';
            }
            else if (nt == 'insterAdShow_battle_skill') {
                return 'event_12';
            }
            else if (nt == 'insterAdShow') {
                return 'event_12';
            }
        }
        exitHandler() {
            NativeTool.callNative("exit");
        }
    }

    class P4399Controller extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.showVideoAdHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsterHandler);
            this.addEventListener(NativeEvent.NATIVE_CALL_RESPONSE("videoAdComplete"), this, this.videoAdComplete);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            this.showBannerHandler();
        }
        videoAdComplete() {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        showBannerHandler() {
            NativeTool.showBannerAd();
        }
        showVideoAdHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            NativeTool.showVideoAd();
        }
        showInsterHandler(data) {
            PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
            NativeTool.showFullAd();
        }
    }

    class QqminiModel {
        constructor() {
            this.openid = '';
        }
        static getApi() {
            if (typeof qq == "undefined") {
                return null;
            }
            else {
                return qq;
            }
        }
    }
    QqminiModel.model = new QqminiModel();

    class QqminiConfig {
    }
    QqminiConfig.appid = '1112141880';
    QqminiConfig.videoid = '389025dba8006b342fbf45fd848d61c5';
    QqminiConfig.bannerid = 'f8525eadda47cc451b679fd7ba3e2a20';
    QqminiConfig.insertid = 'd1aefda67f96d1b689f22ca51c6e0bc4';
    QqminiConfig.appboxid = 'b30b5a581c1017312d670bf7fcef0623';
    QqminiConfig.blockid = 'd66cfe6d252667d460e8a178cfa866cc';
    QqminiConfig.sceneDesk = '1023';
    QqminiConfig.sceneMini = '1104';
    QqminiConfig.gameId = 776;
    QqminiConfig.version = '1.0.0';

    class QqminiAppBoxController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = QqminiModel.getApi();
            this.vo = QqminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_APPBOX_SHOW, this, this.adAppBoxHandler);
            this.initAppBox();
        }
        initAppBox() {
            if (!QqminiConfig.appboxid) {
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_APPBOX_COMPLETE);
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_APPBOX_COMPLETED(PlatformModel.model.adAppBoxId), { isEnded: true });
                return null;
            }
            if (!this.appBox) {
                LogTool.log('盒子广告开始加载');
                let example = {
                    adUnitId: QqminiConfig.appboxid,
                };
                let appBox = this.api.createAppBox(example);
                appBox.load();
                appBox.onClose((res) => {
                    LogTool.log('盒子广告关闭');
                    if (res && res.isEnded) {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_APPBOX_COMPLETE);
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_APPBOX_COMPLETED(PlatformModel.model.adAppBoxId), { isEnded: true });
                    }
                    else {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_APPBOX_DISCONTINUE(PlatformModel.model.adAppBoxId), { isEnded: false });
                    }
                    appBox.load();
                });
                this.appBox = appBox;
            }
            return this.appBox;
        }
        adAppBoxHandler(data) {
            PlatformModel.model.adAppBoxId = ParamUtil.getString(data, 'id', '');
            let AppBox = this.initAppBox();
            if (AppBox) {
                LogTool.log('准备打开盒子广告');
                AppBox.show();
            }
            else {
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            }
        }
        shareCompHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareFailHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
        }
    }

    class QqminiBannerAdController extends Controller {
        constructor() {
            super();
            this.isShow = false;
            this.refreshTime = 30;
        }
        run() {
            super.run();
            this.api = QqminiModel.getApi();
            this.vo = QqminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.showBannerHandler);
            this.initBanner();
        }
        initBanner() {
            if (AdModel.model.isShieldCity == false) {
                LogTool.log("qq.initBanner.banner广告");
                var showList = ['PlayerSetView', 'PageRewardView', 'OnlineView'];
                var preventList = ['BattleEndMysteryBoxView', 'BattleTryHeroView', 'BattleStartTryHeroView', 'SegmentLvUpView', 'SegmentView'];
                this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
                this.checkShowBanner.regOpenView('BattleView', { height: 70 });
                this.checkShowBanner.regOpenView('AlertView', { height: 98 });
                if (AdTool.checkRate('wzsy', true)) {
                    this.checkShowBanner.regOpenView('GoodsGetView', { time: 1000 });
                    this.checkShowBanner.regOpenView('BattleDefeatView', { time: 1000 });
                    this.checkShowBanner.regOpenView('BattleVictoryView', { time: 1000 });
                    this.checkShowBanner.regOpenView('BattleTaskView', { height: 98, time: 1000 });
                }
                else {
                    this.checkShowBanner.regOpenView('GoodsGetView', {});
                    this.checkShowBanner.regOpenView('BattleDefeatView', {});
                    this.checkShowBanner.regOpenView('BattleVictoryView', {});
                    this.checkShowBanner.regOpenView('BattleTaskView', { height: 98 });
                }
                this.startChild(this.checkShowBanner);
            }
            this.addEventListener(BattleEvent.BATTLE_TIME_LAST, this, this.sceneReadyHandler);
        }
        showBannerHandler(data) {
            TimerUtil.stopTimer(this, this.showAdHandler);
            var left = ParamUtil.getInt(data, 'left', 185);
            var height = ParamUtil.getInt(data, 'height', 98);
            var time = ParamUtil.getInt(data, 'time', 30);
            var viewEvent = ParamUtil.getString(data, 'viewEvent', '');
            this.refreshTime = ParamUtil.getInt(this.data, 'refreshTime', 30);
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBannerHandler(viewEvent);
            }
            else if (time) {
                TimerUtil.onceTimer(data.time, this, this.showAdHandler, [left, height]);
            }
            else {
                this.showAdHandler(left, height);
            }
        }
        showAdHandler(left, height) {
            this.isShow = true;
            if (this.bannerAd && left) {
                this.bannerAd.style.left = left;
                this.bannerAd.style.height = height;
                LogTool.log("showAdHandler.showBanner.1");
                this.bannerAd.show();
            }
            else if (this.bannerAd) {
                LogTool.log("showAdHandler.showBanner.2");
                this.bannerAd.show();
            }
            else {
                LogTool.log("showAdHandler.showBanner.3");
                this.showBanner(left, height);
            }
        }
        showBanner(left, height) {
            if (!QqminiConfig.bannerid) {
                return;
            }
            this.closeBannerHandler("showBanner", false);
            var bannerid = QqminiConfig.bannerid;
            let info = this.api.getSystemInfoSync();
            let screenHeight = info.screenHeight;
            let screenWidth = info.screenWidth;
            LogTool.log("Banner-info:" + bannerid + ',h:' + screenHeight + ',w:' + screenWidth);
            let bannerAd = this.bannerAd = this.api.createBannerAd({
                adUnitId: bannerid,
                adIntervals: this.refreshTime,
                style: {
                    left: left,
                    top: screenHeight - height,
                    width: screenWidth,
                    height: height,
                }
            });
            bannerAd.onResize((res) => {
                LogTool.log("onResize.banner.info.1:" + screenHeight + ',' + res.height + ',' + bannerAd.style.realHeight);
                LogTool.log("onResize.banner.info.top:" + bannerAd.style.top);
                if (this.isShow) {
                    LogTool.log("showBanner-onResize.4");
                    LogTool.log("onResize.showBanner.4");
                    bannerAd.show();
                }
            });
            bannerAd.onError((res) => {
                LogTool.log("showBanner-onError:" + res.errCode + ",msg:" + res.errMsg);
                this.closeBannerHandler("onError");
            });
            if (this.isShow) {
                LogTool.log("showBanner.5");
                bannerAd.show();
            }
            this.bannerAd = bannerAd;
        }
        closeBannerHandler(closeType = '', changeShow = true) {
            LogTool.log("showBanner-close:" + closeType);
            if (changeShow) {
                this.isShow = false;
            }
            if (this.bannerAd) {
                LogTool.log("showBanner-close-hide:" + closeType);
                this.bannerAd.hide();
                this.bannerAd.destroy();
                this.bannerAd = null;
            }
        }
        reloadHandler() {
            if (this.bannerAd) {
                this.bannerAd.show();
            }
        }
        sceneReadyHandler() {
            LogTool.log('sceneReadyHandler.showAdHandler');
            if (AdTool.checkRate('wudian')) {
                this.showAdHandler(390, 180);
                TimerUtil.onceTimer(3000, this, this.closeBannerHandler, ['lastTimer']);
            }
        }
    }

    class QqminiBlockAdController extends Controller {
        constructor() {
            super();
            this.isShow = false;
        }
        run() {
            super.run();
            this.api = QqminiModel.getApi();
            this.vo = QqminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BLOCK_SHOW, this, this.showViewHandler);
            this.initBlockAd();
        }
        initBlockAd() {
            LogTool.log("qq.initBlockAd.积木广告");
            ViewTool.synchView('BattleDefeatView', this, PlatformEvent.PLATFORM_AD_BLOCK_SHOW, { left: 40, top: 100, size: 5, orientation: 'landscape' });
            ViewTool.synchView('BattleVictoryView', this, PlatformEvent.PLATFORM_AD_BLOCK_SHOW, { left: 40, top: 100, size: 5, orientation: 'landscape' });
            ViewTool.synchView('AlertView', this, PlatformEvent.PLATFORM_AD_BLOCK_SHOW, { left: 20, top: 90, size: 5, orientation: 'vertical' });
            ViewTool.synchView('GoodsGetView', this, PlatformEvent.PLATFORM_AD_BLOCK_SHOW, { left: 20, top: 90, size: 5, orientation: 'vertical' });
        }
        showViewHandler(data) {
            TimerUtil.stopTimer(this, this.showAdHandler);
            var left = ParamUtil.getInt(data, 'left', 40);
            var top = ParamUtil.getInt(data, 'top', 24);
            var size = ParamUtil.getInt(data, 'top', 4);
            var orientation = ParamUtil.getString(data, 'orientation', 'vertical');
            var time = ParamUtil.getInt(data, 'time', 0);
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBlockAdHandler();
            }
            else if (time) {
                TimerUtil.onceTimer(data.time, this, this.showAdHandler, [left, top, size, orientation]);
            }
            else {
                this.showAdHandler(left, top, size, orientation);
            }
        }
        showAdHandler(left, top, size, orientation) {
            this.isShow = true;
            if (this.blockAd && left) {
                this.blockAd.style.left = left;
                this.blockAd.style.top = top;
                this.blockAd.size = size;
                LogTool.log('qqmini.showAdHandler.积木广告size:' + this.blockAd.size);
                this.blockAd.show();
            }
            else if (this.blockAd) {
                this.blockAd.show();
            }
            else {
                this.loadAd(left, top, size, orientation);
            }
        }
        loadAd(left, top, size, orientation) {
            if (!this.blockAd) {
                LogTool.log('qqmini.loadAd:积木广告开始加载');
                let example = {
                    adUnitId: QqminiConfig.blockid,
                    size: size,
                    orientation: orientation,
                    style: {
                        left: left,
                        top: top
                    }
                };
                let blockAd = this.api.createBlockAd(example);
                blockAd.onResize((res) => {
                });
                blockAd.onLoad((res) => {
                    LogTool.log('qqmini.onLoad');
                    if (this.isShow) {
                        blockAd.show();
                    }
                });
                blockAd.onError((res) => {
                    LogTool.log('qqmini.onError:积木广告错误:' + JSONUtil.stringify(res));
                    this.closeBlockAdHandler();
                });
                if (this.isShow) {
                    blockAd.show();
                }
                this.blockAd = blockAd;
            }
            return this.blockAd;
        }
        closeBlockAdHandler() {
            LogTool.log("showBlockAd-close");
            if (this.blockAd) {
                this.blockAd.hide();
                this.blockAd.destroy();
                this.blockAd = null;
            }
        }
    }

    class QqminiInsertAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = QqminiModel.getApi();
            this.vo = QqminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsertAd);
            this.initAdInsert();
        }
        initAdInsert() {
            this.addEventListener(BattleEvent.BATTLE_CLOSE_CLICK, this, this.showInterstHandler);
        }
        showInterstHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_INSERT_SHOW, { time: 1300 });
        }
        showInsertAd(data) {
            PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
            LogTool.log('qqmini.插屏11 showInsertAd');
            if (!QqminiConfig.insertid) {
                return;
            }
            if (this.api.createInterstitialAd) {
                LogTool.log('qqmini.插屏准备加载');
                this.interstitialAd = this.api.createInterstitialAd({
                    adUnitId: QqminiConfig.insertid,
                });
                this.interstitialAd.onLoad(() => {
                    LogTool.log('qqmini.插屏 广告加载成功');
                    this.interstitialAd.show();
                });
                this.interstitialAd.onError((err) => {
                    LogTool.log('qqmini.插屏 广告加载失败:' + JSONUtil.stringify(err));
                });
                this.interstitialAd.onClose(() => {
                    LogTool.log('qqmini.插屏 关闭成功');
                    this.interstitialAd.destroy();
                });
            }
        }
    }

    class QqminiTyController extends Controller {
        constructor() {
            super();
            this.rateList = ['banner', 'wudian', 'wzsy', 'wudian', 'yanchi', 'shipin'];
        }
        run() {
            super.run();
            this.api = QqminiModel.getApi();
            this.vo = QqminiModel.model;
            this.initSdk();
        }
        initSdk() {
            this.startLogin();
        }
        startLogin() {
            var data = {};
            data.gameId = QqminiConfig.gameId;
            data.version = QqminiConfig.version;
            data.channel_id = PlatformModel.model.channel_id;
            data.openId = PlatformModel.model.openId;
            var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/login';
            NetTool.request(url, data, 'get', this, this.loginResponseHandler);
        }
        loginResponseHandler(data) {
            EpModel.model.adData = EpTool.reAdData(data);
            this.dispatchEvent(EpEvent.EP_DATA_RESPONSE);
            this.getCity();
        }
        getCity() {
            if (QqminiConfig.gameId) {
                var data1 = { gameId: QqminiConfig.gameId, version: QqminiConfig.version, openId: this.vo.openid };
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/isPinbi';
                NetTool.request(url, data1, 'get', this, this.getCityHandler);
            }
        }
        getCityHandler(data) {
            LogTool.log('wxmini.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            this.getRateAip();
        }
        getRateAip() {
            if (this.rateList.length > 0) {
                var key = this.rateList.shift();
                var data1 = { gameId: QqminiConfig.gameId, version: QqminiConfig.version, key: key };
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/adrate';
                NetTool.request(url, data1, 'get', this, (data) => {
                    AdModel.model.setRate(key, ParamUtil.getInt(data, 'rate'));
                    this.getRateAip();
                });
            }
            else {
                this.dispatchEvent(PlatformEvent.PLATFORM_API_INIT);
            }
        }
    }

    class QqminiViedoAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = QqminiModel.getApi();
            this.vo = QqminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.initViedoAd();
        }
        shareHandler() {
            this.api.shareAppMessage(PlatformTool.getShareObject());
            Laya.timer.once(3000, this, () => { this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_COMPLETE); });
        }
        showRewardView(taskCid = 0) {
            var type = PlatformTool.getRewardType();
            if (type == 'share') {
            }
            else if (type == 'adVideo') {
                this.checkVideoLoad();
            }
        }
        initViedoAd() {
            if (!QqminiConfig.videoid) {
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                return null;
            }
            if (!this.rewardedVideoAd) {
                let example = {
                    adUnitId: QqminiConfig.videoid,
                };
                let rewardedVideoAd = this.api.createRewardedVideoAd(example);
                rewardedVideoAd.load();
                rewardedVideoAd.onLoad(() => {
                    LogTool.log('激励视频加载成功11');
                    PlatformModel.model.hasAdVideo = true;
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_LOAD);
                });
                rewardedVideoAd.onError((err) => {
                    PlatformModel.model.hasAdVideo = false;
                    LogTool.log('激励视频错误:' + JSONUtil.stringify(err));
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                });
                rewardedVideoAd.onClose((res) => {
                    LogTool.log('激励视频关闭');
                    if (res && res.isEnded) {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                    }
                    else {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                    }
                    rewardedVideoAd.load();
                });
                this.rewardedVideoAd = rewardedVideoAd;
            }
            return this.rewardedVideoAd;
        }
        checkVideoLoad() {
            let rewardedVideoAd = this.rewardedVideoAd;
            if (PlatformModel.model.hasAdVideo) {
                this.showVideoStartHandler();
            }
            else if (rewardedVideoAd) {
                rewardedVideoAd.load();
                this.onceEventListener(PlatformEvent.PLATFORM_AD_VIDEO_LOAD, this, this.showVideoStartHandler);
            }
        }
        showVideoStartHandler() {
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            let rewardedVideoAd = this.initViedoAd();
            if (rewardedVideoAd && PlatformModel.model.hasAdVideo) {
                rewardedVideoAd.show();
            }
            else {
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
                this.shareHandler();
            }
        }
        shareCompHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareFailHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
        }
    }

    class QqminiController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = QqminiModel.getApi();
            this.vo = QqminiModel.model;
            PlayerConfig.playerType = 3;
            SignConfig.signType = 1;
            GoodsConfig.goodGetType = 5;
            PageConfig.pageRewardType = 4;
            OnlineConfig.onlineType = 5;
            BattleConfig.battleTryType = 2;
            BattleConfig.battleTryTypeTwo = 2;
            BattleConfig.battleTaskType = 5;
            BattleConfig.battleViewType = 1;
            BattleConfig.isAutoShowTask = true;
            CommonConfig.alertType = 4;
            BattleConfig.defeatType = 5;
            BattleConfig.victoryType = 5;
            BattleConfig.isShowEndCrazyChest = true;
            this.startChild(new QqminiTyController());
            this.addEventListener(PlatformEvent.PLATFORM_ADDICO_SHOW, this, this.addicoHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(PlatformEvent.PLATFORM_API_INIT, this, this.initApiHandler);
        }
        initHandler() {
            LogTool.log('qqmini.init()');
            PlatrormLoadingView.close();
        }
        initApiHandler() {
            LogTool.log('qqmini.initApiHandler()');
            if (AdModel.model.getRate('ugc') == 1) {
                PageConfig.isShowRank = true;
                PageConfig.isShowName = true;
            }
            else {
                PageConfig.isShowRank = false;
                PageConfig.isShowName = false;
            }
            this.startChild(new QqminiBannerAdController());
            this.startChild(new QqminiBlockAdController());
            this.startChild(new QqminiAppBoxController());
            this.startChild(new QqminiInsertAdController());
            this.startChild(new QqminiViedoAdController());
            this.initMoreIco();
            this.initAddIco();
            this.dispatchEvent(PageEvent.PAGE_VIEW_REFRESH);
        }
        initMoreIco() {
            EpConfig.epPageType = 1;
            ViewTool.synchView('PageView', this, EpEvent.EP_PAGE10_VIEW_SHOW);
        }
        initAddIco() {
            LogTool.log("qqmini:initAddIco");
        }
        addicoHandler(data) {
            LogTool.log("qqmini.addico");
            this.api.saveAppToDesktop({
                success: () => {
                    LogTool.log("qqmini.addico:success");
                    if (PlatformModel.model.isAddIco == false) {
                        this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: PlatformConfig.addPageReward });
                    }
                    PlatformModel.model.isAddIco = true;
                    PlatformModel.model.saveData();
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_OK, text: "添加成功" });
                },
                fail: (err) => { LogTool.log("qqmini.addico:" + JSONUtil.stringify(err)); },
            });
        }
        initShare() {
            this.api.showShareMenu({
                showShareItems: ['qzone']
            });
        }
        shareHandler() {
            this.api.aldShareAppMessage(PlatformTool.getShareObject());
            Laya.timer.once(3000, this, () => { this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_COMPLETE); });
        }
        shareVideoHandler(data) {
            var data = {
                title: PlatformTool.getShareText(),
                imageUrl: PlatformTool.getShareImageURL(),
                shareAppType: 'qzone',
                success: () => { this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_VIDEO_COMPLETE); }
            };
            this.api.shareAppMessage(data);
        }
        shareCompHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareFailHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
        }
        initAdViewEvent() {
            this.addEventListener(SceneEvent.SCENE_STATE_READY, this, this.startHandler);
            ViewTool.contraryView('PageSkinView', this, EpEvent.EP_PAGE06_VIEW_SHOW);
            TimerUtil.onceTimer(2000, this, this.startHandler);
        }
        startHandler() {
            this.dispatchEvent(EpEvent.EP_PAGE06_VIEW_SHOW, { showType: ViewType.OPEN });
        }
        gotoLinkHandler(data) {
            if (data && data.appId) {
                const version = this.api.getSystemInfoSync().SDKVersion;
                LogTool.log('QqminiController.gotoLinkHandler:' + data.appId + ',version:' + version);
                if (PlatformTool.compareVersion(version, '1.3.0') >= 0) {
                    this.api.navigateToMiniProgram({ appId: data.appId });
                }
                else {
                    this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "当前微信版本过低，无法使用该功能，请升级到最新微信版本后重试。" });
                }
            }
        }
        initAldSdk() {
            this.vo.openid = PlatformModel.model.openId;
            this.initBattleEvent();
        }
        sdkVideoCount(type) {
            this.api.aldSendEvent("videoAdShow", { type: type });
        }
        sdkVideoNoCount(type) {
            this.api.aldSendEvent("videoAdNo", { type: type });
        }
        sdkVideoCompleteCount(type) {
            this.api.aldSendEvent("videoAdComplete", { type: type });
        }
        sdkVideoCloseCount(type) {
            this.api.aldSendEvent("videoAdClose", { type: type });
        }
        initBattleEvent() {
        }
        battleOnStartHandler(data) {
        }
        battleOnCompleteHandler(data) {
        }
    }

    class QttConfig {
    }
    QttConfig.appid = 'a3NVQfP6C11Q';

    class QttModel {
        constructor() {
        }
        static getApi() {
            if (typeof qttGame == "undefined") {
                return null;
            }
            else {
                return qttGame;
            }
        }
    }
    QttModel.model = new QttModel();

    class QttController extends Controller {
        constructor() {
            super();
            this.adNum = 0;
        }
        run() {
            super.run();
            this.api = QttModel.getApi();
            this.vo = QttModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsertAd);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.loadComplete();
        }
        initHandler() {
            LogTool.log('qtt.init()');
            PlatrormLoadingView.close();
            this.initViedoAd();
            this.initBanner();
            this.initAdInsert();
            this.initTracking();
        }
        initViedoAd() {
        }
        adViewHandler(data) {
            SoundTool.setPause('video', true);
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            var options = {};
            options.index = 1;
            options.gametype = 1;
            options.rewardtype = 1;
            options.data = {};
            options.data.title = "领取奖励";
            this.api.showVideo((res) => {
                SoundTool.setPause('video', false);
                if (res == 1) {
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                }
                else if (res == 2) {
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                }
                else {
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                }
            }, options);
        }
        initBanner() {
            LogTool.log("qtt.initBanner");
            this.showBannerHandler();
            this.addEventListener(ViewEvent.VIWE_OPEN('BattleSelectView'), this, this.closeBannerHandler);
            this.addEventListener(ViewEvent.VIWE_CLOSE('BattleSelectView'), this, this.showBannerHandler);
            this.addEventListener(ViewEvent.VIWE_OPEN('BattleDefeatView'), this, this.closeBannerHandler);
            this.addEventListener(ViewEvent.VIWE_CLOSE('BattleDefeatView'), this, this.showBannerHandler);
            this.addEventListener(ViewEvent.VIWE_OPEN('BattleVictoryView'), this, this.closeBannerHandler);
            this.addEventListener(ViewEvent.VIWE_CLOSE('BattleVictoryView'), this, this.showBannerHandler);
        }
        showBannerHandler() {
            this.api.showBanner();
        }
        closeBannerHandler() {
            this.api.hideBanner();
        }
        initAdInsert() {
            LogTool.log('qtt.插屏广告.init');
            var list = ['BattleDefeatView', 'BattleOutView', 'BattlePauseView', 'BattleProblemView',
                'GoodsInfoView', 'GoodsLvUpView', 'GoodsUnlockView',
                'TaskDeliverView', 'RolePhyView', 'RoleAttrUpView'];
            for (var view of list) {
                LogTool.log("qtt.initAdInsert:" + view);
                this.addEventListener(ViewEvent.VIWE_OPEN(view), this, this.showOrAdHandler);
            }
        }
        showOrAdHandler() {
            this.adNum++;
            if (this.adNum < 3) {
                return;
            }
            if (this.adNum % 5 == 0) {
                TimerUtil.onceTimer(500, this, this.showInsertAd);
            }
        }
        showInsertAd(data) {
            PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
            LogTool.log('qtt.插屏 showInsertAd');
            var options = {};
            options.index = 1;
            options.rewardtype = 1;
            this.api.showHDReward(options);
        }
        initTracking() {
            LogTool.log('qtt.Tracking.initTracking');
            this.loadingFinished();
            Laya.stage.on(Laya.Event.CLICK, this, this.startPlayGame);
        }
        loadComplete() {
            LogTool.log('qtt.Tracking.loadComplete');
            this.api.loadComplete({ open_id: PlatformModel.model.openId, app_id: QttConfig.appid, game_name: PlatformConfig.gameName });
        }
        loadingFinished() {
            LogTool.log('qtt.Tracking.loadingFinished');
            this.api.loadingFinished({ open_id: PlatformModel.model.openId, app_id: QttConfig.appid, game_name: PlatformConfig.gameName });
        }
        startPlayGame() {
            LogTool.log('qtt.Tracking.startPlayGame');
            Laya.stage.off(Laya.Event.CLICK, this, this.startPlayGame);
            this.api.startPlayGame({ open_id: PlatformModel.model.openId });
        }
    }

    class ToponController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            PageConfig.pageScale = 0.7;
            BattleConfig.endType = 1;
            BattleConfig.defeatType = 1;
            BattleConfig.victoryType = 1;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.showVideoAdHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsterHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_RANDOM_SHOW, this, this.showRandomHandler);
            this.addEventListener(NativeEvent.NATIVE_CALL_RESPONSE("videoAdComplete"), this, this.videoAdComplete);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            this.initBannerAd();
            this.initInsertAd();
            this.initLog();
        }
        videoAdComplete() {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        initBannerAd() {
            LogTool.log("csj.initBanner");
            var showList = ['LotteryView', 'BattleModesView', 'OnlineView', 'SignDayView', 'PageGoldGunGetView', 'GoodsGetView', 'TalentView',
                'ShopBuyView', 'PageShareView', 'PageCollectionView', 'AlertView', 'BattleResurrecView', 'BattleMatchView', 'BattleMatch5View'];
            var preventList = ['TalentResultView', 'GoodsExhView', 'BattleGetVipView'];
            this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
            this.startChild(this.checkShowBanner);
        }
        bannerViewHandler(data) {
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBanner();
            }
            else {
                this.showBanner();
            }
        }
        showBanner() {
            NativeTool.showBannerAd();
            this.eventLog("bannerAdShow");
        }
        closeBanner() {
            NativeTool.closeBannerAd();
        }
        showVideoAdHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            LogTool.log('csj.激励广告');
            NativeTool.showVideoAd();
            this.eventLog("videoAdShow");
        }
        initInsertAd() {
            LogTool.log('csj.插屏广告.init');
            var list = ['BattleVictoryView', 'BattleDefeatView'];
            for (var view of list) {
                LogTool.log("topon.initAdInsert:" + view);
                this.addEventListener(ViewEvent.VIWE_OPEN(view), this, this.showOrAdHandler);
            }
        }
        initSplashAd() {
            LogTool.log('csj.开屏广告.init');
            this.eventLog("splashAdShow");
        }
        showOrAdHandler() {
            LogTool.log('csj.showInsterHandler');
            var num = MathUtil.randomInt(0, 10);
            if (num <= 5) {
                LogTool.log('csj.showInsterHandler11111');
                return;
            }
            else {
                LogTool.log('csj.showInsterHandler222222');
                TimerUtil.onceTimer(1100, this, this.showInsterHandler);
            }
        }
        showInsterHandler(data) {
            NativeTool.showInsterAd();
            this.eventLog("insterAdShow");
        }
        showRandomHandler(data) {
            PlatformModel.model.adRandomId = ParamUtil.getString(data, 'id', '');
        }
        initLog() {
        }
        eventLog(name, type = '') {
            var eventType = this.getEventType(name, type);
            LogTool.log('eventLog.' + name + ',type:' + type + ',eventType:' + eventType);
            NativeTool.callNative("eventLog", { adName: name, adType: type, eventType: eventType });
        }
        getEventType(name, type = '') {
            if (type) {
                var nt = name + "_" + type;
            }
            else {
                var nt = name;
            }
            if (nt == 'bannerAdShow') {
                return 'event_1';
            }
            else if (nt == 'insterAdShow') {
                return 'event_2';
            }
            else if (nt == 'videoAdShow') {
                return 'event_3';
            }
        }
    }

    class TtminiConfig {
    }
    TtminiConfig.appId = 'tt405e36e3df67cce602';
    TtminiConfig.videoid = '56til98nf4b84dehbk';
    TtminiConfig.bannerid = '1kxaioaxkr1wkokwrj';
    TtminiConfig.insertid = 'a8do46b0ofa13dbfpj';
    TtminiConfig.shareid = '8hdl9jsa46a10nn9go';
    TtminiConfig.sceneDesk = '1230000000000000';
    TtminiConfig.gameId = 724;
    TtminiConfig.version = '1.0.0';

    class TtminiModel {
        constructor() {
            this.recorderEnd = false;
            this.videoShareComplete = false;
            this.state = 0;
            this.scene = 0;
        }
        static getApi() {
            if (typeof tt == "undefined") {
                return null;
            }
            else {
                return tt;
            }
        }
    }
    TtminiModel.model = new TtminiModel();

    class DrSdkTool {
        static init(api) {
            let info = api.getLaunchOptionsSync();
            LogTool.log("Ttmini.DrSdkTool.init():" + JSONUtil.stringify(info));
            let gameQuery = localStorage.getItem("game_query");
            this.channelid = 0;
            this.channel = '';
            if (info && info.query != "" && info.query.channelid) {
                gameQuery = info.query;
                this.getDaren(gameQuery.channel, gameQuery.channelid);
                localStorage.setItem("game_query", gameQuery);
                this.channelid = gameQuery.channelid;
                this.channel = gameQuery.channel;
            }
            if (!gameQuery) {
                if (gameQuery && gameQuery.channelid) {
                    this.channelid = gameQuery.channelid;
                    this.channel = gameQuery.channel;
                }
            }
        }
        static getQuery() {
            let query = null;
            if (this.channelid && this.channel == 'qrcode') {
                query = "channel=share&channelid=" + this.channelid;
            }
            else {
                query = "";
            }
            return query;
        }
        static darenshangbao() {
            this.httpRequest("darenshangbao", {
                gameId: TtminiConfig.gameId,
                channel: this.channel,
                channelId: this.channelid
            });
        }
        static getDaren(channel, channelId) {
            this.httpRequest("daren", {
                gameId: TtminiConfig.gameId,
                channel: channel,
                channelId: channelId
            });
        }
        static darenuploadvideo(videoid) {
            this.httpRequest("darenuploadvideo", {
                gameId: TtminiConfig.gameId,
                channelId: this.channelid,
                videoid: videoid,
            });
        }
        static httpRequest(path, params = {}, callback = null) {
            var xhr = new XMLHttpRequest();
            xhr.onreadystatechange = function () {
                if (xhr.readyState == 4 && (xhr.status != 500)) {
                    var response = xhr.responseText;
                    console.log(response);
                    if (callback != null) {
                        callback(JSON.parse(xhr.responseText));
                    }
                }
            };
            var paramsStr = "";
            var entries = this.entries(params || {});
            for (var i = 0; i < entries.length; ++i) {
                if (entries[i][1] == null)
                    continue;
                paramsStr += entries[i][0] + "=" + entries[i][1] + "&";
            }
            paramsStr = paramsStr.substring(0, paramsStr.length - 1);
            var url = `https://wxxcx.tanyu.mobi:4443/admin/api/${path}?${paramsStr}`;
            console.log("url=>>>>>>>>>", url);
            xhr.open("GET", url, true);
            xhr.setRequestHeader("Access-Control-Allow-Origin", "*");
            xhr.send();
        }
        static entries(obj) {
            var ownProps = Object.keys(obj), i = ownProps.length, resArray = new Array(i);
            while (i--)
                resArray[i] = [ownProps[i], obj[ownProps[i]]];
            return resArray;
        }
    }

    class TtminiShareVideoAdController extends Controller {
        constructor() {
            super();
            this.isShare = false;
        }
        run() {
            super.run();
            this.api = TtminiModel.getApi();
            this.vo = TtminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_VIDEO_SHOW, this, this.shareVideoHandler);
            this.addEventListener(PlatformEvent.PLATFORM_RECORDER_START, this, this.recorderStartHandler);
            this.addEventListener(PlatformEvent.PLATFORM_RECORDER_STOP, this, this.recorderStopHandler);
            this.initRecorder();
        }
        initRecorder() {
            PlatformConfig.platformType = 1;
            LogTool.log("ttmini:initRecorder");
            this.checkIsShowRecorderBtn();
            if (!this.api.getGameRecorderManager) {
                return;
            }
            if (this.api.getGameRecorderManager) {
                LogTool.log("ttmini:initRecorder.start");
                this.addEventListener(BattleEvent.BATTLE_STATE_END, this, this.victoryHandler);
                this.addEventListener(BattleEvent.BATTLE_STATE_START, this, this.battleStartHandler);
            }
        }
        checkIsShowRecorderBtn() {
            var showList = ['PageView'];
            var preventList = ['PlayerSetView'];
            this.checkShowRecorder = new CheckShowController(PlatformEvent.PLATFORM_RECORDER_BTN_VIEW_SHOW, null, showList, preventList);
            this.startChild(this.checkShowRecorder);
            this.addEventListener(SceneEvent.SCENE_BEGAIN_CAMERA_COMPLETE, this, this.battleReadyHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.battleOverHandler);
        }
        battleStartHandler(data) {
            LogTool.log("ttmini:battleStartHandler");
            this.vo.videoPath = null;
            this.vo.recorderEnd = false;
            this.recorder = null;
        }
        battleReadyHandler() {
            this.checkShowRecorder.openView("BattleView");
        }
        battleOverHandler() {
            this.checkShowRecorder.closeView("BattleView");
        }
        recorderStartHandler() {
            LogTool.log("ttmini:recorderStartHandler");
            if (!this.api.getGameRecorderManager) {
                return;
            }
            PlatformModel.model.hasRecorder = false;
            this.vo.videoPath = null;
            this.vo.recorderEnd = false;
            this.vo.state = 1;
            this.vo.videoShareComplete = false;
            const recorder = this.api.getGameRecorderManager();
            this.recorder = recorder;
            this.isShare = false;
            if (!recorder.start) {
                return;
            }
            recorder.onStart(res => {
                LogTool.log('录屏开始');
                this.recorderTime = TimeUtil.getTime();
            });
            recorder.onStop(res => {
                LogTool.log('录屏结束:' + res.videoPath);
                this.vo.videoPath = res.videoPath;
                this.recorderStop();
            });
            recorder.start({
                microphoneEnabled: false,
                duration: 120
            });
        }
        recorderStopHandler(data) {
            LogTool.log('录屏:手动停止:' + JSONUtil.stringify(data));
            this.isShare = ParamUtil.getBool(data, 'isShare', false);
            this.vo.recorderEnd = true;
            if (this.recorder) {
                this.recorder.stop();
                this.recorderStop();
            }
        }
        recorderBattleStop() {
            LogTool.log('录屏:战斗结束:点击确定按钮');
            this.vo.recorderEnd = true;
            if (this.recorder) {
                this.recorder.stop();
            }
            this.recorderStop();
        }
        giveUpRecroder() {
            if (this.recorder) {
                this.recorder.stop();
            }
        }
        recorderStop() {
            this.vo.state = 0;
            LogTool.log('录屏结束:显示分享:' + this.vo.recorderEnd + " , videoPath:" + this.vo.videoPath);
            if (this.vo.recorderEnd && this.vo.videoPath) {
                var time = TimeUtil.getTime() - this.recorderTime;
                if (time < 15000) {
                    LogTool.log('录屏结束:时间太短' + time);
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_INFO, text: "录屏时间太短了,不能分享" });
                    PlatformModel.model.hasRecorder = false;
                    this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_END);
                }
                else if (time > 30000) {
                    LogTool.log('录屏结束:时间太长:' + time);
                    if (this.recorder) {
                        this.recorder.clipVideo({
                            path: this.vo.videoPath,
                            timeRange: [30, 0],
                            success: (res) => {
                                console.log('ttmini.视频剪裁最后20秒:' + res.videoPath);
                                this.vo.videoPath = res.videoPath;
                                PlatformModel.model.hasRecorder = true;
                                this.showRecordHandler();
                                this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_END);
                            },
                            fail: (e) => {
                                console.log('ttmini.视频剪裁错误:' + JSONUtil.stringify(e));
                                PlatformModel.model.hasRecorder = false;
                                this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_END);
                            }
                        });
                    }
                }
                else {
                    PlatformModel.model.hasRecorder = true;
                    this.showRecordHandler();
                    this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_END);
                }
            }
        }
        checkShardVideo() {
            this.showRecordHandler();
        }
        victoryHandler(data) {
            var videoPath = this.vo.videoPath;
            if (data && data.statue) {
            }
            else {
                if (videoPath) {
                    LogTool.log('ttmini.victoryHandler:成功跳转录制视频');
                    TimerUtil.onceTimer(200, this, this.showRecordHandler);
                }
                else {
                    LogTool.log('ttmini.victoryHandler:未录制视频');
                }
            }
        }
        defeatHandler() {
            var videoPath = this.vo.videoPath;
            LogTool.log('视频路径' + videoPath);
            if (videoPath) {
                LogTool.log('ttmini.defeatHandler:失败跳转录制视频');
                TimerUtil.onceTimer(200, this, this.showRecordHandler);
            }
            else {
                LogTool.log('ttmini.defeatHandler:未录制视频');
            }
        }
        showRecordHandler() {
            if (this.isShare || BattleModel.model.isSettlement) {
                this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_VIEW_SHOW);
            }
        }
        shareVideoHandler() {
            LogTool.log('分享录屏:' + this.vo.videoPath);
            var videoPath = this.vo.videoPath;
            if (videoPath) {
                let query = DrSdkTool.getQuery();
                this.api.shareAppMessage({
                    channel: 'video',
                    templateId: TtminiConfig.shareid,
                    videoPath: videoPath,
                    query: query,
                    imageUrl: PlatformTool.getShareImageURL(),
                    extra: {
                        videoPath: videoPath,
                        videoTopics: [PlatformConfig.gameName],
                        withVideoId: true,
                    },
                    success: (res) => {
                        LogTool.log('分享成功！');
                        this.vo.videoShareComplete = true;
                        if (query != '') {
                            DrSdkTool.darenuploadvideo(res.videoId);
                        }
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_VIDEO_COMPLETE);
                        this.dispatchEvent(AdEvent.AD_SHARE_SUCCESS);
                        this.shareReward();
                    },
                    fail: (e) => {
                        LogTool.log('分享失败:' + JSONUtil.stringify(e));
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_VIDEO_FAIL);
                    }
                });
            }
            else {
                LogTool.log('没有录制视频');
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_WARNING, text: "您还没有录制视频!" });
            }
        }
        shareReward() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: PlatformConfig.shareReward });
        }
    }

    class TtminiVideoAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = TtminiModel.getApi();
            this.vo = TtminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.initViedoAd();
            this.initStaEvent();
        }
        initViedoAd() {
            if (!this.api.createRewardedVideoAd) {
                return;
            }
            let videoAd = this.api.createRewardedVideoAd({ adUnitId: TtminiConfig.videoid });
            videoAd.onClose((res) => {
                LogTool.log('激励视频关闭');
                if (res && res.isEnded) {
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                }
                else {
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                }
            });
            this.rewardedVideoAd = videoAd;
        }
        showViedoAd() {
            if (this.rewardedVideoAd) {
                this.rewardedVideoAd.load().then(() => {
                    DrSdkTool.darenshangbao();
                    LogTool.log('激励视频load:成功');
                    this.rewardedVideoAd.show();
                });
            }
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            LogTool.log('激励视频.adViewHandler:' + PlatformModel.model.adVideoId);
            this.showViedoAd();
            this.videAdRepot(PlatformModel.model.adVideoId);
        }
        shareCompHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareFailHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
        }
        initStaEvent() {
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_REVIVE, this, this.reviveRepot);
            this.addEventListener(GuideEvent.GUIDE_STEP_COMPLETE, this, this.guideHandler);
            this.addEventListener(SegmentEvent.SEGMENT_REWARD_REPORT, this, this.segmentHandler);
            this.addEventListener(TaskEvent.TASK_GETREWARD_COMPLETE, this, this.taskRepotHandler);
            this.addEventListener(ShopEvent.SHOP_GETREWARD_COMPLETE, this, this.shopRepotHandler);
        }
        reviveRepot() {
            LogTool.log("ttmini:videAdRepot.adVideoData:" + '英雄试用~复活');
            this.videAdRepotData('heroTryResurre');
        }
        videAdRepot(id) {
            if (id) {
                LogTool.log("ttmini:videAdRepot.id:" + id);
                this.videAdRepotData(id);
            }
        }
        videAdRepotData(name) {
            this.api.reportAnalytics("shangyehua", {
                time: TimeUtil.getTimestamp(),
                shangyehua: name,
            });
        }
        guideHandler(data) {
            LogTool.log('guideHandler.xinshouyindao:' + data.id);
            this.guideRepot('新手指引:' + data.id);
        }
        guideRepot(name) {
            this.api.reportAnalytics("xinshouyindao", {
                time: TimeUtil.getTimestamp(),
                xinshouyindao: name,
            });
        }
        segmentHandler(data) {
            LogTool.log('guideHandler.xinshouyindao:' + data.troNum);
            this.segmentRepot('段位奖励:' + data.troNum);
        }
        segmentRepot(name) {
            this.api.reportAnalytics("duanweijiangli", {
                time: TimeUtil.getTimestamp(),
                duanweijiangli: name,
            });
        }
        taskRepotHandler(data) {
            var name = data.info;
            this.taskRepot('任务宝箱:' + name);
        }
        taskRepot(name) {
            this.api.reportAnalytics("renwubaoxiang", {
                time: TimeUtil.getTimestamp(),
                renwubaoxiang: name,
            });
        }
        shopRepotHandler(data) {
            var name = data.name;
            this.shopRepot('商城售卖:' + name);
        }
        shopRepot(name) {
            this.api.reportAnalytics("shangchengshoumai", {
                time: TimeUtil.getTimestamp(),
                shangchengshoumai: name,
            });
        }
    }

    class TtminiController extends Controller {
        constructor() {
            super();
            this.shareTime = 0;
        }
        run() {
            super.run();
            this.api = TtminiModel.getApi();
            this.vo = TtminiModel.model;
            PlatrormLoadingView.show();
            HeroConfig.unlockTipType = 1;
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_SHOW, this, this.shareHandler);
            this.addEventListener(PlayerEvent.PLAYER_INFO_REQUEST, this, this.initLogin);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(PlatformEvent.PLATFORM_API_INIT, this, this.initApiHandler);
        }
        initApiHandler() {
            this.startChild(new TtminiVideoAdController());
            this.startChild(new TtminiShareVideoAdController());
        }
        initHandler() {
            LogTool.log("Ttmini.init()");
            PlatrormLoadingView.close();
            DrSdkTool.init(this.api);
            this.initShare();
            this.initDesktop();
            this.initSDK();
        }
        initParam() {
        }
        initShare() {
            let query = DrSdkTool.getQuery();
            this.api.onShareAppMessage(function (res) {
                return {
                    query: query,
                    extra: {
                        withVideoId: true,
                    },
                    templateId: TtminiConfig.shareid,
                    success(res) {
                        LogTool.log("ttmini:initShare 分享成功");
                        if (query != "") {
                            DrSdkTool.darenuploadvideo(res.videoId);
                        }
                    },
                    fail(e) {
                        LogTool.log("ttmini:initShare 分享失败" + JSONUtil.stringify(e));
                    }
                };
            });
        }
        initLogin() {
            this.api.login({
                success: (res) => {
                    LogTool.log("login 调用成功" + JSONUtil.stringify(res));
                    this.getInfo();
                },
                fail: (err) => {
                    LogTool.log("login 调用失败" + JSONUtil.stringify(err));
                }
            });
        }
        getInfo() {
            this.api.getUserInfo({
                success: (res) => {
                    LogTool.log("ttmini: getUserInfo 调用成功" + JSONUtil.stringify(res));
                    this.dispatchEvent(PlayerEvent.PLAYER_INFO_RESPONSE, { name: res.userInfo.nickName, ico: res.userInfo.avatarUrl });
                },
                fail: (err) => {
                    LogTool.log("ttmini: getUserInfo 调用失败" + JSONUtil.stringify(err));
                },
            });
        }
        shareHandler() {
            this.api.checkSession({
                success: (res) => {
                    LogTool.log('session未过期');
                    this.startShare();
                },
                fail: (res) => {
                    LogTool.log('session已过期，需要重新登录');
                    this.api.login({
                        success: (res) => {
                            LogTool.log('登录成功:code:' + res.code);
                            this.startShare();
                        },
                        fail: (res) => {
                            this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { type: PromptType.PROMPT_WARNING, text: "登录信息错误,请重新登录后分享" });
                        }
                    });
                }
            });
        }
        startShare() {
            let query = DrSdkTool.getQuery();
            this.api.shareAppMessage({
                query: query,
                templateId: TtminiConfig.shareid,
            });
            LogTool.log("准备分享");
            this.api.onShow(() => { this.onShareHandler(); });
        }
        onShareHandler() {
            LogTool.log("准备分享3333");
            this.dispatchEvent(AdEvent.AD_SHARE_SUCCESS);
            if (this.shareTime > 0) {
                this.shareTime = 0;
                if (TimeUtil.getTime() - this.shareTime < 2500) {
                    LogUtil.log("onShareHandler:时间太短,分享失败");
                    this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_FAIL);
                }
                else {
                    var r = Math.random();
                    if (r < 0.6) {
                        LogUtil.log("onShareHandler:分享成功");
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_COMPLETE);
                    }
                    else {
                        LogUtil.log("onShareHandler:概率太低,分享失败");
                        this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "分享失败！请分享到活跃的群" });
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_FAIL);
                    }
                }
            }
        }
        initDesktop() {
            var res = this.api.getLaunchOptionsSync();
            LogTool.log("initDesktop:" + res.scene);
            if (res.scene == TtminiConfig.sceneDesk) {
                PlatformModel.model.addDesktopFinish = true;
            }
        }
        initSDK() {
            this.getPinbi();
        }
        getPinbi() {
            var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/isPinbi';
            NetTool.request(url, { gameId: TtminiConfig.gameId }, 'get', this, this.getCityHandler);
        }
        getCityHandler(data) {
            LogTool.log('ttmini.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            this.initParam();
            this.dispatchEvent(PlatformEvent.PLATFORM_API_INIT);
        }
        getAdRate() {
            var openid = 10000;
            var data1 = { gameId: TtminiConfig.gameId, version: TtminiConfig.version, openId: openid };
            var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/adrate';
            NetTool.request(url, data1, 'get', this, this.getAdRateHandler);
        }
        getAdRateHandler(data) {
            LogTool.log('ttmini.getAdRate:' + JSONUtil.stringify(data));
            AdModel.model.setRate('share', data.rate);
            AdModel.model.setRate('wudian', data.rate);
            AdModel.model.setRate('shipin', data.rate);
            AdModel.model.setRate('vip', data.rate);
            this.dispatchEvent(PlatformEvent.PLATFORM_API_INIT);
            this.initParam();
        }
    }

    class VivoConfig {
    }
    VivoConfig.gameId = 491;
    VivoConfig.version = '1.0.0';
    VivoConfig.content = "隐私政策\n\
    探娱互动（以下简称“我们”）尊重并保护所有使用服务用户的个人隐私权。您在使用我们的服务时，我们可能会收集和使用您的相关信息。但我们将以高度的勤勉、审慎义务对待这些信息.\n\
    本隐私政策与您所使用服务息息相关，一旦您安装、使用、注册或以其他方式访问我们的服务，那就意味着您已经接受本政策，并且在知情的基础上明确同意按本政策的规定处理、使用和披露您的个人信息。\n\
    1.适用范围2.信息使用3.信息披露4.订阅及自动续订说明5.信息存储6.信息安全7.信息管理8.未成年人信息保护9.修订\n\
    1.适用范围\n\
    a) 在您使用我们网络服务，或访问我们平台网页时，我们自动接收并记录的您的浏览器和计算机上及其他移动终端设备的信息，包括但不限于您的IP地址、地址位置信息、浏览器的类型、使用的语言、访问日期和时间、通讯账户、通讯时长、软硬件特征信息及您需求的网页记录等数据；\n\
    b) 您在注册账户时填写、提供或上传的姓名、个人昵称、身份证号、手机号、QQ号、微信、或其他社交网站信息、个人头像、分享的照片。\n\
    c) 您在使用探娱互动提供的服务时，可能提供的您的家庭地址、个人兴趣爱好及其他个人隐私。\n\
    d) 我们通过合法途径从商业伙伴处取得的用户个人数据。\n\
    2.信息使用\n\
    a) 我们不会向任何无关第三方提供、出售、出租、分享或交易您的个人信息，除非事先得到您的许可，或该第三方和我们（含我们关联公司）单独或共同为您提供服务，且在该服务结束后，其将被禁止访问包括其以前能够访问的所有这些资料。\n\
    b) 我们亦不允许任何第三方以任何手段收集、编辑、出售或者无偿传播您的个人信息。任何我们平台用户如从事上述活动，一经发现，我司有权立即终止与该用户的服务协议。\n\
    c) 我们使用您的信息，会用于身份认证、安全防范、反诈骗检测、客户安全服务、存档备份、商业分析等。\n\
    d) 为服务用户的目的，我们可能通过使用您的个人信息，向您提供您感兴趣的信息，包括但不限于向您提供个性化需求、发送新产品和服务广告、资讯信息、邀请您参加我们的服务调查，或者与我司合作伙伴共享信息以便他们向您发送有关其产品和服务的信息（注：与合作伙伴共享您的信息需要您的事先同意）。\n\
    3.信息披露\n\
    在如下情况下，我们将依据您的个人意愿或法律的规定全部或部分的披露您的个人信息：\n\
    a) 经您事先同意，向第三方披露；\n\
    b) 为提供您所要求的产品和服务，而必须和第三方分享您的个人信息；\n\
    c) 根据法律的有关规定，或者行政或司法机构的要求，向第三方或者行政、司法机构披露；\n\
    d) 如您出现违反中国有关法律、法规或者我们服务协议或相关规则的情况，需要向第三方披露；\n\
    e) 如您是适格的知识产权投诉人并已提起投诉，应被投诉人要求，向被投诉人披露，以便双方处理可能的权利纠纷；\n\
    f) 在我们平台上创建的某一交易中或我们发生合并、收购、资产转让或其他合作等，如交易或合作任何一方履行或部分履行了交易义务并提出信息披露请求的，我们有权决定向该用户提供其交易对方的联络方式等必要信息，以促成交易的完成或纠纷的解决。\n\
    g) 其它我们根据法律、法规或者政策认为合适的披露。\n\
    4.订阅及自动续订说明\n\
    a）付款将在确认购买时向iTunes帐户收取。\n\
    b）订阅自动续订，除非自动续订在当前期限结束前至少24小时关闭。\n\
    c）账户将在本期结束前的24小时内收取续费费用，并确定续约费用。\n\
    d）订购可由用户管理，购买后可通过转到用户的帐户设置关闭自动续订。\n\
    e）免费试用期的任何未使用部分（如果提供）在用户购买该出版物的订阅时将被没收。\n\
    5. 信息存储\n\
    我们会遵守法律法规的规定，将您的个人信息存储在安全的服务器设备或其他安全系统更高的数据库或设备中，我们会为您的信息提供相应的安全保障，以防止信息的丢失、不当使用、未经授权访问或披露。\n\
    6. 信息安全\n\
    a) 我们账号均有安全保护功能，亦请您妥善保管您的用户名及密码信息。我们将通过对用户密码进行加密等安全措施确保您的信息不丢失，不被滥用和变造。尽管有前述安全措施，但同时也请您注意在信息网络上不存在“完善的安全措施”。\n\
    b) 在使用我们网络服务进行网上交易时，您不可避免的要向交易对方或潜在的交易对方披露自己的个人信息，如联络方式或者邮政地址。请您妥善保护自己的个人信息，仅在必要的情形下向他人提供。如您发现自己的个人信息泄密，尤其是我们用户名及密码发生泄露，请您立即联络我们客服，以便我们采取相应措施。\n\
    7.信息管理\n\
    a) 您可以在使用我们的服务过程中对您的个人信息，含注册信息及其他个人信息，按我们的指引进行信息管理，具体的信息管理范围及管理方式取决于您使用的具体服务。比如，对于您的注册信息，您可以访问、修改，但您无权进行删除，否则，您将不允许使用我们提供的服务。\n\
    b) 若我们为实现服务功能或为活动所需向您收集、使用您的信息时，您发现我们违反约定错误收集、使用您的信息的，您可以通过本隐私政策中载明的我们的客服联系方式向我们反馈，我们将按您的要求对信息予以处理。\n\
    c）若您访问、管理您的个人信息时，我们将会对您的身份进行认证，已确保账户安全，您需按我们的指引向我们提供您的身份信息，若您提供的信息验证不成功的，我们将会很遗憾地告知您可能无法对您要求的个人信息进行管理。\n\
    d）我们将尽最大的技术努力满足您对个人信息的管理，但若因技术原因或法律监管要求，可能会无法满足您所有的要求，您可以通过本隐私政策中载明的客服联系方式将问题反馈我们，以便我们改进技术，更好地为您提供服务。\n\
    e) 若您对个人信息需要管理或对我们对您的个人信息管理有疑问的，您可以通过我们的客服进行问题反馈及沟通解决，我们将尽快审核并给予您答复。\n\
    8.未成年人信息保护\n\
    a) 我们非常重视对未成年人信息的保护。若您是18周岁以下的未成年人，在使用我们服务之前，应事先取得您父母或监护人同意。\n\
    9.修订\n\
    我们可能会适时修订本隐私政策，但我们会在网页显著位置予以发布。在该种情况下，若您继续使用我们的服务，即表示同意受经修订的本隐私政策的约束。";

    class VivoContentView extends ui.platform.VivoContentUI {
        constructor() {
            super();
            this.zOrder = 902;
        }
    }

    class VivoContentViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = VivoContentView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.y = 199;
            this.ui.right = 262;
            this.ui.txt_content.text = VivoConfig.content;
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.clickHandler);
        }
        clickHandler() {
            LogTool.log('vivo.clickHandler-close');
            this.close();
        }
    }

    class VivoIcoView extends ui.platform.PlatformVivoIcoUI {
        constructor() {
            super();
            this.zOrder = 10;
        }
    }

    class VivoIcoViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = VivoIcoView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.y = 210;
            this.ui.left = 2;
            LogTool.log('vivo显示更多游戏按钮');
            this.ui.box_ico.on(Laya.Event.CLICK, this, this.clickHandler);
        }
        clickHandler() {
            LogTool.log('vivo.showPlatformView');
            NativeTool.showPlatformView();
        }
    }

    class VivoPrivacyView extends ui.platform.VivoPrivacyUI {
        constructor() {
            super();
            this.zOrder = 901;
        }
    }

    class VivoPrivacyViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = VivoPrivacyView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.y = 199;
            this.ui.right = 262;
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.btn_no.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.txt_read2.on(Laya.Event.CLICK, this, this.showContentHandler);
            this.ui.txt_read1.on(Laya.Event.CLICK, this, this.showContentHandler);
        }
        showContentHandler() {
            LogTool.log('vivo.showPlatformView');
            this.dispatchEvent(PlatformEvent.PLATFORM_CLAUSE_VIEW);
        }
        okHandler() {
            this.close();
            PlatformModel.model.privacyNum++;
            PlatformModel.model.saveData();
        }
        closeHandler() {
            NativeTool.callNative("exit");
        }
        exitHandler() {
            NativeTool.callNative("exit");
        }
    }

    class VivoController extends Controller {
        constructor() {
            super();
            this.adNum = 0;
            this.rateList = [];
        }
        run() {
            super.run();
            PageConfig.pageScale = 0.8;
            BattleConfig.endType = 1;
            BattleConfig.defeatType = 1;
            BattleConfig.victoryType = 1;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.showVideoAdHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsterHandler);
            this.addEventListener(NativeEvent.NATIVE_CALL_RESPONSE("videoAdComplete"), this, this.videoAdComplete);
            ViewManager.register(PlatformEvent.PLATFORM_VIVO_ICO_VIEW, this, VivoIcoViewController);
            ViewManager.register(PlatformEvent.PLATFORM_CLAUSE_VIEW, this, VivoContentViewController);
            ViewManager.register(PlatformEvent.PLATFORM_PRIVACY_VIEW, this, VivoPrivacyViewController);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            this.initSdk();
            this.initPrivacy();
            this.initBannerAd();
            this.initAdInsert();
            this.initLog();
        }
        initParam() {
        }
        initPrivacy(data = null) {
            if (PlatformModel.model.privacyNum < 1) {
                this.dispatchEvent(PlatformEvent.PLATFORM_PRIVACY_VIEW);
            }
        }
        initIco(data = null) {
        }
        videoAdComplete() {
            LogTool.log('vivo.激励广告.奖励');
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        initBannerAd() {
            LogTool.log("vivo.initBanner.初始化banner");
            var showList = ['LotteryView', 'BattleModesView', 'OnlineView', 'SignDayView', 'PageGoldGunGetView', 'GoodsGetView', 'TalentView',
                'ShopBuyView', 'PageShareView', 'PageCollectionView', 'AlertView', 'BattleResurrecView', 'BattleMatchView', 'BattleMatch5View'];
            var preventList = ['TalentResultView', 'GoodsExhView', 'BattleGetVipView'];
            this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
            this.startChild(this.checkShowBanner);
        }
        bannerViewHandler(data) {
            if (data && data.showType == ViewType.CLOSE) {
                LogTool.log('vivo.bannerViewHandler.closeBanner');
                this.closeBanner();
            }
            else {
                LogTool.log('vivo.bannerViewHandler.showBanner');
                this.showBanner(data);
            }
        }
        showBanner(data) {
            LogTool.log('vivo.showBanner.显示banner广告');
            NativeTool.showBannerAd(data);
            this.eventLog("bannerAdShow");
        }
        closeBanner() {
            LogTool.log('vivo.closeBanner.关闭banner广告');
            NativeTool.closeBannerAd();
        }
        showVideoAdHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            LogTool.log('vivo.激励广告显示');
            NativeTool.showVideoAd();
            this.eventLog("videoAdShow", PlatformModel.model.adVideoId);
        }
        initAdInsert() {
            LogTool.log('vivo.插屏广告.init');
            var list = ['BattleDefeatView', 'BattleVictoryView', 'BattleEndView'];
            for (var view of list) {
                LogTool.log("vivo.initAdInsert:" + view);
                this.addEventListener(ViewEvent.VIWE_OPEN(view), this, this.showInsterHandler);
            }
        }
        showOrAdHandler() {
            LogTool.log('vivo.showOrAdHandler');
            this.adNum++;
            if (this.adNum < 3) {
                return;
            }
            if (this.adNum % 5 == 0) {
                TimerUtil.onceTimer(500, this, this.showInsterHandler);
            }
        }
        showInsterHandler(data) {
            LogTool.log('vivo.showInsterHandler.显示插屏广告');
            PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
            NativeTool.showInsterAd();
            this.eventLog("insterAdShow");
        }
        showRandomHandler(data) {
            PlatformModel.model.adRandomId = ParamUtil.getString(data, 'id', '');
            this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: '暂无广告' });
        }
        initSdk() {
            this.startLogin();
        }
        startLogin() {
            var data = {};
            data.gameId = VivoConfig.gameId;
            data.version = VivoConfig.version;
            data.channel_id = PlatformModel.model.channel_id;
            data.openId = PlatformModel.model.openId;
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/login';
            NetTool.request(url, data, 'get', this, this.loginResponseHandler);
        }
        loginResponseHandler(data) {
            EpModel.model.adData = EpTool.reAdData(data);
            this.dispatchEvent(EpEvent.EP_DATA_RESPONSE);
            this.getCity();
        }
        getCity() {
            if (VivoConfig.gameId) {
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/isPinbi';
                NetTool.request(url, { gameId: VivoConfig.gameId }, 'get', this, this.getCityHandler);
            }
        }
        getCityHandler(data) {
            LogTool.log('vivo.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            this.getRateAip();
            this.initParam();
        }
        getRateAip() {
            if (this.rateList.length > 0) {
                var key = this.rateList.shift();
                var data1 = { gameId: VivoConfig.gameId, version: VivoConfig.version, key: key };
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/adrate';
                NetTool.request(url, data1, 'get', this, (data) => {
                    AdModel.model.setRate(key, ParamUtil.getInt(data, 'rate'));
                    this.getRateAip();
                });
            }
            else {
            }
        }
        initLog() {
            this.addEventListener(ViewEvent.VIWE_OPEN("BattleDefeatView"), this, this.logHandler);
        }
        logHandler() {
            this.eventLog("battle_defeat");
        }
        eventLog(name, type = '') {
            var eventType = this.getEventType(name, type);
            NativeTool.callNative("eventLog", { adName: name, adType: type, eventType: eventType });
        }
        getEventType(name, type = '') {
            if (type) {
                var nt = name + "_" + type;
            }
            else {
                var nt = name;
            }
            if (nt == 'bannerAdShow') {
                return 'event_1';
            }
            else if (nt == 'videoAdShow_battle_revive') {
                return 'event_2';
            }
            else if (nt == 'videoAdShow_battle_skill') {
                return 'event_3';
            }
            else if (nt == 'videoAdShow_goods_lvup') {
                return 'event_4';
            }
            else if (nt == 'videoAdShow_goods_unlock') {
                return 'event_5';
            }
            else if (nt == 'videoAdShow_phy_reward') {
                return 'event_6';
            }
            else if (nt == 'videoAdShow_task_deliver') {
                return 'event_7';
            }
            else if (nt == 'videoAdShow_task_sign') {
                return 'event_8';
            }
            else if (nt == 'videoAdShow_taks_quicken') {
                return 'event_9';
            }
            else if (nt == 'battle_defeat') {
                return 'event_11';
            }
            else if (nt == 'insterAdShow_battle_skill') {
                return 'event_12';
            }
            else if (nt == 'insterAdShow') {
                return 'event_12';
            }
        }
    }

    class VvminiConfig {
        static getNative(type) {
            if (this.nativeids[type]) {
                return this.nativeids[type];
            }
            return this.nativeid;
        }
        static getCustom(type) {
            if (this.customId[type]) {
                return this.customId[type];
            }
            return this.customId['ad1'];
        }
    }
    VvminiConfig.appid = '105523475';
    VvminiConfig.videoid = 'd9dfcd7ce0a5454fbd6308abe63c762f';
    VvminiConfig.bannerid = '0e02559e9eda47a68c53bc5c6d15678e';
    VvminiConfig.insertid = '';
    VvminiConfig.nativeid = '69b6b9a7d8dc41209c8808265e8cfaed';
    VvminiConfig.portalid = '57ef9cb99a3442938b074bd71149031a';
    VvminiConfig.nativeids = {
        'ad': '1fb1bcd9228c4431b7e5aea513cdfa17',
        'banner': '0ece86227972485fa334965bf90a141f'
    };
    VvminiConfig.customId = {
        'ad1': '0ece86227972485fa334965bf90a141f',
        'ad2': '1fb1bcd9228c4431b7e5aea513cdfa17',
        'ad3': '69b6b9a7d8dc41209c8808265e8cfaed',
        'ad4': '71fa7a8bc543476e9f5979e0cbf93c96',
        'ad5': 'a3d0515409064fa6b7c1570fda8adbd4',
    };
    VvminiConfig.gameId = 735;
    VvminiConfig.version = '1.0.0';

    class VvminiModel {
        constructor() {
        }
        static getApi() {
            if (typeof qg == "undefined") {
                return null;
            }
            else {
                return qg;
            }
        }
    }
    VvminiModel.model = new VvminiModel();

    class VvminiAddIcoController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = VvminiModel.getApi();
            this.vo = VvminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_ADDICO_SHOW, this, this.addicoHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_END, this, this.addIcoShowHandler);
            this.initAddIco();
        }
        addIcoShowHandler() {
            LogTool.log('Vvmini.addIcoShowHandler.isShieldCity' + AdModel.model.isShieldCity);
            if (AdModel.model.isShieldCity == false) {
                this.initAddIcoHandler();
            }
        }
        addIcoStatue() {
            LogTool.log("vvmini:addIcoStatue");
            if (AdTool.checkRate('kuaijie')) {
                this.initAddIcoHandler();
            }
        }
        initAddIcoHandler() {
            LogTool.log("vvmini:initAddIco-游戏结束");
            if (this.api.hasShortcutInstalled) {
                this.api.hasShortcutInstalled({
                    success: (res) => {
                        LogTool.log("vvmini:hasShortcutInstalled:" + res);
                        if (res) {
                        }
                        else {
                            LogTool.log('桌面还未添加图标');
                            this.addicoHandler();
                        }
                    },
                    fail: (err) => { },
                });
            }
        }
        initAddIco() {
            LogTool.log("vvmini:initAddIco");
            if (this.api.hasShortcutInstalled) {
                this.api.hasShortcutInstalled({
                    success: (res) => {
                        LogTool.log("vvmini:hasShortcutInstalled:" + res);
                        if (res) {
                        }
                        else {
                            LogTool.log('桌面还未添加图标');
                            this.addIcoEvent();
                        }
                    },
                    fail: (err) => { },
                });
            }
        }
        addIcoEvent() {
            this.checkAddIco = new CheckViewShowController(PlatformEvent.PLATFORM_ADDICO_VIEW_SHOW, null, ['PageView'], ['BattleResurrecView', 'AlertView', 'BattleView']);
            this.startChild(this.checkAddIco);
        }
        statusChangeicoHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_VIEW_SHOW, { showType: ViewType.CLOSE });
        }
        addicoHandler() {
            LogTool.log("vvmini.addico");
            this.api.installShortcut({
                success: (res) => {
                    LogTool.log("vvmini.addico.success: " + JSONUtil.stringify(res));
                    TimerUtil.onceTimer(600, this, this.addicoCompHandler);
                },
                fail: (err) => {
                    LogTool.log("vvmini.addico.fail: " + JSONUtil.stringify(err));
                    this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_VIEW_SHOW, { showType: ViewType.CLOSE });
                }
            });
        }
        addicoCompHandler() {
            this.api.hasShortcutInstalled({
                success: (res) => {
                    LogTool.log("vvmini:hasShortcutInstalled:" + res);
                    if (res) {
                        LogTool.log("vvmini.addico:success:" + JSONUtil.stringify(res));
                        PlatformModel.model.isAddIco = true;
                        PlatformModel.model.saveData();
                        this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_COMPLETE);
                        this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_OK, text: "添加成功" });
                    }
                }
            });
        }
    }

    class VvminiBannerAdController extends Controller {
        constructor() {
            super();
            this.bannerTs = 0;
            this.isShowBanner = false;
        }
        run() {
            super.run();
            this.api = VvminiModel.getApi();
            this.vo = VvminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.initBannerAd();
        }
        initBannerAd() {
            if (VvminiConfig.bannerid) {
                LogTool.log("vvmini.initBanner");
                var showList = ['BattleView'];
                var preventList = ['BattleVictoryView', 'BattleDefeatView', 'SegmentLvUpView', 'AlertView', 'BattleTryHeroView', 'BattleTaskView', 'SegmentView', 'BattleVictoryMvpView', 'BattleDefeatMvpView'];
                this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
                this.startChild(this.checkShowBanner);
            }
        }
        bannerViewHandler(data) {
            this.barrerData = data;
            LogTool.log('showBanner.10');
            TimerUtil.onceTimer(100, this, this.showbannerHandler);
        }
        showbannerHandler() {
            LogTool.log('showBanner.9');
            if (this.barrerData && this.barrerData.showType == ViewType.CLOSE) {
                LogTool.log('showBanner.8');
                this.closeBanner();
            }
            else {
                LogTool.log('showBanner.7');
                this.showBanner();
            }
        }
        showBanner() {
            LogTool.log('showBanner.1');
            if (this.isShowBanner) {
                return;
            }
            var ts = TimeUtil.getTimestamp();
            this.isShowBanner = true;
            LogTool.log('showBanner.2');
            if (!this.bannerAd || ts - this.bannerTs > 120) {
                LogTool.log('showBanner.loadBanner');
                this.bannerTs = ts;
                this.loadBanner();
            }
            else if (this.bannerAd) {
                LogTool.log('showBanner.show');
                this.bannerAd.show();
            }
        }
        closeBanner() {
            if (!this.isShowBanner) {
                return;
            }
            LogTool.log('closeBanner.1');
            if (this.isShowBanner && this.bannerAd) {
                LogTool.log('closeBanner.ok');
                this.bannerAd.hide();
            }
            this.isShowBanner = false;
        }
        stopBanner() {
            this.isShowBanner = false;
            if (this.bannerAd) {
                this.bannerAd.hide();
                this.bannerAd.destroy();
                this.bannerAd = null;
            }
        }
        loadBanner() {
            if (!VvminiConfig.bannerid) {
                return;
            }
            if (!this.api.createBannerAd) {
                return;
            }
            if (this.bannerAd) {
                this.stopBanner();
            }
            var bannerid = VvminiConfig.bannerid;
            let info = this.api.getSystemInfoSync();
            let screenHeight = info.screenHeight;
            let screenWidth = info.screenWidth;
            LogTool.log("vvmini.showBannerHandler-bannerid:" + bannerid + ',h:' + screenHeight + ',w:' + screenWidth);
            var top = (screenHeight - 113) / 2;
            LogTool.log("vvmini.createBannerAd:top:" + top);
            var bannerAd = this.api.createBannerAd({
                posId: bannerid,
                adIntervals: 30,
                style: {
                    width: 228,
                }
            });
            TimerUtil.onceTimer(3000, this, () => { bannerAd.show(); });
            bannerAd.onLoad(res => {
                LogTool.log("vvmini.banner加载完成:" + JSONUtil.stringify(res));
                if (this.isShowBanner) {
                    bannerAd.show();
                }
                else {
                    bannerAd.hide();
                    bannerAd.destroy();
                }
            });
            bannerAd.onError(res => {
                LogTool.log("vvmini.banner加载错误:" + JSONUtil.stringify(res));
                LogTool.log("vvmini.banner错误码:" + JSONUtil.stringify(res.errCode));
                if (res.errCode == 200) {
                }
                else {
                    this.stopBanner();
                }
            });
            bannerAd.onSize(res => {
                LogTool.log("vvmini.banner.onSize:" + JSONUtil.stringify(res));
            });
            bannerAd.onClose(res => {
                LogTool.log("vvmini.banner关闭:" + JSONUtil.stringify(res));
                this.isShowBanner = false;
            });
            this.bannerAd = bannerAd;
        }
    }

    class VvminiCustomAdController extends Controller {
        constructor() {
            super();
            this.customTs = 0;
            this.isShowCustom = false;
        }
        run() {
            super.run();
            this.api = VvminiModel.getApi();
            this.addEventListener(PlatformEvent.PLATFORM_AD_CUSTOM_SHOW, this, this.customViewHandler);
            this.initCustomAd();
        }
        initCustomAd() {
            let info = this.api.getSystemInfoSync();
            let screenWidth = info.screenWidth;
            let screenHeight = info.screenHeight;
            var x = (screenWidth - 540) / 2;
            var point = DisplayUtil.viewToScreenPoint(x, 1000, screenWidth, screenHeight);
            LogTool.log("initCustomAd: screenWidth=" + screenWidth);
            LogTool.log("initCustomAd: screenHeight=" + screenHeight);
            LogTool.log("initCustomAd: px=" + point.x);
            LogTool.log("initCustomAd: py=" + point.y);
            LogTool.log("initCustomAd: x=" + x);
            var showList = [];
            var preventList = ['SegmentLvUpView', 'PlatformClauseView'];
            this.checkCustomAd = new CheckShowController(PlatformEvent.PLATFORM_AD_CUSTOM_SHOW, null, showList, preventList);
            this.checkCustomAd.regOpenView("PlayerSetView", { type: 'ad4', isStyle: true });
            this.checkCustomAd.regOpenView("PageRewardView", { type: 'ad4', isStyle: true });
            this.checkCustomAd.regOpenView("GoodsGetView", { type: 'ad4', isStyle: true });
            this.checkCustomAd.regOpenView("OnlineView", { type: 'ad4', isStyle: true });
            this.checkCustomAd.regOpenView("AlertView", { type: 'ad2', left: point.x, top: 1000, height: 300, width: 300, isStyle: false });
            this.checkCustomAd.regOpenView("BattleVictoryView", { type: 'ad4', isStyle: true });
            this.checkCustomAd.regOpenView("BattleDefeatView", { type: 'ad4', isStyle: true });
            this.checkCustomAd.regOpenView("BattleTaskView", { type: 'ad2', left: 540, top: 1000, height: 300, width: 300, isStyle: false });
            this.startChild(this.checkCustomAd);
        }
        customViewHandler(data) {
            this.customData = data;
            LogTool.log('showCustom.10:' + JSONUtil.stringify(this.customData));
            TimerUtil.onceTimer(100, this, this.showCustomHandler, data);
        }
        showCustomHandler() {
            LogTool.log('showCustom.9');
            if (this.customData && this.customData.showType == ViewType.CLOSE) {
                LogTool.log('showCustom.8');
                this.closeCustom();
            }
            else {
                LogTool.log('showCustom.7');
                this.showCustom();
            }
        }
        showCustom() {
            LogTool.log('showCustom.1');
            if (this.isShowCustom) {
                return;
            }
            this.isShowCustom = true;
            var ts = TimeUtil.getTimestamp();
            LogTool.log('showCustom.2');
            if (!this.customAd || ts - this.customTs > 10) {
                LogTool.log('showCustom.loadCustom');
                this.customTs = ts;
                this.loadCustom();
            }
            else if (this.customAd) {
                LogTool.log('showCustom.show');
                this.customAd.show();
            }
        }
        closeCustom() {
            LogTool.log('closeCustom.1');
            this.isShowCustom = false;
            if (this.customAd) {
                LogTool.log('closeCustom.ok');
                this.customAd.hide();
                this.customAd.destroy();
                this.customAd = null;
            }
        }
        loadCustom() {
            var vc = this.api.getSystemInfoSync().platformVersionCode;
            LogTool.log('VvminiCustomAdController.loadCustom:' + JSONUtil.stringify(vc));
            if (vc < 1091) {
                this.stop();
            }
            var customId = VvminiConfig.getCustom(this.customData.type);
            if (!customId) {
                return;
            }
            if (!this.api.createCustomAd) {
                return;
            }
            if (this.customAd) {
                this.closeCustom();
            }
            LogTool.log('loadCustom.this.customData:' + JSONUtil.stringify(this.customData));
            var data = {};
            if (this.customData.isStyle == true) {
                data = {
                    posId: customId
                };
            }
            else {
                data = {
                    posId: customId,
                    style: {
                        left: this.customData.left,
                        top: this.customData.top,
                        height: this.customData.height,
                        width: this.customData.width,
                    }
                };
            }
            var customAd = this.api.createCustomAd(data);
            customAd.onLoad(res => {
                LogTool.log("vvmini.custom加载完成:" + JSONUtil.stringify(res));
                LogTool.log("vvmini.custom加载完成.style:" + JSONUtil.stringify(customAd));
                if (this.isShowCustom) {
                    customAd.show().then(() => {
                        LogTool.log('原生模板广告展示完成');
                    }).catch((err) => {
                        LogTool.log('原生模板广告展示失败' + JSONUtil.stringify(err));
                    });
                }
                if (this.isShowCustom == false) {
                    customAd.hide();
                    customAd.destroy();
                }
            });
            customAd.onError(res => {
                LogTool.log("vvmini.custom加载错误:" + JSONUtil.stringify(res));
                this.closeCustom();
            });
            customAd.onClose(res => {
                LogTool.log("vvmini.custom关闭:" + JSONUtil.stringify(res));
                this.isShowCustom = false;
            });
            this.customAd = customAd;
        }
    }

    class VvminiNativeAdController extends Controller {
        constructor(data) {
            super();
            this.refreshTime = 0;
            this.isClickClose = false;
            this.isStops = false;
            this.data = data;
            this.id = ParamUtil.getString(this.data, "id", this.id);
        }
        run() {
            super.run();
            this.api = VvminiModel.getApi();
            this.viewName = this.data.viewName;
            this.nativeid = VvminiConfig.getNative(this.data.type);
            this.ui = this.data.ui;
            this.ico = this.data.ico;
            this.image = this.data.image;
            this.title = this.data.title;
            this.content = this.data.content;
            this.clickList = this.data.clickList;
            this.showHandler = this.data.showHandler;
            this.closeHandler = this.data.closeHandler;
            this.refreshTime = ParamUtil.getInt(this.data, 'refreshTime');
            this.isClickClose = ParamUtil.getBool(this.data, "isClickClose", false);
            if (this.ui) {
                this.ui.visible = false;
            }
            if (this.ico) {
                this.ico.visible = false;
                this.ico.on(Laya.Event.CLICK, this, this.clickNativeAdHandler);
            }
            if (this.image) {
                this.image.visible = false;
                this.image.on(Laya.Event.CLICK, this, this.clickNativeAdHandler);
            }
            if (this.title) {
                this.title.visible = false;
                this.title.on(Laya.Event.CLICK, this, this.clickNativeAdHandler);
            }
            if (this.content) {
                this.content.visible = false;
                this.content.on(Laya.Event.CLICK, this, this.clickNativeAdHandler);
            }
            if (this.clickList) {
                for (var k in this.clickList) {
                    var clickBox = this.clickList[k];
                    clickBox.on(Laya.Event.CLICK, this, this.clickNativeAdHandler);
                }
            }
            this.addEventListener(ViewEvent.VIWE_CLOSE(this.viewName), this, this.closeHandlers);
            this.addEventListener(AdEvent.AD_NATIVE_CLICK, this, this.clickNativeAdHandler);
            this.loadNativeAd();
        }
        closeHandlers() {
            if (this.isStops == false) {
                this.isStops = true;
                LogTool.log('Vvmini.原生广告.closeHandlers:' + this.viewName + '');
                this.vo = null;
                this.showAd();
                this.callStop();
                this.stopNatived();
                this.stop();
            }
        }
        loadNativeAd() {
            LogTool.log('Vvmini.原生广告开始载' + this.viewName);
            this.nativeAd = this.api.createNativeAd({ adUnitId: this.nativeid });
            this.nativeAd.onLoad((res) => {
                LogTool.log('Vvmini.原生广告加载成功:' + JSONUtil.stringify(res));
                var list = res.adList;
                if (PropUtil.isEmpty(list) == false) {
                    var item = list[0];
                    var vo = new AdNativeVo();
                    vo.nativeId = item.adId;
                    vo.nativeURL = item.imgUrlList[0];
                    vo.nativeTitle = item.title;
                    vo.nativeContent = item.desc;
                    vo.nativeIco = item.icon;
                    vo.nativeLogoUrl = item.logoUrl;
                    this.vo = vo;
                    if (this.showHandler) {
                        LogTool.log("Vvmini:showHandler.");
                        HandlerUtil.call(this.showHandler, { vo: vo });
                    }
                    this.showAd();
                    this.showNativeAdHandler();
                    this.loadComplete();
                    LogTool.log("Vvmini:loadNativeAd.url:" + this.vo.nativeURL);
                }
            });
            this.nativeAd.onError((res) => {
                LogTool.log('Vvmini.原生广告加载失败:' + JSONUtil.stringify(res));
                this.closeHandlers();
            });
            this.nativeAd.load();
        }
        loadComplete() {
            LogTool.log("Vvmini:loadNativeAd.url:" + this.vo.nativeURL);
            if (this.refreshTime > 0) {
                TimerUtil.onceTimer(this.refreshTime, this, this.reloadHandler);
            }
        }
        reloadHandler() {
            if (this.nativeAd) {
                this.nativeAd.load();
            }
        }
        showNativeAdHandler() {
            LogTool.log('Vvmini.原生广告.reportAdShow:' + this.vo.nativeId);
            if (this.nativeAd) {
                this.nativeAd.reportAdShow({ adId: this.vo.nativeId });
                this.adShowHandler();
            }
        }
        clickNativeAdHandler() {
            LogTool.log('Vvmini.原生广告.reportAdClick' + this.vo.nativeId);
            if (this.nativeAd) {
                if (AdModel.model.nativeCanclick == 0) {
                    this.nativeAd.reportAdClick({ adId: this.vo.nativeId });
                    this.adClickHandler();
                }
            }
            if (this.isClickClose) {
                this.closeHandlers();
            }
        }
        stopNatived() {
            LogTool.log('Vvmini.原生广告.stopNatived');
            if (this.nativeAd) {
                if (ParamUtil.isFunction(this.nativeAd.destroy)) {
                    this.nativeAd.destroy();
                    this.nativeAd = null;
                }
            }
        }
        callStop() {
            if (this.closeHandler) {
                LogTool.log("Vvmini:closeHandler.");
                HandlerUtil.call(this.closeHandler);
            }
        }
        adShowHandler() {
            var data1 = { gameId: VvminiConfig.gameId, type: 'show', adid: this.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readShowHandler);
        }
        readShowHandler() {
        }
        adClickHandler() {
            var data1 = { gameId: VvminiConfig.gameId, type: 'click', adid: this.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readClickHandler);
        }
        readClickHandler() {
        }
        showAd() {
            if (this.vo) {
                if (this.ui) {
                    this.ui.visible = true;
                }
                if (this.ico) {
                    LogTool.log('Vvmini.原生广告.ico' + this.vo.nativeIco);
                    this.ico.visible = true;
                    this.ico.skin = this.vo.nativeIco;
                }
                if (this.image) {
                    LogTool.log('Vvmini.原生广告.image' + this.vo.nativeURL);
                    this.image.visible = true;
                    this.image.skin = this.vo.nativeURL;
                }
                if (this.title) {
                    LogTool.log('Vvmini.原生广告.title' + this.vo.nativeTitle);
                    this.title.visible = true;
                    this.title.text = this.vo.nativeTitle;
                }
                if (this.content) {
                    LogTool.log('Vvmini.原生广告.content' + this.vo.nativeContent);
                    this.content.visible = true;
                    this.content.text = this.vo.nativeContent;
                }
            }
            else {
                if (this.ui) {
                    this.ui.visible = false;
                }
                if (this.ico) {
                    this.ico.visible = false;
                }
                if (this.image) {
                    this.image.visible = false;
                }
                if (this.title) {
                    this.image.visible = false;
                }
                if (this.content) {
                    this.content.visible = false;
                }
            }
        }
    }

    class VvminiPortalAdController extends Controller {
        constructor() {
            super();
            this.boxPortalAd = null;
        }
        run() {
            super.run();
            this.api = VvminiModel.getApi();
            this.vo = VvminiModel.model;
            this.initPortalAdView();
        }
        initPortalAdView() {
            if (this.api.createBoxPortalAd) {
                this.boxPortalAd = this.api.createBoxPortalAd({
                    posId: VvminiConfig.portalid,
                    image: '',
                    marginTop: 300,
                });
                this.boxPortalAd.onError(function (err) {
                    LogTool.log("盒子九宫格广告加载失败" + err);
                });
                this.boxPortalAd.onClose(function () {
                    LogTool.log('close');
                    this.boxPortalAd.show();
                });
                this.boxPortalAd.show().then(function () {
                    LogTool.log('show success');
                });
            }
            else {
                LogTool.log('暂不支持互推盒子相关 API');
            }
        }
    }

    class VvminiVideoAdController extends Controller {
        constructor() {
            super();
            this.adViewTime = 0;
        }
        run() {
            super.run();
            this.api = VvminiModel.getApi();
            this.vo = VvminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.initViedoAd();
        }
        initViedoAd() {
            if (!VvminiConfig.videoid) {
                return null;
            }
            if (!this.api.createRewardedVideoAd) {
                LogTool.log('vvmini.激励视频错误.api-error');
                return null;
            }
            if (!this.rewardedVideoAd) {
                let example = {
                    posId: VvminiConfig.videoid,
                    adUnitId: VvminiConfig.videoid,
                };
                let rewardedVideoAd = this.api.createRewardedVideoAd(example);
                rewardedVideoAd.load();
                rewardedVideoAd.onLoad(() => {
                    PlatformModel.model.hasAdVideo = true;
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_LOAD);
                });
                rewardedVideoAd.onError((err) => {
                    PlatformModel.model.hasAdVideo = false;
                    LogTool.log('vvmini.激励视频错误:' + JSONUtil.stringify(err));
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                });
                rewardedVideoAd.onClose((res) => {
                    LogTool.log('vvmini.激励视频关闭');
                    if (res && res.isEnded) {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                    }
                    else {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                    }
                    rewardedVideoAd.load();
                    SoundTool.setPause('adView', false);
                });
                this.rewardedVideoAd = rewardedVideoAd;
            }
            return this.rewardedVideoAd;
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            let rewardedVideoAd = this.initViedoAd();
            LogTool.log('点击开始观看视频111');
            if (rewardedVideoAd && PlatformModel.model.hasAdVideo) {
                LogTool.log('存在视频111');
                if (TimeUtil.getTimestamp() - this.adViewTime <= 10) {
                    LogTool.log('调用激励视频频率过高');
                    this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "暂无广告" });
                }
                else {
                    rewardedVideoAd.show();
                }
                this.adViewTime = TimeUtil.getTimestamp();
                SoundTool.setPause('adView', true);
            }
            else {
                LogTool.log('不存在视频111');
                this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "暂无广告" });
            }
        }
    }

    class VvminiController extends Controller {
        constructor() {
            super();
            this.rateList = ['wudian', 'icontime', 'yanchi', 'ysgg'];
            this.canclick = 1;
        }
        run() {
            super.run();
            this.api = VvminiModel.getApi();
            SceneConfig.playKillSound = true;
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(PlatformEvent.PLATFORM_API_INIT, this, this.initApiHandler);
            this.addEventListener(PlatformEvent.PLATFORM_EXIT, this, this.exitHandler);
        }
        initHandler() {
            this.initSdk();
            this.initPrivacy();
        }
        initApiHandler() {
            this.startChild(new VvminiCustomAdController());
            this.startChild(new VvminiVideoAdController());
            this.startChild(new VvminiBannerAdController());
            this.startChild(new VvminiPortalAdController());
            this.startChild(new VvminiAddIcoController());
        }
        initPrivacy(data = null) {
            if (PlatformModel.model.privacyNum < 1) {
                this.dispatchEvent(PlatformEvent.PLATFORM_PRIVACY_VIEW);
            }
        }
        initParam() {
            LogTool.log('vvmini.initParam:' + AdTool.checkRate('wudian'));
            BattleConfig.battleViewType = 1;
            if (AdModel.model.isShieldCity == false) {
                PlayerConfig.playerType = 2;
                PageConfig.pageRewardType = 3;
                GoodsConfig.goodGetType = 3;
                OnlineConfig.onlineType = 3;
                BattleConfig.battleTaskType = 3;
                SignConfig.signType = 1;
                BattleConfig.battleTryType = 1;
                BattleConfig.battleTryTypeTwo = 1;
                CommonConfig.alertType = 3;
                BattleConfig.victoryType = 3;
                BattleConfig.defeatType = 3;
            }
            else {
                GoodsConfig.goodGetType = 4;
                OnlineConfig.onlineType = 4;
                BattleConfig.battleTaskType = 4;
                PlayerConfig.playerType = 2;
                PageConfig.pageRewardType = 3;
                SignConfig.signType = 0;
                BattleConfig.battleTryType = 0;
                BattleConfig.battleTryTypeTwo = 0;
                CommonConfig.alertType = 3;
                BattleConfig.victoryType = 3;
                BattleConfig.defeatType = 3;
            }
            this.dispatchEvent(PlatformEvent.PLATFORM_API_INIT);
        }
        loadNativeAd(data) {
            LogUtil.log("loadNativeAd:Vvmini:" + data.id);
            if (!this.getChild(data.id)) {
                LogUtil.log("loadNativeAd:Vvmini:startChild");
                this.startChild(new VvminiNativeAdController(data));
            }
        }
        initRemordAd() {
            LogTool.log("vvmini.initNativeAd:PageCompleteView");
            this.addEventListener(ViewEvent.VIWE_OPEN("BattleDefeatView"), this, this.showNativeAdPage);
            this.addEventListener(ViewEvent.VIWE_OPEN("BattleVictoryView"), this, this.showNativeAdPage);
        }
        showNativeAdPage() {
            var vc = this.api.getSystemInfoSync().platformVersionCode;
            LogTool.log('VvminiController.showNativeAdPage:' + vc);
            if (vc > 1053) {
                LogTool.log('VvminiController.showNativeAdPage11111:' + vc);
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { showType: ViewType.OPEN });
            }
            else {
                LogTool.log('VvminiController.showNativeAdPage22222:' + vc);
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, { showType: ViewType.CLOSE });
            }
        }
        initEpView() {
        }
        initSdk() {
            this.startLogin();
        }
        startLogin() {
            var data = {};
            data.gameId = VvminiConfig.gameId;
            data.version = VvminiConfig.version;
            data.channel_id = PlatformModel.model.channel_id;
            data.openId = PlatformModel.model.openId;
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/login';
            NetTool.request(url, data, 'get', this, this.loginResponseHandler);
        }
        loginResponseHandler(data) {
            EpModel.model.adData = EpTool.reAdData(data);
            this.getCity();
        }
        getCity() {
            if (VvminiConfig.gameId) {
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/isPinbi';
                NetTool.request(url, { gameId: VvminiConfig.gameId }, 'get', this, this.getCityHandler);
            }
        }
        getCityHandler(data) {
            LogTool.log('vvmini.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            this.getRateAip();
            this.initRemordAd();
        }
        getRateAip() {
            if (this.rateList.length > 0) {
                var key = this.rateList.shift();
                var data1 = { gameId: VvminiConfig.gameId, version: VvminiConfig.version, key: key };
                var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/adrate';
                LogTool.log('vvmini.getRateAip' + key + data1);
                NetTool.request(url, data1, 'get', this, (data) => {
                    AdModel.model.setRate(key, ParamUtil.getInt(data, 'rate'));
                    this.getRateAip();
                });
            }
            else {
                this.initCanclick();
            }
        }
        initCanclick() {
            var data1 = { gameId: VvminiConfig.gameId, type: 'canclick', adid: VvminiConfig.nativeid };
            var url = 'http://wxxcx.tanyu.mobi:8082/admin/api/ovrate';
            NetTool.request(url, data1, 'get', this, this.readCanclickHandler);
        }
        readCanclickHandler(data) {
            if (data) {
                AdModel.model.nativeCanclick = data.code;
            }
            this.initParam();
        }
        exitHandler() {
            this.api.exitApplication();
        }
    }

    class WxminiConfig {
        static getBanner() {
            var type = RandomUtil.randomInt(0, this.bannerids.length);
            if (this.bannerids[type]) {
                return this.bannerids[type];
            }
            return this.bannerids[0];
        }
        static getCustom(type) {
            if (this.customId[type]) {
                return this.customId[type];
            }
            return this.customId['ad1'];
        }
    }
    WxminiConfig.videoid = 'adunit-6574a7b6829e33ad';
    WxminiConfig.gridid = '';
    WxminiConfig.insertid = '';
    WxminiConfig.customid = 'adunit-f1d31bce53912b07';
    WxminiConfig.sceneDesk = 1023;
    WxminiConfig.sceneMini = [1089, 1001];
    WxminiConfig.shareImageId = ['bNToQA20T86pm3yfWAsfCQ==', '347u636dTJafy5O3b/Sw7g==', 'CfQEvxBxQHizPO+xxHn/Qg=='];
    WxminiConfig.bannerids = ['adunit-f040d676bd7b6255', 'adunit-a87791760ad04f66', 'adunit-e09405c50309469c'];
    WxminiConfig.customId = {
        'ad1': 'adunit-f1d31bce53912b07',
        'ad2': 'adunit-724b56fba3bbbcad',
        'ad3': 'adunit-02d6b645bf798eb3',
    };
    WxminiConfig.gameId = 755;
    WxminiConfig.version = '1.0.2';

    class WxminiEvent {
    }
    WxminiEvent.WXMINI_INFO_VIEW_SHOW = 'WXMINI_INFO_VIEW_SHOW';
    WxminiEvent.WXMINI_INFO_BUTTON_VIEW_SHOW = 'WXMINI_INFO_BUTTON_VIEW_SHOW';

    class WxminiModel {
        constructor() {
            this.code = '';
            this.openid = '';
            this.scene = 0;
        }
        static getApi() {
            if (typeof wx == "undefined") {
                return null;
            }
            else {
                return wx;
            }
        }
    }
    WxminiModel.model = new WxminiModel();

    class WxminiBannerAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            if (WxminiConfig.getBanner()) {
                this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
                this.initBannerAd();
            }
        }
        initBannerAd() {
            var showList = ['PlayerSetView', 'OnlineView', 'BattleTaskView', 'BattleView', 'AlertView', 'BattleDefeatView', 'BattleVictoryView'];
            var preventList = ['BattleTryHeroView'];
            this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, {}, showList, preventList);
            this.checkShowBanner.regOpenView('GoodsGetView', { right: 13, isRestart: true, });
            this.checkShowBanner.regOpenView('PageRewardView', { right: 13, isRestart: true, });
            this.checkShowBanner.regOpenView('AlertView', { isRestart: true });
            this.checkShowBanner.regOpenView('BattleView', { isRestart: true });
            this.startChild(this.checkShowBanner);
        }
        bannerViewHandler(data) {
            TimerUtil.stopTimer(this, this.showBanner);
            var left = ParamUtil.getInt(data, 'left', 0);
            var right = ParamUtil.getInt(data, 'right', 0);
            var isRestart = ParamUtil.getBool(data, 'isRestart', false);
            var time = ParamUtil.getInt(data, 'time', 0);
            if (data && data.showType == ViewType.CLOSE) {
                this.stopBanner();
            }
            else if (time) {
                TimerUtil.onceTimer(data.time, this, this.showBanner, [isRestart, left, right]);
            }
            else {
                this.showBanner(isRestart, left, right);
            }
        }
        showBanner(isRestart, left, right = 0) {
            if (isRestart) {
                this.loadBanner(left, right);
            }
            else if (this.bannerAd && left) {
                this.bannerAd.style.left = left;
                this.bannerAd.show();
            }
            else if (this.bannerAd) {
                this.bannerAd.show();
            }
            else {
                this.loadBanner(left, right);
            }
        }
        loadBanner(left = 0, right = 0) {
            this.stopBanner();
            var bannerid = WxminiConfig.getBanner();
            let info = this.api.getSystemInfoSync();
            let screenHeight = info.screenHeight;
            let screenWidth = info.screenWidth;
            LogTool.log("showBanner-show:id:" + bannerid + ',w:' + screenWidth + ',h:' + screenHeight);
            if (right > 0) {
                left = screenWidth - 200 + right;
            }
            else if (left == 0) {
                left = (screenWidth - 300) / 2;
            }
            LogTool.log('showBanner-show:id+left:' + left);
            let bannerAd = this.api.createBannerAd({
                adUnitId: bannerid,
                adIntervals: true,
                style: {
                    width: 300,
                    top: screenHeight - 118,
                    left: left,
                    height: 105,
                }
            });
            bannerAd.onResize((res) => {
                LogTool.log("wxmini.showBanner-onResize:" + JSONUtil.stringify(res));
                bannerAd.style.top = screenHeight - bannerAd.style.realHeight - 10;
                var w = bannerAd.style.realWidth;
                if (right > 0) {
                    bannerAd.style.left = screenWidth - w + right;
                }
                else if (left == 0) {
                    bannerAd.style.left = (screenWidth - w) / 2;
                }
            });
            bannerAd.onError((res) => {
                LogTool.log("wxmini.showBanner-onError:" + JSONUtil.stringify(res));
                this.closeBanner();
            });
            bannerAd.show();
            this.bannerAd = bannerAd;
        }
        closeBanner() {
            if (this.bannerAd) {
                this.bannerAd.hide();
            }
        }
        stopBanner() {
            if (this.bannerAd) {
                this.bannerAd.hide();
                this.bannerAd.destroy();
                this.bannerAd = null;
            }
        }
    }

    class WxminiCustomAdController extends Controller {
        constructor() {
            super();
            this.isShow = false;
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            if (WxminiConfig.getCustom('ad1')) {
                this.addEventListener(PlatformEvent.PLATFORM_AD_CUSTOMAD_SHOW, this, this.customAdViewHandler);
                this.initCustomAd();
            }
        }
        initCustomAd() {
            var showList = [];
            var preventList = ['BattleLoadView', 'BattleStartTryHeroView', 'BattleTryHeroView', 'SegmentView', 'PlayerSetView', 'OnlineView', 'AlertView', 'SignDayView', 'ShopMallView', 'TaskView', 'HeroView', 'GoodsGetView', 'BattleTryHeroView', 'GuideDialogView'];
            this.checkShowCustomAd = new CheckShowController(PlatformEvent.PLATFORM_AD_CUSTOMAD_SHOW, null, showList, preventList);
            this.checkShowCustomAd.regOpenView('BattleView', { customId: WxminiConfig.getCustom('ad2'), left: 120, top: 65, isRestart: true });
            this.checkShowCustomAd.regOpenView('PageView', { customId: WxminiConfig.getCustom('ad2'), left: 460, top: 110, isRestart: true });
            this.checkShowCustomAd.regOpenView('AlertView', { customId: WxminiConfig.getCustom('ad3'), left: 150, top: 10, isRestart: true });
            this.checkShowCustomAd.regOpenView('BattleDefeatView', { customId: WxminiConfig.getCustom('ad3'), left: 150, top: 10, isRestart: true });
            this.checkShowCustomAd.regOpenView('BattleVictoryView', { customId: WxminiConfig.getCustom('ad3'), left: 150, top: 10, isRestart: true });
            this.checkShowCustomAd.regOpenView('PlatformNativeAd5View', { customId: WxminiConfig.getCustom('ad1'), left: 200, top: 0, isRestart: true, width: 375 });
            this.startChild(this.checkShowCustomAd);
        }
        customAdViewHandler(data) {
            TimerUtil.stopTimer(this, this.showCustomAd);
            var isRestart = ParamUtil.getBool(data, 'isRestart', false);
            var customId = ParamUtil.getString(data, 'customId', WxminiConfig.getCustom('ad1'));
            var time = ParamUtil.getInt(data, 'time', 0);
            var left = ParamUtil.getInt(data, 'left', 30);
            var width = ParamUtil.getInt(data, 'width', 50);
            var top = ParamUtil.getInt(data, 'top', 100);
            if (data && data.showType == ViewType.CLOSE) {
                this.closeCustomAd();
            }
            else if (time) {
                TimerUtil.onceTimer(data.time, this, this.showCustomAd, [isRestart, customId, left, top, width]);
            }
            else {
                TimerUtil.onceTimer(100, this, this.showCustomAd, [isRestart, customId, left, top, width]);
            }
        }
        showCustomAd(isRestart, customId, left, top, width) {
            this.loadCustomAd(customId, left, top, width);
        }
        loadCustomAd(customId, left, top, width) {
            this.stopCustomAd();
            this.isShow = true;
            var customid = customId;
            LogTool.log('WxminiCustomAdController.loadCustomAd:' + customid);
            let info = this.api.getSystemInfoSync();
            let screenHeight = info.screenHeight;
            let screenWidth = info.screenWidth;
            LogTool.log("customAd-show:id:" + customid + ',w:' + screenWidth + ',h:' + screenHeight);
            let customAd = this.api.createCustomAd({
                adUnitId: customid,
                adIntervals: 30,
                style: {
                    left: left,
                    top: top,
                    width: width,
                }
            });
            customAd.onLoad((res) => {
                LogTool.log('Wxmini.customAd' + JSONUtil.stringify(res));
                if (!this.isShow) {
                    this.closeCustomAd();
                }
            });
            customAd.onError((res) => {
                LogTool.log('Wxmini.customAd' + JSONUtil.stringify(res));
            });
            customAd.show();
            this.customAd = customAd;
        }
        closeCustomAd() {
            this.isShow = false;
            if (this.customAd) {
                this.customAd.hide();
            }
        }
        stopCustomAd() {
            this.isShow = false;
            if (this.customAd) {
                this.customAd.hide();
                this.customAd.destroy();
                this.customAd = null;
            }
        }
    }

    class WxminiEpController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            this.initEpView();
        }
        initEpView() {
            ViewTool.synchView('PageView', this, EpEvent.EP_PAGE09_VIEW_SHOW);
        }
    }

    class WxminiGridAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            this.vo = WxminiModel.model;
            if (WxminiConfig.gridid) {
                this.addEventListener(PlatformEvent.PLATFORM_AD_GRID_SHOW, this, this.showGridHandler);
                this.initGridAd();
            }
        }
        initGridAd() {
            var showList = ['BattleView'];
            var preventList = ['BattleMatchView', 'BattleMatch5View',];
            this.checkShow = new CheckShowController(PlatformEvent.PLATFORM_AD_GRID_SHOW, null, showList, preventList);
            this.startChild(this.checkShow);
        }
        showGridHandler(data) {
            if (data && data.showType == ViewType.CLOSE) {
                this.closeGridHandler();
            }
            else {
                this.showGrid();
            }
        }
        showGrid() {
            if (this.gridAd) {
                this.gridAd.show();
            }
            else {
                this.loadGrid();
            }
        }
        loadGrid() {
            var gridid = WxminiConfig.gridid;
            let info = this.api.getSystemInfoSync();
            let screenHeight = info.screenHeight;
            let screenWidth = info.screenWidth;
            LogTool.log("showGrid-show:id:" + gridid + ',w:' + screenWidth + ',h:' + screenHeight);
            var left = (screenWidth - 228) / 2 - 40;
            let gridAd = this.api.createGridAd({
                adUnitId: gridid,
                adIntervals: 30,
                adTheme: 'white',
                gridCount: 5,
                style: {
                    left: left,
                    top: 50,
                    width: 200,
                    height: 50,
                }
            });
            gridAd.onResize((res) => {
                LogTool.log("showGrid-onResize:w" + res.width + ',h:' + res.height + ',rh:' + gridAd.style.realHeight);
                gridAd.style.top = screenHeight - gridAd.style.realHeight - 10;
            });
            gridAd.onError((res) => {
                LogTool.log("showGrid-onError:" + res.errCode + ",msg:" + res.errMsg);
                this.closeGridHandler();
            });
            gridAd.show().then(() => {
                console.log('格子广告显示成功');
            }).catch((e) => {
                console.log('格子广告显示失败');
            });
            this.gridAd = gridAd;
        }
        closeGridHandler() {
            if (this.gridAd) {
                LogTool.log("close Grid");
                this.gridAd.hide();
                this.gridAd.destroy();
                this.gridAd = null;
            }
        }
    }

    class WxminiInfoButtonViewController extends ViewController {
        constructor() {
            super();
        }
        openComplete() {
            super.openComplete();
            var weixin = WxminiModel.getApi();
            var info = weixin.getSystemInfoSync();
            var s = info.screenHeight / Laya.stage.height;
            var bx = Laya.stage.width - 580;
            var by = 650;
            var bw = 150;
            var bh = 150;
            this.button = weixin.createUserInfoButton({
                type: 'image',
                image: './img/img_blank.png',
                style: {
                    left: bx * s,
                    top: by * s,
                    width: bw * s,
                    height: bh * s,
                    lineHeight: 0,
                    color: '#ffffff',
                    textAlign: 'center',
                    fontSize: 24,
                    borderRadius: 4
                }
            });
            this.button.onTap((res) => {
                if (res.userInfo) {
                    LogTool.log("WxminiInfoButtonView.获取登录信息:avatarUrl=" + JSONUtil.stringify(res.userInfo.avatarUrl));
                    LogTool.log("WxminiInfoButtonView.获取登录信息" + JSONUtil.stringify(res));
                    this.dispatchEvent(PlayerEvent.PLAYER_INFO_RESPONSE, { name: res.userInfo.nickName, ico: res.userInfo.avatarUrl });
                    this.dispatchEvent(RankEvent.RANK_VIEW_SHOW, { showType: ViewType.OPEN });
                    this.close();
                }
            });
        }
        close() {
            super.close();
            if (this.button) {
                this.button.destroy();
            }
        }
    }

    class WxminiInfoViewController extends ViewController {
        constructor() {
            super();
        }
        openComplete() {
            super.openComplete();
            this.api = WxminiModel.getApi();
            var info = this.api.getSystemInfoSync();
            this.button = this.api.createUserInfoButton({
                type: 'image',
                image: './img/img_blank.png',
                style: {
                    left: 0,
                    top: info.screenHeight / 4,
                    width: 1280,
                    height: 720,
                    lineHeight: 0,
                    color: '#ffffff',
                    textAlign: 'center',
                    fontSize: 24,
                    borderRadius: 4
                }
            });
            this.button.onTap((res) => {
                if (res.userInfo) {
                    LogTool.log("WxminiLoginView.获取登录信息:avatarUrl=" + JSONUtil.stringify(res.userInfo.avatarUrl));
                    LogTool.log("WxminiLoginView.获取登录信息" + JSONUtil.stringify(res));
                    this.dispatchEvent(PlayerEvent.PLAYER_INFO_RESPONSE, { name: res.userInfo.nickName, ico: res.userInfo.avatarUrl });
                    this.close();
                }
            });
        }
        close() {
            super.close();
            if (this.button) {
                this.button.destroy();
            }
        }
    }

    class WxminiInsertAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsertHanlder);
            this.initInsertAd();
        }
        initInsertAd() {
            if (!WxminiConfig.insertid) {
                return;
            }
            var interstitialAd = this.api.createInterstitialAd({
                adUnitId: WxminiConfig.insertid,
            });
            interstitialAd.onLoad((res) => {
                LogTool.log('Wxmini插屏广告加载成功' + JSONUtil.stringify(res));
                this.interstitialAd = interstitialAd;
            });
            interstitialAd.onError((res) => {
                LogTool.log('Wxmini插屏广告加载失败' + JSONUtil.stringify(res));
            });
        }
        showInsertHanlder() {
            if (this.interstitialAd) {
                this.interstitialAd.show();
            }
        }
    }

    class WxminiTyController extends Controller {
        constructor() {
            super();
            this.rateList = ['sxbanner', 'kjkd', 'jskd', 'kjsp', 'cpgg', 'yczs', 'yanchi', 'mrgx'];
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            this.vo = WxminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_SKD_INIT, this, this.sdkLogin);
        }
        sdkLogin() {
            if (WxminiConfig.gameId) {
                var code = this.vo.code;
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/getopenid?gameId=' + WxminiConfig.gameId + '&code=' + code;
                NetTool.request(url, {}, 'get', this, this.openeIdHandler);
            }
        }
        openeIdHandler(data) {
            if (!data.openid) {
                this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "登录错误:openid错误" });
                return;
            }
            this.vo.openid = data.openid;
            var data = {};
            data.gameId = WxminiConfig.gameId;
            data.version = WxminiConfig.version;
            data.channel_id = PlatformModel.model.channel_id;
            data.openId = this.vo.openid;
            var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/login';
            NetTool.request(url, data, 'get', this, this.loginResponseHandler);
            this.api.uma.setOpenid(this.vo.openid);
            this.initBattleEvent();
        }
        loginResponseHandler(data) {
            EpModel.model.adData = EpTool.reAdData(data);
            this.dispatchEvent(EpEvent.EP_DATA_RESPONSE);
            this.getCity();
        }
        getCity() {
            if (WxminiConfig.gameId) {
                var data1 = { gameId: WxminiConfig.gameId, version: WxminiConfig.version, openId: this.vo.openid };
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/isPinbi';
                NetTool.request(url, data1, 'get', this, this.getCityHandler);
            }
        }
        getCityHandler(data) {
            LogTool.log('wxmini.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            this.getRateAip();
        }
        getRateAip() {
            if (this.rateList.length > 0) {
                var key = this.rateList.shift();
                var data1 = { gameId: WxminiConfig.gameId, version: WxminiConfig.version, key: key };
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/adrate';
                NetTool.request(url, data1, 'get', this, (data) => {
                    AdModel.model.setRate(key, ParamUtil.getInt(data, 'rate'));
                    this.getRateAip();
                });
            }
            else {
                this.dispatchEvent(PlatformEvent.PLATFORM_API_INIT);
            }
        }
        initBattleEvent() {
        }
        battleOnStartHandler(data) {
            var vo = SceneModel.model.vo;
            var stageId = vo.cid;
            var stageName = "第" + vo.cid + "关";
            this.api.uma.stage.onStart({
                stageId: stageId,
                stageName: stageName,
            });
        }
        battleOnCompleteHandler(data) {
            var vo = SceneModel.model.vo;
            var stageId = vo.cid;
            var stageName = "第" + vo.cid + "关";
            this.api.uma.stage.onEnd({
                stageId: stageId,
                stageName: stageName,
            });
        }
    }

    class WxminiVideoAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            this.vo = WxminiModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.initViedoAd();
        }
        initViedoAd() {
            if (!WxminiConfig.videoid) {
                return null;
            }
            if (!this.rewardedVideoAd) {
                let example = {
                    adUnitId: WxminiConfig.videoid,
                };
                let rewardedVideoAd = this.api.createRewardedVideoAd(example);
                rewardedVideoAd.onLoad(() => {
                    LogTool.log('激励视频加载成功');
                    PlatformModel.model.hasAdVideo = true;
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_LOAD);
                });
                rewardedVideoAd.onError((err) => {
                    PlatformModel.model.hasAdVideo = false;
                    LogTool.log('激励视频错误:' + JSONUtil.stringify(err));
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                });
                rewardedVideoAd.onClose((res) => {
                    LogTool.log('激励视频关闭');
                    if (res && res.isEnded) {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                        this.sdkVideoCompleteCount(PlatformModel.model.adVideoId);
                    }
                    else {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                        this.sdkVideoCloseCount(PlatformModel.model.adVideoId);
                    }
                    SoundTool.setPause('adView', false);
                });
                this.rewardedVideoAd = rewardedVideoAd;
            }
            return this.rewardedVideoAd;
        }
        checkVideoLoad() {
            let rewardedVideoAd = this.rewardedVideoAd;
            if (PlatformModel.model.hasAdVideo) {
                this.showVideoStartHandler();
            }
            else if (rewardedVideoAd) {
                rewardedVideoAd.load();
                this.onceEventListener(PlatformEvent.PLATFORM_AD_VIDEO_LOAD, this, this.showVideoStartHandler);
            }
        }
        showVideoStartHandler() {
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            let rewardedVideoAd = this.initViedoAd();
            if (rewardedVideoAd && PlatformModel.model.hasAdVideo) {
                rewardedVideoAd.show();
                SoundTool.setPause('adView', true);
                this.sdkVideoCount(PlatformModel.model.adVideoId);
            }
            else {
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
                this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_SHOW);
                this.sdkVideoNoCount(PlatformModel.model.adVideoId);
            }
        }
        shareCompHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareFailHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
        }
        sdkVideoCount(type) {
            if (WxminiConfig.gameId) {
                var data = {};
                data.gameId = WxminiConfig.gameId;
                data.version = WxminiConfig.version;
                data.openId = this.vo.openid;
                data.channel_id = PlatformModel.model.channel_id;
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/calVideoCount';
                NetTool.request(url, data, 'get', this, (res) => { LogTool.log("VideoCount:" + res.msg); });
            }
            this.api.uma.trackEvent('videoAdShow', { type: type });
        }
        sdkVideoNoCount(type) {
            this.api.uma.trackEvent('videoAdNo', { type: type });
        }
        sdkVideoCompleteCount(type) {
            this.api.uma.trackEvent('videoAdComplete', { type: type });
        }
        sdkVideoCloseCount(type) {
            this.api.uma.trackEvent('videoAdClose', { type: type });
        }
    }

    class WxminiController extends Controller {
        constructor() {
            super();
            this.shareTime = 0;
            this.linkData = null;
            this.linkTime = 0;
        }
        run() {
            super.run();
            this.api = WxminiModel.getApi();
            this.vo = WxminiModel.model;
            WxminiConfig.version = MainConfig.ver;
            this.startChild(new WxminiTyController());
            ViewManager.register(WxminiEvent.WXMINI_INFO_VIEW_SHOW, this, WxminiInfoViewController);
            ViewManager.register(WxminiEvent.WXMINI_INFO_BUTTON_VIEW_SHOW, this, WxminiInfoButtonViewController);
            this.api.onShow(() => { this.dispatchEvent(CommonEvent.WINDOW_FOCUS); });
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_SHOW, this, this.shareHandler);
            this.addEventListener(PlatformEvent.PLATFORM_LINK_GOTO, this, this.gotoLinkHandler);
            this.addEventListener(PlatformEvent.PLATFORM_IMAGE_SHOW, this, this.imageHandler);
            this.addEventListener(PlatformEvent.PLATFORM_INVITE, this, this.inviteHandler);
            this.addEventListener(CommonEvent.VIBRATE_START, this, this.vibrateHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(PlatformEvent.PLATFORM_API_INIT, this, this.initApiHandler);
        }
        initHandler() {
            PlatrormLoadingView.close();
            this.loginHandler();
        }
        initApiHandler() {
            this.startChild(new WxminiBannerAdController());
            this.startChild(new WxminiVideoAdController());
            this.startChild(new WxminiInsertAdController());
            this.startChild(new WxminiGridAdController());
            this.startChild(new WxminiCustomAdController());
            this.startChild(new WxminiEpController());
            this.initShare();
            this.initDesktop();
            this.initLink();
            this.initUserInfoButton();
            this.initParam();
        }
        initParam() {
            PlayerConfig.playerType = 3;
            BattleConfig.battleViewType = 1;
            CommonConfig.alertType = 4;
            BattleConfig.defeatType = 7;
            BattleConfig.victoryType = 7;
            if (AdModel.model.isShieldCity == false) {
                SignConfig.signType = 1;
                PageConfig.pageRewardType = 6;
                OnlineConfig.onlineType = 5;
                BattleConfig.battleTryType = 4;
                BattleConfig.battleTaskType = 7;
                GoodsConfig.goodGetType = 7;
                BattleConfig.battleTryTypeTwo = 3;
            }
            else {
                SignConfig.signType = 0;
                PageConfig.pageRewardType = 0;
                OnlineConfig.onlineType = 2;
                BattleConfig.battleTryType = 0;
                BattleConfig.battleTaskType = 4;
                GoodsConfig.goodGetType = 8;
                BattleConfig.battleTryTypeTwo = 0;
            }
            var opt = this.api.getLaunchOptionsSync();
            if (opt) {
                var channel_id = ParamUtil.getString(opt.query, 'channel_id', '');
                this.vo.scene = opt.scene;
            }
            if (channel_id) {
                PlatformModel.model.channel_id = channel_id;
                PlatformModel.model.saveData();
            }
        }
        loginHandler() {
            this.api.login({
                success: (res) => {
                    LogTool.log('登录成功');
                    if (res.code) {
                        this.vo.code = res.code;
                        this.dispatchEvent(PlatformEvent.PLATFORM_SKD_INIT);
                    }
                    else {
                        this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { type: PromptType.PROMPT_WARNING, text: "登录失败,请重新登录 : " + res.errMsg });
                    }
                },
                fail: (res) => {
                    LogTool.log("登录失败:" + JSONUtil.stringify(res));
                    this.gotoLogin();
                }
            });
        }
        gotoLogin() {
            this.api.showModal({
                title: "您当前没有登录",
                content: "是否重新登录？",
                cancelText: "退出游戏",
                success: (res) => {
                    if (res.confirm) {
                        LogTool.log("用户点击确定登录");
                        this.loginHandler();
                    }
                    else if (res.cancel) {
                        LogTool.log("用户点击取消登录");
                        this.api.exit();
                    }
                }
            });
        }
        initShare() {
            this.api.onShareAppMessage(function () {
                return PlatformTool.getShareObject();
            });
            this.api.uma.trackShare(PlatformTool.getShareObject());
            this.api.showShareMenu();
        }
        shareHandler() {
            this.shareTime = TimeUtil.getTime();
            this.api.shareAppMessage(PlatformTool.getShareObject());
            this.api.uma.trackShare(PlatformTool.getShareObject());
            this.api.onShow(() => { this.onShareHandler(); });
        }
        onShareHandler() {
            if (this.shareTime > 0) {
                if (TimeUtil.getTime() - this.shareTime < 2500) {
                    LogUtil.log("onShareHandler:时间太短,分享失败");
                    this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "分享失败！请分享到活跃的群" });
                    this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_FAIL);
                }
                else {
                    var r = Math.random();
                    if (r < 0.6) {
                        LogUtil.log("onShareHandler:分享成功");
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_COMPLETE);
                        this.dispatchEvent(AdEvent.AD_SHARE_SUCCESS);
                    }
                    else {
                        LogUtil.log("onShareHandler:概率太低,分享失败");
                        this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "分享失败！请分享到活跃的群" });
                        this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_FAIL);
                    }
                }
                this.shareTime = 0;
            }
        }
        initLink() {
        }
        gotoLinkHandler(data) {
            if (data && data.appId) {
                this.linkData = data;
                LogTool.log('WxminiController.gotoLinkHandler:' + data.appId);
                if (this.checkVersion('1.3.0')) {
                    this.startGoLink();
                }
                else {
                    this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "当前微信版本过低，无法使用该功能，请升级到最新微信版本后重试。" });
                }
            }
        }
        startGoLink() {
            this.sdkGoLinkClickCount();
            this.linkTime = 0;
            this.api.navigateToMiniProgram({
                appId: this.linkData.appId,
                path: this.linkData.path,
                success: () => {
                    this.sdkGoLinkOpenCount();
                    this.linkTime = TimeUtil.getTimestamp();
                },
                fail: () => {
                    if (AdTool.checkRate('jiugongge')) {
                        this.dispatchEvent(EpEvent.EP_PAGE11_VIEW_SHOW, { showType: ViewType.OPEN });
                    }
                }
            });
        }
        startGoLinkHandler(res) {
            if (this.linkTime > 0) {
                if (TimeUtil.getTimestamp() - this.linkTime > 60) {
                    this.linkTime = 0;
                }
                else {
                    this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: '你在[' + this.linkData.name + ']中体验未满一分钟,继续即可领取奖励', okHandler: Laya.Handler.create(this, this.gotoHandler) });
                }
            }
        }
        gotoHandler() {
            this.startGoLink();
        }
        imageHandler(data) {
            var url = data.url;
            if (url) {
                this.api.previewImage({
                    urls: [url],
                    success: () => {
                        LogTool.log("显示二维码:" + url);
                    }
                });
            }
        }
        initDesktop() {
            var res = this.api.getLaunchOptionsSync();
            LogTool.log("initDesktop:" + res.scene);
            if (PlatformModel.model.isAddMini == false) {
                if (WxminiConfig.sceneMini.indexOf(res.scene) >= 0) {
                    PlatformModel.model.isAddMini = true;
                    PlatformModel.model.saveData();
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: PlatformConfig.addMiniReward, title: '获得收藏奖励' });
                }
            }
        }
        inviteHandler() {
            if (!this.api.startStateService) {
                LogTool.log('wxmini.好友邀请api不存在');
                return;
            }
            this.api.startStateService({
                userState: 'start',
                success: () => {
                    LogTool.log('wxmini.开启状态管理服务成功');
                    this.api.postMessage('start');
                },
                fail: (res) => {
                    LogTool.log('wxmini.开启状态管理服务失败:' + JSONUtil.stringify(res));
                }
            });
            const m = this.api.getGameServerManager();
            this.api.onMessage(type => {
                if (type === 'start') {
                    m.getFriendsStateData({
                        success: res => {
                            LogTool.log('wxmini.获取好友列表:' + JSONUtil.stringify(res));
                            var list = res.list;
                            if (list.length > 0) {
                                var item = ArrayUtil.randomItem(list);
                                m.inviteFriend({ openId: item.openId });
                            }
                            else {
                                LogTool.log('wxmini.好友列表为空');
                            }
                        },
                        fail: res => {
                            console.error('wxmini.获取好友列表失败');
                        }
                    });
                }
            });
        }
        vibrateHandler(data) {
            LogTool.log("震动");
            if (data && data.type == 1) {
                if ('vibrateLong' in this.api) {
                    this.api.vibrateLong({
                        success: res => {
                            LogTool.log('wxmini.震动:' + JSONUtil.stringify(res));
                        },
                        fail: res => {
                            LogTool.log('wxmini.震动失败' + JSONUtil.stringify(res));
                        }
                    });
                }
            }
            else {
                if ('vibrateShort' in this.api) {
                    this.api.vibrateShort({
                        success: res => {
                            LogTool.log('wxmini.震动:' + JSONUtil.stringify(res));
                        },
                        fail: res => {
                            LogTool.log('wxmini.震动失败' + JSONUtil.stringify(res));
                        }
                    });
                }
            }
        }
        initUserInfoButton() {
            if (PlayerModel.model.isChange == false) {
                this.dispatchEvent(WxminiEvent.WXMINI_INFO_BUTTON_VIEW_SHOW);
                this.addEventListener(ViewEvent.VIWE_OPEN("PageView"), this, this.openBtnHandler);
                this.addEventListener(ViewEvent.VIWE_CLOSE("PageView"), this, this.closeBtnHandler);
            }
        }
        openBtnHandler() {
            if (PlayerModel.model.isChange == false) {
                this.dispatchEvent(WxminiEvent.WXMINI_INFO_BUTTON_VIEW_SHOW, { showType: ViewType.OPEN });
            }
        }
        closeBtnHandler() {
            this.dispatchEvent(WxminiEvent.WXMINI_INFO_BUTTON_VIEW_SHOW, { showType: ViewType.CLOSE });
        }
        checkVersion(v) {
            const version = this.api.getSystemInfoSync().SDKVersion;
            if (PlatformTool.compareVersion(version, v) >= 0) {
                return true;
            }
            return false;
        }
        sdkGoLinkClickCount() {
            if (WxminiConfig.gameId) {
                var data = {};
                data.gameId = WxminiConfig.gameId;
                data.version = WxminiConfig.version;
                data.openId = this.vo.openid;
                data.scene = this.linkData.scene;
                data.appKey = this.linkData.appId;
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/clickCount';
                NetTool.request(url, data, 'get', this, (res) => { LogTool.log("ClickCount:" + res.msg); });
            }
        }
        sdkGoLinkOpenCount() {
            if (WxminiConfig.gameId) {
                var data = {};
                data.gameId = WxminiConfig.gameId;
                data.version = WxminiConfig.version;
                data.openId = this.vo.openid;
                data.scene = this.linkData.scene;
                data.appKey = this.linkData.appId;
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/openCount';
                NetTool.request(url, data, 'get', this, (res) => { LogTool.log("OpenCount:" + res.msg); });
            }
        }
    }

    class PlatformType {
    }
    PlatformType.PLATFORM_FW = 'fw';
    PlatformType.PLATFORM_CSJ = 'csj';
    PlatformType.PLATFORM_OPPO = 'oppo';
    PlatformType.PLATFORM_VIVO = 'vivo';
    PlatformType.PLATFORM_WX = 'wx';
    PlatformType.PLATFORM_XM = 'xm';
    PlatformType.PLATFORM_WXMINI = 'wxmini';
    PlatformType.PLATFORM_BDMINI = 'bdmini';
    PlatformType.PLATFORM_TTMINI = 'ttmini';
    PlatformType.PLATFORM_QQMINI = 'qqmini';
    PlatformType.PLATFORM_OPMINI = 'opmini';
    PlatformType.PLATFORM_VVMINI = 'vvmini';
    PlatformType.PLATFORM_4399 = '4399';
    PlatformType.PLATFORM_QTT = 'qtt';
    PlatformType.PLATFORM_TOPON = 'topon';
    PlatformType.PLATFORM_MZMINI = 'mzmini';
    PlatformType.PLATFORM_4399MINI = '4399mini';

    class PlatformAddIcoView extends ui.platform.PlatformAddIcoUI {
        constructor() {
            super();
            this.zOrder = 9;
        }
    }

    class PlatformAddIcoViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformAddIcoView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_ico.on(Laya.Event.CLICK, this, this.clickHandler);
            this.addEventListener(PlatformEvent.PLATFORM_ADDICO_COMPLETE, this, this.close);
        }
        clickHandler() {
            if (EpConfig.epPageType == 1) {
                LogUtil.log('EpPage10.qqmini:添加桌面 ---');
                this.dispatchEvent(PlatformEvent.PLATFORM_ADDITION_VIEW_SHOW);
            }
            else {
                LogUtil.log('EpPage10:添加桌面 ---');
                this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_SHOW);
            }
        }
    }

    class PlatformAdditionView extends ui.platform.PlatformAdditionUI {
        constructor() {
            super();
            this.zOrder = 60;
        }
    }

    class PlatformAdditionViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlatformAdditionView;
            this.viewName = 'PlatformAdditionView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_scale.scale(PageConfig.pageScale, PageConfig.pageScale);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
        }
        okHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_ADDICO_SHOW);
            this.close();
        }
    }

    class PlatformAddMiniView extends ui.platform.PlatformAddMIniUI {
        constructor() {
            super();
            this.zOrder = 60;
        }
    }

    class PlatformAddMiniViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlatformAddMiniView;
            this.viewName = 'PlatformAddMiniView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
        }
    }

    class PlatrormFollowIcoView extends ui.platform.PlatformFollowIcoUI {
        constructor() {
            super();
            this.zOrder = 10;
        }
    }

    class PlatformFollowIcoViewController extends ViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/ui.atlas';
            this.viewClass = PlatrormFollowIcoView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.on(Laya.Event.CLICK, this, this.clickHandler);
            LogTool.log("PlatformFollowIcoViewController.isShieldCity:" + AdModel.model.isShieldCity);
            if (this.data) {
                if (this.data.y) {
                    this.ui.y = this.data.y;
                }
                if (this.data.x) {
                    this.ui.y = this.data.x;
                }
                if (this.data.bottom) {
                    this.ui.bottom = this.data.bottom;
                }
                if (this.data.right) {
                    this.ui.right = this.data.right;
                }
                if (this.data.zOrder) {
                    this.ui.zOrder = this.data.zOrder;
                }
            }
            else {
                this.ui.y = 199;
                this.ui.right = 262;
            }
        }
        clickHandler() {
            LogTool.log("PlatrormFollowIcoView:clickHandler.1");
            this.dispatchEvent(PlatformEvent.PLATFORM_FOLLOW_VIEW_SHOW);
        }
    }

    class PlatrormFollowRewardView extends ui.platform.PlatformFollowRewardUI {
        constructor() {
            super();
            this.zOrder = 61;
        }
    }

    class PlatformFollowRewardViewController extends DialogViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/ui.atlas';
            this.viewClass = PlatrormFollowRewardView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.clickHandler);
            this.ui.img_ok.visible = false;
            var list = PlatformConfig.followReward;
            this.ui.ui_goods.dataSource = GoodsViewTool.getGoodsRewardData(list[0]);
            this.ui.ui_goods1.dataSource = GoodsViewTool.getGoodsRewardData(list[1]);
            for (var k in list) {
                var cid = list[k].cid;
                var vo = GoodsVoBuilder.getGoodsVo(cid);
                if (vo == null) {
                    this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list });
                }
                if (vo && vo.loc == 0) {
                    this.ui.img_ok.visible = true;
                    this.ui.btn_ok.visible = false;
                }
                else {
                    this.ui.img_ok.visible = false;
                    this.ui.btn_ok.visible = true;
                }
            }
        }
        clickHandler() {
            var list = PlatformConfig.followReward;
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: list });
            for (var k in list) {
                var cid = list[k].cid;
                var vo = GoodsModel.model.getGoodsByCid(cid);
                if (vo) {
                    this.dispatchEvent(GoodsEvent.GOODS_LOC_SET_REQUEST, { id: vo.id });
                }
            }
            this.ui.img_ok.visible = true;
            this.ui.btn_ok.visible = false;
        }
    }

    class PlatrormFollowView extends ui.platform.PlatformFollowUI {
        constructor() {
            super();
            this.zOrder = 61;
        }
    }

    class PlatformFollowViewController extends DialogViewController {
        constructor() {
            super();
            this.viewURL = 'res/atlas/ui.atlas';
            this.viewClass = PlatrormFollowView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.clickHandler);
            this.ui.ui_goods.dataSource = GoodsViewTool.getGoodsRewardData(PlatformConfig.followReward1[0]);
            this.ui.ui_goods1.dataSource = GoodsViewTool.getGoodsRewardData(PlatformConfig.followReward1[1]);
        }
        clickHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_FOLLOW_START);
            this.close();
        }
    }

    class PlatformNativeAd1View extends ui.platform.PlatformNativeAd1UI {
        constructor() {
            super();
            this.zOrder = 900;
        }
    }

    class PlatformNativeAd1ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeAd1View;
            this.viewName = "PlatformNativeAd1View";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            if (this.data && "bottom" in this.data) {
                this.ui.img_ad.bottom = this.data.bottom;
            }
            this.ui.img_ad.x = ParamUtil.getInt(this.data, 'x', 360);
            this.ui.zOrder = ParamUtil.getInt(this.data, 'zOrder', 900);
            AdTool.nativeAdShow(this, { type: 'banner', ui: this.ui, image: this.ui.img_ad }, null, this.close);
        }
    }

    class PlatformNativeAd2View extends ui.platform.PlatformNativeAd2UI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class PlatformNativeAd2ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeAd2View;
            this.viewName = "PlatformNativeAd2View";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            if (this.data && "bottom" in this.data) {
                this.ui.img_ad.bottom = this.data.bottom;
            }
            var type = ParamUtil.getString(this.data, 'type', 'banner');
            this.ui.zOrder = ParamUtil.getInt(this.data, 'zOrder', 50);
            this.ui.img_ad.right = ParamUtil.getInt(this.data, 'right', 50);
            AdTool.nativeAdShow(this, { type: type, ui: this.ui, image: this.ui.img_ad }, null, this.close);
        }
    }

    class PlatformNativeAdPageView extends ui.platform.PlatformNativeAdPageUI {
        constructor() {
            super();
            this.zOrder = 130;
        }
    }

    class PlatformNativeAdPageViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeAdPageView;
            this.viewName = 'PlatformNativeAdPageView';
            this.isAutoShow = false;
        }
        openComplete() {
            super.openComplete();
            LogTool.log("PlatformNativeAdPageView:openComplete");
            this.ui = this.view;
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.showAd();
            this.showbtn();
            this.ui.zOrder = ParamUtil.getInt(this.data, 'zOrder', 51);
            this.ui.box_ad.x = ParamUtil.getInt(this.data, 'x', 335);
        }
        showAd() {
            var type = ParamUtil.getString(this.data, 'type', 'ad');
            AdTool.nativeAdShow(this, { type: type, ui: this.ui, image: this.ui.img_ad, title: this.ui.txt_title, content: this.ui.txt_content, clickList: [this.ui.txt_title, this.ui.btn_shop], isClickClose: true }, this.showOpenAnim, this.close);
        }
        showbtn() {
            if (AdTool.checkRate('ysgg', true)) {
                this.ui.btn_look.visible = true;
                this.ui.btn_shop.visible = false;
            }
            else {
                this.ui.btn_look.visible = false;
                this.ui.btn_shop.visible = true;
            }
        }
    }

    class PlatformNativeAdView extends ui.platform.PlatformNativeAdUI {
        constructor() {
            super();
            this.zOrder = 902;
        }
    }

    class PlatformNativeAdViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeAdView;
            this.viewName = "PlatformNativeAdView";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.txt_ad.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            if (this.data && "right" in this.data) {
                this.ui.img_ad.right = this.data.right;
            }
            if (this.data && "y" in this.data) {
                this.ui.img_ad.y = this.data.y;
            }
            if (this.data && "x" in this.data) {
                this.ui.img_ad.x = this.data.x;
            }
            if (this.data && "zorder" in this.data) {
                this.ui.zOrder = this.data.zorder;
            }
            if (this.data && "width" in this.data) {
                this.ui.img_ad.width = this.data.width;
            }
            if (this.data && "height" in this.data) {
                this.ui.img_ad.height = this.data.height;
            }
            var type = ParamUtil.getString(this.data, 'type', 'ad');
            LogTool.log('原生广告=y=' + this.data.y + 'right=' + this.data.right + 'zorder=' + this.data.zorder + 'x=' + this.data.x);
            AdTool.nativeAdShow(this, { type: type, ui: this.ui, image: this.ui.img_ad, }, null, this.close);
            if (AdModel.model.isShieldCity == true) {
                this.ui.txt_ad.visible = false;
            }
            else {
                this.ui.txt_ad.visible = true;
            }
        }
        okHandler() {
            AdTool.nativeAdClick(this);
        }
    }

    class PlatformNativeIcon1View extends ui.platform.PlatformNativeIcon1UI {
        constructor() {
            super();
            this.zOrder = 10;
        }
    }

    class PlatformNativeIcon1ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeIcon1View;
            this.viewName = "PlatformNativeIcon1View";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            AdTool.nativeAdShow(this, { type: 'ico', ui: this.ui, ico: this.ui.img_ad, }, null, this.close);
        }
    }

    class PlatformNativeIcon3View extends ui.platform.PlatformNativeIcon3UI {
        constructor() {
            super();
            this.zOrder = 10;
        }
    }

    class PlatformNativeIcon1ViewController$1 extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeIcon3View;
            this.viewName = "PlatformNativeIcon3View";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            var type = ParamUtil.getString(this.data, 'type', 'ico');
            AdTool.nativeAdShow(this, { type: type, ui: this.ui, ico: this.ui.img_ad, }, null, this.close);
        }
    }

    class PlatformNativeIconView extends ui.platform.PlatformNativeIconUI {
        constructor() {
            super();
            this.zOrder = 10;
        }
    }

    class PlatformNativeIconViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeIconView;
            this.viewName = "PlatformNativeIconView";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            if (this.data && this.data.y) {
                this.ui.box_ad.y = this.data.y;
            }
            if (this.data && this.data.right) {
                this.ui.box_ad.right = this.data.right;
            }
            if (this.data && this.data.zorder) {
                this.ui.zOrder = this.data.zorder;
            }
            var refreshTime = ParamUtil.getInt(this.data, 'refreshTime', 60);
            var type = ParamUtil.getString(this.data, 'type', 'ico');
            LogTool.log('现在图标的=y=' + this.data.y + 'right=' + this.data.right + 'zorder=' + this.data.zorder);
            AdTool.nativeAdShow(this, { type: type, ui: this.ui, ico: this.ui.img_ad, refreshTime: refreshTime }, null, this.close);
        }
    }

    class PlatformRecorderBtnView extends ui.platform.PlatformRecorderBtnUI {
        constructor() {
            super();
            this.zOrder = 21;
        }
    }

    class PlatformRecorderBtnViewController extends ViewController {
        constructor() {
            super();
            this.num = 0;
            this.viewClass = PlatformRecorderBtnView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.txt_state.visible = false;
            this.ui.img_tt.visible = false;
            this.ui.btn_start.on(Laya.Event.CLICK, this, this.clickHandler);
            this.addEventListener(PlatformEvent.PLATFORM_RECORDER_BTN_VIEW_CLOSE, this, this.close);
            this.startAutoRecord();
        }
        startAutoRecord() {
            if (BattleModel.model.isBattle) {
                if (!this.ui.img_tt.visible) {
                    TimerUtil.onceTimer(60000, this, this.clickHandler);
                }
            }
        }
        clickHandler() {
            if (this.ui.img_tt.visible == true) {
                TimerUtil.stopTimer(this, this.timeHandler);
                this.checkTimeTitleHandler();
                this.ui.img_tt.visible = false;
                this.ui.txt_state.visible = false;
            }
            else {
                this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_START);
                this.num = 0;
                this.ui.txt_state.text = ' 已录屏：0秒';
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "录屏开始" });
                this.ui.img_tt.visible = true;
                this.ui.txt_state.visible = true;
                TimerUtil.loopTimer(1000, this, this.timeHandler);
            }
        }
        timeHandler() {
            if (this.num < 30) {
                this.num++;
                this.ui.txt_state.text = ' 已录屏：' + this.num + '秒';
            }
            else {
                TimerUtil.stopTimer(this, this.timeHandler);
                this.checkTimeMaxHanlder();
                return;
            }
        }
        checkTimeTitleHandler() {
            if (this.num <= 15) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "录屏时间不能小于15秒" });
            }
            else {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "录屏结束" });
                this.ui.img_tt.visible = false;
                this.ui.txt_state.visible = false;
                this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_STOP, { isShare: true });
            }
        }
        checkTimeMaxHanlder() {
            this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "录屏时间超过30秒，录屏结束" });
            this.ui.img_tt.visible = false;
            this.ui.txt_state.visible = false;
            this.dispatchEvent(PlatformEvent.PLATFORM_RECORDER_STOP);
        }
    }

    class PlatformRecorderStateView extends ui.platform.PlatformRecorderStateUI {
        constructor() {
            super();
            this.zOrder = 60;
        }
    }

    class PlatformRecorderStateViewController extends ViewController {
        constructor() {
            super();
            this.viewClass = PlatformRecorderStateView;
        }
    }

    class PlatformShareView extends ui.platform.PlatformShareUI {
        constructor() {
            super();
            this.zOrder = 110;
        }
    }

    class PlatformShareViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlatformShareView;
            this.viewName = 'PlatformShareView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            TimerUtil.onceTimer(2500, this, this.showClose);
            this.ui.box_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_share.on(Laya.Event.CLICK, this, this.clickHandler);
        }
        showClose() {
            this.ui.box_close.visible = true;
        }
        clickHandler() {
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_VIDEO_COMPLETE, this, this.videoHandler);
            this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_VIDEO_SHOW);
        }
        videoHandler() {
            this.close();
        }
    }

    class PlatformNativeAd3View extends ui.platform.PlatformNativeAd3UI {
        constructor() {
            super();
            this.zOrder = 105;
        }
    }

    class PlatformNativeAd3ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeAd3View;
            this.viewName = "PlatformNativeAd3View";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.img_ad1.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            if (this.data && "right" in this.data) {
                this.ui.img_ad.right = this.data.right;
            }
            if (this.data && "y" in this.data) {
                this.ui.img_ad.y = this.data.y;
            }
            if (this.data && "x" in this.data) {
                this.ui.img_ad.x = this.data.x;
            }
            if (this.data && "zorder" in this.data) {
                this.ui.zOrder = this.data.zorder;
            }
            if (this.data && "width" in this.data) {
                this.ui.img_ad.width = this.data.width;
            }
            if (this.data && "height" in this.data) {
                this.ui.img_ad.height = this.data.height;
            }
            var type = ParamUtil.getString(this.data, 'type', 'ad');
            LogTool.log('原生广告=y=' + this.data.y + 'right=' + this.data.right + 'zorder=' + this.data.zorder + 'x=' + this.data.x);
            AdTool.nativeAdShow(this, { type: type, ui: this.ui, image: this.ui.img_ad, }, null, this.close);
            if (AdModel.model.isShieldCity == true) {
                this.ui.img_ad1.visible = false;
            }
            else {
                this.ui.img_ad1.visible = true;
            }
        }
        okHandler() {
            AdTool.nativeAdClick(this);
        }
    }

    class PlatformNativeAd4View extends ui.platform.PlatformNativeAd4UI {
        constructor() {
            super();
            this.zOrder = 105;
        }
    }

    class PlatformNativeAd4ViewController extends PanelViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeAd4View;
            this.viewName = "PlatformNativeAd4View";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.img_ad1.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            if (this.data && "right" in this.data) {
                this.ui.img_ad.right = this.data.right;
            }
            if (this.data && "y" in this.data) {
                this.ui.img_ad.y = this.data.y;
            }
            if (this.data && "x" in this.data) {
                this.ui.img_ad.x = this.data.x;
            }
            if (this.data && "zorder" in this.data) {
                this.ui.zOrder = this.data.zorder;
            }
            if (this.data && "width" in this.data) {
                this.ui.img_ad.width = this.data.width;
            }
            if (this.data && "height" in this.data) {
                this.ui.img_ad.height = this.data.height;
            }
            var type = ParamUtil.getString(this.data, 'type', 'ad');
            LogTool.log('原生广告=y=' + this.data.y + 'right=' + this.data.right + 'zorder=' + this.data.zorder + 'x=' + this.data.x);
            AdTool.nativeAdShow(this, { type: type, ui: this.ui, image: this.ui.img_ad, }, null, this.close);
            if (AdModel.model.isShieldCity == true) {
                this.ui.img_ad1.visible = false;
            }
            else {
                this.ui.img_ad1.visible = true;
            }
        }
        okHandler() {
            AdTool.nativeAdClick(this);
        }
    }

    class PlatformClauseView extends ui.platform.PlatformClauseUI {
        constructor() {
            super();
            this.zOrder = 1100;
        }
    }

    class PlatformClauseViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlatformClauseView;
            this.viewName = 'PlatformClauseView';
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.y = 199;
            this.ui.right = 262;
            this.text = ParamUtil.getString(this.data, 'text', '同意');
            this.ui.btn_ok.label = this.text;
            LogTool.log('PlatformClauseViewController.显示');
            this.ui.txt_content.text = PlatformConfig.content;
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.clickHandler);
            this.ui.txt_content.height = this.ui.txt_content.textField.textHeight;
        }
        clickHandler() {
            LogTool.log('PlatformClauseViewController.clickHandler-close');
            this.close();
        }
    }

    class PlatformPrivacyView extends ui.platform.PlatformPrivacyUI {
        constructor() {
            super();
            this.zOrder = 1100;
        }
    }

    class PlatformPrivacyViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlatformPrivacyView;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.y = 199;
            this.ui.right = 262;
            LogTool.log('PlatformPrivacyViewController.显示');
            this.ui.btn_ok.on(Laya.Event.CLICK, this, this.okHandler);
            this.ui.btn_no.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.txt_read2.on(Laya.Event.CLICK, this, this.showContentHandler);
            this.ui.txt_read1.on(Laya.Event.CLICK, this, this.showContentHandler);
        }
        showContentHandler() {
            LogTool.log('PlatformPrivacyViewController.showContentHandler');
            this.dispatchEvent(PlatformEvent.PLATFORM_CLAUSE_VIEW);
        }
        okHandler() {
            this.close();
            NativeTool.userAgreed();
            PlatformModel.model.privacyNum++;
            PlatformModel.model.saveData();
            this.dispatchEvent(PlatformEvent.PLATFORM_PRIVACY_AGREE);
        }
        closeHandler() {
            this.close();
            this.dispatchEvent(PlatformEvent.PLATFORM_EXIT);
        }
    }

    class P4399miniModel {
        constructor() {
            this.code = '';
            this.openid = '';
            this.scene = 0;
        }
        static getApi() {
            if (typeof gamebox == "undefined") {
                return null;
            }
            else {
                return gamebox;
            }
        }
    }
    P4399miniModel.model = new P4399miniModel();

    class P4399miniBannerAdController extends Controller {
        constructor() {
            super();
            this.isShow = false;
            this.refreshTime = 30;
        }
        run() {
            super.run();
            this.api = P4399miniModel.getApi();
            this.vo = P4399miniModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.showBannerHandler);
            this.initBanner();
        }
        initBanner() {
            var showList = ['PlayerSetView', 'GoodsGetView', 'PageRewardView', 'OnlineView', 'BattleTaskView', 'AlertView', 'BattleDefeatView', 'BattleVictoryView'];
            var preventList = ['BattleEndMysteryBoxView', 'BattleTryHeroView', 'BattleStartTryHeroView', 'SegmentLvUpView', 'BattleVictoryMvpView', 'BattleDefeatMvpView'];
            this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
            this.startChild(this.checkShowBanner);
        }
        showBannerHandler(data) {
            TimerUtil.stopTimer(this, this.showAdHandler);
            var left = ParamUtil.getInt(data, 'left', 185);
            var height = ParamUtil.getInt(data, 'height', 98);
            var time = ParamUtil.getInt(data, 'time', 0);
            var viewEvent = ParamUtil.getString(data, 'viewEvent', '');
            this.refreshTime = ParamUtil.getInt(this.data, 'refreshTime', 30);
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBannerHandler(viewEvent);
            }
            else if (time) {
                TimerUtil.onceTimer(data.time, this, this.showAdHandler, [left, height]);
            }
            else {
                this.showAdHandler(left, height);
            }
        }
        showAdHandler(left, height) {
            this.isShow = true;
            if (this.bannerAd && left) {
                this.bannerAd.style.left = left;
                this.bannerAd.style.height = height;
                LogTool.log("showAdHandler.showBanner.1");
                this.bannerAd.show().catch(err => {
                    LogTool.log('Banner 广告显示失败1' + JSONUtil.stringify(err));
                });
            }
            else if (this.bannerAd) {
                LogTool.log("showAdHandler.showBanner.2");
                this.bannerAd.show().catch(err => {
                    LogTool.log('Banner 广告显示失败2' + JSONUtil.stringify(err));
                });
            }
            else {
                LogTool.log("showAdHandler.showBanner.3");
                this.showBanner(left, height);
            }
        }
        showBanner(left, height) {
            this.closeBannerHandler("showBanner", false);
            var pixelRatio = this.api.getSystemInfoSync().pixelRatio;
            var screenWidth = 400 * pixelRatio;
            var screenHeight = 95 * pixelRatio;
            var bannerLeft = (this.api.getSystemInfoSync().screenWidth * pixelRatio - screenWidth) / 2;
            var bannerTop = this.api.getSystemInfoSync().screenHeight * pixelRatio - screenHeight;
            var bannerAd = this.api.createBannerAd({
                style: {
                    width: screenWidth,
                    height: screenHeight,
                    left: bannerLeft,
                    top: bannerTop
                }
            });
            bannerAd.onLoad((res) => {
                if (this.isShow) {
                    LogTool.log("showBanner-onLoad.4");
                }
            });
            bannerAd.onError((res) => {
                this.closeBannerHandler("onError" + +JSONUtil.stringify(res));
            });
            if (this.isShow) {
                LogTool.log("showBanner.5");
                bannerAd.show().catch(err => {
                    LogTool.log('Banner 广告显示失败5' + JSONUtil.stringify(err));
                });
            }
            this.bannerAd = bannerAd;
        }
        closeBannerHandler(closeType = '', changeShow = true) {
            LogTool.log("showBanner-close:" + closeType);
            if (changeShow) {
                this.isShow = false;
            }
            if (this.bannerAd) {
                LogTool.log("showBanner-close-hide:" + closeType);
                this.bannerAd.hide();
                this.bannerAd.destroy();
                this.bannerAd = null;
            }
        }
    }

    class P4399miniInsertAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = P4399miniModel.getApi();
            this.vo = P4399miniModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsertAd);
            this.initAdInsert();
        }
        initAdInsert() {
            this.addEventListener(BattleEvent.BATTLE_CLOSE_CLICK, this, this.showInterstHandler);
            this.addEventListener(SignEvent.SIGN_CLOSE_CLICK, this, this.showInterstHandler);
            this.addEventListener(OnlineEvent.ONLINE_CLOSE_CLICK, this, this.showInterstHandler);
            this.addEventListener(GoodsEvent.GOODS_CLOSE_CLICK, this, this.showInterstHandler);
        }
        showInterstHandler(data) {
            var time = ParamUtil.getInt(data, 'time', 1500);
            LogTool.log('P4399miniInsertAdController.showInterstHandler:' + time);
            TimerUtil.onceTimer(time, this, () => {
                this.dispatchEvent(PlatformEvent.PLATFORM_AD_INSERT_SHOW, { time: 1500 });
            });
        }
        showInsertAd(data) {
            PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
            LogTool.log('4399mini.插屏11 showInsertAd');
            if (this.api.createInterstitialAd) {
                LogTool.log('4399mini.插屏准备加载');
                this.interstitialAd = this.api.createInterstitialAd();
                this.interstitialAd.load()
                    .then(() => this.interstitialAd.show())
                    .catch(err => {
                    LogTool.log('InterstitialAd 广告显示失败' + err);
                });
                this.interstitialAd.onLoad((res) => {
                    LogTool.log('4399mini.插屏 广告加载成功' + JSONUtil.stringify(res));
                });
                this.interstitialAd.onError((res) => {
                    LogTool.log('4399mini.插屏 广告加载失败:' + JSONUtil.stringify(res));
                    this.interstitialAd.load()
                        .then(() => this.interstitialAd.show())
                        .catch(err => {
                        LogTool.log('InterstitialAd 广告显示失败' + err);
                    });
                });
                this.interstitialAd.onClose((res) => {
                    LogTool.log('4399mini.插屏 关闭成功' + JSONUtil.stringify(res));
                    this.interstitialAd.destroy();
                });
            }
        }
    }

    class P4399miniConfig {
    }
    P4399miniConfig.gameId = 783;
    P4399miniConfig.version = '1.0.0';

    class P4399miniTyController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = P4399miniModel.getApi();
            this.vo = P4399miniModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_SKD_INIT, this, this.getCity);
        }
        getCity() {
            if (P4399miniConfig.gameId) {
                var data1 = { gameId: P4399miniConfig.gameId, version: P4399miniConfig.version };
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/isPinbi';
                NetTool.request(url, data1, 'get', this, this.getCityHandler);
            }
        }
        getCityHandler(data) {
            LogTool.log('4399mini.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            LogTool.log('4399mini.isShieldCity:' + AdModel.model.isShieldCity);
            this.dispatchEvent(PlatformEvent.PLATFORM_API_INIT);
        }
    }

    class P4399miniVideoAdController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = P4399miniModel.getApi();
            this.vo = P4399miniModel.model;
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.adViewHandler);
            this.initViedoAd();
        }
        initViedoAd() {
            LogTool.log('激励视频加载:initViedoAd');
            if (!this.rewardedVideoAd) {
                let rewardedVideoAd = this.api.createRewardedVideoAd();
                rewardedVideoAd.onLoad((res) => {
                    LogTool.log('激励视频加载成功' + JSONUtil.stringify(res));
                    PlatformModel.model.hasAdVideo = true;
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_LOAD);
                });
                rewardedVideoAd.onError((res) => {
                    PlatformModel.model.hasAdVideo = false;
                    LogTool.log('激励视频错误:' + JSONUtil.stringify(res));
                    this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_FAIL);
                });
                rewardedVideoAd.onClose((res) => {
                    LogTool.log('激励视频关闭');
                    if (res && res.isEnded) {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
                    }
                    else {
                        this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_DISCONTINUE(PlatformModel.model.adVideoId), { isEnded: false });
                    }
                    SoundTool.setPause('adView', false);
                });
                this.rewardedVideoAd = rewardedVideoAd;
            }
            return this.rewardedVideoAd;
        }
        checkVideoLoad() {
            let rewardedVideoAd = this.rewardedVideoAd;
            if (PlatformModel.model.hasAdVideo) {
                this.showVideoStartHandler();
            }
            else if (rewardedVideoAd) {
                rewardedVideoAd.load();
                this.onceEventListener(PlatformEvent.PLATFORM_AD_VIDEO_LOAD, this, this.showVideoStartHandler);
            }
        }
        showVideoStartHandler() {
        }
        adViewHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            let rewardedVideoAd = this.initViedoAd();
            LogTool.log('adViewHandler:' + JSONUtil.stringify(rewardedVideoAd));
            if (rewardedVideoAd && PlatformModel.model.hasAdVideo) {
                rewardedVideoAd.load()
                    .then(() => rewardedVideoAd.show())
                    .catch(err => {
                    LogTool.log('激励视频 广告显示失败-catch' + JSONUtil.stringify(err));
                });
                SoundTool.setPause('adView', true);
                LogTool.log('显示视频');
            }
            else {
                LogTool.log('没有视频_跳转分享');
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
                this.onceEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
                this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_SHOW);
            }
        }
        shareCompHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        shareFailHander() {
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_COMPLETE, this, this.shareCompHander);
            this.removeEventListener(PlatformEvent.PLATFORM_SHARE_FAIL, this, this.shareFailHander);
        }
    }

    class P4399miniController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.api = P4399miniModel.getApi();
            this.vo = P4399miniModel.model;
            this.startChild(new P4399miniTyController());
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(PlatformEvent.PLATFORM_SHARE_SHOW, this, this.shareHandler);
            this.addEventListener(PlatformEvent.PLATFORM_API_INIT, this, this.initApiHandler);
        }
        initHandler() {
            BattleConfig.crazyType = 1;
            BattleConfig.isAutoShowTask = true;
            PlayerConfig.playerType = 3;
            SignConfig.signType = 2;
            GoodsConfig.goodGetType = 6;
            PageConfig.pageRewardType = 5;
            OnlineConfig.onlineType = 6;
            BattleConfig.battleTryType = 3;
            BattleConfig.battleTaskType = 6;
            BattleConfig.battleViewType = 1;
            BattleConfig.defeatType = 6;
            BattleConfig.victoryType = 6;
            this.startChild(new P4399miniVideoAdController());
            this.startChild(new P4399miniBannerAdController());
            this.startChild(new P4399miniInsertAdController());
            this.loginHandler();
        }
        initApiHandler() {
        }
        shareHandler() {
            this.api.shareMessageToFriend({
                type: 1,
                success: res => {
                    LogTool.log('分享成功回调');
                },
                fail: res => {
                    LogTool.log('分享失败回调');
                },
                complete: res => {
                    LogTool.log('成功失败都会走的回调');
                },
            });
        }
        loginHandler() {
            this.api.login({
                success: (res) => {
                    LogTool.log('登录成功');
                    if (res.code) {
                        this.vo.code = res.code;
                        this.dispatchEvent(PlatformEvent.PLATFORM_SKD_INIT);
                    }
                    else {
                        this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { type: PromptType.PROMPT_WARNING, text: "登录失败,请重新登录 : " + res.errMsg });
                    }
                },
                fail: (res) => {
                    LogTool.log("登录失败:" + JSONUtil.stringify(res.errMsg));
                }
            });
        }
    }

    class XmConfig {
    }
    XmConfig.gameId = 810;
    XmConfig.version = '1.0.0';

    class XmController extends Controller {
        constructor() {
            super();
            this.feedVideoList = ['addGift', 'addbox', 'heroTryBattle', 'heroTryPreWar', 'giveHeroGift', 'unlockHero', 'heroTryBattle', 'launchMissile', 'firstAid'];
            this.rateKey = ['ys_zhuye', 'ys_guanbi', 'ys_mengceng', 'ys_jiesuan', 'ys_jili',];
            this.ckey = '';
        }
        run() {
            super.run();
            BattleConfig.battleLvType = 1;
            BattleConfig.battleDefProType = 1;
            BattleConfig.battleViewType = 1;
            PlayerConfig.IsShowModifyName = false;
            this.addEventListener(PlatformEvent.PLATFORM_AD_BANNER_SHOW, this, this.bannerViewHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, this, this.showVideoAdHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_INSERT_SHOW, this, this.showInsterHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_RANDOM_SHOW, this, this.showRandomHandler);
            this.addEventListener(PlatformEvent.PLATFORM_AD_FEED_SHOW, this, this.showFeedAdHandler);
            this.addEventListener(PlatformEvent.PLATFORM_PRIVACY_AGREE, this, this.agreeHandler);
            this.addEventListener(NativeEvent.NATIVE_CALL_RESPONSE("videoAdComplete"), this, this.videoAdComplete);
            this.addEventListener(PlatformEvent.PLATFORM_EXIT, this, this.exitHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
        }
        initHandler() {
            this.initSDK();
            this.initPrivacy();
        }
        initParam() {
            this.initFeedAd();
            this.initSplashAd();
            this.initLog();
            this.dispatchEvent(PageEvent.PAGE_VOIDE_BTN_SHOW);
        }
        exitHandler() {
            NativeTool.exitGame();
        }
        initPrivacy() {
            if (PlatformModel.model.privacyNum < 1) {
                this.dispatchEvent(PlatformEvent.PLATFORM_PRIVACY_VIEW);
            }
            else {
                NativeTool.userAgreed();
                this.agreeHandler();
            }
        }
        agreeHandler() {
            NativeTool.showLogin();
        }
        videoAdComplete() {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETED(PlatformModel.model.adVideoId), { isEnded: true });
        }
        initFeedAd() {
            LogTool.log("xm.initFeedAd");
            var showList = [];
            var preventList = ['BattleVictoryMvpView', 'BattleDefeatMvpView', 'BattleStartTryHeroView', 'BattleTryHeroView'];
            this.checkShowFeed = new CheckShowController(PlatformEvent.PLATFORM_AD_FEED_SHOW, null, showList, preventList);
            this.checkShowFeed.regOpenView('BattleView', { type: 3, isShieldCity: AdModel.model.isShieldCity });
            if (AdTool.checkRate('ys_jiesuan')) {
                this.checkShowFeed.regOpenView('BattleVictoryView', { type: 1 });
                this.checkShowFeed.regOpenView('BattleDefeatView', { type: 1 });
            }
            if (AdTool.checkRate('ys_zhuye')) {
                this.checkShowFeed.regOpenView('PageView', { type: 1 });
            }
            TimerUtil.onceTimer(2300, this, () => {
                this.showFeedAdHandler({ type: 2 });
            });
            this.startChild(this.checkShowFeed);
        }
        showFeedAdHandler(data) {
            LogTool.log('xm.自渲染广告');
            var btnMis = AdTool.checkRate('ys_guanbi', true);
            var bgMis = AdTool.checkRate('ys_mengceng', true);
            if (data && data.showType == ViewType.CLOSE) {
                this.closeFeed();
            }
            else {
                this.showFeed(data.type, btnMis, bgMis, data.isShieldCity);
            }
        }
        showFeed(type, btnMis, bgMis, isShieldCity) {
            LogTool.log("feedAdShow.show");
            NativeTool.showFeedAd({ type: type, btnMis: btnMis, bgMis: bgMis, isShieldCity: isShieldCity });
            this.eventLog("feedAdShow");
        }
        closeFeed() {
            LogTool.log("feedAdShow.closeFeed");
            NativeTool.closeFeedAd();
        }
        initBannerAd() {
            if (AdModel.model.isShieldCity) {
                return;
            }
            LogTool.log("xm.initBanner");
            var showList = ['LotteryView', 'BattleModesView', 'OnlineView', 'SignDayView', 'PageGoldGunGetView', 'GoodsGetView', 'TalentView',
                'ShopBuyView', 'PageShareView', 'PageCollectionView', 'AlertView', 'BattleResurrecView', 'BattleMatchView', 'BattleMatch5View'];
            var preventList = ['TalentResultView', 'GoodsExhView', 'BattleGetVipView'];
            this.checkShowBanner = new CheckShowController(PlatformEvent.PLATFORM_AD_BANNER_SHOW, null, showList, preventList);
            this.startChild(this.checkShowBanner);
        }
        bannerViewHandler(data) {
            if (data && data.showType == ViewType.CLOSE) {
                this.closeBanner();
            }
            else {
                this.showBanner();
            }
        }
        showBanner() {
            LogTool.log("bannerAdShow.show");
            NativeTool.showBannerAd();
            this.eventLog("bannerAdShow");
        }
        closeBanner() {
            NativeTool.closeBannerAd();
        }
        showVideoAdHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            LogTool.log('xm.激励广告');
            if (this.feedVideoList.indexOf(data.id) == -1) {
                NativeTool.showVideoAd();
            }
            else {
                var btnMis = AdTool.checkRate('ys_guanbi', true);
                var bgMis = AdTool.checkRate('ys_mengceng', true);
                if (AdTool.checkRate('ys_jili')) {
                    NativeTool.showFeedAd({ type: 1, btnMis: btnMis, bgMis: bgMis });
                    TimerUtil.onceTimer(1000, this, this.videoAdComplete);
                }
                else {
                    NativeTool.showVideoAd();
                }
            }
            this.eventLog("videoAdShow");
        }
        initInsertAd() {
        }
        showOrAdHandler() {
            LogTool.log('xm.showInsterHandler');
            TimerUtil.onceTimer(500, this, this.showInsterHandler);
        }
        showInsterHandler(data) {
            if (AdModel.model.isShieldCity) {
                return;
            }
            var list = ['BattleVictoryView', 'BattleDefeatView',];
            for (var view of list) {
                PlatformModel.model.adInserId = ParamUtil.getString(data, 'id', '');
                NativeTool.showInsterAd();
                this.eventLog("insterAdShow");
            }
        }
        showRandomHandler(data) {
            PlatformModel.model.adRandomId = ParamUtil.getString(data, 'id', '');
        }
        initLog() {
        }
        eventLog(name, type = '') {
            var eventType = this.getEventType(name, type);
            LogTool.log('eventLog.' + name + ',type:' + type + ',eventType:' + eventType);
            NativeTool.callNative("eventLog", { adName: name, adType: type, eventType: eventType });
        }
        getEventType(name, type = '') {
            if (type) {
                var nt = name + "_" + type;
            }
            else {
                var nt = name;
            }
            if (nt == 'bannerAdShow') {
                return 'event_1';
            }
            else if (nt == 'insterAdShow') {
                return 'event_2';
            }
            else if (nt == 'videoAdShow') {
                return 'event_3';
            }
            else if (nt == 'splashAdShow') {
                return 'event_4';
            }
        }
        initSplashAd() {
            if (AdModel.model.isShieldCity) {
                return;
            }
            LogTool.log('xm.开屏广告.init');
            NativeTool.showSplashAd();
            this.eventLog("splashAdShow");
        }
        initSDK() {
            this.getPinbi();
        }
        getPinbi() {
            var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/isPinbi';
            NetTool.request(url, { gameId: XmConfig.gameId }, 'get', this, this.getCityHandler);
        }
        getCityHandler(data) {
            LogTool.log('xm.getCity:' + data);
            if (data == 1) {
                AdModel.model.isShieldCity = true;
            }
            else {
                AdModel.model.isShieldCity = false;
            }
            LogTool.log('xm.isShieldCity:' + AdModel.model.isShieldCity);
            this.getAdRate();
        }
        getAdRate() {
            if (this.rateKey.length > 0) {
                this.ckey = this.rateKey.shift();
                var data1 = { gameId: XmConfig.gameId, version: XmConfig.version, openId: 10000, key: this.ckey };
                var url = 'https://wxxcx.tanyu.mobi:4443/admin/api/adrate';
                NetTool.request(url, data1, 'get', this, this.getAdRateHandler);
            }
            else {
                this.initParam();
            }
        }
        getAdRateHandler(data) {
            LogTool.log('xm.getAdRate:' + this.ckey + ':' + JSONUtil.stringify(data));
            AdModel.model.setRate(this.ckey, data.rate);
            this.getAdRate();
        }
    }

    class PlatformNativeAd5View extends ui.platform.PlatformNativeAd5UI {
        constructor() {
            super();
            this.zOrder = 105;
        }
    }

    class PlatformNativeAd5ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlatformNativeAd5View;
            this.viewName = "PlatformNativeAd5View";
        }
        openComplete() {
            super.openComplete();
            this.ui = this.view;
            this.ui.txt_skip.on(Laya.Event.CLICK, this, this.closeHandler);
        }
        closeHandler() {
            this.close();
        }
    }

    class PlatformController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            PlatformTool.initParam();
            PlatformModel.model.loadData();
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE_VIEW_SHOW, this, PlatformNativeAdViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE1_VIEW_SHOW, this, PlatformNativeAd1ViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE2_VIEW_SHOW, this, PlatformNativeAd2ViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE3_VIEW_SHOW, this, PlatformNativeAd3ViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE4_VIEW_SHOW, this, PlatformNativeAd4ViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE5_VIEW_SHOW, this, PlatformNativeAd5ViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE_PAGE_VIEW_SHOW, this, PlatformNativeAdPageViewController);
            ViewManager.register(PlatformEvent.PLATFORM_ADDICO_VIEW_SHOW, this, PlatformAddIcoViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE_ICON_VIEW_SHOW, this, PlatformNativeIconViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE_ICON1_VIEW_SHOW, this, PlatformNativeIcon1ViewController);
            ViewManager.register(PlatformEvent.PLATFORM_AD_NATIVE_ICON3_VIEW_SHOW, this, PlatformNativeIcon1ViewController$1);
            ViewManager.register(PlatformEvent.PLATFORM_RECORDER_STATE_VIEW_SHOW, this, PlatformRecorderStateViewController);
            ViewManager.register(PlatformEvent.PLATFORM_FOLLOW_ICO_VIEW_SHOW, this, PlatformFollowIcoViewController);
            ViewManager.register(PlatformEvent.PLATFORM_FOLLOW_VIEW_SHOW, this, PlatformFollowViewController);
            ViewManager.register(PlatformEvent.PLATFORM_FOLLOW_REWARD_VIEW_SHOW, this, PlatformFollowRewardViewController);
            ViewManager.register(PlatformEvent.PLATFORM_SHARE_VIEW_SHOW, this, PlatformShareViewController);
            ViewManager.register(PlatformEvent.PLATFORM_ADD_MINI_VIEW, this, PlatformAddMiniViewController);
            ViewManager.register(PlatformEvent.PLATFORM_ADDITION_VIEW_SHOW, this, PlatformAdditionViewController);
            ViewManager.register(PlatformEvent.PLATFORM_CLAUSE_VIEW, this, PlatformClauseViewController);
            ViewManager.register(PlatformEvent.PLATFORM_PRIVACY_VIEW, this, PlatformPrivacyViewController);
            ViewManager.register(PlatformEvent.PLATFORM_RECORDER_BTN_VIEW_SHOW, this, PlatformRecorderBtnViewController);
            this.addEventListener(AdEvent.AD_VIDEO_SHOW, this, this.showAdHandler);
            this.addEventListener(AdEvent.AD_INSERT_SHOW, this, this.showAdInsert);
            this.addEventListener(AdEvent.AD_SHARE_SHOW, this, this.showAdShare);
            this.addEventListener(PlatformEvent.PLATFORM_AD_VIDEO_COMPLETE, this, this.adCompHandler);
            this.initParamHandler();
        }
        initParamHandler() {
            if (MainConfig.platform == PlatformType.PLATFORM_QQMINI) {
                this.startChild(new QqminiController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_WXMINI) {
                this.startChild(new WxminiController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_BDMINI) {
                this.startChild(new BdminiController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_TTMINI) {
                this.startChild(new TtminiController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_OPMINI) {
                this.startChild(new OpminiController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_VVMINI) {
                this.startChild(new VvminiController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_CSJ) {
                this.startChild(new CsjController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_4399) {
                this.startChild(new P4399Controller());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_QTT) {
                this.startChild(new QttController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_OPPO) {
                this.startChild(new OppoController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_TOPON) {
                this.startChild(new ToponController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_MZMINI) {
                this.startChild(new MzminiController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_VIVO) {
                this.startChild(new VivoController());
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_XM) {
                this.startChild(new XmController);
            }
            else if (MainConfig.platform == PlatformType.PLATFORM_4399MINI) {
                this.startChild(new P4399miniController);
            }
            else {
                this.startChild(new SjController());
            }
        }
        showAdHandler(data) {
            PlatformModel.model.adVideoId = ParamUtil.getString(data, 'id', '');
            LogTool.log('PlatformController.showAdHandler:' + PlatformModel.model.adVideoId);
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_VIDEO_SHOW, data);
        }
        adCompHandler(data) {
            this.dispatchEvent(AdEvent.AD_VIDEO_COMPLETE(PlatformModel.model.adVideoId), { isEnded: true });
        }
        showAdInsert(data) {
            this.dispatchEvent(PlatformEvent.PLATFORM_AD_INSERT_SHOW, data);
        }
        showAdShare(data) {
            this.dispatchEvent(PlatformEvent.PLATFORM_SHARE_SHOW, data);
        }
    }

    class PlayerSet1View extends ui.player.PlayerSet1UI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class PlayerSet1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlayerSet1View;
            this.viewName = 'PlayerSetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var ugc = AdModel.model.getRate('ugc');
            LogTool.log("PlayerSetViewController.txt_input.ugc" + ugc);
            if (ugc == 0 && PageConfig.pageType == 1) {
                this.ui.txt_input.visible = false;
                this.ui.list_ioc.y = 248;
            }
            else {
                this.ui.txt_input.visible = true;
            }
            this.ui.txt_privacy.on(Laya.Event.CLICK, this, this.privacyHandler);
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_ok.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.txt_input.text = PlayerModel.model.name;
            this.ui.img_head.skin = PlayerModel.model.ico;
            this.ui.list_ioc.on(Laya.Event.CHANGE, this, this.changeHandler);
            this.ui.box_name.on(Laya.Event.CLICK, this, this.getNameHandler);
            this.showbtn();
            this.showDataHandler();
        }
        showbtn() {
            this.ui.img_close.visible = false;
            LogTool.log('11111111111111111111111111111111111111:' + AdTool.checkRate('yanchi', true));
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_close.visible = true;
                });
            }
            else {
                this.ui.img_close.visible = true;
            }
        }
        getNameHandler() {
            var name = PlayerConfig.getPlayerName();
            this.ui.txt_input.text = name;
        }
        showDataHandler() {
            var nlist = [];
            for (let index = 0; index < PlayerIcoConfig.icoMax; index++) {
                var data = {};
                data.img_ico = PlayerIcoConfig.getIco(index);
                nlist.push(data);
            }
            this.ui.list_ioc.dataSource = nlist;
        }
        changeHandler() {
            var data = this.ui.list_ioc.selectedItem;
            if (data && data.img_ico) {
                this.ui.img_head.skin = data.img_ico;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.okHandler);
        }
        okHandler() {
            var str = this.ui.txt_input.text;
            if (str.length > 8) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称长度在0~8个字符" });
                return;
            }
            if (str.length <= 0) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称不能为空" });
                return;
            }
            this.dispatchEvent(PlayerEvent.PLAYER_INFO_SET, { name: str, ico: this.ui.img_head.skin });
            this.close();
        }
        privacyHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_CLAUSE_VIEW, { text: '返回' });
        }
    }

    class PlayerSet2View extends ui.player.PlayerSet2UI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class PlayerSet2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlayerSet2View;
            this.viewName = 'PlayerSetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var ugc = AdModel.model.getRate('ugc');
            LogTool.log("PlayerSetViewController.txt_input.ugc" + ugc);
            if (ugc == 0 && PageConfig.pageType == 1) {
                this.ui.txt_input.visible = false;
                this.ui.list_ioc.y = 248;
            }
            else {
                this.ui.txt_input.visible = true;
            }
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_ok.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.txt_input.text = PlayerModel.model.name;
            this.ui.img_head.skin = PlayerModel.model.ico;
            this.ui.list_ioc.on(Laya.Event.CHANGE, this, this.changeHandler);
            this.ui.box_name.on(Laya.Event.CLICK, this, this.getNameHandler);
            this.ui.txt_privacy.on(Laya.Event.CLICK, this, this.privacyHandler);
            this.showbtn();
            this.showDataHandler();
        }
        showbtn() {
            this.ui.img_close.visible = false;
            LogTool.log('11111111111111111111111111111111111111:' + AdTool.checkRate('yanchi', true));
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_close.visible = true;
                });
            }
            else {
                this.ui.img_close.visible = true;
            }
        }
        getNameHandler() {
            var name = PlayerConfig.getPlayerName();
            this.ui.txt_input.text = name;
        }
        showDataHandler() {
            var nlist = [];
            for (let index = 0; index < PlayerIcoConfig.icoMax; index++) {
                var data = {};
                data.img_ico = PlayerIcoConfig.getIco(index);
                nlist.push(data);
            }
            this.ui.list_ioc.dataSource = nlist;
        }
        changeHandler() {
            var data = this.ui.list_ioc.selectedItem;
            if (data && data.img_ico) {
                this.ui.img_head.skin = data.img_ico;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.okHandler);
        }
        okHandler() {
            var str = this.ui.txt_input.text;
            if (str.length > 8) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称长度在0~8个字符" });
                return;
            }
            if (str.length <= 0) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称不能为空" });
                return;
            }
            this.dispatchEvent(PlayerEvent.PLAYER_INFO_SET, { name: str, ico: this.ui.img_head.skin });
            this.close();
        }
        privacyHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_CLAUSE_VIEW, { text: '返回' });
        }
    }

    class PlayerSet3View extends ui.player.PlayerSet3UI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class PlayerSet3ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlayerSet3View;
            this.viewName = 'PlayerSetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var ugc = AdModel.model.getRate('ugc');
            LogTool.log("PlayerSetViewController.txt_input.ugc" + ugc);
            if (ugc == 0 && PageConfig.pageType == 1) {
                this.ui.txt_input.visible = false;
                this.ui.list_ioc.y = 248;
            }
            else {
                this.ui.txt_input.visible = true;
            }
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_ok.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.txt_input.text = PlayerModel.model.name;
            this.ui.img_head.skin = PlayerModel.model.ico;
            this.ui.list_ioc.on(Laya.Event.CHANGE, this, this.changeHandler);
            this.ui.box_name.on(Laya.Event.CLICK, this, this.getNameHandler);
            this.showbtn();
            this.showDataHandler();
        }
        showbtn() {
            this.ui.img_close.visible = false;
            LogTool.log('11111111111111111111111111111111111111:' + AdTool.checkRate('yanchi', true));
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.img_close.visible = true;
                });
            }
            else {
                this.ui.img_close.visible = true;
            }
        }
        getNameHandler() {
            var name = PlayerConfig.getPlayerName();
            this.ui.txt_input.text = name;
        }
        showDataHandler() {
            var nlist = [];
            for (let index = 0; index < PlayerIcoConfig.icoMax; index++) {
                var data = {};
                data.img_ico = PlayerIcoConfig.getIco(index);
                nlist.push(data);
            }
            this.ui.list_ioc.dataSource = nlist;
        }
        changeHandler() {
            var data = this.ui.list_ioc.selectedItem;
            if (data && data.img_ico) {
                this.ui.img_head.skin = data.img_ico;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.okHandler);
        }
        okHandler() {
            var str = this.ui.txt_input.text;
            if (str.length > 8) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称长度在0~8个字符" });
                return;
            }
            if (str.length <= 0) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称不能为空" });
                return;
            }
            this.dispatchEvent(PlayerEvent.PLAYER_INFO_SET, { name: str, ico: this.ui.img_head.skin });
            this.close();
        }
        privacyHandler() {
            this.dispatchEvent(PlatformEvent.PLATFORM_CLAUSE_VIEW, { text: '返回' });
        }
    }

    class PlayerSetView extends ui.player.PlayerSetUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class PlayerSetViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = PlayerSetView;
            this.viewName = 'PlayerSetView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            var ugc = AdModel.model.getRate('ugc');
            LogTool.log("PlayerSetViewController.txt_input.ugc" + ugc);
            if (ugc == 0 && PageConfig.pageType == 1) {
                this.ui.txt_input.visible = false;
                this.ui.list_ioc.y = 248;
            }
            else {
                this.ui.txt_input.visible = true;
            }
            this.ui.img_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_ok.on(Laya.Event.CLICK, this, this.adHandler);
            this.ui.txt_input.text = PlayerModel.model.name;
            this.ui.img_head.skin = PlayerModel.model.ico;
            this.ui.list_ioc.on(Laya.Event.CHANGE, this, this.changeHandler);
            this.ui.box_name.on(Laya.Event.CLICK, this, this.getNameHandler);
            if (PlayerConfig.IsShowModifyName == true) {
                this.ui.txt_input.visible = true;
                this.ui.box_name.visible = true;
            }
            else {
                this.ui.txt_input.visible = false;
                this.ui.box_name.visible = false;
            }
            this.showDataHandler();
        }
        getNameHandler() {
            var name = PlayerConfig.getPlayerName();
            this.ui.txt_input.text = name;
        }
        showDataHandler() {
            var nlist = [];
            for (let index = 0; index < PlayerIcoConfig.icoMax; index++) {
                var data = {};
                data.img_ico = PlayerIcoConfig.getIco(index);
                nlist.push(data);
            }
            this.ui.list_ioc.dataSource = nlist;
        }
        changeHandler() {
            var data = this.ui.list_ioc.selectedItem;
            if (data && data.img_ico) {
                this.ui.img_head.skin = data.img_ico;
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.okHandler);
        }
        okHandler() {
            var str = this.ui.txt_input.text;
            if (str.length > 8) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称长度在0~8个字符" });
                return;
            }
            if (str.length <= 0) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_BANNED, text: "名称不能为空" });
                return;
            }
            this.dispatchEvent(PlayerEvent.PLAYER_INFO_SET, { name: str, ico: this.ui.img_head.skin });
            this.close();
        }
    }

    class PlayerController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            PlayerModel.model.init();
            if (!PlayerModel.model.name) {
                PlayerModel.model.name = PlayerConfig.getPlayerName();
                PlayerModel.model.ico = PlayerIcoConfig.getIco(MathUtil.randomInt(0, 9));
                PlayerModel.model.saveData();
            }
            this.addEventListener(PlayerEvent.PLAYER_SET_VIEW_SHOW, this, this.playSetHandler);
            this.addEventListener(PlayerEvent.PLAYER_INFO_RESPONSE, this, this.infoHandler);
            this.addEventListener(PlayerEvent.PLAYER_INFO_SET, this, this.infoHandler);
            this.addEventListener(PlayerEvent.PLAYER_NAME_SET, this, this.nameHandler);
        }
        nameHandler(data) {
            PlayerModel.model.name = data.name;
            PlayerModel.model.saveData();
        }
        infoHandler(data) {
            if (data.name) {
                PlayerModel.model.name = data.name;
            }
            if (data.ico) {
                PlayerModel.model.ico = data.ico;
            }
            PlayerModel.model.isChange = true;
            PlayerModel.model.saveData();
            this.dispatchEvent(PlayerEvent.PLAYER_INFO_CHANGE);
        }
        playSetHandler(data) {
            if (PlayerConfig.playerType == 1) {
                ViewManager.show(this, PlayerSet1ViewController, data);
            }
            else if (PlayerConfig.playerType == 2) {
                ViewManager.show(this, PlayerSet2ViewController, data);
            }
            else if (PlayerConfig.playerType == 3) {
                ViewManager.show(this, PlayerSet3ViewController, data);
            }
            else {
                ViewManager.show(this, PlayerSetViewController, data);
            }
        }
    }

    class SceneViewClassConfig {
        static getClass(name) {
            var c = this.classList[name];
            if (c) {
                return c;
            }
            return null;
        }
        static regClass(name, clas) {
            this.classList[name] = clas;
        }
    }
    SceneViewClassConfig.classList = {};

    class AstartMapUtil {
        static findPath(map, start_x, start_y, end_x, end_y, isDir8 = true) {
            start_x = Math.round(start_x);
            start_y = Math.round(start_y);
            end_x = Math.round(end_x);
            end_y = Math.round(end_y);
            if (this.checkOpen(map, start_x, start_y) == false) {
                return [];
            }
            if (this.checkOpen(map, end_x, end_y) == false) {
                return [];
            }
            this.recover();
            var openList = {};
            var result = [];
            var result_point = null;
            this.addPoint(openList, this.getObject(start_x, start_y, 0));
            do {
                var currentPoint = this.getMinPoint(openList);
                if (!currentPoint) {
                    return [];
                }
                currentPoint.isClose = true;
                var surroundPoint = this.surroundPoint(currentPoint, isDir8);
                for (var i in surroundPoint) {
                    var item = surroundPoint[i];
                    if (this.checkOpen(map, item.x, item.y) &&
                        this.checkClose(openList, item.x, item.y) == false) {
                        if (currentPoint.x == item.x || currentPoint.y == item.y) {
                            var g = currentPoint.G + 10;
                        }
                        else {
                            var g = currentPoint.G + 14;
                        }
                        var iitem = this.getPoint(openList, item.x, item.y);
                        if (!iitem) {
                            item.H = Math.abs(end_x - item.x) * 10 + Math.abs(end_y - item.y) * 10;
                            item.G = g;
                            item.F = item.H + g;
                            item.parent = currentPoint;
                            this.addPoint(openList, item);
                        }
                        else {
                            if (g < iitem.G) {
                                iitem.parent = currentPoint;
                                iitem.G = g;
                                iitem.F = iitem.H + g;
                            }
                        }
                    }
                }
                result_point = this.getPoint(openList, end_x, end_y);
            } while (!result_point);
            if (!result_point) {
                result = [];
            }
            else {
                var currentObj = result_point;
                do {
                    result.unshift({ x: currentObj.x, y: currentObj.y });
                    currentObj = currentObj.parent;
                } while (currentObj && (currentObj.x != start_x || currentObj.y != start_y));
            }
            return result;
        }
        static surroundPoint(curPoint, isDir8) {
            var x = curPoint.x;
            var y = curPoint.y;
            if (isDir8) {
                return [
                    this.getObject(x - 1, y - 1),
                    this.getObject(x, y - 1),
                    this.getObject(x + 1, y - 1),
                    this.getObject(x + 1, y),
                    this.getObject(x + 1, y + 1),
                    this.getObject(x, y + 1),
                    this.getObject(x - 1, y + 1),
                    this.getObject(x - 1, y)
                ];
            }
            else {
                return [
                    this.getObject(x, y - 1),
                    this.getObject(x + 1, y),
                    this.getObject(x, y + 1),
                    this.getObject(x - 1, y)
                ];
            }
        }
        static addPoint(list, point) {
            var k = point.x + '_' + point.y;
            list[k] = point;
        }
        static getPoint(list, x, y) {
            var k = x + '_' + y;
            return list[k];
        }
        static getMinPoint(list) {
            var minPoint = null;
            for (var k in list) {
                var point = list[k];
                if (point.isClose) {
                }
                else if (minPoint == null) {
                    minPoint = point;
                }
                else if (point.F < minPoint.F) {
                    minPoint = point;
                }
            }
            return minPoint;
        }
        static checkClose(list, x, y) {
            var point = this.getPoint(list, x, y);
            if (!point) {
                return false;
            }
            else if (point.isClose) {
                return true;
            }
            return false;
        }
        static checkOpen(map, x, y) {
            var k = x + '_' + y;
            if (map[k]) {
                return true;
            }
            return false;
        }
        static obstacleToOpenMap(map) {
            var left = 0;
            var right = 0;
            var top = 0;
            var bottom = 0;
            var init = false;
            for (var k in map) {
                var arr = k.split('_');
                var x = MathUtil.int(arr[0]);
                var y = MathUtil.int(arr[1]);
                if (init == false) {
                    init = true;
                    left = x;
                    top = y;
                    right = x;
                    bottom = y;
                }
                else {
                    if (x < left) {
                        left = x;
                    }
                    if (x > right) {
                        right = x;
                    }
                    if (y < top) {
                        top = y;
                    }
                    if (y > bottom) {
                        bottom = y;
                    }
                }
            }
            var nmap = {};
            for (var x = left; x <= right; x++) {
                for (var y = top; y <= bottom; y++) {
                    var k = x + '_' + y;
                    if (map[k]) {
                    }
                    else {
                        nmap[k] = 1;
                    }
                }
            }
            return nmap;
        }
        static getObject(x = 0, y = 0, G = 0) {
            var p;
            if (this.poolIndex < this.poolList.length) {
                p = this.poolList[this.poolIndex];
                p.G = 0;
                p.F = 0;
                p.H = 0;
                p.isClose = false;
                p.parent = null;
            }
            else {
                p = {};
                this.poolList.push(p);
            }
            this.poolIndex++;
            p.x = x;
            p.y = y;
            p.G = G;
            return p;
        }
        static recover() {
            this.poolIndex = 0;
        }
    }
    AstartMapUtil.poolList = [];
    AstartMapUtil.poolIndex = 0;

    class SceneFindPathTool {
        static initMap(map) {
            map = this.zoomMap(map, this.zoom);
            this.map = AstartMapUtil.obstacleToOpenMap(map);
        }
        static zoomMap(map, zoom = 1) {
            var cmap = {};
            for (var k in map) {
                var arr = k.split('_');
                var x = MathUtil.int(arr[0]);
                var y = MathUtil.int(arr[1]);
                var v = map[k];
                var sx = Math.round(x * zoom);
                var sy = Math.round(y * zoom);
                var sk = sx + '_' + sy;
                if (cmap[sk]) {
                }
                else if (v) {
                    cmap[sk] = v;
                }
            }
            return cmap;
        }
        static findPath(sx, sy, tx, ty, sDis, eDis) {
            sx = Math.round(sx * this.zoom);
            sy = Math.round(sy * this.zoom);
            tx = Math.round(tx * this.zoom);
            ty = Math.round(ty * this.zoom);
            var path = AstartMapUtil.findPath(this.map, sx, sy, tx, ty);
            if (path.length < eDis) {
                console.log("SceneFindPathTool:findPath." + sx + ',' + sy + ',' + tx + ',' + ty);
                return null;
            }
            var dis = Math.min(sDis, path.length - eDis);
            if (path.length > sDis) {
                path = path.slice(0, dis);
            }
            for (var k in path) {
                var v = path[k];
                v.x = Math.round(v.x / this.zoom);
                v.y = Math.round(v.y / this.zoom);
            }
            return path;
        }
        static findPathTo(sx, sy, tx, ty, sDis, eDis) {
            sx = Math.round(sx);
            sy = Math.round(sy);
            tx = Math.round(tx);
            ty = Math.round(ty);
            return [{ x: tx, y: ty }];
        }
    }
    SceneFindPathTool.zoom = 0.5;

    class SceneEffectViewController extends View3DController {
        constructor(parentView, vo) {
            super();
            this.turnY = 0;
            this.data = vo;
            this.parentView = parentView;
            var img = ParamUtil.getString(this.data, 'image');
            this.viewURL = SceneConfig.getEffectUrl(img);
            this.isAutoDestroy = false;
        }
        openComplete() {
            super.openComplete();
            this.body = this.view;
            this.body.transform.localPositionX = ParamUtil.getNumber(this.data, 'x', 0);
            this.body.transform.localPositionY = ParamUtil.getNumber(this.data, 'y', 0);
            this.body.transform.localPositionZ = ParamUtil.getNumber(this.data, 'z', 0);
            Display3DUtil.playParticle(this.body);
            var time = ParamUtil.getInt(this.data, 'time', 2000);
            TimerUtil.onceTimer(time, this, this.close);
            this.turnY = ParamUtil.getNumber(this.data, 'turnY', 0);
            if (this.turnY) {
                TimerUtil.loopFrame(1, this, this.trunHandle);
            }
        }
        trunHandle() {
            this.body.transform.localRotationEulerY += this.turnY;
        }
    }

    class SenceGoodsConfig {
    }
    SenceGoodsConfig.list = [
        { cid: 30021101, x: 0, y: -0.5, z: -53 },
        { cid: 30021101, x: 25, y: -0.5, z: -20 },
        { cid: 30021101, x: -25, y: -0.5, z: -20 },
        { cid: 30021101, x: 0, y: -0.5, z: 53 },
        { cid: 30021101, x: 25, y: -0.5, z: 20 },
        { cid: 30021101, x: -25, y: -0.5, z: 20 },
        { cid: 30021101, x: 13, y: -0.5, z: -13.5 },
        { cid: 30021101, x: -13, y: -0.5, z: -13.5 },
        { cid: 30021101, x: 13, y: -0.5, z: 13.5 },
        { cid: 30021101, x: -13, y: -0.5, z: 13.5 },
        { cid: 30021001, x: 2, y: -0.5, z: 80 },
        { cid: 30021001, x: 4, y: -0.5, z: 80 },
        { cid: 30021001, x: 0, y: -0.5, z: 80 },
        { cid: 30021001, x: -2, y: -0.5, z: 80 },
        { cid: 30021001, x: -4, y: -0.5, z: 80 },
        { cid: 30021002, x: 14, y: 0.5, z: 45 },
        { cid: 30021001, x: 16, y: 0.5, z: 45 },
        { cid: 30021002, x: 18, y: 0.5, z: 45 },
        { cid: 30021002, x: 14, y: 0.5, z: 43 },
        { cid: 30021001, x: 16, y: 0.5, z: 43 },
        { cid: 30021002, x: 18, y: 0.5, z: 43 },
        { cid: 30021002, x: -14, y: 0.5, z: 45 },
        { cid: 30021001, x: -16, y: 0.5, z: 45 },
        { cid: 30021002, x: -18, y: 0.5, z: 45 },
        { cid: 30021002, x: -14, y: 0.5, z: 43 },
        { cid: 30021001, x: -16, y: 0.5, z: 43 },
        { cid: 30021002, x: -18, y: 0.5, z: 43 },
        { cid: 30021002, x: 14, y: -0.5, z: 22 },
        { cid: 30021001, x: 16, y: -0.5, z: 22 },
        { cid: 30021002, x: 18, y: -0.5, z: 22 },
        { cid: 30021002, x: 14, y: -0.5, z: 20 },
        { cid: 30021002, x: 16, y: -0.5, z: 20 },
        { cid: 30021002, x: 18, y: -0.5, z: 20 },
        { cid: 30021002, x: -14, y: -0.5, z: 22 },
        { cid: 30021001, x: -16, y: -0.5, z: 22 },
        { cid: 30021002, x: -18, y: -0.5, z: 22 },
        { cid: 30021002, x: -14, y: -0.5, z: 20 },
        { cid: 30021002, x: -16, y: -0.5, z: 20 },
        { cid: 30021002, x: -18, y: -0.5, z: 20 },
        { cid: 30021002, x: 14, y: -0.5, z: -22 },
        { cid: 30021002, x: 16, y: -0.5, z: -22 },
        { cid: 30021002, x: 18, y: -0.5, z: -22 },
        { cid: 30021002, x: 14, y: -0.5, z: -20 },
        { cid: 30021002, x: 16, y: -0.5, z: -20 },
        { cid: 30021002, x: 18, y: -0.5, z: -20 },
        { cid: 30021002, x: -14, y: -0.5, z: -22 },
        { cid: 30021002, x: -16, y: -0.5, z: -22 },
        { cid: 30021002, x: -18, y: -0.5, z: -22 },
        { cid: 30021002, x: -14, y: -0.5, z: -20 },
        { cid: 30021002, x: -16, y: -0.5, z: -20 },
        { cid: 30021002, x: -18, y: -0.5, z: -20 },
        { cid: 30021002, x: 13, y: -0.2, z: 4 },
        { cid: 30021002, x: 13, y: -0.2, z: 2 },
        { cid: 30021002, x: 13, y: -0.2, z: 0 },
        { cid: 30021002, x: 13, y: -0.2, z: -2 },
        { cid: 30021002, x: 13, y: -0.2, z: -4 },
        { cid: 30021002, x: -13, y: -0.2, z: 4 },
        { cid: 30021002, x: -13, y: -0.2, z: 2 },
        { cid: 30021002, x: -13, y: -0.2, z: 0 },
        { cid: 30021002, x: -13, y: -0.2, z: -2 },
        { cid: 30021002, x: -13, y: -0.2, z: -4 },
    ];

    class SceneDropTool {
        static getBattleGoodsDropsList(vo, atter, nlist) {
            if (SceneModel.model.vo.battleType == 3) {
                SceneDropTool.getLevGoodsDropsList(vo, atter, nlist);
            }
            else {
                SceneDropTool.getGoodsDropsList(vo, atter, nlist);
            }
        }
        static getGoodsDropsList(vo, atter, nlist) {
            var bulletList = ArrayUtil.randomArray(SceneConfig.buffList, 1);
            for (var k in bulletList) {
                var cid = bulletList[k];
                var nvo = this.getDropsElement(vo, cid);
                nlist.push(nvo);
            }
            return nlist;
        }
        static getLevGoodsDropsList(vo, atter, nlist) {
            if (RandomUtil.randomHit(0.5)) {
                var bulletList = SceneConfig.buffLevList;
                for (var k in bulletList) {
                    var cid = bulletList[k];
                    var nvo = this.getDropsElement(vo, cid);
                    nlist.push(nvo);
                }
                return nlist;
            }
        }
        static getDropsElement(vo, cid) {
            var mon = SceneVoBuilder.getElementVo(cid);
            mon.ix = vo.x + MathUtil.randomNumber(-1, 1);
            mon.iy = vo.y;
            mon.iz = vo.z + MathUtil.randomNumber(-1, 1);
            mon.halo = 3;
            return mon;
        }
    }

    class SceneNpcTool {
        static randomNpc(cid = 0, vnum, stre, campType = 0) {
            if (!cid) {
                cid = RandomUtil.randomItem(SceneConfig.npcList);
            }
            var npc = SceneTool.createNpc(cid);
            npc.campType = campType;
            if (campType == 0) {
                npc.camp = IdUtil.getId();
                var pos = SceneTool.randomPos();
            }
            else {
                npc.camp = campType;
                var pos = SceneTool.randomPosCamp(campType);
            }
            npc.ix = -2;
            npc.iy = pos.y;
            npc.iz = pos.z;
            npc.halo = 2;
            npc.name = PlayerConfig.getPlayerName();
            npc.lv = Math.round((vnum + 1) / 4 + 0.5);
            SceneSkillTool.buildSkillList(npc);
            if (stre <= 1) {
                npc.attPollTime = 9000;
                var cdPro = -1;
            }
            else if (stre <= 2) {
                npc.attPollTime = 7000;
                var cdPro = -0.5;
            }
            else {
                npc.attPollTime = 5000;
                var cdPro = -0.25;
            }
            var gun = SceneVoBuilder.getElementVo(npc.attCid);
            SceneGoodsTool.setGoods(npc, gun);
            if (gun) {
                npc.attCd = gun.attCd;
            }
            npc.dis = MathUtil.randomInt(30, 50);
            var pro = 0.1 * (vnum - 5);
            if (pro >= 1) {
                pro = 1;
            }
            npc.attPro = pro;
            var mt = 15 - vnum;
            if (mt < 5) {
                mt = 5;
            }
            npc.movePollTime = mt * 200;
            npc.v = 0.5;
            npc.cdPro = cdPro;
            if (npc.ttype == 2) {
                npc.isAutoRevive = false;
                npc.hp = npc.hpMax;
                npc.defPro = 0.8;
            }
            else if (npc.ttype == 3) {
                npc.isAutoRevive = false;
                var hp = MathUtil.int(npc.hpMax * (1 + npc.attPro));
                npc.hp = npc.hpBase = npc.hpMax = hp;
            }
            else {
                var hp = MathUtil.int(npc.hpMax * (1 + npc.attPro));
                npc.hp = npc.hpBase = npc.hpMax = hp;
                npc.isAutoRevive = true;
            }
            LogTool.log("怪物强度:vnum:" + vnum + ",streng=" + stre + ",dis=" + npc.dis + ",attPro=" + npc.attPro + ',hp' + npc.hp + ',att' + npc.att + ',cdPro:' + cdPro);
            return npc;
        }
    }

    class SceneBeginCameraController extends Controller {
        constructor(scene) {
            super();
            this.scene = scene;
            this.camera = SceneModel.model.camera;
        }
        run() {
            super.run();
            this.addEventListener(SceneEvent.SCENE_VIEW_START, this, this.startMove);
            this.addEventListener(StageMouseEvent.STAGE_MOUSE_CLICK, this, this.endHandler);
        }
        startMove() {
            this.scene.addChild(this.camera);
            this.camera.transform.localPositionX = 0;
            this.camera.transform.localPositionZ = -30;
            this.camera.transform.localPositionY = 10;
            this.camera.transform.localRotationEulerX = -30;
            this.camera.transform.localRotationEulerY = 180;
            TweenUtil.to(this, this.camera.transform, { localPositionZ: 45, localPositionX: 0, localPositionY: 10 }, 8000, Laya.Ease.quadOut, this.startMove3);
        }
        startMove3() {
            this.camera.transform.localPositionX = 0;
            this.camera.transform.localPositionZ = 45;
            this.camera.transform.localPositionY = 10;
            this.camera.transform.localRotationEulerX = -30;
            this.camera.transform.localRotationEulerY = 180;
            TweenUtil.to(this, this.camera.transform, { localPositionZ: 53.6, localPositionX: 0, localPositionY: 1.4, localRotationEulerX: 0 }, 6500, Laya.Ease.quadOut, this.endHandler);
        }
        endHandler() {
            this.dispatchEvent(SceneEvent.SCENE_BEGAIN_CAMERA_COMPLETE);
            this.stop();
        }
    }

    class SceneEndCameraController extends Controller {
        constructor(scene, result) {
            super();
            this.scene = scene;
            this.camera = SceneModel.model.camera;
            this.result = result;
        }
        run() {
            super.run();
            this.scene.addChild(this.camera);
            TimerUtil.onceTimer(2000, this, this.startMove);
            TimerUtil.onceTimer(100, this, this.showUnit);
            TimerUtil.loopTimer(300, this, this.showDazzleHandler);
        }
        showUnit() {
            var list = SceneModel.model.vo.unitList;
            var index = 0;
            for (var i in list) {
                var vo = list[i];
                if (vo.ttype == 1) {
                    if ((this.result == 1 && vo.camp == 1) || (this.result != 1 && vo.camp != 1)) {
                        var pos = SceneConfig.endScenePos[index];
                        this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(vo.id), { state: 'victory' });
                        this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_ATTR_SET(vo.id), { x: pos.x, y: 4.5, z: pos.z, dir: 180, hp: 100 });
                        index++;
                    }
                    else {
                    }
                }
            }
        }
        showDazzleHandler() {
            var random = RandomUtil.randomInt(0, 2);
            var x = RandomUtil.randomInt(-10, 10);
            var y = RandomUtil.randomInt(5, 15);
            this.dispatchEvent(SceneEvent.SCENE_EFFECT_VIEW_SHOW, { image: SceneConfig.dazzleList[random], x: x, y: y, z: 10, time: 3000 });
        }
        startMove() {
            this.scene.addChild(this.camera);
            this.camera.transform.localPositionX = 0;
            this.camera.transform.localPositionZ = -10;
            this.camera.transform.localPositionY = 6;
            this.camera.transform.localRotationEulerX = -5;
            this.camera.transform.localRotationEulerY = 180;
            TweenUtil.to(this, this.camera.transform, { localPositionZ: -2.5, localPositionX: 0, localPositionY: 6 }, 8000, Laya.Ease.quadOut, this.endHandler);
        }
        endHandler() {
            this.dispatchEvent(SceneEvent.SCENE_END_CAMERA_COMPLETE, { result: this.result });
            this.stop();
        }
    }

    class SceneFallController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            this.vo = SceneModel.model.vo;
            this.evo = SceneVoBuilder.getElementVo(30071001);
            this.evo.camp = 0;
            TimerUtil.loopTimer(this.evo.attCd, this, this.attHandler);
        }
        attHandler() {
            var list = this.vo.unitList;
            for (var k in list) {
                var vo = list[k];
                if (vo.y < -10) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: this.evo.att, atter: this.evo });
                }
            }
        }
    }

    class SceneGuideAnimViewController extends View3DController {
        constructor(scene) {
            super();
            this.scene = scene;
        }
        openComplete() {
            super.openComplete();
            this.ui = this.scene.getChildByName('guide');
            if (this.ui) {
                TimerUtil.loopFrame(1, this, this.animHandler);
            }
        }
        animHandler() {
            var l = this.ui.numChildren;
            for (var i = 0; i < l; i++) {
                var item = this.ui.getChildAt(i);
                if (item.meshRenderer) {
                    var list = item.meshRenderer.materials;
                    for (var k in list) {
                        var mater = list[k];
                        if (mater instanceof Laya.UnlitMaterial) {
                            mater.tilingOffsetW += 0.02;
                        }
                    }
                }
            }
        }
    }

    class SceneFightController extends Controller {
        constructor(scene) {
            super();
            this.dropsList = [];
            this.scene = scene;
            this.vo = SceneModel.model.vo;
        }
        run() {
            super.run();
            this.startChild(new SceneFallController());
            this.vo.npcCamp = 2;
            this.startChild(new SceneGuideAnimViewController(this.scene));
            this.startChild(new SceneBeginCameraController(this.scene));
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_DEATH, this, this.deathHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYEER_SELECT, this, this.selectPlayerHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYEER_RELPACE, this, this.relpacePlayerHanler);
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.resultHandler);
            this.initTimer();
            this.initPlayer();
            this.initTeam();
            this.initNpc();
            this.initGoods();
            this.lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
        }
        initTimer() {
            this.vo.startTs = TimeUtil.getTimestamp();
            if (this.vo.totalTime) {
                this.vo.leftTime = this.vo.totalTime;
                TimerUtil.loopTimer(1000, this, this.timerHandler);
            }
        }
        timerHandler() {
            if (this.vo.isPause) {
                return;
            }
            if (this.vo.state >= 2) {
                return;
            }
            if (this.vo.teamKillNum >= 30) {
                this.vo.state = 2;
                this.dispatchEvent(SceneEvent.SCENE_STATE_OVER, { result: 1 });
                TimerUtil.stopTimer(this, this.timerHandler);
                return;
            }
            if (this.vo.foeKillNum >= 30) {
                this.vo.state = 2;
                this.dispatchEvent(SceneEvent.SCENE_STATE_OVER, { result: -1 });
                TimerUtil.stopTimer(this, this.timerHandler);
                return;
            }
            this.vo.leftTime--;
            if (this.vo.leftTime <= 0) {
                this.vo.leftTime = 0;
                TimerUtil.stopTimer(this, this.timerHandler);
                this.refreshHp();
                this.vo.state = 2;
                if (this.vo.teamIntegralTotal >= this.vo.foeIntegralTotal) {
                    this.vo.state = 2;
                    this.dispatchEvent(SceneEvent.SCENE_STATE_OVER, { result: 1 });
                }
                else {
                    this.vo.state = 2;
                    this.dispatchEvent(SceneEvent.SCENE_STATE_OVER, { result: -1 });
                }
            }
        }
        selectPlayerHandler(data) {
            var vo = data.selectVo;
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(vo.id));
            this.addTeam(this.vo.playerVo.cid);
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(this.vo.playerVo.id));
            this.vo.playerVo = data.playerVo;
            this.initPlayer();
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_CHANGE);
        }
        relpacePlayerHanler(data) {
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(this.vo.playerVo.id));
            this.vo.playerVo = data.playerVo;
            this.initPlayer();
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYEER_CHANGE);
        }
        initPlayer() {
            this.playerVo = this.vo.playerVo;
            this.playerVo.ix = 6;
            this.playerVo.iy = 0;
            this.playerVo.iz = -55;
            this.playerVo.isAutoRemove = false;
            this.playerVo.isAutokDir = false;
            this.playerVo.campType = 1;
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: this.playerVo });
        }
        initTeam() {
            var i = 0;
            if (this.vo.teamNum) {
                var list = this.vo.locList1;
                for (var k = 1; k < 5; k++) {
                    var cid = list[k];
                    this.addTeam(cid, i);
                    i++;
                }
            }
        }
        addTeam(cid = 0, index = 0) {
            var streng = 3;
            var mon = SceneNpcTool.randomNpc(cid, this.vo.victoryNum, streng, 1);
            mon.camp = 1;
            mon.halo = 1;
            mon.ix += 1 * index;
            mon.iy = 0;
            mon.iz = -55;
            this.vo.teamList.push(mon);
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: mon });
        }
        initNpc() {
            this.monAddHandler(5);
        }
        monAddHandler(num) {
            var npcList = this.vo.locList2;
            var list = SceneConfig.getMonStrengList(this.vo.victoryNum);
            list = RandomUtil.randomArray(list, num);
            for (var i = 0; i < num; i++) {
                var streng = list[i];
                var cid = npcList[i];
                var mon = SceneNpcTool.randomNpc(cid, this.vo.victoryNum, streng, this.vo.npcCamp);
                mon.dir = 180;
                mon.ix += 1 * i;
                mon.iy = 0;
                mon.iz = 56.5;
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: mon });
            }
        }
        initPillbox() {
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            for (var i in SceneConfig.pillboxList_2) {
                var co = SceneConfig.pillboxList_2[i];
                var npc = SceneNpcTool.randomNpc(co.cid, this.vo.victoryNum, 1, this.vo.npcCamp);
                npc.ix = co.x;
                npc.iy = co.y;
                npc.iz = co.z;
                npc.camp = 2;
                if (co.stre == 2) {
                    npc.dir = 180;
                    npc.hpMax = 300 + 60 * (lv - 1);
                    npc.scale = 1.5;
                }
                else {
                    npc.dir = 0;
                    npc.hpMax = 200 + 30 * (lv - 1);
                }
                npc.haloY = co.haloY;
                npc.hp = npc.hpMax;
                this.vo.teamAllMaxHp += npc.hpMax;
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: npc });
            }
            for (var i in SceneConfig.pillboxList_1) {
                var co = SceneConfig.pillboxList_1[i];
                var npc = SceneNpcTool.randomNpc(co.cid, this.vo.victoryNum, 1, 1);
                npc.ix = co.x;
                npc.iy = co.y;
                npc.iz = co.z;
                npc.halo = 1;
                npc.haloY = co.haloY;
                if (co.stre == 2) {
                    npc.dir = 0;
                    npc.hpMax = 300 + 60 * (lv - 1);
                    npc.scale = 1.5;
                }
                else {
                    npc.dir = 180;
                    npc.hpMax = 200 + 30 * (lv - 1);
                }
                npc.hp = npc.hpMax;
                this.vo.foeAllmaxHp += npc.hpMax;
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: npc });
            }
            TimerUtil.loopTimer(500, this, this.hpTotalHandler);
        }
        initGoods() {
            for (var i in SenceGoodsConfig.list) {
                var goodVo = SenceGoodsConfig.list[i];
                var good = SceneVoBuilder.getElementVo(goodVo.cid);
                good.ix = goodVo.x;
                good.iy = goodVo.y;
                good.iz = goodVo.z;
                good.halo = 3;
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: good });
            }
        }
        initBullet() {
            var n = 10;
            for (var i = 0; i < n; i++) {
                var mon = SceneTool.randomBullet();
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: mon });
            }
            var n = 5;
            for (var i = 0; i < n; i++) {
                var mon = SceneTool.randomBullet();
                mon.ix = this.playerVo.ix + MathUtil.randomNumber(-5, 5);
                mon.iz = this.playerVo.iz + MathUtil.randomNumber(-5, 5);
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: mon });
            }
        }
        deathHandler(data) {
            if (this.vo.state >= 2) {
                return;
            }
            var vo = data.vo;
            var atter = data.atter;
            if (!atter) {
                return;
            }
            if (vo.isPlayer) {
                this.vo.playerDieNum++;
                this.dispatchEvent(SceneEvent.SCENE_STATE_FALL, { showType: ViewType.OPEN, atter: atter, });
                atter.killFlg = true;
                this.dispatchEvent(SceneNpcEvent.SCENE_NPC_FLG(atter.id), { flg: true });
            }
            else {
                if (atter.isPlayer) {
                    this.vo.playerKillNum++;
                    this.dispatchEvent(SceneFightEvent.SCENE_FIGHT_NPC_KILL, { killer: vo, num: this.vo.playerKillNum, seckill: data.seckill });
                    this.playerKill();
                    if (vo.killFlg) {
                        vo.killFlg = false;
                        this.dispatchEvent(SceneNpcEvent.SCENE_NPC_FLG(atter.id), { flg: false });
                        this.dispatchEvent(SceneNpcEvent.SCENE_NPC_FLG_CHANGE, { flg: false });
                    }
                }
            }
            if (vo.camp == 1) {
                this.vo.foeKillNum++;
                this.vo.foeIntegralTotal += (25 + (this.lv - 1) * 3);
            }
            else {
                this.vo.teamKillNum++;
                this.vo.teamIntegralTotal += (25 + (this.lv - 1) * 3);
            }
            this.vo.killMap[atter.id] = MathUtil.int(this.vo.killMap[atter.id]) + 1;
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_KILL, data);
        }
        playerKill() {
            if (SceneConfig.playKillSound) {
                var index = '' + Math.min(10, this.vo.playerKillNum);
                SoundTool.playSound(index);
            }
        }
        goodsDrops(vo, atter) {
            SceneDropTool.getBattleGoodsDropsList(vo, atter, this.dropsList);
            TimerUtil.callLater(this, this.dropsHandler);
        }
        dropsHandler() {
            if (this.dropsList && this.dropsList.length > 0) {
                var vo = this.dropsList.shift();
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: vo });
                if (this.dropsList.length > 0) {
                    TimerUtil.onceTimer(100, this, this.dropsHandler);
                }
            }
        }
        hpTotalHandler() {
            this.refreshHp();
            if (this.vo.teamHp == 0) {
                this.vo.state = 2;
                this.dispatchEvent(SceneEvent.SCENE_STATE_OVER, { result: -1 });
                TimerUtil.stopTimer(this, this.hpTotalHandler);
            }
            else if (this.vo.foeHp == 0) {
                this.vo.state = 2;
                this.dispatchEvent(SceneEvent.SCENE_STATE_OVER, { result: 1 });
                TimerUtil.stopTimer(this, this.hpTotalHandler);
            }
        }
        refreshHp() {
            var list = SceneModel.model.vo.unitList;
            var hp1 = 0;
            var hp2 = 0;
            for (var i in list) {
                var vo = list[i];
                if (vo.ttype == 2) {
                    if (vo.camp == 1) {
                        hp1 += vo.hp;
                    }
                    else {
                        hp2 += vo.hp;
                    }
                }
            }
            this.vo.teamHp = hp1;
            this.vo.foeHp = hp2;
        }
        getTeamList(camp) {
            var list = SceneModel.model.vo.unitList;
            var teamlist = [];
            for (var i in list) {
                var vo = list[i];
                if (vo.ttype == 2) {
                    if (vo.camp == camp) {
                        teamlist.push(vo);
                    }
                    else {
                        teamlist.push(vo);
                    }
                }
            }
            return teamlist;
        }
        resultHandler(data) {
            var result = data.result;
            this.startChild(new SceneEndCameraController(this.scene, result));
        }
    }

    class SceneLineViewController extends View3DController {
        constructor(scene, data) {
            super();
            this.startColor = new Laya.Color(1, 1, 33 / 155, 1);
            this.endColor = new Laya.Color(1, 1, 1, 1);
            this.scene = scene;
            this.data = data;
            this.parentView = scene;
        }
        openComplete() {
            super.openComplete();
            var startPoint = this.data.startPoint;
            var toPoint = this.data.toPoint;
            var lineSprite3D = this.view = new Laya.PixelLineSprite3D(1);
            lineSprite3D.addLine(startPoint, toPoint, this.startColor, this.endColor);
            this.scene.addChild(lineSprite3D);
            TimerUtil.onceFrame(2, this, this.close);
        }
    }

    class SceneBattleViewController extends Scene3DController {
        constructor() {
            super();
            this.vo = SceneModel.model.vo;
            this.viewURL = SceneConfig.getSceneUrl(this.vo.cid);
            this.viewName = 'SceneBattleView';
        }
        openComplete() {
            super.openComplete();
            this.scene = this.view;
            SceneModel.model.scene = this.scene;
            Display3DUtil.showShadow(this.scene);
            SceneFindPathTool.initMap(this.vo.terrain);
            Display3DUtil.setCollisionGroup(this.scene, Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1);
            this.initCamer();
            this.addEventListener(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, this, this.elementAddHandler);
            this.addEventListener(SceneEvent.SCENE_EFFECT_VIEW_SHOW, this, this.effectAddHandler);
            this.addEventListener(SceneEvent.SCENE_LINE_VIEW_SHOW, this, this.showLineHandler);
            this.addEventListener(SceneEvent.SCENE_BEGAIN_CAMERA_COMPLETE, this, this.sceneStartHandler);
            this.addEventListener(SceneEvent.SCENE_VIEW_EXIT, this, this.exitHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_SET, this, this.stateHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_PAUSE, this, this.pauseHandler);
            this.addEventListener(SceneEvent.SCENE_PAUSE_REQUEST, this, this.pauseHandler);
            this.startChild(new SceneFightController(this.scene));
            this.vo.loadComp = true;
            this.dispatchEvent(SceneEvent.SCENE_LOAD_COMPLETE);
        }
        sceneStartHandler(data) {
            this.vo.state = 1;
            this.vo.startTs = TimeUtil.getTimestamp();
            SoundTool.stopMusic();
            this.dispatchEvent(SceneEvent.SCENE_STATE_READY);
        }
        initCamer() {
            var camera = this.scene.getChildByName('Camera');
            camera.enableHDR = false;
            camera.orthographic = false;
            SceneModel.model.camera = camera;
        }
        elementAddHandler(data) {
            var vo = data.vo;
            var clas = SceneViewClassConfig.getClass(vo.className);
            if (clas) {
                this.startChild(new clas(this.scene, vo));
            }
        }
        effectAddHandler(data) {
            this.startChild(new SceneEffectViewController(this.scene, data));
        }
        showLineHandler(data) {
            this.startChild(new SceneLineViewController(this.scene, data));
        }
        stateHandler(data) {
            this.vo.state = ParamUtil.getInt(data, 'state', 1);
            this.dispatchEvent(SceneEvent.SCENE_STATE_CHANGE);
        }
        pauseHandler(data) {
            var type = ParamUtil.getString(data, 'type', 'scene');
            var isPause = ParamUtil.getBool(data, 'isPause');
            if (isPause) {
                this.vo.pauseVo.add(type);
            }
            else {
                this.vo.pauseVo.remove(type);
            }
            this.vo.isPause = this.vo.pauseVo.getValue();
            this.dispatchEvent(SceneEvent.SCENE_PAUSE_RESPONSE);
        }
        exitHandler(data) {
            if (this.vo.state >= 2) {
                return;
            }
            this.vo.state = 2;
            if (data && data.isExit) {
                this.vo.isExit = true;
            }
            this.dispatchEvent(SceneEvent.SCENE_STATE_OVER, { result: -1 });
        }
        close() {
            if (SceneModel.model.camera) {
                this.scene.addChild(SceneModel.model.camera);
            }
            super.close();
            this.dispatchEvent(SceneEvent.SCENE_STATE_END);
        }
    }

    class SceneGoodsVo extends SceneElementVo {
        constructor() {
            super(...arguments);
            this.att = 0;
            this.attPro = 0;
            this.hp = 0;
            this.hpPro = 0;
            this.pickAnim = null;
        }
    }

    class SceneGoodsBuffVo extends SceneGoodsVo {
        constructor() {
            super(...arguments);
            this.invinTime = 0;
            this.attPro = 0;
            this.hpPro = 0;
        }
    }

    class SceneGunVo extends SceneGoodsVo {
        constructor() {
            super(...arguments);
            this.attType = 0;
            this.attStype = 0;
            this.att = 0;
            this.attCd = 100;
            this.attAcc = 0;
            this.attNum = 1;
            this.attTime = 0;
            this.attDis = 0;
            this.attV = 0;
            this.aimType = 0;
            this.info = '';
            this.attBulletNum = 0;
            this.attBulletMax = 30;
            this.attBulletTime = 3000;
            this.attBulletJud = 0.5;
            this.attPierce = 1;
            this.attBulletNumBase = 0;
            this.attBulletMaxBase = 30;
            this.isShowAttLine = true;
            this.checkBullet = false;
            this.bullet = 100;
            this.skill = 0;
            this.attSound = '';
        }
    }

    class SceneUnitVo extends SceneElementVo {
        constructor() {
            super(...arguments);
            this.state = 0;
            this.angle = 0;
            this.actState = 'stand';
            this.dis = 50;
            this.hp = 100;
            this.hpMax = 100;
            this.ep = 0;
            this.epMax = 100;
            this.att = 0;
            this.def = 0;
            this.v = 1;
            this.hpBase = 100;
            this.attBase = 0;
            this.defBase = 0;
            this.attCid = 0;
            this.attVo = null;
            this.skills = [];
            this.skillList = {};
            this.attCd = 100;
            this.attPierce = 1;
            this.checkBullet = false;
            this.bullet = 100;
            this.atterVo = null;
            this.killFlg = false;
            this.dieAnim = '';
            this.isInvin = false;
            this.invinEndTs = 0;
            this.invinTime = 0;
            this.isHide = false;
            this.isMoveLock = false;
            this.isActionLock = false;
            this.attBuffPro = 0;
            this.attPro = 0;
            this.defPro = 0;
            this.hpPro = 0;
            this.vPro = 0;
            this.hitPro = 0;
            this.rvPro = 0;
            this.cdPro = 0;
            this.bnPro = 0;
            this.isPlayer = false;
            this.isDie = false;
            this.isMove = false;
            this.isAtt = false;
            this.isReload = false;
            this.isJump = false;
            this.isFly = false;
            this.isRepel = false;
            this.canRepel = true;
            this.hasShield = true;
            this.canReHp = true;
            this.isShowAttAim = false;
            this.isAutokDir = true;
            this.isAutoRemove = true;
            this.isShowReload = true;
            this.isAutoRevive = false;
            this.dieTs = 0;
            this.followId = 0;
            this.isHit = false;
        }
        getSkillVo(cid) {
            return this.skillList[cid];
        }
        get isGrounded() {
            if (this.unitController) {
                return this.unitController.isGrounded;
            }
            return true;
        }
    }

    class SceneNpcVo extends SceneUnitVo {
        constructor() {
            super(...arguments);
            this.attPollTime = 1000;
            this.movePollTime = 5000;
            this.moveWeight = 0.9;
            this.npcPatrolType = 1;
            this.isAtt = true;
        }
    }

    class ScenePlayerVo extends SceneUnitVo {
        constructor() {
            super(...arguments);
            this.isAim = false;
            this.aimType = 1;
            this.visType = 3;
            this.cameraZ = -2;
            this.cameraY = 1.8;
            this.isAutoAim = false;
            this.autoAimTs = 0;
        }
    }

    class SceneSkillVo extends SceneElementVo {
        constructor() {
            super(...arguments);
            this.att = 0;
            this.attCd = 100;
            this.attAcc = 0;
            this.attNum = 1;
            this.attTime = 0;
            this.attDis = 0;
            this.attDir = 0;
            this.attAngle = 0;
            this.attV = 1;
            this.skillArea = 0;
            this.skillTriggerArea = 0;
            this.repelDis = 0;
            this.throwDis = 0;
            this.gravity = 0;
            this.isOpenRepel = false;
            this.isSlowDown = false;
            this.skillCdTs = 0;
            this.attSound = '';
            this.hitSound = '';
            this.isShowAttLine = true;
            this.anim = '';
            this.skillUseType = 0;
            this.skillHpRc = 0;
            this.skillDurationTime = 0;
            this.info = '';
        }
    }

    class BitmapText3D extends Laya.Sprite3D {
        constructor() {
            super();
            this.spaceWidth = 10;
            this.maxWidth = 700;
            this.widthGap = 0;
            this.heightGap = 0;
            this.textWidth = 0;
            this.textHeight = 0;
            this.width = 0;
            this.height = 0;
        }
        load(url) {
            this.fontUrl = url;
            BitmapFonts3D.loadFont(url, HandlerUtil.create(this, this.loadCompHandeler, [url]));
        }
        loadCompHandeler(url) {
            if (this.fontUrl == url) {
                this.font = BitmapFonts3D.getFont(url);
                this.showText();
            }
        }
        set text(v) {
            this._text = '' + v;
            this.showText();
        }
        get text() {
            return this._text;
        }
        showText() {
            this.width = 0;
            this.height = 0;
            if (this.font) {
                this.clear();
                if (this._text) {
                    var l = this._text.length;
                    var maxWidth = this.maxWidth;
                    var widthGap = this.width;
                    var heightGap = this.heightGap;
                    var mw = 0;
                    var mh = 0;
                    var cx = 0;
                    var cy = 0;
                    for (var i = 0; i < l; i++) {
                        var c = this._text.charAt(i);
                        if (c == '\n') {
                            cx = 0;
                            cy = mh + heightGap;
                        }
                        else {
                            var img = this.font.getImage(c);
                            if (img) {
                                if (this.spaceWidth && c == ' ') {
                                    img.width = this.spaceWidth;
                                    img.height = this.spaceWidth;
                                }
                                this.addChild(img);
                                if (cx + img.width + widthGap > maxWidth) {
                                    img.x = 0;
                                    img.y = mh + heightGap;
                                    cx = img.x + img.width;
                                    cy = img.y;
                                    mw = Math.max(mw, img.x + img.width);
                                    mh = Math.max(mh, img.y + img.height);
                                }
                                else {
                                    img.x = cx + widthGap;
                                    img.y = cy;
                                    cx = img.x + img.width;
                                    cy = img.y;
                                    mw = Math.max(mw, img.x + img.width);
                                    mh = Math.max(mh, img.y + img.height);
                                }
                            }
                        }
                    }
                    this.width = this.textWidth = mw;
                    this.height = this.textHeight = mh;
                }
            }
        }
        clear() {
            if (this.font) {
                var l = this.numChildren;
                for (var i = 0; i < l; i++) {
                    var view = this.getChildAt(i);
                    this.font.recoverImage(view);
                }
            }
            this.removeChildren();
        }
    }

    class SceneHpTextViewController extends ViewController {
        constructor(element, vo) {
            super();
            this.scale = 0.5;
            this.element = element;
            this.vo = vo;
        }
        run() {
            super.run();
            this.hpBar = DisplayUtil.getChildByName(this.element, 'BarHp');
            if (this.hpBar) {
                this.hpBar.removeChildren();
                var text = this.text = new BitmapText3D();
                text.load('font/white.json');
                text.transform.localScaleX = this.scale;
                text.transform.localScaleZ = this.scale;
                this.hpBar.addChild(text);
                this.addEventListener(SceneUnitEvent.SCENE_UNIT_HP_CHANGE(this.vo.id), this, this.hpHandler);
                this.hpHandler();
            }
        }
        hpHandler() {
            this.text.text = '' + this.vo.hp;
            this.text.transform.localPositionX = -this.text.textWidth * this.text.transform.localScaleX / 2;
            this.text.transform.localPositionZ = -this.text.textHeight * this.text.transform.localScaleZ / 2;
        }
    }

    class SceneNpcDiaViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            TimerUtil.loopTimer(500, this, this.skillHandler);
        }
        skillHandler() {
            if (this.npcVo.hp < this.npcVo.hpMax * 0.3 && !this.npcVo.isPlayer) {
                this.useSkill();
            }
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneGebbiesViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneNpcJettViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneNpcLgoaiViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneNpcMcCartneyViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneElementEffectViewController extends View3DController {
        constructor(parentView, vo) {
            super();
            this.effectId = 0;
            this.turnY = 0;
            this.data = vo;
            this.parentView = parentView;
            this.id = ParamUtil.getInt(vo, 'id', IdUtil.getId());
            var img = ParamUtil.getString(this.data, 'image');
            this.viewURL = SceneConfig.getEffectUrl(img);
            this.isAutoDestroy = false;
        }
        openComplete() {
            super.openComplete();
            this.body = this.view;
            this.body.transform.localPositionX = ParamUtil.getNumber(this.data, 'x', 0);
            this.body.transform.localPositionY = ParamUtil.getNumber(this.data, 'y', 0);
            this.body.transform.localPositionZ = ParamUtil.getNumber(this.data, 'z', 0);
            Display3DUtil.playParticle(this.body);
            var time = ParamUtil.getInt(this.data, 'time', 2000);
            TimerUtil.onceTimer(time, this, this.close);
            this.effectId = ParamUtil.getObject(this.data, 'id', IdUtil.getId());
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_EFFECT_CLOSE(this.effectId), this, this.close);
            this.turnY = ParamUtil.getNumber(this.data, 'turnY', 0);
            if (this.turnY) {
                TimerUtil.loopFrame(1, this, this.trunHandle);
            }
        }
        trunHandle() {
            this.body.transform.localRotationEulerY += this.turnY;
        }
    }

    class SceneElementViewController extends View3DController {
        constructor(scene, vo) {
            super();
            this.haloId = 0;
            this.scene = scene;
            this.vo = vo;
            this.sceneVo = SceneModel.model.vo;
            this.parentView = this.scene;
            this.element = this.view = new Laya.Sprite3D;
            this.vo.transform = this.element.transform;
            this.element.transform.localPositionX = this.vo.ix;
            this.element.transform.localPositionY = this.vo.iy;
            this.element.transform.localPositionZ = this.vo.iz;
            this.element.transform.localRotationEulerY = this.vo.dir;
            this.element.transform.localScaleX = this.vo.scale;
            this.element.transform.localScaleY = this.vo.scale;
            this.element.transform.localScaleZ = this.vo.scale;
            this.url = SceneConfig.getElementUrl(this.vo.image);
            this.isAutoDestroy = false;
        }
        openComplete() {
            super.openComplete();
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_STOP(this.vo.id), this, this.close);
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_RELOAD(this.vo.id), this, this.startLoad);
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(this.vo.id), this, this.addEffectHandler);
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_ACTION_ADD(this.vo.id), this, this.addActionHandler);
            this.addEventListener(SceneElementEvent.SCENE_ELEMENT_ATTR_SET(this.vo.id), this, this.posHandler);
            if (this.vo.isAutoLoad) {
                this.startLoad();
            }
            if (this.vo.durationTime) {
                TimerUtil.onceTimer(this.vo.durationTime, this, this.close);
            }
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_ADDED, { vo: this.vo });
        }
        startLoad() {
            if (this.url) {
                LoaderUtil.load3D(this.url, null, this, this.loadHnadler);
            }
        }
        loadHnadler(obj) {
            if (this.body) {
                ViewPoolUtil.recover(this.body);
            }
            this.body = obj;
            this.body.transform.localScaleX = 1;
            this.body.transform.localScaleY = 1;
            this.body.transform.localScaleZ = 1;
            this.body.transform.localRotationEulerY = 0;
            this.element.addChild(obj);
            this.startAction();
            this.showHalo();
            this.initComplete();
        }
        initComplete() {
        }
        startAction() {
            var list = this.vo.actions;
            for (var k in list) {
                var atc = list[k];
                var clas = SceneViewClassConfig.getClass(atc);
                if (clas) {
                    this.startChild(new clas(this.element, this.vo));
                }
            }
        }
        showHalo() {
            if (this.haloId) {
                this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_CLOSE(this.haloId));
            }
            if (this.vo.halo) {
                this.haloId = IdUtil.getId();
                var img = 'halo_' + this.vo.halo;
                this.addEffectHandler({ id: this.haloId, image: img });
            }
        }
        addEffectHandler(data) {
            this.startChild(new SceneElementEffectViewController(this.element, data));
        }
        addActionHandler(data) {
            var clas = SceneViewClassConfig.getClass(data.action);
            if (clas) {
                this.startChild(new clas(this.element, this.vo));
            }
        }
        posHandler(data) {
            if ('x' in data) {
                this.element.transform.localPositionX = data.x;
            }
            if ('y' in data) {
                this.element.transform.localPositionY = data.y;
            }
            if ('z' in data) {
                this.element.transform.localPositionZ = data.z;
            }
            if ('dir' in data) {
                this.element.transform.localRotationEulerY = this.vo.dir = data.dir;
            }
        }
        close() {
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_CLOSEED(this.vo.id));
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_REMOVEED, { vo: this.vo });
            super.close();
            this.vo.isRemove = true;
        }
    }

    class SceneBuffViewController extends SceneElementViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        initComplete() {
            super.initComplete();
            this.sceneVo.addGoods(this.vo);
            this.element.transform.localScaleX = 2;
            this.element.transform.localScaleY = 2;
            this.element.transform.localScaleZ = 2;
            this.anim = DisplayUtil.getChildByName(this.element, 'anim_1');
            if (this.anim) {
                TimerUtil.loopFrame(1, this, this.loopHandler);
            }
            else {
                TimerUtil.loopFrame(1, this, this.loop2Handler);
            }
        }
        loopHandler() {
            if (this.anim) {
                this.anim.transform.localRotationEulerY++;
            }
        }
        loop2Handler() {
            if (this.element) {
                this.element.transform.localRotationEulerY++;
            }
        }
        close() {
            this.sceneVo.removeGoods(this.vo.id);
            super.close();
        }
    }

    class SceneGoodsViewController extends SceneElementViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.goodsVo = vo;
        }
        initComplete() {
            super.initComplete();
            this.sceneVo.addGoods(this.goodsVo);
            this.element.transform.localScaleX = 1;
            this.element.transform.localScaleY = 1;
            this.element.transform.localScaleZ = 1;
            this.anim = DisplayUtil.getChildByName(this.element, 'anim_1');
            if (this.anim) {
                TimerUtil.loopFrame(1, this, this.loopHandler);
            }
            else {
                TimerUtil.loopFrame(1, this, this.loop2Handler);
            }
        }
        loopHandler() {
            if (this.anim) {
                this.anim.transform.localRotationEulerY++;
            }
        }
        loop2Handler() {
            if (this.element) {
                this.element.transform.localRotationEulerY++;
            }
        }
        close() {
            this.sceneVo.removeGoods(this.vo.id);
            super.close();
        }
    }

    class Hit3DTool {
        static init() {
            if (this.point == null) {
                this.point = new Laya.Vector2();
                this.ray = new Laya.Ray(new Laya.Vector3(), new Laya.Vector3());
                this.hit = new Laya.HitResult();
            }
        }
        static checkCameraHit(scene, camera, x = 0, y = 0, distance, collisonGroup, collisionMask) {
            if (this.point == null) {
                this.init();
            }
            this.point.x = x;
            this.point.y = y;
            camera.viewportPointToRay(this.point, this.ray);
            scene.physicsSimulation.rayCast(this.ray, this.hit, distance, collisonGroup, collisionMask);
            return this.hit;
        }
        static checkCameraHitList(scene, camera, x = 0, y = 0, distance, collisonGroup, collisionMask) {
            if (this.point == null) {
                this.init();
            }
            this.point.x = x;
            this.point.y = y;
            camera.viewportPointToRay(this.point, this.ray);
            var hits = [];
            scene.physicsSimulation.rayCastAll(this.ray, hits, distance, collisonGroup, collisionMask);
            return hits;
        }
        static checkCamera3DHit(scene, camera, x, y, z, distance, collisonGroup, collisionMask) {
            if (this.mdv3 == null) {
                this.mdv3 = new Laya.Vector3();
                this.mdv4 = new Laya.Vector4();
            }
            this.mdv3.x = x;
            this.mdv3.y = y;
            this.mdv3.z = z;
            camera.worldToViewportPoint(this.mdv3, this.mdv4);
            this.point.x = this.mdv4.x * Laya.stage.clientScaleX;
            this.point.y = this.mdv4.y * Laya.stage.clientScaleY;
            camera.viewportPointToRay(this.point, this.ray);
            scene.physicsSimulation.rayCast(this.ray, this.hit, distance, collisonGroup, collisionMask);
            return this.hit;
        }
        static check3DHit(scene, fx, fy, fz, tx, ty, tz, collisonGroup, collisionMask) {
            if (this.point == null) {
                this.init();
            }
            var distance = DisplayUtil.distance3D(fx, fy, fz, tx, ty, tz) + 1;
            this.ray.origin.x = fx;
            this.ray.origin.y = fy;
            this.ray.origin.z = fz;
            this.ray.direction.x = tx - fx;
            this.ray.direction.y = ty - fy;
            this.ray.direction.z = tz - fz;
            Laya.Vector3.normalize(this.ray.direction, this.ray.direction);
            scene.physicsSimulation.rayCast(this.ray, this.hit, distance, collisonGroup, collisionMask);
            return this.hit;
        }
        static checkShapeHit(scene, camera, x = 0, y = 0, distance = 10) {
            if (!this.sphereCollider) {
                this.sphereCollider = new Laya.SphereColliderShape(0.5);
                this.from = new Laya.Vector3(0, 1, 10);
                this.to = new Laya.Vector3(0, 1, -5);
            }
            this.point.x = x;
            this.point.y = y;
            this.from.x = camera.transform.localPositionX;
            this.from.y = camera.transform.localPositionY;
            this.from.z = camera.transform.localPositionZ;
            camera.viewportPointToRay(this.point, this.ray);
            var p = this.getRayPoint(this.ray, distance);
            this.to.x = p.x;
            this.to.y = p.y;
            this.to.z = p.z;
            scene.physicsSimulation.shapeCast(this.sphereCollider, this.from, this.to, this.hit);
            return this.hit;
        }
        static checkShapeHitList(scene, camera, x = 0, y = 0, distance = 10) {
            if (!this.sphereCollider) {
                this.sphereCollider = new Laya.SphereColliderShape(0.5);
                this.from = new Laya.Vector3(0, 1, 10);
                this.to = new Laya.Vector3(0, 1, -5);
            }
            this.point.x = x;
            this.point.y = y;
            this.from.x = camera.transform.localPositionX;
            this.from.y = camera.transform.localPositionY;
            this.from.z = camera.transform.localPositionZ;
            camera.viewportPointToRay(this.point, this.ray);
            var p = this.getRayPoint(this.ray, distance);
            this.to.x = p.x;
            this.to.y = p.y;
            this.to.z = p.z;
            var hit = [];
            scene.physicsSimulation.shapeCastAll(this.sphereCollider, this.from, this.to, hit);
            return hit;
        }
        static getRayPoint(ray, dis) {
            if (this.xzPoint == null) {
                this.xzPoint = new Laya.Vector3(0, 0, 0);
            }
            var ox = ray.origin.x;
            var oy = ray.origin.y;
            var oz = ray.origin.z;
            var dx = ray.direction.x * dis;
            var dy = ray.direction.y * dis;
            var dz = ray.direction.z * dis;
            this.xzPoint.x = dx + ox;
            this.xzPoint.y = dy + oy;
            this.xzPoint.z = dz + oz;
            return this.xzPoint;
        }
    }

    class MapTool {
        static checkLine(map, sx, sy, tx, ty, checkNum = 1) {
            var list = this.getLine(sx, sy, tx, ty);
            var num = 0;
            for (var k in list) {
                var vo = list[k];
                if (this.checkGrid(map, vo.x, vo.y) == false) {
                    num++;
                }
                if (num >= checkNum) {
                    return false;
                }
            }
            return true;
        }
        static checkGrid(map, x, y) {
            x = Math.round(x);
            y = Math.round(y);
            var k = x + "_" + y;
            if (map[k] == 1) {
                return false;
            }
            return true;
        }
        static getLine(sx, sy, tx, ty) {
            var sx = Math.round(sx);
            var sy = Math.round(sy);
            var tx = Math.round(tx);
            var ty = Math.round(ty);
            var dx = Math.round(tx - sx);
            var dy = Math.round(ty - sy);
            var idx = Math.abs(dx);
            var idy = Math.abs(dy);
            var cx = 0;
            var cy = 0;
            var list = [];
            if (dx == 0 && dy == 0) {
                return list;
            }
            else if (idx > idy) {
                for (var i = 1; i < idx; i++) {
                    if (dx > 0) {
                        cx = Math.round(sx + i);
                    }
                    else {
                        cx = Math.round(sx - i);
                    }
                    if (dy == 0) {
                        cy = sy;
                    }
                    else if (dy > 0) {
                        if (dx > 0) {
                            cy = Math.round(i * dy / dx + sy);
                        }
                        else {
                            cy = Math.round(-i * dy / dx + sy);
                        }
                    }
                    else {
                        if (dx > 0) {
                            cy = Math.round(i * dy / dx + sy);
                        }
                        else {
                            cy = Math.round(-i * dy / dx + sy);
                        }
                    }
                    list.push({ x: cx, y: cy });
                }
            }
            else {
                for (var i = 1; i < idy; i++) {
                    if (dy > 0) {
                        cy = Math.round(sy + i);
                    }
                    else {
                        cy = Math.round(sy - i);
                    }
                    if (dx == 0) {
                        cx = sx;
                    }
                    else if (dx > 0) {
                        if (dy > 0) {
                            cx = Math.round(i * dx / dy + sx);
                        }
                        else {
                            cx = Math.round(-i * dx / dy + sx);
                        }
                    }
                    else {
                        if (dy > 0) {
                            cx = Math.round(i * dx / dy + sx);
                        }
                        else {
                            cx = Math.round(-i * dx / dy + sx);
                        }
                    }
                    list.push({ x: cx, y: cy });
                }
            }
            return list;
        }
    }

    class SceneTargetTool {
        static checkTarget(atter) {
            var list = SceneModel.model.vo.unitList;
            var disMin = 0;
            var cvo = null;
            var playerVo = null;
            for (var k in list) {
                var vo = list[k];
                if (vo && vo.isDie == false) {
                    if (vo.isHide == false) {
                        if (vo.camp != atter.camp) {
                            var dis = DisplayUtil.distance(atter.x, atter.z, vo.x, vo.z);
                            if (dis < atter.dis) {
                                if (this.checkHits(atter, vo)) {
                                    if (cvo == null) {
                                        disMin = dis;
                                        cvo = vo;
                                    }
                                    else if (vo.isPlayer) {
                                        playerVo = vo;
                                    }
                                    else if (dis < disMin) {
                                        disMin = dis;
                                        cvo = vo;
                                    }
                                }
                            }
                        }
                    }
                }
            }
            if (cvo) {
                return cvo;
            }
            if (playerVo) {
                if (RandomUtil.randomHit(0.2)) {
                    return playerVo;
                }
            }
            return null;
        }
        static checkHits(atter, defer) {
            var scene = SceneModel.model.scene;
            var hit = Hit3DTool.check3DHit(scene, atter.x, atter.y + 1.8, atter.z, defer.x, defer.y + 1.8, defer.z);
            if (hit && hit.collider) {
                var vo = hit.collider['unitVo'];
                if (vo && vo.id == defer.id) {
                    return true;
                }
            }
            return false;
        }
        static checkHit(atter, defer, pos = null) {
            if (atter.attVo == null) {
                return false;
            }
            if (pos) {
                this.pos.x = pos.position.x;
                this.pos.y = pos.position.y;
                this.pos.z = pos.position.z;
            }
            else {
                this.pos.x = atter.x;
                this.pos.y = atter.y;
                this.pos.z = atter.z;
            }
            var dir = Display3DUtil.angle(defer.x, defer.z, this.pos.x, this.pos.z);
            var dr = Math.abs((dir - atter.dir) % 360);
            if (dr > 120) {
                return false;
            }
            var dis = DisplayUtil.distance(defer.x, defer.z, this.pos.x, this.pos.z);
            if (dis > atter.dis) {
                return false;
            }
            return this.checkLine(this.pos.x, 0, this.pos.z, defer.x, 0, defer.z, atter.attPierce);
        }
        static checkLine(sx, sy, sz, tx, ty, tz, attPierce = 2) {
            var map = SceneModel.model.vo.terrain;
            return MapTool.checkLine(map, sx, sz, tx, tz, attPierce);
        }
        static getStartPoint(sp) {
            this.startPoint.x = sp.x;
            this.startPoint.y = sp.y + 0.1;
            this.startPoint.z = sp.z;
            return this.startPoint;
        }
        static getToPoint(atter, hiter, dir = 0) {
            if (atter.attVo == null) {
                return null;
            }
            if (hiter) {
                this.toPoint.x = hiter.x + MathUtil.randomNumber(-1, 1);
                this.toPoint.y = hiter.y + 1.7;
                this.toPoint.z = hiter.z + MathUtil.randomNumber(-1, 1);
            }
            else {
                var sp = atter.transform.position;
                var dis = 20;
                var dx = MathUtil.sin(dir) * dis;
                var dz = MathUtil.cos(dir) * dis;
                var dy = MathUtil.sin(atter.angle) * dis;
                this.toPoint.x = sp.x + dx;
                this.toPoint.y = sp.y + 1.7 + dy;
                this.toPoint.z = sp.z + dz;
            }
            return this.toPoint;
        }
        static randomEnemy(vo) {
            var list = SceneModel.model.vo.unitList;
            var nlist = [];
            for (var k in list) {
                var tvo = list[k];
                if (tvo.camp != vo.camp) {
                    if (tvo.isHide == false) {
                        nlist.push(tvo);
                    }
                }
            }
            if (nlist.length == 0) {
                return null;
            }
            return RandomUtil.randomItem(nlist);
        }
        static findGoods(vo) {
            var list = SceneModel.model.vo.goodsList;
            var minVo;
            var minDis = 99999999999;
            for (var k in list) {
                var defer = list[k];
                var dis = DisplayUtil.distance(defer.x, defer.z, vo.x, vo.z);
                if (!minVo) {
                    minVo = defer;
                    minDis = dis;
                }
                else if (minDis > dis) {
                    minVo = defer;
                    minDis = dis;
                }
            }
            return minVo;
        }
        static findTargetList(x, z, dis, camp) {
            var list = SceneModel.model.vo.unitList;
            var clist = [];
            for (var k in list) {
                var vo = list[k];
                if (vo && vo.isDie == false) {
                    if (vo.camp != camp) {
                        if (vo.stype == 9 || vo.stype == 8) {
                            var dis1 = DisplayUtil.distance(vo.x, vo.z, x, z);
                            if (dis1 <= dis) {
                                clist.push(vo);
                            }
                        }
                    }
                }
            }
            return clist;
        }
        static findTarget(x, z, dis, camp) {
            var list = SceneModel.model.vo.unitList;
            for (var k in list) {
                var vo = list[k];
                if (vo && vo.isDie == false) {
                    if (vo.camp != camp) {
                        if (vo.stype == 9 || vo.stype == 8) {
                            var dis1 = DisplayUtil.distance(vo.x, vo.z, x, z);
                            if (dis1 <= dis) {
                                return vo;
                            }
                        }
                    }
                }
            }
            return null;
        }
        static findAreaTarege(pvo, dirDiff = 10) {
            var list = SceneModel.model.vo.unitList;
            var dis = pvo.dis;
            var cdir = 0;
            var minDir = 0;
            var minVo;
            for (var k in list) {
                var vo = list[k];
                if (vo && vo.isDie == false) {
                    if (vo.camp != pvo.camp) {
                        if (vo.stype == 9 || vo.stype == 8) {
                            var dis1 = DisplayUtil.distance(vo.x, vo.z, pvo.x, pvo.z);
                            if (dis1 <= dis) {
                                var dir = Display3DUtil.angle(vo.x, vo.z, pvo.x, pvo.z);
                                var cdirDiff = DisplayUtil.angleDiff(dir, pvo.dir);
                                if (Math.abs(cdirDiff) < dirDiff) {
                                    if (minVo == null) {
                                        minVo = vo;
                                        minDir = cdirDiff;
                                        cdir = dir;
                                    }
                                    else if (cdirDiff < minDir) {
                                        minVo = vo;
                                        minDir = cdirDiff;
                                        cdir = dir;
                                    }
                                }
                            }
                        }
                    }
                }
            }
            return minDir;
        }
    }
    SceneTargetTool.pos = new Laya.Vector3();
    SceneTargetTool.startPoint = new Laya.Vector3();
    SceneTargetTool.toPoint = new Laya.Vector3();

    class SceneAttrController extends Controller {
        constructor(element, vo) {
            super();
            this.element = element;
            this.unitVo = vo;
            this.sceneVo = SceneModel.model.vo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT(this.unitVo.id), this, this.unitAttHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_HP_ADD(this.unitVo.id), this, this.hpAddHandler);
        }
        unitAttHandler(data) {
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie == true) {
                return;
            }
            if (this.unitVo.isInvin == true) {
                return;
            }
            var att = this.getDefAtt(data.att);
            var attPro = ParamUtil.getNumber(data, 'attPro', 0);
            if (attPro > 0) {
                att = MathUtil.int(this.unitVo.hpMax * attPro);
            }
            if (this.unitVo.defPro) {
                att = MathUtil.int(att - att * this.unitVo.defPro);
            }
            if (this.unitVo.defPro < 1 && att <= 0) {
                att = 1;
            }
            var atter = data.atter;
            var seckill = data.seckill;
            this.unitVo.hp -= att;
            this.unitVo.hp = MathUtil.int(this.unitVo.hp);
            if (this.unitVo.hp <= 0) {
                this.unitVo.hp = 0;
                this.unitVo.isDie = true;
                this.unitVo.dieTs = TimeUtil.getTimestamp();
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.unitVo.id), { state: 'die' });
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_DIE(this.unitVo.id), { vo: this.unitVo, atter: atter, seckill: seckill });
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_DEATH, { vo: this.unitVo, atter: atter, seckill: seckill });
                if (this.unitVo.dieAnim) {
                    this.dispatchEvent(SceneEvent.SCENE_EFFECT_VIEW_SHOW, { image: this.unitVo.dieAnim, x: this.unitVo.x, y: this.unitVo.y, z: this.unitVo.z, time: 4000 });
                }
                if (this.unitVo.isAutoRemove && this.unitVo.isAutoRevive == false) {
                    TimerUtil.onceTimer(100, this, this.closeHandler);
                }
            }
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_CHANGE(this.unitVo.id), { vo: this.unitVo, type: "att" });
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_CHANGES, { att: att, vo: this.unitVo, atter: atter });
        }
        getDefAtt(att) {
            var att1 = Math.ceil(att * (1 - this.unitVo.def));
            var att2 = MathUtil.int(att1 * (1 - this.unitVo.defPro));
            return att2;
        }
        hpAddHandler(data) {
            var hp = ParamUtil.getInt(data, 'hp');
            this.unitVo.hp += hp;
            if (this.unitVo.hp > this.unitVo.hpMax) {
                this.unitVo.hp = this.unitVo.hpMax;
            }
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_CHANGE(this.unitVo.id), { vo: this.unitVo, type: "add" });
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_CHANGES, { att: 0, vo: this.unitVo, atter: null });
        }
        closeHandler() {
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(this.unitVo.id));
        }
    }

    class SceneSoundTool {
        static playDisSound(vo, sound, volume = 1) {
            var playerVo = SceneModel.model.vo.playerVo;
            if (playerVo) {
                var dis = DisplayUtil.distance(vo.x, vo.z, playerVo.x, playerVo.z);
                if (dis < 10) {
                    var v = (10 - dis) / 10 * volume;
                    SoundTool.playSound(sound, v, 100);
                }
            }
            else {
                var camera = SceneModel.model.camera;
                var pos = camera.transform.position;
                var dis = DisplayUtil.distance(vo.x, vo.z, pos.x, pos.z);
                if (dis < 10) {
                    var v = (10 - dis) / 10 * volume;
                    SoundTool.playSound(sound, v, 100);
                }
            }
        }
    }

    class SceneGunAttController extends Controller {
        constructor(element, vo) {
            super();
            this.attTs = 0;
            this.element = element;
            this.unitVo = vo;
            this.sceneVo = SceneModel.model.vo;
        }
        run() {
            super.run();
            if (!this.unitVo.attVo) {
                return;
            }
            if (!this.unitVo.attVo.skill) {
                return;
            }
            this.fireBox = DisplayUtil.getChildByName(this.element, 'fireBox');
            if (this.fireBox) {
                this.fireBox.removeChildren();
            }
            this.initFire();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_START(this.unitVo.id), this, this.doAttTimer);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_GUN_ATT_STOP(this.unitVo.id), this, this.stopAtt);
            this.addEventListener(SceneGunEvent.SCENE_GUN_RELOAD(this.unitVo.id), this, this.reloadBullet);
            this.addEventListener(SceneGunEvent.SCENE_GUN_RELOAD_STOP(this.unitVo.id), this, this.stopReloadBullet);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.unitVo.id), this, this.skillUseHandler);
        }
        stopAtt() {
            if (this.unitVo.isAtt) {
                this.unitVo.isAtt = false;
                TimerUtil.stopTimer(this, this.attHandler);
            }
        }
        doAttTimer(data) {
            if (this.unitVo.isReload) {
                return;
            }
            if (this.unitVo.isAtt == false) {
                this.unitVo.isAtt = true;
                var attCd = this.getAttCd();
                TimerUtil.loopTimer(attCd, this, this.attHandler);
                this.attHandler();
            }
        }
        attHandler() {
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isActionLock) {
                return;
            }
            var ct = TimeUtil.getTime();
            var attCd = this.getAttCd();
            if (ct - this.attTs < attCd - 50) {
                return;
            }
            this.attTs = ct;
            if (this.unitVo.isDie) {
                this.stopAtt();
                return;
            }
            this.attToDir();
        }
        attToDir() {
            var gun = this.unitVo.attVo;
            if (!gun) {
                return;
            }
            if (this.unitVo.isReload) {
                return;
            }
            if (gun.attBulletNum <= 0) {
                this.reloadBullet();
                return;
            }
            var attDir = this.unitVo.dir;
            if (gun.attNum == 1) {
                this.addBullet(attDir);
            }
            else {
                var diff = 5;
                var dirs = (gun.attNum - 1) * diff / 2;
                for (var i = 0; i < gun.attNum; i++) {
                    var dir = diff * i - dirs + attDir;
                    this.addBullet(dir);
                }
            }
            gun.attBulletNum--;
            this.dispatchEvent(SceneGunEvent.SCENE_UNIT_BULLET_CHANGE(this.unitVo.id));
        }
        addBullet(dir) {
            if (this.sceneVo.isPause) {
                return;
            }
            var gun = this.unitVo.attVo;
            if (gun) {
                var hitVo = this.unitVo.targetVo;
                var skillVo = SceneVoBuilder.getElementVo(gun.skill);
                skillVo.camp = this.unitVo.camp;
                skillVo.atterVo = this.unitVo;
                skillVo.targetVo = hitVo;
                skillVo.attDir = dir;
                skillVo.attAngle = this.unitVo.angle;
                if (this.fireBox) {
                    skillVo.startPoint = this.fireBox.transform.position;
                }
                this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.unitVo.id), { hitVo: hitVo });
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_CAMERA_SHOCK(this.unitVo.id), { hitVo: hitVo });
                if (gun.attSound) {
                    SceneSoundTool.playDisSound(this.unitVo, gun.attSound);
                }
                this.showFire(hitVo);
            }
        }
        reloadBullet() {
            if (this.unitVo.isActionLock) {
                return;
            }
            var gun = this.unitVo.attVo;
            if (gun && gun.attBulletNum < gun.attBulletMax) {
                if (this.unitVo.checkBullet == false || SceneGoodsTool.getBulletNum(this.unitVo) > 0) {
                    this.unitVo.isReload = true;
                    var attBulletTime = this.getAttBulletTime();
                    TimerUtil.onceTimer(attBulletTime, this, this.reloadBulletTimerHandler);
                    this.dispatchEvent(SceneGunEvent.SCENE_GUN_RELOAD_START(this.unitVo.id), { time: attBulletTime });
                    if (this.unitVo.isShowReload) {
                        this.playAnim('reload');
                    }
                }
                else {
                    this.dispatchEvent(SceneGunEvent.SCENE_GUN_BULLET_EXHAUST(this.unitVo.id));
                }
            }
        }
        stopReloadBullet() {
            this.unitVo.isReload = false;
            TimerUtil.stopTimer(this, this.reloadBulletTimerHandler);
            this.dispatchEvent(SceneGunEvent.SCENE_GUN_RELOAD_STOP(this.unitVo.id));
        }
        reloadBulletTimerHandler() {
            this.unitVo.isReload = false;
            var gun = this.unitVo.attVo;
            if (!gun) {
                return;
            }
            if (gun.attBulletNum < gun.attBulletMax) {
                var lnum = gun.attBulletMax - gun.attBulletNum;
                if (this.unitVo.checkBullet) {
                    var num = SceneGoodsTool.getBulletNum(this.unitVo);
                    if (num >= lnum) {
                        SceneGoodsTool.subBulletNum(this.unitVo, lnum);
                        gun.attBulletNum = gun.attBulletMax;
                    }
                    else {
                        SceneGoodsTool.subBulletNum(this.unitVo, num);
                        gun.attBulletNum += num;
                    }
                }
                else {
                    gun.attBulletNum = gun.attBulletMax;
                }
                this.dispatchEvent(SceneGunEvent.SCENE_UNIT_BULLET_CHANGE(this.unitVo.id));
                this.dispatchEvent(SceneGunEvent.SCENE_GUN_RELOAD_CONPLETE(this.unitVo.id));
            }
            this.playAnim();
        }
        initFire() {
            var url = SceneConfig.getEffectUrl('fire');
            LoaderUtil.load3D(url, null, this, this.fireLoadHandler);
        }
        fireLoadHandler(obj) {
            this.fireBody = obj;
        }
        showFire(hitVo) {
            if (this.fireBody && this.fireBox) {
                this.fireBox.addChild(this.fireBody);
                this.fireBody.transform.localRotationEulerZ = MathUtil.randomInt(0, 360);
                TimerUtil.onceFrame(1, this, this.unLauchsHandler);
            }
        }
        unLauchsHandler() {
            this.fireBody.removeSelf();
        }
        skillUseHandler(data) {
            if (this.unitVo.isActionLock) {
                return;
            }
            var cid = ParamUtil.getInt(data, 'cid');
            var skillVo = this.unitVo.getSkillVo(cid);
            if (SceneSkillTool.checkSkill(skillVo) == 'ok') {
                skillVo.skillCdTs = TimeUtil.getLocalTime();
                this.skillUse(cid);
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE_COMPLETE(skillVo.id));
            }
        }
        skillUse(cid) {
            var skillVo = SceneVoBuilder.getElementVo(cid);
            skillVo.camp = this.unitVo.camp;
            skillVo.atterVo = this.unitVo;
            skillVo.targetVo = null;
            skillVo.attDir = this.unitVo.dir;
            skillVo.attAngle = this.unitVo.angle;
            if (this.fireBox) {
                skillVo.startPoint = this.fireBox.transform.position;
            }
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
        }
        playAnim(anim = null) {
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ANIM_PLAY(this.unitVo.id), { anim: anim });
        }
        getAttBulletTime() {
            var v = this.unitVo.attVo.attBulletTime * (1 - this.unitVo.rvPro);
            if (v < 100) {
                v = 100;
            }
            return v;
        }
        getAttCd() {
            var v = this.unitVo.attCd * (1 - this.unitVo.cdPro);
            if (v < 100) {
                v = 100;
            }
            return v;
        }
    }

    class SceneBuffEvent {
        static SCENE_BUFF_ADD(id) { return 'SCENE_BUFF_ADD@' + id; }
        ;
        static SCENE_BUFF_REMOVE(id) { return 'SCENE_BUFF_REMOVE@' + id; }
        ;
    }

    class SceneBuffVo {
        constructor() {
            this.vPro = 0;
            this.attPro = 0;
            this.list = {};
        }
        addBuff(id, buffType, value, time) {
            if (!id) {
                id = IdUtil.getId();
            }
            if (time) {
                var endTs = TimeUtil.getTime() + time;
            }
            else {
                var endTs = 0;
            }
            this.list[id] = { id: id, buffType: buffType, value: value, time: time, endTs: endTs };
        }
        removeBuff(id) {
            delete this.list[id];
        }
    }

    class SceneBuffController extends Controller {
        constructor(element, vo) {
            super();
            this.vo = vo;
            if (!this.vo.buffVo) {
                this.vo.buffVo = new SceneBuffVo;
            }
        }
        run() {
            super.run();
            this.addEventListener(SceneBuffEvent.SCENE_BUFF_ADD(this.vo.id), this, this.buffAddHandler);
            this.addEventListener(SceneBuffEvent.SCENE_BUFF_REMOVE(this.vo.id), this, this.buffRemoveHandler);
        }
        buffAddHandler(data) {
            this.vo.buffVo.addBuff(data.id, data.buffType, data.value, data.time);
            this.checkBuff();
        }
        buffRemoveHandler(data) {
            this.vo.buffVo.removeBuff(data.id);
            this.checkBuff();
        }
        checkBuff() {
            var list = this.vo.buffVo.list;
            var nlist = {};
            var time = 0;
            var ts = TimeUtil.getTime();
            var attrLib = {};
            for (var k in list) {
                var buff = list[k];
                var endTs = buff.endTs;
                if (endTs == 0 || endTs > ts) {
                    var buffType = buff.buffType;
                    var value = ParamUtil.getNumber(attrLib, buffType, 0);
                    attrLib[buffType] = value + buff.value;
                    nlist[buff.id] = buff;
                    if (time == 0) {
                        time = endTs;
                    }
                    else if (endTs < time) {
                        time = endTs;
                    }
                }
            }
            this.vo.buffVo.list = nlist;
            this.vo.buffVo.vPro = ParamUtil.getNumber(attrLib, 'vPro', 0);
            this.vo.buffVo.attPro = ParamUtil.getNumber(attrLib, 'attPro', 0);
            this.vo.isMoveLock = ParamUtil.getBool(attrLib, 'isMoveLock', false);
            this.vo.isActionLock = ParamUtil.getBool(attrLib, 'isActionLock', false);
            var isHide = ParamUtil.getBool(attrLib, 'isHide', false);
            if (isHide != this.vo.isHide) {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HIDE(this.vo.id), { isHide: isHide });
            }
            if (time) {
                var t = endTs - ts;
                TimerUtil.onceTimer(t, this, this.checkBuff);
            }
        }
    }

    class SceneUnitViewController extends SceneElementViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.fly = new Laya.Vector3(0, 30, 0);
            this.repel = new Laya.Vector3(0, 5, 0);
            this.repelV3 = new Laya.Vector3(0, 0, 0);
            this.moveV3 = new Laya.Vector3(0, 0, 0);
            this.isMove = false;
            this.moveDir = 0;
            this.isMoveDir = false;
            this.moveX = 0;
            this.moveZ = 0;
            this.isMoveTo = false;
            this.attDir = 0;
            this.animName = '';
            this.unitVo = vo;
            this.url = SceneConfig.getUnitUrl(vo.image);
            this.sceneVo.addUnit(this.unitVo);
        }
        initComplete() {
            super.initComplete();
            var character = this.element.addComponent(Laya.CharacterController);
            var r = this.unitVo.scale * 0.5;
            var h = this.unitVo.scale * 1.8;
            var sphereShape = new Laya.BoxColliderShape(r, h, r);
            sphereShape.localOffset = new Laya.Vector3(0, h / 2, 0);
            character.colliderShape = sphereShape;
            character.restitution = 0;
            if (this.unitVo.camp == 1) {
                character.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER2;
                character.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER5;
            }
            else {
                character.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER3;
                character.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER4;
            }
            character['unitVo'] = this.unitVo;
            this.unitVo.unitController = this.unitController = character;
            this.unitAnim = DisplayUtil.getComponent(this.element, Laya.Animator);
            this.playAnim(this.unitVo.actState);
            this.startChild(new SceneGunAttController(this.element, this.unitVo));
            this.startChild(new SceneAttrController(this.element, this.unitVo));
            this.startChild(new SceneBuffController(this.element, this.unitVo));
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_STOP(this.unitVo.id), this, this.stopAtt);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ANIM_PLAY(this.unitVo.id), this, this.animPlayHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_FLY(this.unitVo.id), this, this.doFly);
            this.addEventListener(SceneEvent.SCENE_STATE_OVER, this, this.doStand);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_JUMP(this.unitVo.id), this, this.duJump);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_REPEL(this.unitVo.id), this, this.repelHadnler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.unitVo.id), this, this.actHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_DIR_SET(this.unitVo.id), this, this.dirHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_TARGET(this.unitVo.id), this, this.attTargetHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_HIDE(this.unitVo.id), this, this.hideHandler);
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ADDED, { vo: this.unitVo });
        }
        actHandler(data) {
            var state = data.state;
            if (state == 'stand') {
                this.doStand();
            }
            else if (state == 'move') {
                this.doMove(data.dir);
            }
            else if (state == 'att') {
                this.doAtt(data.dir);
            }
            else if (state == 'hit') {
                this.doHit(data.dir);
            }
            else if (state == 'skill') {
                this.doSkill(data.anim);
            }
            else if (state == 'victory') {
                this.doVictory();
            }
            else if (state == 'die') {
                this.doDie();
            }
        }
        doStand() {
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isGrounded == false) {
                return;
            }
            if (this.unitVo.isFly) {
                return;
            }
            if (this.unitVo.isRepel) {
                return;
            }
            this.isMove = false;
            this.moveV3.x = 0;
            this.moveV3.z = 0;
            this.playAnim('stand');
            this.stopMove();
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_STAND(this.unitVo.id));
        }
        duJump() {
            if (this.unitVo.isFly) {
                return;
            }
            if (this.unitVo.isRepel) {
                return;
            }
            if (this.unitVo.isMoveLock) {
                return;
            }
            if (this.unitVo.isActionLock) {
                return;
            }
            if (this.unitVo.isGrounded) {
                this.unitVo.isJump = true;
                this.playAnim('jump');
                if (this.unitController) {
                    this.unitController.jump();
                }
                TimerUtil.loopFrame(1, this, this.jumpHandler);
            }
        }
        jumpHandler() {
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isGrounded) {
                this.unitVo.isJump = false;
                TimerUtil.stopTimer(this, this.jumpHandler);
                this.refershAnim();
            }
        }
        doFly() {
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isGrounded == false) {
                return;
            }
            if (this.unitVo.isRepel) {
                return;
            }
            if (this.unitVo.isMoveLock) {
                return;
            }
            if (this.unitVo.isActionLock) {
                return;
            }
            if (this.unitVo.isGrounded) {
                this.unitVo.isFly = true;
                this.playAnim('stand');
                if (this.unitController) {
                    this.unitController.jump(this.fly);
                }
                TimerUtil.loopFrame(1, this, this.flyHandler);
                this.showFlyEffect();
            }
        }
        flyHandler() {
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isGrounded) {
                this.unitVo.isFly = false;
                TimerUtil.stopTimer(this, this.flyHandler);
                this.refershAnim();
                this.closeFlyEffect();
            }
        }
        showFlyEffect() {
            this.flyEffectId = IdUtil.getId();
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(this.vo.id), { id: this.flyEffectId, image: 'fly', time: 5000 });
        }
        closeFlyEffect() {
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_CLOSE(this.flyEffectId));
            this.flyEffectId = 0;
        }
        doRepel(dir, dis, v = 1, h = 0) {
            if (!this.unitVo.canRepel) {
                return;
            }
            if (this.unitVo.isRepel) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (!dis || !v) {
                return;
            }
            this.unitVo.isRepel = true;
            var time = dis / v * 1000;
            this.repelV3.x = MathUtil.sin(dir) * v / 60;
            this.repelV3.z = MathUtil.cos(dir) * v / 60;
            if (this.unitController) {
                this.unitController.move(this.repelV3);
            }
            TimerUtil.onceTimer(time, this, this.repelEndHandler);
            if (h) {
                this.repel.y = h;
                if (this.unitController) {
                    this.unitController.jump(this.repel);
                }
            }
        }
        repelEndHandler() {
            this.unitVo.isRepel = false;
            this.repelV3.x = 0;
            this.repelV3.y = 0;
            this.repelV3.z = 0;
            if (this.unitController) {
                this.unitController.move(this.repelV3);
            }
        }
        repelHadnler(data) {
            var dir = ParamUtil.getNumber(data, 'dir', 0);
            var dis = ParamUtil.getNumber(data, 'dis', 0);
            var v = ParamUtil.getNumber(data, 'v', 0);
            var h = ParamUtil.getNumber(data, 'h', 0);
            this.doRepel(dir, dis, v, h);
        }
        doMove(dir) {
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isRepel) {
                return;
            }
            if (this.unitVo.isMoveLock) {
                return;
            }
            if (this.unitVo.isActionLock) {
                return;
            }
            this.stopMove();
            this.isMoveDir = true;
            var v = this.getV();
            this.moveV3.x = MathUtil.sin(dir) * v;
            this.moveV3.z = MathUtil.cos(dir) * v;
            if (this.unitController) {
                this.unitController.move(this.moveV3);
            }
            else {
                TimerUtil.loopFrame(1, this, this.timerHandler);
            }
            this.moveDir = dir;
            this.showDir();
            if (this.unitVo.isFly) {
            }
            else if (this.isMove == false) {
                this.isMove = true;
                this.playAnim('run');
            }
        }
        timerHandler() {
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isMoveLock) {
                this.doStand();
                return;
            }
            if (this.unitVo.isActionLock) {
                this.doStand();
                return;
            }
            var sx = Math.round(this.element.transform.localPositionX);
            var sz = Math.round(this.element.transform.localPositionZ);
            var x = this.element.transform.localPositionX + this.moveV3.x;
            var z = this.element.transform.localPositionZ + this.moveV3.z;
            if (SceneTerrainTool.check(x, z)) {
                this.element.transform.localPositionX = x;
                this.element.transform.localPositionZ = z;
            }
            else if (SceneTerrainTool.check(sx, z)) {
                this.element.transform.localPositionZ = z;
            }
            else if (SceneTerrainTool.check(x, sz)) {
                this.element.transform.localPositionX = x;
            }
            else {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_OBST(this.unitVo.id));
            }
        }
        playMoveSound() {
            if (this.isMove) {
                this.playDisSound('move', 0.5);
                TimerUtil.onceTimer(350, this, this.playMoveSound);
            }
        }
        moveToPath(path) {
            this.path = path;
            this.movePathNext();
        }
        movePathNext() {
            if (this.path && this.path.length > 0) {
                var point = this.path.shift();
                this.moveTo(point.x, point.y);
            }
            else {
                this.doStand();
            }
        }
        moveTo(x, z) {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isRepel) {
                return;
            }
            if (this.unitVo.isMoveLock) {
                return;
            }
            if (this.unitVo.isActionLock) {
                return;
            }
            this.stopMove();
            this.moveX = x;
            this.moveZ = z;
            var dis = DisplayUtil.distance(this.unitVo.x, this.unitVo.z, x, z);
            if (dis > 0) {
                var dir = Display3DUtil.angle(this.unitVo.x, this.unitVo.z, x, z) + 180;
                if (dir) {
                    this.moveDir = dir;
                    this.showDir();
                }
                var v = this.getV();
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_MOVE(this.unitVo.id), { dir: dir, v: v });
                if (this.isMove == false) {
                    this.isMove = true;
                    this.playAnim('run');
                }
                this.moveV3.x = MathUtil.sin(dir) * v;
                this.moveV3.z = MathUtil.cos(dir) * v;
                this.isMoveTo = true;
                TimerUtil.loopFrame(1, this, this.timerToHandler);
            }
            else {
                this.movePathNext();
            }
        }
        timerToHandler() {
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isMoveLock) {
                this.doStand();
                return;
            }
            if (this.unitVo.isActionLock) {
                this.doStand();
                return;
            }
            var x = this.element.transform.localPositionX + this.moveV3.x;
            var z = this.element.transform.localPositionZ + this.moveV3.z;
            var v = this.getV();
            var dis = DisplayUtil.distance(this.moveX, this.moveZ, x, z);
            if (dis <= v) {
                this.isMove = false;
                this.isMoveTo = false;
                this.element.transform.localPositionX = this.moveX;
                this.element.transform.localPositionZ = this.moveZ;
                this.movePathNext();
            }
            else {
                this.element.transform.localPositionX = x;
                this.element.transform.localPositionZ = z;
            }
        }
        stopMove() {
            this.isMove = false;
            if (this.isMoveDir == true) {
                this.isMoveDir = false;
                this.moveV3.x = 0;
                this.moveV3.y = 0;
                this.moveV3.z = 0;
                if (this.unitController) {
                    this.unitController.move(this.moveV3);
                }
                else {
                    TimerUtil.stopTimer(this, this.timerHandler);
                }
            }
            if (this.isMoveTo) {
                this.isMoveTo = false;
                TimerUtil.stopTimer(this, this.timerToHandler);
            }
        }
        attTargetHandler(data) {
            this.attTarget(data.target);
        }
        attTarget(vo) {
            this.unitVo.targetVo = vo;
            if (this.unitVo.isDie) {
                this.stopAtt();
                return;
            }
            if (!vo) {
                this.stopAtt();
                return;
            }
            if (vo.isDie) {
                this.stopAtt();
                return;
            }
            if (this.unitVo.isMoveLock) {
                this.stopAtt();
                return;
            }
            if (this.unitVo.isActionLock) {
                this.stopAtt();
                return;
            }
            var dir = Display3DUtil.angle(vo.x, vo.z, this.unitVo.x, this.unitVo.z);
            this.doAtt(dir);
        }
        doAtt(dir = 0) {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.unitVo.isDie) {
                return;
            }
            if (this.unitVo.isReload) {
                return;
            }
            if (this.unitVo.isActionLock) {
                return;
            }
            this.attDir = dir;
            this.showDir();
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT_START(this.unitVo.id), { dir: this.attDir });
        }
        stopAtt() {
            this.unitVo.targetVo = null;
            this.showDir();
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_GUN_ATT_STOP(this.unitVo.id));
        }
        showDir() {
            if (this.unitVo.isAutokDir) {
                if (this.unitVo.isAtt) {
                    var dir = this.attDir;
                }
                else {
                    var dir = this.moveDir;
                }
                this.element.transform.localRotationEulerY = this.unitVo.dir = dir;
            }
        }
        doSkill(anim) {
            if (anim) {
                this.playAnim(anim);
            }
            else {
                this.playAnim('skill');
            }
            TimerUtil.onceTimer(800, this, this.refershAnim);
        }
        doHit(dir) {
            dir += 90;
            var x = MathUtil.sin(dir) * 5;
            var z = MathUtil.cos(dir) * 5;
            TweenUtil.to(this, this.element.transform, { localRotationEulerX: x, localRotationEulerZ: z }, 200, Laya.Ease.quadInOut, this.doHitEndHandler);
        }
        doHitEndHandler() {
            TweenUtil.to(this, this.element.transform, { localRotationEulerX: 0, localRotationEulerZ: 0 }, 200, Laya.Ease.quadInOut);
        }
        doDie() {
            this.unitVo.isDie = true;
            this.stopMove();
            this.playAnim('die');
        }
        dirHandler(data) {
            this.attDir = data.dir;
            this.showDir();
        }
        doVictory() {
            this.playAnim('victory');
        }
        hideHandler(data) {
            var isHide = ParamUtil.getBool(data, 'isHide', false);
            if (isHide != this.unitVo.isHide) {
                this.unitVo.isHide = isHide;
                if (this.unitVo.isHide) {
                    Display3DUtil.setDisplayAlpha(this.body, 0.5);
                }
                else {
                    Display3DUtil.setDisplayAlpha(this.body, 1);
                }
            }
        }
        animPlayHandler(data) {
            var anim = data.anim;
            if (anim) {
                this.playAnim(anim);
            }
            else {
                this.refershAnim();
            }
        }
        refershAnim() {
            if (this.unitVo.isDie == false) {
                if (this.unitVo.isFly) {
                    this.playAnim('stand');
                }
                else if (this.isMove) {
                    this.playAnim('run');
                }
                else {
                    this.playAnim('stand');
                }
            }
        }
        playDisSound(sound, volume = 1) {
            var playerVo = this.sceneVo.playerVo;
            var dis = DisplayUtil.distance(this.unitVo.x, this.unitVo.z, playerVo.x, playerVo.z);
            if (dis < 10) {
                var v = (10 - dis) / 10 * volume;
                SoundTool.playSound(sound, v, 100);
            }
        }
        playAnim(name = null, time = 0.1, startTime = 0, speed = 1) {
            var oldName = this.animName;
            if (!name) {
                name = this.animName;
            }
            else {
                this.animName = name;
            }
            if (this.unitAnim) {
                if (name == 'run' || name == 'stand') {
                    if (name != oldName) {
                        this.unitAnim.crossFade(name, time, 0, startTime);
                    }
                }
                else {
                    this.unitAnim.crossFade(name, time, 0, startTime);
                }
            }
        }
        close() {
            this.sceneVo.removeUnit(this.unitVo.id);
            super.close();
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REMOVEED, { vo: this.unitVo });
        }
        getV() {
            var v = this.unitVo.v * (this.unitVo.vPro + this.unitVo.buffVo.vPro + 1) * 0.1;
            if (this.unitVo.isFly) {
                v = v * 3;
            }
            return v;
        }
    }

    class SceneNpcViewController extends SceneUnitViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.enemyTs = 0;
            this.countAttTs = 0;
            this.npcVo = vo;
        }
        initComplete() {
            super.initComplete();
            this.addEventListener(SceneEvent.SCENE_STATE_READY, this, this.startHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_CHANGE, this, this.startHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT(this.npcVo.id), this, this.attTarHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_OBST(this.npcVo.id), this, this.onCollisionHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_DIE(this.npcVo.id), this, this.dieHandler);
            this.startHandler();
        }
        startHandler() {
            if (this.sceneVo.state == 1) {
                if (this.npcVo.attVo && this.npcVo.attVo.skill) {
                    var time = this.npcVo.movePollTime + RandomUtil.randomInt(-500, 500);
                    TimerUtil.loopTimer(time, this, this.moveAct);
                    var time = this.npcVo.attPollTime + RandomUtil.randomInt(-500, 500);
                    TimerUtil.loopTimer(time, this, this.attTimerHandler);
                }
            }
        }
        moveAct() {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.sceneVo.isPause) {
                return;
            }
            if (this.npcVo.isDie) {
                return;
            }
            if (RandomUtil.randomHit(0.9) || this.enemyVo) {
                if (this.findEnemy()) {
                    return;
                }
            }
            if (RandomUtil.randomHit(0.9)) {
                if (this.randomMove()) {
                    return;
                }
            }
            this.doStand();
        }
        findEnemy() {
            if (this.enemyVo) {
                if (this.enemyVo.isDie) {
                    this.enemyVo = null;
                }
            }
            var ts = TimeUtil.getTime();
            if (ts - this.enemyTs > 30000) {
                this.enemyVo = null;
            }
            if (this.enemyVo) {
                var enemy = this.enemyVo;
            }
            else {
                var enemy = SceneTargetTool.randomEnemy(this.npcVo);
                this.enemyVo = enemy;
                this.enemyTs = ts;
            }
            if (enemy) {
                var path = SceneFindPathTool.findPath(this.npcVo.x, this.npcVo.z, enemy.x, enemy.z, 10, 8);
                if (path) {
                    this.moveToPath(path);
                    return true;
                }
                console.log("npc:查找敌人.没有找到路径:" + this.npcVo.x + ',' + this.npcVo.z + ',' + enemy.x + ',' + enemy.z);
            }
            else {
                console.log("npc:没有找到敌人");
            }
            return false;
        }
        randomMove() {
            var p = SceneTerrainTool.randomPos(this.npcVo.x, this.npcVo.z);
            if (p) {
                var path = SceneFindPathTool.findPathTo(this.npcVo.x, this.npcVo.z, p.x, p.z, 10, 1);
                if (path) {
                    this.moveToPath(path);
                    return true;
                }
                console.log("npc:随机移动.没有找到路径" + this.npcVo.x + ',' + this.npcVo.z + ',' + p.x + ',' + p.z);
            }
            else {
                console.log("npc:随机移动.没有随机到合适的点");
            }
            return false;
        }
        attTarHandler(data) {
            if (!this.npcVo.attVo) {
                return;
            }
            if (!this.npcVo.attVo.skill) {
                return;
            }
            var atter = data.atter;
            if (!atter) {
                return;
            }
            if (atter.stype == 6) {
                this.moveAct();
                return;
            }
            var ts = TimeUtil.getLocalTime();
            if (ts - this.countAttTs > 1000) {
                this.countAttTs = ts;
                TimerUtil.onceTimer(2000, this, this.attTarget, [atter]);
            }
        }
        onCollisionHandler() {
            this.moveAct();
        }
        attTimerHandler() {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.npcVo.isDie) {
                return;
            }
            var hitVo = SceneTargetTool.checkTarget(this.npcVo);
            if (hitVo) {
                this.attTarget(hitVo);
            }
            else {
                this.stopAtt();
            }
        }
        dieHandler() {
            if (this.npcVo.isAutoRevive) {
                TimerUtil.onceTimer(SceneConfig.reviveTime * 1000, this, this.reviveHandler);
            }
        }
        reviveHandler() {
            if (this.sceneVo.state != 1) {
                return;
            }
            this.npcVo.isAtt = false;
            this.npcVo.isReload = false;
            this.npcVo.hp = this.npcVo.hpMax;
            this.npcVo.isDie = false;
            var p = SceneTerrainTool.redomPosCamp(this.npcVo.campType);
            this.element.transform.localPositionX = p.x;
            this.element.transform.localPositionY = p.y;
            this.element.transform.localPositionZ = p.z;
            this.playAnim('stand', 0.01);
            this.doStand();
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_CHANGE(this.unitVo.id), { vo: this.unitVo, type: "revive" });
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_CHANGES, { att: 0, vo: this.unitVo, atter: null });
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REVIVED(this.npcVo.id));
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REVIVED_COMPLETE);
        }
    }

    class SceneHitTool {
        static checkHitss(atter, pos = null) {
            var scene = SceneModel.model.scene;
            var camera = SceneModel.model.camera;
            var x = Laya.stage.width / 2;
            var y = Laya.stage.height / 2;
            var hit = Hit3DTool.checkCameraHit(scene, camera, x, y, 100);
            if (hit && hit.collider) {
                var vo = hit.collider['unitVo'];
                if (vo && vo.isDie == false && vo.camp != atter.camp) {
                    return vo;
                }
            }
            return null;
        }
        static checkHitTarget(atter, target) {
            var scene = SceneModel.model.scene;
            var camera = SceneModel.model.camera;
            var pos = camera.transform.position;
            var collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER4;
            var hit = Hit3DTool.check3DHit(scene, pos.x, pos.y, pos.z, target.x, target.y + 1.5, target.z, collisionGroup);
            if (hit && hit.collider) {
                var vo = hit.collider['unitVo'];
                if (vo && vo.isDie == false && vo.camp != atter.camp) {
                    return vo;
                }
            }
            return null;
        }
        static checkHits(atter, pos = null) {
            var list = SceneModel.model.vo.unitList;
            for (var k in list) {
                var vo = list[k];
                if (vo && vo.isDie == false) {
                    if (vo.camp != atter.camp) {
                        if (this.checkHit(atter, vo, pos)) {
                            return vo;
                        }
                    }
                }
            }
            return null;
        }
        static checkHit(atter, defer, pos) {
            if (pos) {
                this.pos.x = pos.position.x;
                this.pos.y = pos.position.y;
                this.pos.z = pos.position.z;
            }
            else {
                this.pos.x = atter.x;
                this.pos.y = atter.y;
                this.pos.z = atter.z;
            }
            var dir = Display3DUtil.angle(defer.x, defer.z, this.pos.x, this.pos.z);
            var dr = Math.abs((dir - atter.dir) % 360);
            if (dr > atter.dis - 2) {
                return false;
            }
            var dis = DisplayUtil.distance(defer.x, defer.z, this.pos.x, this.pos.z);
            if (dis > atter.dis - 5) {
                return false;
            }
            var ady = dis * MathUtil.tan(atter.angle);
            var dy = defer.y - this.pos.y;
            if (Math.abs(ady - dy) < 1) {
                return false;
            }
            var ds = Math.abs(dis * MathUtil.tan(dr));
            if (ds > 0.6) {
                return false;
            }
            return this.checkLine(this.pos.x, 0, this.pos.z, defer.x, 0, defer.z, atter.attPierce);
        }
        static checkLine(sx, sy, sz, tx, ty, tz, attPierce) {
            var map = SceneModel.model.vo.terrain;
            return MapTool.checkLine(map, sx, sz, tx, tz, attPierce);
        }
        static findTarget(atter) {
            var list = SceneModel.model.vo.unitList;
            var dis = atter.dis;
            var minDis = 0;
            var target = null;
            for (var k in list) {
                var vo = list[k];
                if (vo && vo.isDie == false) {
                    if (vo.camp != atter.camp) {
                        if (vo.stype == 9 || vo.stype == 8) {
                            var dis1 = DisplayUtil.distance(vo.x, vo.z, atter.x, atter.z);
                            if (dis1 <= dis) {
                                var dir = Display3DUtil.angle(vo.x, vo.z, atter.x, atter.z);
                                var dirDiff = DisplayUtil.angleDiff(dir, atter.dir);
                                dirDiff = Math.abs(dirDiff);
                                if (dirDiff < 15) {
                                    var h = vo.y - atter.y;
                                    h = Math.abs(h);
                                    var angle = Display3DUtil.angle(h, dis1);
                                    angle = Math.abs(angle);
                                    if (h < 1) {
                                        if (vo.isFly == false) {
                                            if (!target) {
                                                minDis = dis1;
                                                target = vo;
                                            }
                                            else if (dis1 < minDis) {
                                                minDis = dis1;
                                                target = vo;
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
            return target;
        }
        static getStartPoint(sp) {
            this.startPoint.x = sp.x;
            this.startPoint.y = sp.y;
            this.startPoint.z = sp.z;
            return this.startPoint;
        }
        static getToPoint(atter, hiter, dir = 0) {
            if (atter.attVo == null) {
                return null;
            }
            if (hiter) {
                this.toPoint.x = hiter.x;
                this.toPoint.y = hiter.y + 1.7;
                this.toPoint.z = hiter.z;
            }
            else {
                var sp = atter.transform.position;
                var dis = 20;
                var dx = MathUtil.sin(dir) * dis;
                var dz = MathUtil.cos(dir) * dis;
                var dy = MathUtil.sin(atter.angle) * dis;
                this.toPoint.x = sp.x + dx;
                this.toPoint.y = sp.y + 1.7 + dy;
                this.toPoint.z = sp.z + dz;
            }
            return this.toPoint;
        }
    }
    SceneHitTool.pos = new Laya.Vector3();
    SceneHitTool.startPoint = new Laya.Vector3();
    SceneHitTool.toPoint = new Laya.Vector3();

    class ScenePickupTool {
        static pickupGoods(c, playerVo) {
            var unpickVo = this.getPickupGoods(playerVo);
            if (unpickVo) {
                if (unpickVo.cid == 30021101) {
                    var playerVo1 = playerVo;
                    if (playerVo1.hpMax == playerVo1.hp) {
                        return;
                    }
                    else {
                        c.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_ADD(playerVo.id), { hp: unpickVo.num });
                        c.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(unpickVo.id));
                        c.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_PICKUP_RESPONSE, { vo: unpickVo });
                        c.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_PICKUP_CONPLETE(unpickVo.cid));
                        if (unpickVo.pickAnim) {
                            c.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(playerVo.id), { image: unpickVo.pickAnim, time: 4000 });
                        }
                    }
                }
                else {
                    c.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_UNPICK, { vo: unpickVo });
                    c.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(unpickVo.id));
                    c.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_PICKUP_RESPONSE, { vo: unpickVo });
                    c.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_PICKUP_CONPLETE(unpickVo.cid));
                    if (unpickVo.pickAnim) {
                        c.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(playerVo.id), { image: unpickVo.pickAnim, time: 4000 });
                    }
                }
                SoundTool.playSound('pickup');
            }
        }
        static getPickupGoods(playerVo) {
            var list = SceneModel.model.vo.goodsList;
            var unpickVo;
            var unpickDis = 999999;
            for (var k in list) {
                var vo = list[k];
                var dis = DisplayUtil.distance(vo.x, vo.z, playerVo.x, playerVo.z);
                if (dis < 1) {
                    if (dis < unpickDis) {
                        unpickDis = dis;
                        unpickVo = vo;
                    }
                }
            }
            return unpickVo;
        }
    }

    class ScenePlayerGoodsController extends Controller {
        constructor(element, vo) {
            super();
            this.element = element;
            this.vo = vo;
            this.sceneVo = SceneModel.model.vo;
        }
        run() {
            super.run();
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_GOODS_USE, this, this.goodsUseHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_PICKUP, this, this.pickUpHandler);
            TimerUtil.loopTimer(500, this, this.pickupGoods);
        }
        pickupGoods() {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.vo.isDie) {
                return;
            }
            ScenePickupTool.pickupGoods(this, this.vo);
        }
        pickUpHandler(data) {
            var vo = data.vo;
            this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_STOP(vo.id));
            SoundTool.playSound('pickup');
        }
        goodsUseHandler(data) {
        }
    }

    class ScenePlayerVipController extends Controller {
        constructor(element, vo) {
            super();
            this.element = element;
            this.vo = vo;
            this.sceneVo = SceneModel.model.vo;
        }
        run() {
            super.run();
            this.addEventListener(SceneEvent.SCENE_STATE_READY, this, this.sceneStartHandler);
        }
        sceneStartHandler() {
            this.checkVipBuff();
        }
        checkVipBuff() {
            if (SceneModel.model.vo.vipBuff > 0) {
                SceneModel.model.vo.vipBuff = 0;
                this.addVipBuffHandler();
            }
        }
        addVipBuffHandler() {
            this.vo.attBuffPro += SceneConfig.vip.attPro;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_GOODS_CHANGE, { vo: null });
        }
    }

    class ScenePlayerVisualController extends Controller {
        constructor(element, vo) {
            super();
            this.iCameraX = -0.3;
            this.iCameraY = 1.8;
            this.iCameraZ = -2;
            this.dirV = 0;
            this.angleV = 0;
            this.toNum = 0;
            this.exeNum = 12;
            this.isLook = false;
            this.element = element;
            this.vo = vo;
        }
        run() {
            super.run();
            this.spine = DisplayUtil.getChildByName(this.element, 'mixamorig_Spine1');
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_DIR, this, this.dirHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_AIM, this, this.aimHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_VIS, this, this.visHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_LOOKAT, this, this.lookatHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_CAMERA_SHOCK(this.vo.id), this, this.shockHandledr);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_REVIVED(this.vo.id), this, this.reivieHandler);
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_AIM(this.vo.id), this, this.aimHandler);
            this.addEventListener(SceneEvent.SCENE_STATE_READY, this, this.initCamera);
            this.cameraBox = new Laya.Sprite3D();
            this.element.addChild(this.cameraBox);
            this.iCameraZ = this.vo.cameraZ;
            this.iCameraY = this.vo.cameraY;
            this.sceneVo = SceneModel.model.vo;
            this.initCamera();
        }
        initCamera() {
            var camera = this.camera = SceneModel.model.camera;
            this.cameraBox.addChild(camera);
            camera.transform.localRotationEulerX = 0;
            camera.transform.localRotationEulerY = 0;
            camera.transform.localRotationEulerZ = 0;
            camera.transform.localPositionX = 0;
            camera.transform.localPositionY = 0;
            camera.transform.localPositionZ = 0;
            this.cameraBox.transform.localRotationEulerX = 0;
            this.cameraBox.transform.localRotationEulerY = 180;
            this.cameraBox.transform.localRotationEulerZ = 0;
            this.cameraBox.transform.localPositionX = this.iCameraX;
            this.cameraBox.transform.localPositionY = this.iCameraY;
            this.cameraBox.transform.localPositionZ = this.iCameraZ;
        }
        cameraHandler(data) {
            this.cameraBox.transform.localPositionY = data.iCameraY;
            this.cameraBox.transform.localPositionZ = data.iCameraZ;
        }
        dirHandler(data) {
            this.vo.dir += data.dx;
            this.vo.angle += data.dy;
            if (this.vo.angle > 60) {
                this.vo.angle = 60;
            }
            else if (this.vo.angle < -25) {
                this.vo.angle = -25;
            }
            this.element.transform.localRotationEulerY = this.vo.dir;
            this.showAngle();
        }
        showAngle() {
            this.cameraBox.transform.localRotationEulerX = this.vo.angle;
            if (this.spine) {
                this.spine.transform.localRotationEulerX = -this.vo.angle + 1;
            }
        }
        shockHandledr(data) {
            this.camera.transform.localPositionZ = -0.05;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_SHOCK, { state: 1 });
            if (data && data.hitVo) {
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_COLL_CHANGE, { state: 3 });
            }
            TimerUtil.onceFrame(1, this, this.unLauchHandler);
        }
        unLauchHandler() {
            this.camera.transform.localPositionZ = 0;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_SHOCK, { state: 0 });
        }
        aimHandler(data) {
            this.vo.isAim = ParamUtil.getBool(data, 'isAim', !this.vo.isAim);
            if (this.vo.isAim) {
                this.showAnim();
            }
            else {
                this.closeAnim();
            }
        }
        showAnim() {
            this.vo.isAim = true;
            this.vo.aimType = this.vo.attVo.aimType;
            if (this.vo.aimType == 4) {
                SceneModel.model.camera.fieldOfView = 30;
                this.cameraBox.transform.localPositionZ = 0;
            }
            else {
                SceneModel.model.camera.fieldOfView = 40;
            }
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AIM_CHANGE);
        }
        closeAnim() {
            this.vo.isAim = false;
            SceneModel.model.camera.fieldOfView = 60;
            this.cameraBox.transform.localPositionZ = this.iCameraZ;
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AIM_CHANGE);
        }
        visHandler(data) {
            var visType = ParamUtil.getInt(data, 'visType', 0);
            if (visType) {
                this.vo.visType = visType;
            }
            else {
                if (this.vo.visType == 1) {
                    this.vo.visType = 3;
                }
                else {
                    this.vo.visType = 1;
                }
            }
            if (this.vo.visType == 3) {
                this.showVis(3);
            }
            else {
                this.showVis(1);
            }
        }
        showVis(vis) {
            if (vis == 3) {
                this.vo.visType = 3;
                this.cameraBox.transform.localPositionX = this.iCameraX;
                this.cameraBox.transform.localPositionY = this.iCameraY;
                this.cameraBox.transform.localPositionZ = this.iCameraZ;
            }
            else {
                this.vo.visType = 1;
                this.cameraBox.transform.localPositionX = 0;
                this.cameraBox.transform.localPositionY = this.iCameraY - 0.2;
                this.cameraBox.transform.localPositionZ = 0;
            }
        }
        reivieHandler(data) {
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_AIM, { isAim: false });
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_VIS, { visType: 3 });
        }
        lookatHandler(data) {
            var target = data.target;
            var pos = this.cameraBox.transform.position;
            var dir = Display3DUtil.angle(target.x, target.z, pos.x, pos.z);
            var dis = DisplayUtil.distance(target.x, target.z, this.vo.x, this.vo.z);
            var h = target.y - pos.y + 1.5;
            var angle = Display3DUtil.angle(h, dis);
            this.dirV = (dir - this.vo.dir) / this.exeNum;
            this.angleV = (angle - this.vo.angle) / this.exeNum;
            this.toNum = 0;
            if (this.isLook == false) {
                this.isLook = true;
                TimerUtil.loopFrame(1, this, this.lookLoopHandler);
            }
        }
        lookLoopHandler() {
            this.toNum++;
            if (this.toNum >= this.exeNum) {
                this.isLook = false;
                TimerUtil.stopTimer(this, this.lookLoopHandler);
            }
            this.element.transform.localRotationEulerY = this.vo.dir = this.vo.dir + this.dirV;
            this.vo.angle += this.angleV;
            this.showAngle();
        }
    }

    class ScenePlayerViewController extends SceneUnitViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.manualAimTarget = false;
            this.index = 0;
            this.playerVo = vo;
            vo.isInvin = true;
            vo.attPierce = 4;
        }
        initComplete() {
            super.initComplete();
            this.startChild(new ScenePlayerVisualController(this.element, this.playerVo));
            this.startChild(new ScenePlayerVipController(this.element, this.playerVo));
            this.startChild(new ScenePlayerGoodsController(this.element, this.playerVo));
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_MOVE, this, this.moveHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_MOVE_STOP, this, this.moveStopHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_ATT, this, this.attDirHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_AIM_ATT, this, this.aimAttHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_AUTO_AIM_SET, this, this.aimSetHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_SWITCH_AIM, this, this.aimSwitchHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_ATT_STOP, this, this.attStopHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_JUMP, this, this.jumpsHandler);
            this.addEventListener(ScenePlayerEvent.SCENE_PLAYER_REVIVE, this, this.reviveHandler);
            this.autoLauchInit();
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.playerVo.id), { cid: SceneConfig.reShieldCid });
        }
        autoLauchInit() {
            this.playerVo.autoAimTs = TimeUtil.getLocalTime();
            TimerUtil.loopTimer(100, this, this.autoLauchHandler);
        }
        autoLauchHandler() {
            var time = TimeUtil.getLocalTime() - this.playerVo.autoAimTs;
            if (time > 500) {
                this.playerVo.isAutoAim = true;
                this.autoAimHandler();
            }
            else {
                this.manualAimHandler();
            }
        }
        manualAimHandler() {
            var hitVo = SceneHitTool.checkHitss(this.playerVo);
            var state = 1;
            this.unitVo.targetVo = null;
            if (hitVo) {
                var dis = DisplayUtil.distance(hitVo.x, hitVo.z, this.playerVo.x, this.playerVo.z);
                if (dis <= this.unitVo.dis) {
                    this.unitVo.targetVo = hitVo;
                    state = 2;
                }
                else {
                    state = 4;
                }
            }
            else {
                state = 1;
            }
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_COLL_CHANGE, { state: state });
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_LOCK_TARGET, { vo: null });
        }
        autoAimHandler() {
            if (this.manualAimTarget == true && this.aimTarget) {
                var hitVo2 = SceneHitTool.checkHitTarget(this.playerVo, this.aimTarget);
                if (hitVo2) {
                    return;
                }
                else {
                    this.manualAimTarget = false;
                    this.aimTargetHandler(null);
                    return;
                }
            }
            var hitVo = SceneHitTool.findTarget(this.playerVo);
            var state = 1;
            this.unitVo.targetVo = null;
            if (hitVo) {
                var hitVo2 = SceneHitTool.checkHitTarget(this.playerVo, hitVo);
                if (hitVo2) {
                    this.unitVo.targetVo = hitVo2;
                    state = 2;
                    this.aimTargetHandler(hitVo2);
                }
                else {
                    state = 4;
                    this.aimTargetHandler(null);
                }
            }
            else {
                state = 1;
                this.aimTargetHandler(null);
            }
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_COLL_CHANGE, { state: state });
        }
        aimTargetHandler(hitVo) {
            this.aimTarget = hitVo;
            if (hitVo) {
                TimerUtil.loopFrame(1, this, this.aimHandler, [hitVo]);
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_LOCK_TARGET, { vo: hitVo });
            }
            else {
                TimerUtil.stopTimer(this, this.aimHandler);
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_LOCK_TARGET, { vo: null });
            }
        }
        aimHandler(hitVo) {
            if (this.playerVo.isAutoAim) {
                this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_LOOKAT, { target: hitVo });
            }
            else {
                TimerUtil.stopTimer(this, this.aimHandler);
            }
        }
        aimSetHandler(data) {
            this.playerVo.isAutoAim = ParamUtil.getBool(data, 'isAutoAim');
            if (this.playerVo.isAutoAim == false) {
                this.playerVo.autoAimTs = TimeUtil.getLocalTime();
            }
        }
        aimSwitchHandler(data) {
            var aimTarget = this.getNextAimTarget();
            if (aimTarget) {
                this.manualAimTarget = true;
                this.aimTargetHandler(aimTarget);
            }
        }
        getNextAimTarget() {
            if (this.targetList == null) {
                this.initAimSwitch();
            }
            for (var i = 0; i < this.targetList.length; i++) {
                var vo = this.targetList[this.index];
                if (vo && vo.isDie == false && vo != this.aimTarget) {
                    var dis = DisplayUtil.distance(this.playerVo.x, this.playerVo.z, vo.x, vo.z);
                    if (dis < this.playerVo.dis) {
                        return vo;
                    }
                }
                this.index++;
                if (this.index >= this.targetList.length) {
                    this.index = 0;
                }
            }
        }
        initAimSwitch() {
            var list = this.sceneVo.unitList;
            var nlist = [];
            for (var k in list) {
                var vo = list[k];
                if (vo.camp != 1) {
                    nlist.push(vo);
                }
            }
            this.targetList = nlist;
        }
        moveHandler(data) {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.playerVo.isDie) {
                return;
            }
            this.doMove(this.playerVo.dir + data.dir);
        }
        moveStopHandler() {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.playerVo.isDie) {
                return;
            }
            this.doStand();
        }
        attDirHandler(data) {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.playerVo.isDie) {
                return;
            }
            this.doAtt(this.playerVo.dir);
        }
        attStopHandler(data) {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.playerVo.isDie) {
                return;
            }
            this.stopAtt();
        }
        aimAttHandler() {
            if (this.sceneVo.state != 1) {
                return;
            }
            if (this.playerVo.isDie) {
                return;
            }
            var dir = SceneTargetTool.findAreaTarege(this.playerVo);
            this.dispatchEvent(ScenePlayerEvent.SCENE_PLAYER_DIR, { dx: dir, dy: 0 });
            this.doAtt(this.playerVo.dir);
        }
        jumpsHandler() {
            this.duJump();
        }
        reviveHandler(data) {
            this.playerVo.isAtt = false;
            this.playerVo.isReload = false;
            this.playerVo.hp = this.playerVo.hpMax;
            this.playerVo.attBuffPro = 0;
            this.playerVo.isDie = false;
            this.doStand();
            for (var k in this.playerVo.skillList) {
                var skillVo = this.playerVo.skillList[k];
                skillVo.skillCdTs = 0;
            }
            var cid = this.playerVo.skills[1];
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.playerVo.id), { cid: cid });
            var p = SceneTerrainTool.redomPosCamp(this.playerVo.camp);
            this.element.transform.localPositionX = p.x;
            this.element.transform.localPositionY = p.y;
            this.element.transform.localPositionZ = p.z;
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_CHANGE(this.playerVo.id), { vo: this.playerVo });
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REVIVED(this.playerVo.id));
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REVIVED_COMPLETE);
        }
    }

    class SceneSkillViewController extends SceneElementViewController {
        constructor(scene, vo) {
            if (vo.atterVo) {
                vo.ix = vo.atterVo.x;
                vo.iy = vo.atterVo.y;
                vo.iz = vo.atterVo.z;
            }
            super(scene, vo);
            this.skillVo = vo;
            this.url = SceneConfig.getSkillUrl(vo.image);
        }
        openComplete() {
            super.openComplete();
            this.dispatchEvent(SceneSkillEvent.SCENE_SKILL_USEED(this.skillVo.cid));
            if (this.skillVo.attSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.attSound);
            }
        }
        initComplete() {
            super.initComplete();
            Display3DUtil.playParticle(this.element);
        }
    }

    class SceneSkillAimViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        run() {
            super.run();
            this.skillAimHandler();
        }
        skillAimHandler() {
            if (!this.skillVo.atterVo.isDie) {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_AIM(this.skillVo.atterVo.id));
            }
            this.stop();
        }
    }

    class SceneSkillArcheryViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.num = 3;
            this.url = null;
        }
        openComplete() {
            super.openComplete();
            this.num = 3;
            TimerUtil.loopTimer(500, this, this.archeryHandler);
        }
        archeryHandler() {
            var attDir = this.skillVo.atterVo.dir;
            var attNum = 5;
            var diff = 3;
            var dirs = (attNum - 1) * diff / 2;
            for (var i = 0; i < attNum; i++) {
                var dir = diff * i - dirs + attDir;
                this.addSkill(dir);
            }
            this.num -= 1;
            if (this.num <= 0 || this.skillVo.atterVo.isDie) {
                this.stop();
            }
        }
        addSkill(dir) {
            var skillVo = SceneVoBuilder.getElementVo(40021020, 'skillDir');
            skillVo.camp = this.skillVo.camp;
            skillVo.atterVo = this.skillVo.atterVo;
            skillVo.targetVo = this.skillVo.targetVo;
            skillVo.startPoint = this.skillVo.startPoint;
            skillVo.attDir = dir;
            skillVo.att = SceneUnitAttConfig.getAtt(this.skillVo.att, this.skillVo.atterVo.lv);
            skillVo.attAngle = this.skillVo.atterVo.angle;
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
        }
    }

    class SceneSkillArtilleryViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.num = 1;
            this.url = null;
        }
        openComplete() {
            super.openComplete();
            this.num = 1;
            TimerUtil.loopTimer(500, this, this.archeryHandler);
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_CAMERA_SHOCK(this.skillVo.atterVo.id));
        }
        archeryHandler() {
            var attDir = this.skillVo.atterVo.dir;
            var attNum = 4;
            var diff = 3;
            var dirs = (attNum - 1) * diff / 2;
            for (var i = 0; i < attNum; i++) {
                var dir = diff * i - dirs + attDir;
                this.addSkill(dir);
            }
            this.num -= 1;
            if (this.num <= 0 || this.skillVo.atterVo.isDie) {
                this.stop();
            }
        }
        addSkill(dir) {
            var skillVo = SceneVoBuilder.getElementVo(40021034, 'skillRocket');
            skillVo.camp = this.skillVo.camp;
            skillVo.atterVo = this.skillVo.atterVo;
            skillVo.targetVo = this.skillVo.targetVo;
            skillVo.startPoint = this.skillVo.startPoint;
            skillVo.attDir = dir;
            skillVo.att = SceneUnitAttConfig.getAtt(this.skillVo.att, this.skillVo.atterVo.lv);
            skillVo.attAngle = this.skillVo.atterVo.angle;
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
        }
    }

    class ScriptEvent {
    }
    ScriptEvent.SCRIPT_TRIGGER = 'SCRIPT_TRIGGER';
    ScriptEvent.SCRIPT_COLLISION = 'SCRIPT_COLLISION';

    class CollisionEventScript extends Laya.Script3D {
        constructor() {
            super();
        }
        onTriggerEnter(other) {
            if (this.owner) {
                this.owner.event(ScriptEvent.SCRIPT_TRIGGER);
            }
        }
        onCollisionEnter(collision) {
            if (this.owner) {
                this.owner.event(ScriptEvent.SCRIPT_COLLISION, { target: collision, owner: this.owner });
            }
        }
    }

    class SceneSkillAvalancheViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.ix = 0;
            this.iy = 0;
            this.iz = 0;
            this.lastTime = 0;
            this.upV3 = new Laya.Vector3(0, 0, 0);
            this.toV3 = new Laya.Vector3(0, 0, 0);
            this.dir = new Laya.Vector3(0, 0, 0);
            this.dx = 0;
            this.dy = 0;
            this.dz = 0;
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            if (this.element && this.skillVo.startPoint) {
                this.element.transform.localPositionX = this.skillVo.startPoint.x;
                this.element.transform.localPositionY = this.skillVo.startPoint.y;
                this.element.transform.localPositionZ = this.skillVo.startPoint.z;
            }
            this.ix = this.element.transform.localPositionX;
            this.iy = this.element.transform.localPositionY;
            this.iz = this.element.transform.localPositionZ;
            if (this.skillVo.attDis == 0) {
                this.skillVo.attDis = 100;
            }
            this.moveDir();
            let rigidBody = this.element.addComponent(Laya.Rigidbody3D);
            let boxShape = new Laya.BoxColliderShape(0.1, 0.1, 0.1);
            rigidBody.colliderShape = boxShape;
            rigidBody.mass = 0;
            if (this.skillVo.camp == 1) {
                rigidBody.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER4;
                rigidBody.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER3;
            }
            else {
                rigidBody.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER5;
                rigidBody.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER2;
            }
            rigidBody.gravity = new Laya.Vector3(0, this.skillVo.gravity, 0);
            this.element.addComponent(CollisionEventScript);
            this.element.on(ScriptEvent.SCRIPT_TRIGGER, this, this.onEndHandler);
            this.element.on(ScriptEvent.SCRIPT_COLLISION, this, this.onEndHandler);
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_CAMERA_SHOCK(this.skillVo.atterVo.id));
            if (this.skillVo.anim) {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill', anim: this.skillVo.anim });
            }
        }
        moveTo(vo) {
            var tx = vo.x;
            var ty = vo.y + 1.5;
            var tz = vo.z;
            var fx = this.element.transform.localPositionX;
            var fy = this.element.transform.localPositionY;
            var fz = this.element.transform.localPositionZ;
            var v = this.skillVo.attV;
            Display3DUtil.direction3D(fx, fy, fz, tx, ty, tz, this.dir);
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        moveDir() {
            var dir = this.skillVo.attDir;
            var angle = this.skillVo.attAngle;
            Display3DUtil.toDirection3D(dir, angle, this.dir);
            var v = this.skillVo.attV;
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = this.element.transform.localPositionX + this.dx;
            this.toV3.y = this.element.transform.localPositionY + this.dy;
            this.toV3.z = this.element.transform.localPositionZ + this.dz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        followToHandler() {
            var tx = this.element.transform.localPositionX + this.dx;
            var ty = this.element.transform.localPositionY + this.dy;
            var tz = this.element.transform.localPositionZ + this.dz;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            this.element.transform.localPositionX = tx;
            this.element.transform.localPositionY = ty;
            this.element.transform.localPositionZ = tz;
            var target = this.skillVo.targetVo = SceneTargetTool.findTarget(this.skillVo.x, this.skillVo.z, this.skillVo.skillTriggerArea, this.skillVo.camp);
            if (target) {
                TimerUtil.stopTimer(this, this.followToHandler);
                this.hitTarget();
                return;
            }
            var cdis = DisplayUtil.distance(this.ix, this.iz, this.skillVo.x, this.skillVo.z);
            if (cdis >= this.skillVo.attDis) {
                this.onEndHandler();
            }
        }
        onEndHandler(data = null) {
            TimerUtil.stopTimer(this, this.followToHandler);
            if (this.skillVo.skillArea) {
                this.hitTarget();
            }
            else {
                this.stop();
            }
        }
        hitTarget() {
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
            this.attTargetHandler();
            ViewPoolUtil.recover(this.element);
        }
        attTargetHandler() {
            var atter = this.skillVo.atterVo;
            var hitVo = this.skillVo.targetVo;
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            this.lastTime = MathUtil.int(this.skillVo.skillDurationTime / 1000);
            this.hitList = [];
            if (this.skillVo.skillArea) {
                var list = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                for (var k in list) {
                    var vo = list[k];
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: att, atter: atter });
                    this.dispatchEvent(SceneBuffEvent.SCENE_BUFF_ADD(vo.id), { buffType: 'vPro', value: -0.5, time: 2000 });
                    if (this.skillVo.isOpenRepel == true) {
                        this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                    }
                    if (this.skillVo.effectImage) {
                        this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(vo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                    }
                }
                if (list.length > 0) {
                    this.hitList = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                }
                if (this.hitList.length > 0) {
                    TimerUtil.loopTimer(1000, this, this.attHithandler, [att, atter]);
                }
            }
            else {
                if (this.hitList.length > 0) {
                    TimerUtil.loopTimer(1000, this, this.attHithandler, [att, atter]);
                }
                if (this.skillVo.isOpenRepel == true) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                }
                if (this.skillVo.effectImage) {
                    this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(vo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                }
            }
        }
        attHithandler(att, atter) {
            for (var k in this.hitList) {
                this.attHandler(att, atter, this.hitList[k]);
            }
        }
        attHandler(att, atter, vo) {
            if (this.skillVo.atterVo) {
                if (!vo.isDie) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: (att * 0.4), atter: atter });
                }
                this.lastTime -= 1;
                if (this.lastTime <= 0 || vo.isDie) {
                    this.stop();
                }
            }
        }
    }

    class SceneSkillDirViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.ix = 0;
            this.iy = 0;
            this.iz = 0;
            this.upV3 = new Laya.Vector3(0, 0, 0);
            this.toV3 = new Laya.Vector3(0, 0, 0);
            this.dir = new Laya.Vector3(0, 0, 0);
            this.dx = 0;
            this.dy = 0;
            this.dz = 0;
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            if (this.element && this.skillVo.startPoint) {
                this.element.transform.localPositionX = this.skillVo.startPoint.x;
                this.element.transform.localPositionY = this.skillVo.startPoint.y;
                this.element.transform.localPositionZ = this.skillVo.startPoint.z;
            }
            this.ix = this.element.transform.localPositionX;
            this.iy = this.element.transform.localPositionY;
            this.iz = this.element.transform.localPositionZ;
            if (this.skillVo.attDis == 0) {
                this.skillVo.attDis = 100;
            }
            this.moveDir();
            let rigidBody = this.element.addComponent(Laya.Rigidbody3D);
            let boxShape = new Laya.BoxColliderShape(0.1, 0.1, 0.1);
            rigidBody.colliderShape = boxShape;
            rigidBody.mass = 0;
            if (this.skillVo.camp == 1) {
                rigidBody.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER4;
                rigidBody.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER3;
            }
            else {
                rigidBody.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER5;
                rigidBody.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER2;
            }
            rigidBody.gravity = new Laya.Vector3(0, this.skillVo.gravity, 0);
            this.element.addComponent(CollisionEventScript);
            this.element.on(ScriptEvent.SCRIPT_TRIGGER, this, this.onEndHandler);
            this.element.on(ScriptEvent.SCRIPT_COLLISION, this, this.onEndHandler);
            if (this.skillVo.anim) {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill', anim: this.skillVo.anim });
            }
        }
        moveTo(vo) {
            var tx = vo.x;
            var ty = vo.y + 1.5;
            var tz = vo.z;
            var fx = this.element.transform.localPositionX;
            var fy = this.element.transform.localPositionY;
            var fz = this.element.transform.localPositionZ;
            var v = this.skillVo.attV;
            Display3DUtil.direction3D(fx, fy, fz, tx, ty, tz, this.dir);
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        moveDir() {
            var dir = this.skillVo.attDir;
            var angle = this.skillVo.attAngle;
            Display3DUtil.toDirection3D(dir, angle, this.dir);
            var v = this.skillVo.attV;
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = this.element.transform.localPositionX + this.dx;
            this.toV3.y = this.element.transform.localPositionY + this.dy;
            this.toV3.z = this.element.transform.localPositionZ + this.dz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        followToHandler() {
            var tx = this.element.transform.localPositionX + this.dx;
            var ty = this.element.transform.localPositionY + this.dy;
            var tz = this.element.transform.localPositionZ + this.dz;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            this.element.transform.localPositionX = tx;
            this.element.transform.localPositionY = ty;
            this.element.transform.localPositionZ = tz;
            var target = this.skillVo.targetVo = SceneTargetTool.findTarget(this.skillVo.x, this.skillVo.z, this.skillVo.skillTriggerArea, this.skillVo.camp);
            if (target) {
                TimerUtil.stopTimer(this, this.followToHandler);
                this.hitTarget();
                return;
            }
            var cdis = DisplayUtil.distance(this.ix, this.iz, this.skillVo.x, this.skillVo.z);
            if (cdis >= this.skillVo.attDis) {
                this.onEndHandler();
            }
        }
        onEndHandler(data = null) {
            TimerUtil.stopTimer(this, this.followToHandler);
            if (this.skillVo.skillArea) {
                this.hitTarget();
            }
            else {
                this.stop();
            }
        }
        hitTarget() {
            if (this.skillVo.effectImage) {
                this.dispatchEvent(SceneEvent.SCENE_EFFECT_VIEW_SHOW, { image: this.skillVo.effectImage, x: this.skillVo.x, y: this.skillVo.y, z: this.skillVo.z, time: 2000 });
            }
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
            this.attTargetHandler();
            this.stop();
        }
        attTargetHandler() {
            var atter = this.skillVo.atterVo;
            var hitVo = this.skillVo.targetVo;
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            if (this.skillVo.skillArea) {
                var list = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                for (var k in list) {
                    var vo = list[k];
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: att, atter: atter });
                    if (this.skillVo.isOpenRepel == true) {
                        this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                    }
                    if (this.skillVo.isSlowDown == true) {
                        this.dispatchEvent(SceneBuffEvent.SCENE_BUFF_ADD(vo.id), { buffType: 'vPro', value: -0.5, time: this.skillVo.skillDurationTime });
                    }
                }
            }
            else {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(hitVo.id), { att: att, atter: atter });
                if (this.skillVo.isOpenRepel == true) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(hitVo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                }
                if (this.skillVo.isSlowDown == true) {
                    this.dispatchEvent(SceneBuffEvent.SCENE_BUFF_ADD(hitVo.id), { buffType: 'vPro', value: -0.5, time: this.skillVo.skillDurationTime });
                }
            }
        }
    }

    class SceneSkillFirstAidViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        run() {
            super.run();
            this.skillFirstAidHandler();
            if (this.skillVo.effectImage) {
                this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(this.skillVo.atterVo.id), { image: this.skillVo.effectImage, time: 3000 });
            }
        }
        skillFirstAidHandler() {
            if (!this.skillVo.atterVo.isDie) {
                LogTool.log('SceneSkillFirstAidViewController.skillFirstAidHandler+' + this.skillVo.atterVo.hpMax);
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_ADD(this.skillVo.atterVo.id), { hp: SceneUnitHprConfig.getHp(this.skillVo.atterVo.hpMax, this.skillVo.atterVo.lv) });
            }
            this.stop();
        }
    }

    class SceneSkillFixedViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.followX = 0;
            this.followZ = 0;
            this.dir = 0;
            this.dx = 0;
            this.dz = 0;
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.targetVo) {
                this.element.transform.localPositionY = 1;
                this.followMoveTo(this.skillVo.targetVo);
            }
            else {
                this.close();
            }
        }
        followMoveTo(vo, x = 0, z = 0) {
            this.followX = x;
            this.followZ = z;
            this.followToVo = vo;
            var v = this.skillVo.attV;
            this.dir = Display3DUtil.angle(x, z, this.skillVo.x, this.skillVo.z);
            this.dx = MathUtil.sin(this.dir) * v;
            this.dz = MathUtil.cos(this.dir) * v;
            this.element.transform.localRotationEulerY = this.dir;
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        followToHandler() {
            var tx = this.followToVo.x + this.followX;
            var tz = this.followToVo.z + this.followZ;
            var v = this.skillVo.attV;
            var dis = DisplayUtil.distance(tx, tz, this.skillVo.x, this.skillVo.z);
            if (dis <= v) {
                this.element.transform.localPositionX = tx;
                this.element.transform.localPositionZ = tz;
                TimerUtil.stopTimer(this, this.followToHandler);
                this.hitTareget();
                return;
            }
            this.element.transform.localPositionX += this.dx;
            this.element.transform.localPositionZ += this.dz;
        }
        hitTareget() {
            if (this.skillVo.effectImage) {
                this.dispatchEvent(SceneEvent.SCENE_EFFECT_VIEW_SHOW, { image: this.skillVo.effectImage, x: this.skillVo.x, y: this.skillVo.y, z: this.skillVo.z, time: 2000 });
            }
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
            this.attTargetHandler();
            this.stop();
        }
        attTargetHandler() {
            var atter = this.skillVo.atterVo;
            var hitVo = this.skillVo.targetVo;
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            if (this.skillVo.skillArea) {
                var list = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                for (var k in list) {
                    var vo = list[k];
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: att, atter: atter });
                }
            }
            else {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(hitVo.id), { att: att, atter: atter });
            }
        }
    }

    class SceneSkillFlyViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        run() {
            super.run();
            this.skillFlyHandler();
        }
        skillFlyHandler() {
            if (!this.skillVo.atterVo.isDie) {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_FLY(this.skillVo.atterVo.id));
            }
            this.stop();
        }
    }

    class SceneSkillLineViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.startColor = new Laya.Color(1, 1, 33 / 155, 1);
            this.endColor = new Laya.Color(1, 1, 1, 1);
        }
        openComplete() {
            super.openComplete();
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            var isHit = false;
            var hitVo = this.skillVo.targetVo;
            if (hitVo && SceneTargetTool.checkHits(this.skillVo.atterVo, hitVo)) {
                isHit = true;
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(hitVo.id), { att: att, atter: this.skillVo.atterVo });
            }
            if (this.skillVo.isShowAttLine && this.skillVo.startPoint) {
                var startPoint = SceneHitTool.getStartPoint(this.skillVo.startPoint);
                var toPoint = SceneHitTool.getToPoint(this.skillVo.atterVo, hitVo, this.skillVo.dir);
                var lineSprite3D = this.view = new Laya.PixelLineSprite3D(1);
                lineSprite3D.addLine(startPoint, toPoint, this.startColor, this.endColor);
                this.scene.addChild(lineSprite3D);
            }
            TimerUtil.onceTimer(30, this, this.close);
        }
    }

    class SceneSkillMineThrowViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.url = null;
        }
        openComplete() {
            super.openComplete();
            var attDir = this.skillVo.atterVo.dir;
            var attNum = 3;
            var diff = 15;
            var dirs = (attNum - 1) * diff / 2;
            for (var i = 0; i < attNum; i++) {
                var dir = diff * i - dirs + attDir;
                this.addSkill(dir);
            }
            this.stop();
        }
        addSkill(dir) {
            var skillVo = SceneVoBuilder.getElementVo(this.skillVo.cid, 'skillMine');
            skillVo.camp = this.skillVo.camp;
            skillVo.atterVo = this.skillVo.atterVo;
            skillVo.targetVo = this.skillVo.targetVo;
            skillVo.startPoint = this.skillVo.startPoint;
            skillVo.attDir = dir;
            skillVo.attAngle = this.skillVo.atterVo.angle;
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
        }
    }

    class SceneSkillMineViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        initComplete() {
            super.initComplete();
            var dir = this.skillVo.attDir;
            if (this.skillVo.throwDis && this.skillVo.atterVo) {
                var dir = dir;
                var dx = MathUtil.sin(dir) * 1;
                var dz = MathUtil.cos(dir) * 1;
                this.element.transform.localPositionX = this.skillVo.atterVo.x + dx;
                this.element.transform.localPositionZ = this.skillVo.atterVo.z + dz;
            }
            this.element.transform.localPositionY = this.skillVo.atterVo.y + 1.5;
            this.body.removeSelf();
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill' });
            TimerUtil.onceTimer(500, this, this.addHandler);
        }
        addHandler() {
            this.element.addChild(this.body);
            var dir = this.skillVo.attDir;
            var dx = MathUtil.sin(dir) * 10;
            var dz = MathUtil.cos(dir) * 10;
            let rigidBody = this.element.addComponent(Laya.Rigidbody3D);
            let boxShape = new Laya.BoxColliderShape(0.2, 0.05, 0.2);
            rigidBody.colliderShape = boxShape;
            rigidBody.mass = 1;
            rigidBody.friction = 4;
            rigidBody.restitution = 0;
            rigidBody.linearVelocity = new Laya.Vector3(dx, 0, dz);
            TimerUtil.onceTimer(5000, this, this.attTargetHandler);
        }
        attTargetHandler() {
            var atter = this.skillVo.atterVo;
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            var list = this.findTarget(this.skillVo.skillTriggerArea);
            if (list.length > 0) {
                var hitList = this.findTarget(this.skillVo.skillArea);
                for (var k in hitList) {
                    var vo = hitList[k];
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: att, atter: atter });
                    if (this.skillVo.isOpenRepel == true) {
                        this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                    }
                }
            }
            if (this.skillVo.effectImage) {
                this.dispatchEvent(SceneEvent.SCENE_EFFECT_VIEW_SHOW, { image: this.skillVo.effectImage, x: this.skillVo.x, y: this.skillVo.y, z: this.skillVo.z, time: 2000 });
            }
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
            this.stop();
        }
        findTarget(checkArea) {
            var atter = this.skillVo.atterVo;
            return SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, checkArea, atter.camp);
        }
    }

    class SceneSkillParViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.ix = 0;
            this.iy = 0;
            this.iz = 0;
            this.upV3 = new Laya.Vector3(0, 0, 0);
            this.toV3 = new Laya.Vector3(0, 0, 0);
            this.dir = new Laya.Vector3(0, 0, 0);
            this.dx = 0;
            this.dy = 0;
            this.dz = 0;
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            if (this.element && this.skillVo.startPoint) {
                this.element.transform.localPositionX = this.skillVo.startPoint.x;
                this.element.transform.localPositionY = this.skillVo.startPoint.y;
                this.element.transform.localPositionZ = this.skillVo.startPoint.z;
            }
            this.ix = this.element.transform.localPositionX;
            this.iy = this.element.transform.localPositionY;
            this.iz = this.element.transform.localPositionZ;
            if (this.skillVo.attDis == 0) {
                this.skillVo.attDis = 100;
            }
            if (this.skillVo.targetVo) {
                this.moveTo(this.skillVo.targetVo);
            }
            else {
                this.moveDir();
            }
            let rigidBody = this.element.addComponent(Laya.Rigidbody3D);
            let boxShape = new Laya.BoxColliderShape(0.1, 0.1, 0.1);
            rigidBody.colliderShape = boxShape;
            rigidBody.mass = 1;
            rigidBody.gravity = new Laya.Vector3(0, this.skillVo.gravity, 0);
            this.element.addComponent(CollisionEventScript);
            this.element.on(ScriptEvent.SCRIPT_TRIGGER, this, this.onEndHandler);
            this.element.on(ScriptEvent.SCRIPT_COLLISION, this, this.onEndHandler);
        }
        moveTo(vo) {
            var tx = vo.x;
            var ty = vo.y + 1.5;
            var tz = vo.z;
            var fx = this.element.transform.localPositionX;
            var fy = this.element.transform.localPositionY;
            var fz = this.element.transform.localPositionZ;
            var v = this.skillVo.attV;
            Display3DUtil.direction3D(fx, fy, fz, tx, ty, tz, this.dir);
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        moveDir() {
            var atter = this.skillVo.atterVo;
            Display3DUtil.toDirection3D(atter.dir, atter.angle, this.dir);
            var v = this.skillVo.attV;
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = this.element.transform.localPositionX + this.dx;
            this.toV3.y = this.element.transform.localPositionY + this.dy;
            this.toV3.z = this.element.transform.localPositionZ + this.dz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        followToHandler() {
            var tx = this.element.transform.localPositionX + this.dx;
            var ty = this.element.transform.localPositionY + this.dy;
            var tz = this.element.transform.localPositionZ + this.dz;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            this.element.transform.localPositionX = tx;
            this.element.transform.localPositionY = ty;
            this.element.transform.localPositionZ = tz;
            var target = this.skillVo.targetVo = SceneTargetTool.findTarget(this.skillVo.x, this.skillVo.z, this.skillVo.skillTriggerArea, this.skillVo.camp);
            if (target) {
                TimerUtil.stopTimer(this, this.followToHandler);
                this.hitTarget();
                return;
            }
            var cdis = DisplayUtil.distance(this.ix, this.iz, this.skillVo.x, this.skillVo.z);
            if (cdis >= this.skillVo.attDis) {
                this.onEndHandler();
            }
        }
        onEndHandler() {
            TimerUtil.stopTimer(this, this.followToHandler);
            if (this.skillVo.skillArea) {
                this.hitTarget();
            }
            else {
                this.stop();
            }
        }
        hitTarget() {
            if (this.skillVo.effectImage) {
                this.dispatchEvent(SceneEvent.SCENE_EFFECT_VIEW_SHOW, { image: this.skillVo.effectImage, x: this.skillVo.x, y: this.skillVo.y, z: this.skillVo.z, time: 2000 });
            }
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
            this.attTargetHandler();
            this.stop();
        }
        attTargetHandler() {
            var atter = this.skillVo.atterVo;
            var hitVo = this.skillVo.targetVo;
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            if (this.skillVo.skillArea) {
                var list = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                for (var k in list) {
                    var vo = list[k];
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: att, atter: atter });
                    if (this.skillVo.isOpenRepel == true) {
                        this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                    }
                }
            }
            else {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(hitVo.id), { att: att, atter: atter });
                if (this.skillVo.isOpenRepel == true) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                }
            }
        }
    }

    class SceneSkillRecoveryViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.lastTime = 0;
            this.unitList = [];
        }
        openComplete() {
            super.openComplete();
            this.unitList = SceneModel.model.vo.unitList;
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            this.lastTime = MathUtil.int(this.skillVo.skillDurationTime / 1000);
            if (this.skillVo.atterVo && this.skillVo.atterVo.canReHp == true && !this.skillVo.atterVo.isDie) {
                this.skillRecoveryHandler();
                if (this.skillVo.effectImage) {
                    this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(this.skillVo.atterVo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                    this.dispatchEvent(SceneSkillEvent.SCENE_SKILL_RECOVERY_USED(this.skillVo.atterVo.id), { skillHpRc: SceneUnitHprConfig.getHp(this.skillVo.skillHpRc, this.skillVo.atterVo.lv) });
                }
            }
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill' });
            TimerUtil.loopTimer(500, this, this.skillRecoveryHandler);
        }
        skillRecoveryHandler() {
            if (this.skillVo.atterVo && this.skillVo.atterVo.canReHp == true) {
                if (!this.skillVo.atterVo.isDie) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_HP_ADD(this.skillVo.atterVo.id), { hp: this.skillVo.skillHpRc });
                }
                this.lastTime -= 0.5;
                if (this.lastTime <= 0 || this.skillVo.atterVo.isDie) {
                    this.stop();
                }
            }
        }
    }
    function SceneSkilEvent(SceneSkilEvent) {
        throw new Error("Function not implemented.");
    }

    class SceneSkillReShieldViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            this.skillShieldHandler();
        }
        skillShieldHandler() {
            if (!this.skillVo.atterVo.isDie) {
                if (this.skillVo.atterVo && !this.skillVo.atterVo.isDie) {
                    this.skillVo.atterVo.isInvin = true;
                    if (this.skillVo.effectImage) {
                        this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(this.skillVo.atterVo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                    }
                }
                TimerUtil.onceTimer(this.skillVo.skillDurationTime, this, this.stopHandler);
            }
        }
        stopHandler() {
            this.skillVo.atterVo.isInvin = false;
            this.stop();
        }
    }

    class SceneSkillRobotViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.robotCid = 30012017;
            this.svo = SceneModel.model.vo;
        }
        run() {
            super.run();
            this.skillRobotHandler();
        }
        skillRobotHandler() {
            if (!this.skillVo.atterVo.isDie) {
                if (this.checkBotNum() == true) {
                    var streng = 3;
                    var robot = SceneNpcTool.randomNpc(this.robotCid, this.svo.victoryNum, streng, this.skillVo.atterVo.camp);
                    robot.camp = this.skillVo.atterVo.camp;
                    robot.halo = this.skillVo.atterVo.halo;
                    var dir = this.skillVo.attDir;
                    var dx = MathUtil.sin(dir) * 2;
                    var dz = MathUtil.cos(dir) * 2;
                    robot.ix = this.skillVo.atterVo.x + dx;
                    robot.iy = this.skillVo.atterVo.y;
                    robot.iz = this.skillVo.atterVo.z + dz;
                    robot.dir = this.skillVo.atterVo.dir;
                    robot.hp = robot.hpMax = this.skillVo.atterVo.hpMax;
                    robot.ownerId = this.skillVo.atterVo.id;
                    this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: robot });
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill' });
                }
            }
            this.stop();
        }
        checkBotNum() {
            var num = 0;
            for (var k in this.svo.unitList) {
                var robot = this.svo.unitList[k];
                if (robot.ttype == 3 && robot.ownerId == this.skillVo.atterVo.id) {
                    num++;
                }
                if (num >= 2) {
                    return false;
                }
            }
            return true;
        }
    }

    class SceneSkillShieldViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.unitList = [];
            this.num = 1;
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            this.unitList = SceneModel.model.vo.unitList;
            this.skillShieldHandler();
            TimerUtil.onceTimer(300, this, this.attHandler);
        }
        skillShieldHandler() {
            if (!this.skillVo.atterVo.isDie) {
                this.skillVo.atterVo.isInvin = true;
                if (this.skillVo.effectImage) {
                    this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(this.skillVo.atterVo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                }
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill' });
            }
            TimerUtil.onceTimer(this.skillVo.skillDurationTime, this, this.stopHandler);
        }
        stopHandler() {
            if (this.skillVo.atterVo && this.skillVo.atterVo.hasShield == true) {
                this.skillVo.atterVo.isInvin = false;
            }
            this.stop();
        }
        attHandler() {
            var attNum = 8;
            var diff = 45;
            var dirs = (attNum - 1) * diff / 2;
            for (var i = 0; i < attNum; i++) {
                var dir = diff * i - dirs + 0;
                this.addSkill(dir);
            }
        }
        addSkill(dir) {
            var skillVo = SceneVoBuilder.getElementVo(40021012, 'skillDir');
            skillVo.camp = this.skillVo.camp;
            skillVo.atterVo = this.skillVo.atterVo;
            skillVo.targetVo = this.skillVo.targetVo;
            skillVo.startPoint = this.skillVo.startPoint;
            skillVo.attDir = dir;
            skillVo.attAngle = 0;
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
        }
    }

    class SceneSkillTrackViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.upV3 = new Laya.Vector3(0, 0, 0);
            this.toV3 = new Laya.Vector3(0, 0, 0);
            this.dir = new Laya.Vector3(0, 0, 0);
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            if (this.element && this.skillVo.startPoint) {
                this.element.transform.localPositionX = this.skillVo.startPoint.x;
                this.element.transform.localPositionY = this.skillVo.startPoint.y;
                this.element.transform.localPositionZ = this.skillVo.startPoint.z;
            }
            if (this.skillVo.targetVo) {
                this.followMoveTo(this.skillVo.targetVo);
            }
            else {
                this.close();
            }
        }
        followMoveTo(vo) {
            this.followToVo = vo;
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        followToHandler() {
            var fx = this.element.transform.localPositionX;
            var fy = this.element.transform.localPositionY;
            var fz = this.element.transform.localPositionZ;
            var tx = this.followToVo.x;
            var ty = this.followToVo.y + 1.5;
            var tz = this.followToVo.z;
            var v = this.skillVo.attV;
            Display3DUtil.direction3D(fx, fy, fz, tx, ty, tz, this.dir);
            var dx = this.dir.x * v;
            var dy = this.dir.y * v;
            var dz = this.dir.z * v;
            this.element.transform.localPositionX += dx;
            this.element.transform.localPositionY += dy;
            this.element.transform.localPositionZ += dz;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            var dis = DisplayUtil.distance3D(tx, ty, tz, this.skillVo.x, this.skillVo.y, this.skillVo.z);
            if (dis <= v) {
                this.element.transform.localPositionX = tx;
                this.element.transform.localPositionY = ty;
                this.element.transform.localPositionZ = tz;
                TimerUtil.stopTimer(this, this.followToHandler);
                this.hitTarget();
                return;
            }
        }
        hitTarget() {
            if (this.skillVo.effectImage) {
                this.dispatchEvent(SceneEvent.SCENE_EFFECT_VIEW_SHOW, { image: this.skillVo.effectImage, x: this.skillVo.x, y: this.skillVo.y, z: this.skillVo.z, time: 2000 });
            }
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
            this.attTargetHandler();
            this.stop();
        }
        attTargetHandler() {
            var atter = this.skillVo.atterVo;
            var hitVo = this.skillVo.targetVo;
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            if (this.skillVo.skillArea) {
                var list = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                for (var k in list) {
                    var vo = list[k];
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: att, atter: atter });
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                }
            }
            else {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(hitVo.id), { att: att, atter: atter });
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(hitVo.id), { dir: 180 + hitVo.dir, dis: 5, v: 10, h: 10 });
            }
        }
    }

    class SceneSkillSoundViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        run() {
            super.run();
            this.skillavalancheHandler();
        }
        skillavalancheHandler() {
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill' });
            var hitList = this.findTarget(this.skillVo.skillArea);
            for (var k in hitList) {
                var vo = hitList[k];
                this.dispatchEvent(SceneBuffEvent.SCENE_BUFF_ADD(vo.id), { buffType: 'isActionLock', value: 1, time: this.skillVo.skillDurationTime });
                if (this.skillVo.effectImage) {
                    this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(vo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                }
            }
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
        }
        findTarget(checkArea) {
            var atter = this.skillVo.atterVo;
            return SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, checkArea, atter.camp);
        }
    }

    class SceneSkillSneakViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
        }
        run() {
            super.run();
            this.skillSneakHandler();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.skillVo.atterVo.id), this, this.removeHandler);
            TimerUtil.onceTimer(this.skillVo.skillDurationTime, this, this.removeHandler);
        }
        skillSneakHandler() {
            if (!this.skillVo.atterVo.isDie) {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill' });
                this.hideId = IdUtil.getId();
                this.dispatchEvent(SceneBuffEvent.SCENE_BUFF_ADD(this.skillVo.atterVo.id), { id: this.hideId, buffType: 'isHide', value: 1, time: 0 });
            }
        }
        removeHandler() {
            this.dispatchEvent(SceneBuffEvent.SCENE_BUFF_REMOVE(this.skillVo.atterVo.id), { id: this.hideId });
            this.stop();
        }
    }

    class SceneNpcAbangViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneNpcDrphilosViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneNpcBurtsmontherViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneNpcRichlockeViewController extends Controller {
        constructor(element, npcVo) {
            super();
            this.element = element;
            this.npcVo = npcVo;
        }
        run() {
            super.run();
            this.addEventListener(SceneUnitEvent.SCENE_UNIT_ATT_LAUNCH(this.npcVo.id), this, this.useSkill);
        }
        useSkill() {
            if (this.npcVo.skills[0]) {
                var cid = this.npcVo.skills[0];
                var skillVo = this.npcVo.getSkillVo(cid);
                if (SceneSkillTool.checkSkill(skillVo) == 'ok' && !this.npcVo.isPlayer) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_SKILL_USE(this.npcVo.id), { cid: skillVo.cid });
                }
            }
        }
    }

    class SceneSkillSnowflakeViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.num = 1;
            this.url = null;
        }
        openComplete() {
            super.openComplete();
            this.num = 1;
            TimerUtil.loopTimer(500, this, this.archeryHandler);
        }
        archeryHandler() {
            var attDir = this.skillVo.atterVo.dir;
            var attNum = 6;
            var diff = 6;
            var dirs = (attNum - 1) * diff / 2;
            for (var i = 0; i < attNum; i++) {
                var dir = diff * i - dirs + attDir;
                this.addSkill(dir);
            }
            this.num -= 1;
            if (this.num <= 0 || this.skillVo.atterVo.isDie) {
                this.stop();
            }
        }
        addSkill(dir) {
            var skillVo = SceneVoBuilder.getElementVo(40021030, 'skillAvalanche');
            skillVo.camp = this.skillVo.camp;
            skillVo.atterVo = this.skillVo.atterVo;
            skillVo.targetVo = this.skillVo.targetVo;
            skillVo.startPoint = this.skillVo.startPoint;
            skillVo.attDir = dir;
            skillVo.att = SceneUnitAttConfig.getAtt(this.skillVo.att, this.skillVo.atterVo.lv);
            skillVo.attAngle = this.skillVo.atterVo.angle;
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
        }
    }

    class SceneSkillRocketViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.ix = 0;
            this.iy = 0;
            this.iz = 0;
            this.lastTime = 0;
            this.upV3 = new Laya.Vector3(0, 0, 0);
            this.toV3 = new Laya.Vector3(0, 0, 0);
            this.dir = new Laya.Vector3(0, 0, 0);
            this.dx = 0;
            this.dy = 0;
            this.dz = 0;
        }
        openComplete() {
            super.openComplete();
            if (this.skillVo.atterVo.isDie) {
                this.stop();
                return;
            }
            if (this.element && this.skillVo.startPoint) {
                this.element.transform.localPositionX = this.skillVo.startPoint.x;
                this.element.transform.localPositionY = this.skillVo.startPoint.y;
                this.element.transform.localPositionZ = this.skillVo.startPoint.z;
            }
            this.ix = this.element.transform.localPositionX;
            this.iy = this.element.transform.localPositionY;
            this.iz = this.element.transform.localPositionZ;
            if (this.skillVo.attDis == 0) {
                this.skillVo.attDis = 100;
            }
            this.moveDir();
            let rigidBody = this.element.addComponent(Laya.Rigidbody3D);
            let boxShape = new Laya.BoxColliderShape(0.1, 0.1, 0.1);
            rigidBody.colliderShape = boxShape;
            rigidBody.mass = 0;
            if (this.skillVo.camp == 1) {
                rigidBody.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER4;
                rigidBody.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER3;
            }
            else {
                rigidBody.collisionGroup = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER5;
                rigidBody.canCollideWith = Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER1 | Laya.Physics3DUtils.COLLISIONFILTERGROUP_CUSTOMFILTER2;
            }
            rigidBody.gravity = new Laya.Vector3(0, this.skillVo.gravity, 0);
            this.element.addComponent(CollisionEventScript);
            this.element.on(ScriptEvent.SCRIPT_TRIGGER, this, this.onEndHandler);
            this.element.on(ScriptEvent.SCRIPT_COLLISION, this, this.onEndHandler);
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_CAMERA_SHOCK(this.skillVo.atterVo.id));
            if (this.skillVo.anim) {
                this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_STATE_SET(this.skillVo.atterVo.id), { state: 'skill', anim: this.skillVo.anim });
            }
        }
        moveTo(vo) {
            var tx = vo.x;
            var ty = vo.y + 1.5;
            var tz = vo.z;
            var fx = this.element.transform.localPositionX;
            var fy = this.element.transform.localPositionY;
            var fz = this.element.transform.localPositionZ;
            var v = this.skillVo.attV;
            Display3DUtil.direction3D(fx, fy, fz, tx, ty, tz, this.dir);
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        moveDir() {
            var dir = this.skillVo.attDir;
            var angle = this.skillVo.attAngle;
            Display3DUtil.toDirection3D(dir, angle, this.dir);
            var v = this.skillVo.attV;
            this.dx = this.dir.x * v;
            this.dy = this.dir.y * v;
            this.dz = this.dir.z * v;
            this.toV3.x = this.element.transform.localPositionX + this.dx;
            this.toV3.y = this.element.transform.localPositionY + this.dy;
            this.toV3.z = this.element.transform.localPositionZ + this.dz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            TimerUtil.loopFrame(1, this, this.followToHandler);
        }
        followToHandler() {
            var tx = this.element.transform.localPositionX + this.dx;
            var ty = this.element.transform.localPositionY + this.dy;
            var tz = this.element.transform.localPositionZ + this.dz;
            this.toV3.x = tx;
            this.toV3.y = ty;
            this.toV3.z = tz;
            this.element.transform.lookAt(this.toV3, this.upV3);
            this.element.transform.localPositionX = tx;
            this.element.transform.localPositionY = ty;
            this.element.transform.localPositionZ = tz;
            var target = this.skillVo.targetVo = SceneTargetTool.findTarget(this.skillVo.x, this.skillVo.z, this.skillVo.skillTriggerArea, this.skillVo.camp);
            if (target) {
                TimerUtil.stopTimer(this, this.followToHandler);
                this.hitTarget();
                return;
            }
            var cdis = DisplayUtil.distance(this.ix, this.iz, this.skillVo.x, this.skillVo.z);
            if (cdis >= this.skillVo.attDis) {
                this.onEndHandler();
            }
        }
        onEndHandler(data = null) {
            TimerUtil.stopTimer(this, this.followToHandler);
            if (this.skillVo.skillArea) {
                this.hitTarget();
            }
            else {
                this.stop();
            }
        }
        hitTarget() {
            if (this.skillVo.hitSound) {
                SceneSoundTool.playDisSound(this.skillVo, this.skillVo.hitSound);
            }
            this.attTargetHandler();
            ViewPoolUtil.recover(this.element);
        }
        attTargetHandler() {
            var atter = this.skillVo.atterVo;
            var hitVo = this.skillVo.targetVo;
            var att = SceneSkillTool.getAtt(this.skillVo, this.skillVo.atterVo);
            this.lastTime = MathUtil.int(this.skillVo.skillDurationTime / 1000);
            this.hitList = [];
            if (this.skillVo.skillArea) {
                var list = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                for (var k in list) {
                    var vo = list[k];
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: att, atter: atter });
                    if (this.skillVo.isOpenRepel == true) {
                        this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                    }
                    if (this.skillVo.effectImage) {
                        this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(vo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                    }
                }
                if (list.length > 0) {
                    this.hitList = SceneTargetTool.findTargetList(this.skillVo.x, this.skillVo.z, this.skillVo.skillArea, atter.camp);
                }
                if (this.hitList.length > 0) {
                    TimerUtil.loopTimer(1000, this, this.attHithandler, [att, atter]);
                }
            }
            else {
                if (this.hitList.length > 0) {
                    TimerUtil.loopTimer(1000, this, this.attHithandler, [att, atter]);
                }
                if (this.skillVo.isOpenRepel == true) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_REPEL(vo.id), { dir: 180 + vo.dir, dis: 5, v: 10, h: 10 });
                }
                if (this.skillVo.effectImage) {
                    this.dispatchEvent(SceneElementEvent.SCENE_ELEMENT_EFFECT_SHOW(vo.id), { image: this.skillVo.effectImage, time: this.skillVo.skillDurationTime });
                }
            }
        }
        attHithandler(att, atter) {
            for (var k in this.hitList) {
                this.attHandler(att, atter, this.hitList[k]);
            }
        }
        attHandler(att, atter, vo) {
            if (this.skillVo.atterVo) {
                if (!vo.isDie) {
                    this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: (att * 0.45), atter: atter });
                }
                this.lastTime -= 1;
                if (this.lastTime <= 0 || vo.isDie) {
                    this.stop();
                }
            }
        }
    }

    class SceneSkillLaunchMissileViewController extends SceneSkillViewController {
        constructor(scene, vo) {
            super(scene, vo);
            this.num = 5;
            this.url = null;
        }
        openComplete() {
            super.openComplete();
            this.num = 5;
            TimerUtil.loopTimer(800, this, this.archeryHandler);
            this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_CAMERA_SHOCK(this.skillVo.atterVo.id));
        }
        killAllNpcHandler() {
            var list = SceneModel.model.vo.unitList;
            for (var i in list) {
                var vo = list[i];
                if (vo.ttype == 1) {
                    if (vo.camp != 1) {
                        this.dispatchEvent(SceneUnitEvent.SCENE_UNIT_ATT(vo.id), { att: 999999999, atter: this.skillVo.atterVo });
                    }
                }
            }
        }
        archeryHandler() {
            var attDir = this.skillVo.atterVo.dir;
            var attNum = 10;
            var diff = 4;
            var dirs = (attNum - 1) * diff / 2;
            for (var i = 0; i < attNum; i++) {
                var dir = diff * i - dirs + attDir;
                this.addSkill(dir);
            }
            this.num -= 1;
            if (this.num <= 0 || this.skillVo.atterVo.isDie) {
                this.killAllNpcHandler();
                this.stop();
            }
        }
        addSkill(dir) {
            var skillVo = SceneVoBuilder.getElementVo(40021023, 'skillDir');
            skillVo.camp = this.skillVo.camp;
            skillVo.atterVo = this.skillVo.atterVo;
            skillVo.targetVo = this.skillVo.targetVo;
            skillVo.startPoint = this.skillVo.startPoint;
            skillVo.attDir = dir;
            skillVo.att = SceneUnitAttConfig.getAtt(this.skillVo.att, this.skillVo.atterVo.lv);
            skillVo.attAngle = this.skillVo.atterVo.angle;
            this.dispatchEvent(SceneEvent.SCENE_ELEMENT_VIEW_SHOW, { vo: skillVo });
        }
    }

    class SceneClassController extends Controller {
        constructor() { super(); }
        run() {
            super.run();
            SceneViewClassConfig.regClass('element', SceneElementViewController);
            SceneViewClassConfig.regClass('unit', SceneUnitViewController);
            SceneViewClassConfig.regClass('player', ScenePlayerViewController);
            SceneViewClassConfig.regClass('npc', SceneNpcViewController);
            SceneViewClassConfig.regClass('goods', SceneGoodsViewController);
            SceneViewClassConfig.regClass('buff', SceneBuffViewController);
            SceneViewClassConfig.regClass('skill', SceneSkillViewController);
            SceneViewClassConfig.regClass('skillTrack', SceneSkillTrackViewController);
            SceneViewClassConfig.regClass('skillFixed', SceneSkillFixedViewController);
            SceneViewClassConfig.regClass('skillDir', SceneSkillDirViewController);
            SceneViewClassConfig.regClass('skillLine', SceneSkillLineViewController);
            SceneViewClassConfig.regClass('skillPar', SceneSkillParViewController);
            SceneViewClassConfig.regClass('skillRecovery', SceneSkillRecoveryViewController);
            SceneViewClassConfig.regClass('skillFirstAid', SceneSkillFirstAidViewController);
            SceneViewClassConfig.regClass('skillShield', SceneSkillShieldViewController);
            SceneViewClassConfig.regClass('skillAim', SceneSkillAimViewController);
            SceneViewClassConfig.regClass('skillMine', SceneSkillMineViewController);
            SceneViewClassConfig.regClass('skillMineTrow', SceneSkillMineThrowViewController);
            SceneViewClassConfig.regClass('skillFly', SceneSkillFlyViewController);
            SceneViewClassConfig.regClass('skillReShield', SceneSkillReShieldViewController);
            SceneViewClassConfig.regClass('skillArchery', SceneSkillArcheryViewController);
            SceneViewClassConfig.regClass('skillArtillery', SceneSkillArtilleryViewController);
            SceneViewClassConfig.regClass('skillRocket', SceneSkillRocketViewController);
            SceneViewClassConfig.regClass('skillRobot', SceneSkillRobotViewController);
            SceneViewClassConfig.regClass('skillAvalanche', SceneSkillAvalancheViewController);
            SceneViewClassConfig.regClass('skillSnowflake', SceneSkillSnowflakeViewController);
            SceneViewClassConfig.regClass('skillSound', SceneSkillSoundViewController);
            SceneViewClassConfig.regClass('skillSneak', SceneSkillSneakViewController);
            SceneViewClassConfig.regClass('skillLaunchMissile', SceneSkillLaunchMissileViewController);
            SceneViewClassConfig.regClass('effect', SceneEffectViewController);
            SceneVoClassConfig.regClass('element', SceneElementVo);
            SceneVoClassConfig.regClass('element', SceneElementVo);
            SceneVoClassConfig.regClass('unit', SceneUnitVo);
            SceneVoClassConfig.regClass('player', ScenePlayerVo);
            SceneVoClassConfig.regClass('npc', SceneNpcVo);
            SceneVoClassConfig.regClass('goods', SceneGoodsVo);
            SceneVoClassConfig.regClass('gun', SceneGunVo);
            SceneVoClassConfig.regClass('buff', SceneGoodsBuffVo);
            SceneVoClassConfig.regClass('skill', SceneSkillVo);
            SceneVoClassConfig.regClass('skillTrack', SceneSkillVo);
            SceneVoClassConfig.regClass('skillFixed', SceneSkillVo);
            SceneVoClassConfig.regClass('skillDir', SceneSkillVo);
            SceneVoClassConfig.regClass('skillLine', SceneSkillVo);
            SceneVoClassConfig.regClass('skillPar', SceneSkillVo);
            SceneVoClassConfig.regClass('skillRecovery', SceneSkillVo);
            SceneVoClassConfig.regClass('skillShield', SceneSkillVo);
            SceneVoClassConfig.regClass('skillMine', SceneSkillVo);
            SceneVoClassConfig.regClass('skillMineTrow', SceneSkillVo);
            SceneVoClassConfig.regClass('skillFirstAid', SceneSkillVo);
            SceneVoClassConfig.regClass('skillAim', SceneSkillVo);
            SceneVoClassConfig.regClass('skillFly', SceneSkillVo);
            SceneVoClassConfig.regClass('skillReShield', SceneSkillVo);
            SceneVoClassConfig.regClass('skillArchery', SceneSkillVo);
            SceneVoClassConfig.regClass('skillArtillery', SceneSkillVo);
            SceneVoClassConfig.regClass('skillRocket', SceneSkillVo);
            SceneVoClassConfig.regClass('skillRobot', SceneSkillVo);
            SceneVoClassConfig.regClass('skillAvalanche', SceneSkillVo);
            SceneVoClassConfig.regClass('skillSnowflake', SceneSkillVo);
            SceneVoClassConfig.regClass('skillSound', SceneSkillVo);
            SceneVoClassConfig.regClass('skillSneak', SceneSkillVo);
            SceneVoClassConfig.regClass('skillLaunchMissile', SceneSkillVo);
            SceneViewClassConfig.regClass('dia', SceneNpcDiaViewController);
            SceneViewClassConfig.regClass('gebbie', SceneGebbiesViewController);
            SceneViewClassConfig.regClass('mcCartney', SceneNpcMcCartneyViewController);
            SceneViewClassConfig.regClass('jett', SceneNpcJettViewController);
            SceneViewClassConfig.regClass('igoai', SceneNpcLgoaiViewController);
            SceneViewClassConfig.regClass('abang', SceneNpcAbangViewController);
            SceneViewClassConfig.regClass('drphilos', SceneNpcDrphilosViewController);
            SceneViewClassConfig.regClass('ricklocke', SceneNpcRichlockeViewController);
            SceneViewClassConfig.regClass('burtsmother', SceneNpcBurtsmontherViewController);
            SceneViewClassConfig.regClass('hpText', SceneHpTextViewController);
        }
    }

    class Mouse3DTool {
        static getMouseHit(scene, camera, distance, collisonGroup, collisionMask) {
            var x = Laya.MouseManager.instance.mouseX;
            var y = Laya.MouseManager.instance.mouseY;
            return Hit3DTool.checkCameraHit(scene, camera, x, y, distance, collisonGroup, collisionMask);
        }
        static getMouseHitList(scene, camera, distance, collisonGroup, collisionMask) {
            var x = Laya.MouseManager.instance.mouseX;
            var y = Laya.MouseManager.instance.mouseY;
            return Hit3DTool.checkCameraHitList(scene, camera, x, y, distance, collisonGroup, collisionMask);
        }
        static getMouseXZPoint(camera) {
            var mx = Laya.MouseManager.instance.mouseX;
            var my = Laya.MouseManager.instance.mouseY;
            return this.getXZPoint(camera, mx, my);
        }
        static getXZPoint(camera, x = 0, y = 0) {
            if (this.xzPoint == null) {
                this.xzPoint = new Laya.Vector3(0, 0, 0);
            }
            if (this.point == null) {
                this.point = new Laya.Vector2();
            }
            if (this.ray == null) {
                this.ray = new Laya.Ray(new Laya.Vector3(), new Laya.Vector3());
            }
            this.point.x = x;
            this.point.y = y;
            camera.viewportPointToRay(this.point, this.ray);
            var ox = this.ray.origin.x;
            var oy = this.ray.origin.y;
            var oz = this.ray.origin.z;
            var dx = this.ray.direction.x;
            var dy = this.ray.direction.y;
            var dz = this.ray.direction.z;
            var px = -oy * dx / dy + ox;
            var pz = -oy * dz / dy + oz;
            this.xzPoint.x = px;
            this.xzPoint.y = 0;
            this.xzPoint.z = pz;
            return this.xzPoint;
        }
        static getRayPoint(ray, dis) {
            if (this.xzPoint == null) {
                this.xzPoint = new Laya.Vector3(0, 0, 0);
            }
            var ox = ray.origin.x;
            var oy = ray.origin.y;
            var oz = ray.origin.z;
            var dx = ray.direction.x * dis;
            var dy = ray.direction.y * dis;
            var dz = ray.direction.z * dis;
            this.xzPoint.x = dx + ox;
            this.xzPoint.y = dy + oy;
            this.xzPoint.z = dz + oz;
            return this.xzPoint;
        }
    }

    class SceneEditorViewController extends View3DController {
        constructor() {
            super();
            this.terrain = {};
            this.map = {};
            this.type = 1;
            this.sx = 0;
            this.sy = 0;
            this.locx = 0;
            this.locz = 0;
            this.rx = 0;
            this.ry = 0;
            this.linesX = 0;
            this.linesY = 0;
            this.lineeX = 0;
            this.lineeY = 0;
            this.vo = SceneModel.model.vo = SceneVoBuilder.getSceneVo(1);
            this.viewURL = 'scene/LayaScene_scene_' + this.vo.cid + '/Conventional/scene_' + this.vo.cid + '.ls';
            this.viewName = 'SceneEditorView';
        }
        openComplete() {
            super.openComplete();
            this.scene = this.view;
            this.camera = this.scene.getChildByName('Camera');
            SceneModel.model.camera = this.camera;
            this.camera.enableHDR = false;
            this.camera.orthographic = true;
            this.camera.transform.localPositionX = 0;
            this.camera.transform.localPositionY = 10;
            this.camera.transform.localPositionZ = 0;
            this.camera.transform.localRotationEulerX = -90;
            this.camera.transform.localRotationEulerY = 0;
            this.camera.transform.localRotationEulerZ = 0;
            this.camera.orthographicVerticalSize = 20;
            this.terrain = this.vo.terrain;
            Laya.stage.on(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            Laya.stage.on(Laya.Event.MOUSE_UP, this, this.upHandler);
            Laya.stage.on(Laya.Event.RIGHT_MOUSE_DOWN, this, this.rightDownHandler);
            Laya.stage.on(Laya.Event.RIGHT_MOUSE_UP, this, this.rightUpHandler);
            Laya.stage.on(Laya.Event.MOUSE_WHEEL, this, this.wheelHandler);
            Laya.stage.on(Laya.Event.KEY_DOWN, this, this.keyHandler);
            var url = 'scene/LayaScene_editor/Conventional/editor.lh';
            LoaderUtil.load3D(url, this.scene, this, this.load1Hnadler);
        }
        load1Hnadler(obj) {
            this.editor = this.editor1 = obj;
            var url = 'scene/LayaScene_editor/Conventional/editor.lh';
            LoaderUtil.load3D(url, this.scene, this, this.load2Hnadler);
        }
        load2Hnadler(obj) {
            this.editor2 = obj;
            var url = 'scene/LayaScene_editor/Conventional/editor.lh';
            LoaderUtil.load3D(url, this.scene, this, this.load3Hnadler);
        }
        load3Hnadler(obj) {
            this.editor3 = obj;
            this.initTerrain();
        }
        close() {
            super.close();
            Laya.stage.off(Laya.Event.MOUSE_DOWN, this, this.downHandler);
            Laya.stage.off(Laya.Event.MOUSE_UP, this, this.upHandler);
            Laya.stage.off(Laya.Event.MOUSE_MOVE, this, this.mosueMoveHandler);
            Laya.stage.off(Laya.Event.MOUSE_WHEEL, this, this.wheelHandler);
            Laya.stage.off(Laya.Event.KEY_DOWN, this, this.keyHandler);
            Laya.stage.off(Laya.Event.RIGHT_MOUSE_DOWN, this, this.rightDownHandler);
            Laya.stage.off(Laya.Event.RIGHT_MOUSE_UP, this, this.rightUpHandler);
        }
        downHandler(e) {
            if (e.shiftKey) {
                this.addTerrain();
                Laya.stage.on(Laya.Event.MOUSE_MOVE, this, this.mosueMoveHandler);
            }
            else if (e.ctrlKey) {
                this.removeTerrain();
                Laya.stage.on(Laya.Event.MOUSE_MOVE, this, this.mosueMoveHandler);
            }
            else {
                Laya.stage.on(Laya.Event.MOUSE_MOVE, this, this.mosueMoveHandler);
                this.sx = Laya.stage.mouseX;
                this.sy = Laya.stage.mouseY;
                this.locx = this.camera.transform.localPositionX;
                this.locz = this.camera.transform.localPositionZ;
            }
        }
        upHandler() {
            Laya.stage.off(Laya.Event.MOUSE_MOVE, this, this.mosueMoveHandler);
        }
        mosueMoveHandler(e) {
            if (e.shiftKey) {
                this.addTerrain();
            }
            else if (e.ctrlKey) {
                this.removeTerrain();
            }
            else {
                this.camera.transform.localPositionX = this.locx - (Laya.stage.mouseX - this.sx) / 20;
                this.camera.transform.localPositionZ = this.locz - (Laya.stage.mouseY - this.sy) / 20;
            }
        }
        rightDownHandler(e) {
            Laya.stage.on(Laya.Event.MOUSE_MOVE, this, this.rmosueMoverHandler);
            this.sx = Laya.stage.mouseX;
            this.sy = Laya.stage.mouseY;
            this.rx = this.camera.transform.localRotationEulerX;
            this.ry = this.camera.transform.localRotationEulerY;
        }
        rightUpHandler() {
            Laya.stage.off(Laya.Event.MOUSE_MOVE, this, this.rmosueMoverHandler);
        }
        rmosueMoverHandler(e) {
            this.camera.transform.localRotationEulerX = this.rx - (Laya.stage.mouseY - this.sy) / 20;
            this.camera.transform.localRotationEulerY = this.ry - (Laya.stage.mouseX - this.sx) / 20;
        }
        initTerrain() {
            for (var k in this.terrain) {
                var list = k.split("_");
                var x = MathUtil.int(list[0]);
                var z = MathUtil.int(list[1]);
                var v = this.terrain[k];
                if (v == 1) {
                    var box = DisplayUtil.instantiate(this.editor1, this.scene, x, 1, z);
                }
                else if (v == 2) {
                    var box = DisplayUtil.instantiate(this.editor2, this.scene, x, 1, z);
                }
                else {
                    var box = DisplayUtil.instantiate(this.editor3, this.scene, x, 1, z);
                }
                this.map[k] = box;
            }
        }
        addTerrain() {
            var p = Mouse3DTool.getMouseXZPoint(this.camera);
            var x = Math.round(p.x);
            var z = Math.round(p.z);
            var k = Math.round(x) + "_" + Math.round(z);
            if (this.map[k]) {
                this.scene.removeChild(this.map[k]);
            }
            var box = DisplayUtil.instantiate(this.editor, this.scene, x, 1, z);
            this.map[k] = box;
            this.terrain[k] = this.type;
            if (this.type == 9) {
                this.linesX = x;
                this.linesY = z;
            }
            console.log("addTerrain:" + k);
        }
        removeTerrain() {
            var p = Mouse3DTool.getMouseXZPoint(this.camera);
            var x = Math.round(p.x);
            var z = Math.round(p.z);
            var k = Math.round(x) + "_" + Math.round(z);
            if (this.map[k]) {
                this.scene.removeChild(this.map[k]);
                delete this.map[k];
            }
            delete this.terrain[k];
            if (this.type == 9) {
                this.lineeX = x;
                this.lineeY = z;
                this.showLint();
            }
        }
        showSceneBox() {
            if (!this.sceneBox) {
                this.sceneBox = this.scene.getChildByName("scene");
            }
            if (this.sceneBox.parent) {
                this.sceneBox.removeSelf();
            }
            else {
                this.scene.addChild(this.sceneBox);
            }
        }
        wheelHandler(e) {
            if (e.delta > 0) {
                this.camera.transform.localPositionY -= 0.5;
            }
            else {
                this.camera.transform.localPositionY += 0.5;
            }
        }
        keyHandler(e) {
            if (e.keyCode == Laya.Keyboard.NUMBER_1) {
                this.type = 1;
                this.editor = this.editor1;
            }
            else if (e.keyCode == Laya.Keyboard.NUMBER_2) {
                this.type = 2;
                this.editor = this.editor2;
            }
            else if (e.keyCode == Laya.Keyboard.NUMBER_3) {
                this.type = 3;
                this.editor = this.editor3;
            }
            else if (e.keyCode == Laya.Keyboard.NUMBER_9) {
                this.type = 9;
                this.editor = this.editor3;
            }
            else if (e.keyCode == Laya.Keyboard.BACKQUOTE) {
                this.showSceneBox();
            }
            else if (e.keyCode == Laya.Keyboard.ENTER) {
                this.showLog();
            }
        }
        showLog() {
            var stt = "";
            var i = 0;
            for (var k in this.terrain) {
                var item = this.terrain[k];
                if (item < 3) {
                    stt += '"' + k + '":' + item + ",";
                }
                if (i > 10) {
                    stt += "\n";
                    i = 0;
                }
                i++;
            }
            LogTool.log(stt);
            var pos = [];
            for (var k in this.terrain) {
                var item = this.terrain[k];
                if (item == 3) {
                    var arr = k.split("_");
                    var x = MathUtil.int(arr[0]);
                    var z = MathUtil.int(arr[1]);
                    pos.push({ x: x, z: z });
                }
            }
            var st = JSONUtil.stringify(pos);
            LogTool.log(st);
            this.dispatchEvent(CommonEvent.LOG_VIEW_SHOW);
        }
        showLint() {
            var list = MapTool.getLine(this.linesX, this.linesY, this.lineeX, this.lineeY);
            for (var k in list) {
                var co = list[k];
                var box = DisplayUtil.instantiate(this.editor, this.scene, co.x, 1, co.y);
            }
        }
    }

    class TransformUtil {
        static copy(t1, t2) {
            t2.localPositionX = t1.localPositionX;
            t2.localPositionY = t1.localPositionY;
            t2.localPositionZ = t1.localPositionZ;
            t2.localRotationEulerX = t1.localRotationEulerX;
            t2.localRotationEulerY = t1.localRotationEulerY;
            t2.localRotationEulerZ = t1.localRotationEulerZ;
            t2.localScaleX = t1.localScaleX;
            t2.localScaleY = t1.localScaleY;
            t2.localScaleZ = t1.localScaleZ;
        }
    }

    class SceneViewController extends Scene3DController {
        constructor() {
            super();
            this.dataList = [];
            this.viewURL = SceneConfig.getSceneUrl(1);
            this.viewName = 'SceneView';
        }
        openComplete() {
            super.openComplete();
            this.dataList.push(this.data);
            if (!this.scene) {
                this.scene = this.view;
                this.camera = this.scene.getChildByName('Camera');
                if (this.camera) {
                    this.camera.enableHDR = false;
                }
                if (!SceneModel.model.cameraTransform) {
                    SceneModel.model.cameraTransform = {};
                    TransformUtil.copy(this.camera.transform, SceneModel.model.cameraTransform);
                }
            }
            this.addEventListener(SceneEvent.SCENE_VIEW_SET, this, this.setHandler);
            this.addEventListener(SceneEvent.SCENE_VIEW_CLOSE, this, this.closeHandler);
            this.initPlayer(this.data);
        }
        initPlayer(data) {
            TransformUtil.copy(SceneModel.model.cameraTransform, this.camera.transform);
            var x = ParamUtil.getNumber(data, 'x', 0);
            var z = ParamUtil.getNumber(data, 'z', 0);
            this.camera.transform.localPositionX = 6.17 + x;
            this.camera.transform.localPositionZ = -6.47 + z;
            var box = this.scene.getChildByName('role_box');
            var playerVo = SceneTool.createPlayer();
            playerVo.isPlayer = true;
            playerVo.camp = 0;
            playerVo.halo = 1;
            playerVo.ix = box.transform.localPositionX;
            playerVo.iy = box.transform.localPositionY;
            playerVo.iz = box.transform.localPositionZ;
            playerVo.dir = -250;
            playerVo.actState = 'stand';
            this.playerVo = playerVo;
            if (!this.player) {
                this.player = new SceneUnitViewController(this.scene, playerVo);
                this.startChild(this.player);
            }
            else {
                this.setHandler(this.data);
            }
        }
        setHandler(data) {
            this.player.vo = this.playerVo;
            this.player.playAnim('stand', 0.01);
        }
        closeHandler(data) {
            var data = this.removeData(data);
            if (data) {
                this.parentView = data.parentView;
                this.parentView.addChild(this.view);
                this.initPlayer(data);
            }
            else {
                this.close();
            }
        }
        removeData(data) {
            var nlist = [];
            var ddata = null;
            for (var k in this.dataList) {
                var sdata = this.dataList[k];
                if (sdata && sdata.parentView != data.parentView) {
                    nlist.push(sdata);
                    ddata = sdata;
                }
            }
            this.dataList = nlist;
            return ddata;
        }
    }

    class SceneController extends Controller {
        constructor() { super(); }
        run() {
            super.run();
            this.startChild(new SceneClassController());
            SceneModel.model.init();
            ViewManager.register(SceneEvent.SCENE_VIEW_SHOW, this, SceneViewController);
            ViewManager.register(SceneEvent.SCENE_EDITOR_VIEW_SHOW, this, SceneEditorViewController);
            this.addEventListener(SceneEvent.SCENE_BATTLE_VIEW_SHOW, this, this.showBattleHandler);
        }
        showBattleHandler(data) {
            var cid = ParamUtil.getInt(data, 'cid', 1);
            var vo = SceneModel.model.vo = SceneVoBuilder.getSceneVo(cid);
            vo.battleType = ParamUtil.getInt(data, 'battleType', 1);
            vo.teamNum = ParamUtil.getInt(data, 'teamNum');
            vo.victoryNum = ParamUtil.getInt(data, 'victoryNum', 1);
            vo.npcCamp = ParamUtil.getInt(data, 'monCamp', 0);
            vo.vipBuff = ParamUtil.getInt(data, 'vipBuff', 0);
            vo.totalTime = ParamUtil.getInt(data, 'totalTime', 180);
            vo.difficulty = ParamUtil.getInt(data, 'difficulty', 0);
            vo.playerVo = data.playerVo;
            vo.lv = ParamUtil.getInt(data, 'lv', 1);
            vo.locList1 = ParamUtil.getObject(data, 'locList1', []);
            vo.locList2 = ParamUtil.getObject(data, 'locList2', []);
            LogTool.log('SceneController.vo.locList1:' + JSONUtil.stringify(vo.locList1));
            LogTool.log('SceneController:vo.locList2:' + JSONUtil.stringify(vo.locList2));
            LogTool.log("vo.victoryNum:" + vo.victoryNum);
            ViewManager.show(this, SceneBattleViewController, data);
        }
    }

    class SegmentLuckyBoxConfig {
        static getCard(cardType, triphyNum) {
            var normalCardList = [];
            var rareCardList = [];
            var epicCardList = [];
            for (var k in this.normalCardList) {
                if (triphyNum >= this.normalCardList[k].triphyNum) {
                    normalCardList.push(this.normalCardList[k]);
                }
            }
            for (var k in this.rareCardList) {
                if (triphyNum >= this.rareCardList[k].triphyNum) {
                    rareCardList.push(this.rareCardList[k]);
                }
            }
            for (var k in this.epicCardList) {
                if (triphyNum >= this.epicCardList[k].triphyNum) {
                    epicCardList.push(this.epicCardList[k]);
                }
            }
            if (cardType == 0) {
                if (normalCardList.length > 0) {
                    var card = RandomUtil.randomItem(normalCardList);
                }
                else {
                    return null;
                }
            }
            else if (cardType == 1) {
                if (rareCardList.length > 0) {
                    var card = RandomUtil.randomItem(rareCardList);
                }
                else {
                    return null;
                }
            }
            else {
                if (epicCardList.length > 0) {
                    var card = RandomUtil.randomItem(epicCardList);
                }
                else {
                    return null;
                }
            }
            return ObjectUtil.copy(card);
        }
        static getLuckyBox(triphyNum, rwType) {
            var rewardList = [];
            var list = [];
            if (rwType == 1) {
                list = this.rwList1;
            }
            else {
                list = this.rwList2;
            }
            var reward = RandomUtil.randomWeight(list, 1);
            var rewardItem = reward[0];
            if (reward) {
                if (rewardItem.cardType == 0 || rewardItem.cardType == 1 || rewardItem.cardType == 2) {
                    var card = this.getCard(rewardItem.cardType, triphyNum);
                    if (card) {
                        card.num = rewardItem.num;
                        card.rewardType = rewardItem.rewardType;
                        rewardList.push(card);
                    }
                }
                else {
                    rewardList.push(rewardItem);
                }
            }
            if (rewardList.length > 0) {
                return rewardList;
            }
            else {
                return [{ cid: 20010001, num: 500, cardType: 2, rewardType: 1 }];
            }
        }
    }
    SegmentLuckyBoxConfig.normalCardList = [
        { cid: 30011001, num: 1, triphyNum: 100, cardType: 0, rewardType: 0 },
        { cid: 30011002, num: 1, triphyNum: 160, cardType: 0, rewardType: 0 },
        { cid: 30011003, num: 1, triphyNum: 120, cardType: 0, rewardType: 0 },
        { cid: 30011005, num: 1, triphyNum: 200, cardType: 0, rewardType: 0 },
        { cid: 30011006, num: 1, triphyNum: 400, cardType: 0, rewardType: 0 },
        { cid: 30011007, num: 1, triphyNum: 500, cardType: 0, rewardType: 0 },
        { cid: 30011008, num: 1, triphyNum: 600, cardType: 0, rewardType: 0 }
    ];
    SegmentLuckyBoxConfig.rareCardList = [
        { cid: 30011004, num: 1, triphyNum: 300, cardType: 1, rewardType: 0 },
        { cid: 30011009, num: 1, triphyNum: 700, cardType: 1, rewardType: 0 }
    ];
    SegmentLuckyBoxConfig.epicCardList = [
        { cid: 30011010, num: 1, triphyNum: 800, cardType: 2, rewardType: 0 }
    ];
    SegmentLuckyBoxConfig.rwList1 = [
        { cardType: 0, num: 10, weight: 20, rewardType: 0 },
        { cardType: 1, num: 5, weight: 20, rewardType: 0 },
        { cardType: 3, num: 2000, cid: 20010003, weight: 15, rewardType: 0 },
        { cardType: 4, num: 100, cid: 20010001, weight: 15, rewardType: 0 },
        { cardType: 0, num: 20, weight: 10, rewardType: 0 },
        { cardType: 1, num: 10, weight: 10, rewardType: 0 },
        { cardType: 0, num: 80, weight: 6, rewardType: 1 },
        { cardType: 1, num: 40, weight: 3, rewardType: 1 },
        { cardType: 2, num: 8, weight: 1, rewardType: 1 },
    ];
    SegmentLuckyBoxConfig.rwList2 = [
        { cardType: 0, num: 80, weight: 6, rewardType: 1 },
        { cardType: 1, num: 40, weight: 3, rewardType: 1 },
        { cardType: 2, num: 8, weight: 1, rewardType: 1 },
    ];

    class SegmentLuckyBoxView extends ui.segment.SegmentLuckyBoxUI {
        constructor() {
            super();
            this.zOrder = 85;
        }
    }

    class SegmentLuckyBoxViewController extends DialogViewController {
        constructor() {
            super();
            this.rwType = 1;
            this.dataList = [];
            this.selectIndex = -1;
            this.viewClass = SegmentLuckyBoxView;
            this.viewName = 'SegmentLuckyBoxView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.img_get.visible = false;
            this.ui.img_ad.visible = false;
            this.ui.img_get.on(Laya.Event.CLICK, this, this.getHandler);
            this.ui.img_ad.on(Laya.Event.CLICK, this, this.adOpenBoxHandler);
            this.boxNum = 0;
            this.rewardList = [];
            this.ui.img_info.skin = 'ui/img_UM_ui_text64.png';
            this.ui.img_info.visible = true;
            this.ui.img_giveUp.on(Laya.Event.CLICK, this, this.close);
            this.ui.img_select.on(Laya.Event.CLICK, this, this.selectHandler);
            this.addEventListener(SegmentEvent.SEGMENT_LUCKY_BOX_VIEW_REFRESH, this, this.showList);
            this.showList();
        }
        selectHandler() {
            this.ui.img_get.visible = true;
            this.ui.img_ad.visible = true;
            this.ui.img_giveUp.visible = false;
            this.ui.img_select.visible = false;
            if (!this.dataList[0]) {
                this.selectIndex = 0;
            }
            else if (!this.dataList[1]) {
                this.selectIndex = 1;
            }
            else if (!this.dataList[2]) {
                this.selectIndex = 2;
            }
            else {
                return;
            }
            this.boxHandler();
        }
        showList() {
            var nlist = [];
            var index = 0;
            for (var i = 0; i < 3; i++) {
                var data = {};
                var boxVo = {};
                boxVo.index = index;
                boxVo.goods = this.dataList[index];
                if (boxVo.goods) {
                    data.img_box = { visible: false };
                    data.img_hand = { visible: false };
                    data.ui_card = GoodsViewTool.getGoodsRewardData(boxVo.goods);
                    if (boxVo.goods.rewardType == 1) {
                        data.img_bg = { skin: 'ui/img_UM_shop_ui_bg2.png' };
                        data.img_title = { skin: 'ui/img_UM_ui_text68.png' };
                    }
                    else {
                        data.img_bg = { skin: 'ui/img_UM_shop_ui_bg4.png' };
                        data.img_title = { skin: 'ui/img_UM_ui_text67.png' };
                    }
                }
                else {
                    data.img_box = { visible: true };
                    data.ui_card = { visible: false };
                    data.img_bg = { skin: 'ui/img_UM_shop_ui_bg3.png' };
                    data.img_title = { skin: 'ui/img_UM_ui_text66.png' };
                }
                nlist.push(data);
                index++;
            }
            this.ui.list_box.dataSource = nlist;
        }
        getRwHandler(e) {
            if (MouseTool.checkClick(e)) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.selectIndex = vo.index;
                    vo.isReceive = true;
                    this.ui.img_get.visible = true;
                    this.ui.img_ad.visible = true;
                    if (this.boxNum == 0) {
                        this.ui.img_info.skin = 'ui/img_UM_ui_text71.png';
                        this.boxHandler();
                    }
                    else if (this.boxNum == 1) {
                        this.ui.img_info.skin = 'ui/img_UM_ui_text72.png';
                        this.adHandler();
                    }
                    else {
                        this.ui.img_info.visible = false;
                        this.adHandler();
                        this.ui.img_get.centerX = 0;
                        this.ui.img_ad.visible = false;
                    }
                }
            }
        }
        adHandler() {
            AdTool.videoAdShow(this, this.boxHandler, 'mysteriousBox' + this.boxNum);
        }
        boxHandler() {
            var rwlist = SegmentLuckyBoxConfig.getLuckyBox(SegmentModel.model.maxTriphyNum, this.rwType);
            this.dataList[this.selectIndex] = rwlist[0];
            for (var k in rwlist) {
                this.rewardList.push(rwlist[k]);
            }
            if (this.boxNum == 0) {
                this.rwType = 1;
                this.ui.img_info.skin = 'ui/img_UM_ui_text71.png';
            }
            else if (this.boxNum == 1) {
                this.rwType = 2;
                this.ui.img_info.skin = 'ui/img_UM_ui_text72.png';
            }
            else {
                this.ui.img_info.visible = false;
                this.rwType = 1;
            }
            this.boxNum++;
            this.dispatchEvent(SegmentEvent.SEGMENT_LUCKY_BOX_VIEW_REFRESH);
        }
        getHandler() {
            var reward = GoodsTool.mergeList(this.rewardList);
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: reward, rewardType: 1 });
            this.close();
        }
        adOpenBoxHandler() {
            if (!this.dataList[0]) {
                this.selectIndex = 0;
            }
            else if (!this.dataList[1]) {
                this.selectIndex = 1;
            }
            else if (!this.dataList[2]) {
                this.selectIndex = 2;
            }
            else {
                return;
            }
            if (this.boxNum >= 2) {
                this.ui.img_get.centerX = 0;
                this.ui.img_ad.visible = false;
            }
            this.adHandler();
        }
    }

    class SegmentLvUpView extends ui.segment.SegmentLvUpUI {
        constructor() {
            super();
            this.zOrder = 52;
        }
    }

    class SegmentLvUpViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = SegmentLvUpView;
            this.viewName = 'SegmentLvUpView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.img_goto.on(Laya.Event.CLICK, this, this.gotoHandler);
            this.showList();
        }
        showList() {
            var list = SegmentConfig.rewardList;
            var nlist = [];
            for (var k in list) {
                var segmentVo = list[k];
                var data = {};
                data.vo = segmentVo;
                if ((SegmentModel.model.maxSegment + 1) == segmentVo.segment) {
                    LogTool.log(JSONUtil.stringify(segmentVo));
                    data.txt_tong = { text: '' + segmentVo.goods.num };
                    data.txt_name = { text: GoodsListConfig.getVo(segmentVo.goods.cid).name };
                    if (segmentVo.goods.goodsType == 'box' || segmentVo.goods.goodsType == 'tong' || segmentVo.goods.goodsType == 'jin') {
                        data.img_rw = { skin: GoodsConfig.getSegmentIcoUrl(segmentVo.goods.cid), x: 0, y: 48 };
                    }
                    else {
                        data.img_rw = { skin: GoodsConfig.getImgUrl(segmentVo.goods.cid), x: 9, y: 40 };
                    }
                    nlist.push(data);
                }
            }
            this.ui.list_rw.dataSource = nlist;
            this.showSegmentHandler();
        }
        gotoHandler() {
            this.close();
            this.dispatchEvent(SegmentEvent.SEGMENT_VIEW_SHOW, { showType: ViewType.OPEN });
        }
        showSegmentHandler() {
            this.ui.img_segment1.skin = SegmentTool.getSegmentImg(SegmentModel.model.maxSegment);
            this.ui.img_segment2.skin = SegmentTool.getSegmentImg(SegmentModel.model.maxSegment + 1);
            ;
            this.ui.txt_name1.text = '' + SegmentTool.getSegmentName(SegmentModel.model.maxSegment);
            this.ui.txt_name2.text = '' + SegmentTool.getSegmentName(SegmentModel.model.maxSegment + 1);
        }
    }

    class SegmentView extends ui.segment.SegmentUI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class SegmentViewController extends DialogViewController {
        constructor() {
            super();
            this.index = 0;
            this.viewClass = SegmentView;
            this.viewName = 'SegmentView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.list_segment.scrollBar.visible = false;
            this.ui.list_segment.on(Laya.Event.CLICK, this, this.getRewardHandler);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showList);
            this.showList();
            var width = 312;
            if (this.index >= 0) {
                this.ui.list_segment.scrollBar.value = width * this.index - width * 1.5;
            }
            this.addEventListener(BattleEvent.BATTLE_LOAD_START, this, this.close);
        }
        showList() {
            this.troNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            var list = SegmentConfig.rewardList;
            var nlist = [];
            this.index = -1;
            var i = 0;
            var currentItem = null;
            var currentTriphy = 0;
            for (var k in list) {
                var segmentVo = list[k];
                var data = {};
                data.vo = segmentVo;
                data.txt_name = segmentVo.name;
                data.img_segment = segmentVo.img;
                data.txt_num = '' + segmentVo.unlockTroNum;
                if (currentItem) {
                    currentItem.img_arrow = { visible: false };
                    currentItem.txt_num2 = { visible: false };
                    currentItem.img_strip = { visible: true, scaleX: 1 };
                }
                if (segmentVo.goods.goodsType == 'box' || segmentVo.goods.goodsType == 'tong' || segmentVo.goods.goodsType == 'jin') {
                    data.img_box = { skin: GoodsConfig.getSegmentIcoUrl(segmentVo.goods.cid), visible: true };
                    data.ui_card = { visible: false };
                    if (segmentVo.goods.goodsType == 'tong' || segmentVo.goods.goodsType == 'jin') {
                        data.txt_name1 = { visible: true, text: GoodsListConfig.getVo(segmentVo.goods.cid).name };
                    }
                    else {
                        data.txt_name1 = { visible: true, text: this.getBoxName(segmentVo) };
                    }
                }
                else {
                    data.img_box = { visible: false };
                    data.ui_card = GoodsViewTool.getGoodsRewardData(segmentVo.goods);
                    data.txt_name1 = { visible: false };
                }
                data.txt_num1 = 'x' + segmentVo.goods.num;
                if (SegmentModel.model.maxTriphyNum >= segmentVo.unlockTroNum) {
                    if (SegmentModel.model.getState(segmentVo.lv) == 3) {
                        data.img_lock = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                        data.img_state = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                        data.box_get = { vo: segmentVo, disabled: true, visible: false };
                        data.img_available = { visible: false };
                    }
                    else {
                        data.img_lock = { skin: 'ui/img_UM_ui_tick.png', visible: false };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: false };
                        data.img_state = { visible: false };
                        data.img_available = { visible: true };
                        data.box_get = { vo: segmentVo, disabled: false, visible: true, guideName: 'segm_' + i };
                        if (this.index == -1) {
                            this.index = i;
                        }
                    }
                    currentItem = data;
                    currentTriphy = segmentVo.unlockTroNum;
                }
                else {
                    data.img_lock = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                    data.img_state = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                    data.box_get = { vo: segmentVo, disabled: true, visible: false };
                    data.img_arrow = { visible: false };
                    data.txt_num2 = { visible: false };
                    data.img_available = { visible: false };
                    data.img_strip = { visible: false, scaleX: 1 };
                }
                nlist.push(data);
                i++;
            }
            if (currentItem) {
                currentItem.img_arrow = { visible: true };
                currentItem.txt_num2 = { visible: true, text: '' + currentTriphy };
                currentItem.img_strip = { visible: true, scaleX: 0.5 };
            }
            this.ui.list_segment.dataSource = nlist;
        }
        getRewardHandler(e) {
            if (MouseTool.checkClick(e, 'box_get')) {
                var vo = ViewDataTool.getDataValue(e.target);
                var reward = [];
                var rewardType = 0;
                if (vo) {
                    SegmentModel.model.setState(vo.lv, 3);
                    SegmentModel.model.saveData();
                    if (vo.goods.cid == 3001) {
                        reward = GoodsBoxConfig.getBronzeBox(SegmentModel.model.maxTriphyNum);
                        reward = GoodsTool.mergeList(reward);
                        rewardType = vo.goods.cid;
                    }
                    else if (vo.goods.cid == 3002) {
                        reward = GoodsBoxConfig.getGoldBox(SegmentModel.model.maxTriphyNum);
                        reward = GoodsTool.mergeList(reward);
                        rewardType = vo.goods.cid;
                    }
                    else if (vo.goods.cid == 3003) {
                        reward = GoodsBoxConfig.getMasonryBox(SegmentModel.model.maxTriphyNum);
                        reward = GoodsTool.mergeList(reward);
                        rewardType = vo.goods.cid;
                    }
                    else if (vo.goods.cid == 3004) {
                        reward = GoodsBoxConfig.geLegendBox(SegmentModel.model.maxTriphyNum);
                        reward = GoodsTool.mergeList(reward);
                        rewardType = vo.goods.cid;
                    }
                    else if (vo.goods.cid == 3005) {
                        reward = GoodsBoxConfig.getRainbowBox(SegmentModel.model.maxTriphyNum);
                        reward = GoodsTool.mergeList(reward);
                        rewardType = vo.goods.cid;
                    }
                    else {
                        reward.push({ cid: vo.goods.cid, num: vo.goods.num });
                        rewardType = 1;
                    }
                    this.dispatchEvent(SegmentEvent.SEGMENT_REWARD_REPORT, { troNum: vo.unlockTroNum });
                    this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: reward, rewardType: rewardType });
                    if (vo.isPopup == true) {
                        this.dispatchEvent(SegmentEvent.SEGMENT_LUCKY_BOX_VIEW_SHOW);
                    }
                }
            }
        }
        getBoxName(segmentVo) {
            var boxName = '';
            if (segmentVo.goods.cid == 3001) {
                boxName = '青铜宝箱';
            }
            else if (segmentVo.goods.cid == 3002) {
                boxName = '黄金宝箱';
            }
            else if (segmentVo.goods.cid == 3003) {
                boxName = '钻石宝箱';
            }
            else if (segmentVo.goods.cid == 3004) {
                boxName = '传说宝箱';
            }
            else {
                boxName = '彩虹宝箱';
            }
            return boxName;
        }
        testHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: 20 }] });
            LogTool.log('++++++' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY));
        }
        testHandler1() {
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_TRIPHY, num: 20 }] });
            LogTool.log('------' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY));
        }
    }

    class SegmentController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            SegmentModel.model.init();
            ViewManager.register(SegmentEvent.SEGMENT_VIEW_SHOW, this, SegmentViewController);
            ViewManager.register(SegmentEvent.SEGMENT_LV_UP_VIEW_SHOW, this, SegmentLvUpViewController);
            ViewManager.register(SegmentEvent.SEGMENT_LUCKY_BOX_VIEW_SHOW, this, SegmentLuckyBoxViewController);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.initHandler);
            this.addEventListener(MainEvent.MAIN_INIT_COMPLETE, this, this.initHandler);
            this.addEventListener(BattleEvent.BATTLE_SETTLE_COMPLETE, this, this.settleHandler);
        }
        initHandler() {
            var troNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            var segment = SegmentTool.getSegment(troNum);
            if (segment > SegmentModel.model.maxSegment) {
                this.dispatchEvent(SegmentEvent.SEGMENT_LV_UP_VIEW_SHOW);
            }
            if (troNum > SegmentModel.model.maxTriphyNum) {
                SegmentModel.model.maxSegment = segment;
                SegmentModel.model.maxTriphyNum = troNum;
                SegmentModel.model.saveData();
                this.dispatchEvent(SegmentEvent.SEGMENT_TRIPHY_NUM_CHANGE);
            }
            this.checkSegmentFinally();
        }
        checkSegmentFinally() {
            var vo = SegmentTool.getCompeletSegmentVo();
            if (vo) {
                SegmentModel.model.tipsIco = true;
            }
            else {
                SegmentModel.model.tipsIco = false;
            }
            SegmentModel.model.saveData();
        }
        settleHandler() {
            this.dispatchEvent(SegmentEvent.SEGMENT_VIEW_SHOW, { showType: ViewType.OPEN });
        }
    }

    class ShopConfig {
        static getCheckList(index) {
            return this.chestList[index];
        }
    }
    ShopConfig.boxNum = 5;
    ShopConfig.shopType = 0;
    ShopConfig.chestList = [
        { price: { cid: 20010001, num: 500 }, goods: { cid: 20010003, num: 2000 } },
        { price: { cid: 20010001, num: 2000 }, goods: { cid: 20010003, num: 10000 } },
        { price: { cid: 20010001, num: 0 }, goods: { cid: 20010003, num: 2000 } },
        { price: { cid: 20010001, num: 0 }, goods: { cid: 20010003, num: 5000 } },
    ];
    ShopConfig.chestNum = [1, 3, 10, 10];
    ShopConfig.rewardNum1 = 500;
    ShopConfig.rewardNum2 = 200;
    ShopConfig.resNum = 5;
    ShopConfig.list = {
        30042001: { cid: 30042001, price: { cid: 20010001, num: 0 }, goods: { cid: 30042001, num: 1 } },
        30042002: { cid: 30042002, price: { cid: 20010001, num: 5000 }, goods: { cid: 30042002, num: 1 } },
        30042003: { cid: 30042003, price: { cid: 20010001, num: 10000 }, goods: { cid: 30042003, num: 1 } },
        30042004: { cid: 30042004, price: { cid: 20010001, num: 15000 }, goods: { cid: 30042004, num: 1 } },
        30042101: { cid: 30042101, price: { cid: 20010001, num: 0 }, goods: { cid: 30042101, num: 1 } },
        30042102: { cid: 30042102, price: { cid: 20010001, num: 1000 }, goods: { cid: 30042102, num: 1 } },
        30042103: { cid: 30042103, price: { cid: 20010001, num: 2000 }, goods: { cid: 30042103, num: 1 } },
        30042104: { cid: 30042104, price: { cid: 20010001, num: 3000 }, goods: { cid: 30042104, num: 1 } },
        30042105: { cid: 30042105, price: { cid: 20010001, num: 4000 }, goods: { cid: 30042105, num: 1 } },
        30042106: { cid: 30042106, price: { cid: 20010001, num: 5000 }, goods: { cid: 30042106, num: 1 } },
        30042107: { cid: 30042107, price: { cid: 20010001, num: 6000 }, goods: { cid: 30042107, num: 1 } },
        30042108: { cid: 30042108, price: { cid: 20010001, num: 7000 }, goods: { cid: 30042108, num: 1 } },
        30042109: { cid: 30042109, price: { cid: 20010001, num: 8000 }, goods: { cid: 30042109, num: 1 } },
        30042201: { cid: 30042201, price: { cid: 20010001, num: 0 }, goods: { cid: 30042201, num: 1 } },
        30042202: { cid: 30042202, price: { cid: 20010001, num: 1000 }, goods: { cid: 30042202, num: 1 } },
        30042203: { cid: 30042203, price: { cid: 20010001, num: 2000 }, goods: { cid: 30042203, num: 1 } },
        30042204: { cid: 30042204, price: { cid: 20010001, num: 3000 }, goods: { cid: 30042204, num: 1 } },
        30042205: { cid: 30042205, price: { cid: 20010001, num: 4000 }, goods: { cid: 30042205, num: 1 } },
        30042206: { cid: 30042206, price: { cid: 20010001, num: 5000 }, goods: { cid: 30042206, num: 1 } },
        30042207: { cid: 30042207, price: { cid: 20010001, num: 6000 }, goods: { cid: 30042207, num: 1 } },
        30042208: { cid: 30042208, price: { cid: 20010001, num: 7000 }, goods: { cid: 30042208, num: 1 } },
        30042209: { cid: 30042209, price: { cid: 20010001, num: 8000 }, goods: { cid: 30042209, num: 1 } },
        30042210: { cid: 30042210, price: { cid: 20010001, num: 9000 }, goods: { cid: 30042210, num: 1 } },
        30042211: { cid: 30042211, price: { cid: 20010001, num: 10000 }, goods: { cid: 30042211, num: 1 } },
        30042212: { cid: 30042212, price: { cid: 20010001, num: 11000 }, goods: { cid: 30042212, num: 1 } },
        30042301: { cid: 30042301, price: { cid: 20010001, num: 5000 }, goods: { cid: 30042301, num: 1 } },
        30042302: { cid: 30042302, price: { cid: 20010001, num: 10000 }, goods: { cid: 30042302, num: 1 } },
        30042303: { cid: 30042303, price: { cid: 20010001, num: 20000 }, goods: { cid: 30042303, num: 1 } },
        30042304: { cid: 30042304, price: { cid: 20010001, num: 30000 }, goods: { cid: 30042304, num: 1 } },
        30042305: { cid: 30042305, price: { cid: 20010001, num: 50000 }, goods: { cid: 30042305, num: 1 } },
        30042401: { cid: 30042401, price: { cid: 20010001, num: 5000 }, goods: { cid: 30042401, num: 1 } },
        30042402: { cid: 30042402, price: { cid: 20010001, num: 8000 }, goods: { cid: 30042402, num: 1 } },
        30042403: { cid: 30042403, price: { cid: 20010001, num: 20000 }, goods: { cid: 30042403, num: 1 } },
        30041101: { cid: 30041101, price: { cid: 20010001, num: 0 }, goods: { cid: 30041101, num: 1 } },
        30041102: { cid: 30041102, price: { cid: 20010001, num: 1000 }, goods: { cid: 30041102, num: 1 } },
        30041103: { cid: 30041103, price: { cid: 20010001, num: 2000 }, goods: { cid: 30041103, num: 1 } },
        30041104: { cid: 30041104, price: { cid: 20010001, num: 3000 }, goods: { cid: 30041104, num: 1 } },
        30041105: { cid: 30041105, price: { cid: 20010001, num: 4000 }, goods: { cid: 30041105, num: 1 } },
        30041106: { cid: 30041106, price: { cid: 20010001, num: 5000 }, goods: { cid: 30041106, num: 1 } },
        30041107: { cid: 30041107, price: { cid: 20010001, num: 6000 }, goods: { cid: 30041107, num: 1 } },
        30041108: { cid: 30041108, price: { cid: 20010001, num: 7000 }, goods: { cid: 30041108, num: 1 } },
        30041109: { cid: 30041109, price: { cid: 20010001, num: 8000 }, goods: { cid: 30041109, num: 1 } },
        30041110: { cid: 30041110, price: { cid: 20010001, num: 9000 }, goods: { cid: 30041110, num: 1 } },
        30041111: { cid: 30041111, price: { cid: 20010001, num: 10000 }, goods: { cid: 30041111, num: 1 } },
        30041201: { cid: 30041201, price: { cid: 20010001, num: 0 }, goods: { cid: 30041201, num: 1 } },
        30041202: { cid: 30041202, price: { cid: 20010001, num: 1000 }, goods: { cid: 30041202, num: 1 } },
        30041203: { cid: 30041203, price: { cid: 20010001, num: 2000 }, goods: { cid: 30041203, num: 1 } },
        30041204: { cid: 30041204, price: { cid: 20010001, num: 3000 }, goods: { cid: 30041204, num: 1 } },
        30041205: { cid: 30041205, price: { cid: 20010001, num: 4000 }, goods: { cid: 30041205, num: 1 } },
        30041206: { cid: 30041206, price: { cid: 20010001, num: 5000 }, goods: { cid: 30041206, num: 1 } },
        30041207: { cid: 30041207, price: { cid: 20010001, num: 6000 }, goods: { cid: 30041207, num: 1 } },
        30041208: { cid: 30041208, price: { cid: 20010001, num: 7000 }, goods: { cid: 30041208, num: 1 } },
        30041209: { cid: 30041209, price: { cid: 20010001, num: 8000 }, goods: { cid: 30041209, num: 1 } },
        30041210: { cid: 30041210, price: { cid: 20010001, num: 9000 }, goods: { cid: 30041210, num: 1 } },
        30041211: { cid: 30041211, price: { cid: 20010001, num: 10000 }, goods: { cid: 30041211, num: 1 } },
    };
    ShopConfig.getExcellentGoods = 200;
    ShopConfig.getLegendGoods = 500;
    ShopConfig.bronzeBoxList = [
        { cid: 3001, num: 1, price: { cid: 20010001, num: 100 }, name: '青铜宝箱' },
    ];
    ShopConfig.goldBoxList = [
        { cid: 3002, num: 1, price: { cid: 20010001, num: 200 }, name: '黄金宝箱' },
    ];
    ShopConfig.JinBoxList = [
        { cid: 3003, num: 1, price: { cid: 20010001, num: 500 }, name: '砖石宝箱' },
    ];
    ShopConfig.preferentialList = [
        { cid: 3004, price: { cid: 20010001, num: 100 }, name: '每日特惠' },
    ];
    ShopConfig.rwList = [
        { cid: 30011001, num: 40, cardType: 0, price: { cid: 20010001, num: 300 } },
        { cid: 30011002, num: 40, cardType: 0, price: { cid: 20010001, num: 300 } },
        { cid: 30011003, num: 40, cardType: 0, price: { cid: 20010001, num: 300 } },
        { cid: 30011004, num: 10, cardType: 1, price: { cid: 20010001, num: 300 } },
        { cid: 30011005, num: 40, cardType: 0, price: { cid: 20010001, num: 300 } },
        { cid: 30011006, num: 40, cardType: 0, price: { cid: 20010001, num: 300 } },
        { cid: 30011007, num: 40, cardType: 0, price: { cid: 20010001, num: 300 } },
        { cid: 30011008, num: 40, cardType: 0, price: { cid: 20010001, num: 300 } },
        { cid: 30011009, num: 10, cardType: 1, price: { cid: 20010001, num: 300 } },
        { cid: 30011010, num: 2, cardType: 2, price: { cid: 20010001, num: 300 } },
    ];

    class ShopBuyView extends ui.shop.ShopBuyUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class ShopBuyViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = ShopBuyView;
            this.viewName = 'ShopBuyView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.checkGetHandler);
                this.ui.btn_cancel.on(Laya.Event.CLICK, this, this.close);
            }
            this.vo = this.data.vo;
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showGoodsHandler);
            this.showGoodsHandler();
        }
        showGoodsHandler() {
            this.ui.txt_priceJin.text = "" + this.vo.price.num;
            this.ui.txt_priceTong.text = "" + this.vo.goods.num;
        }
        checkGetHandler() {
            if (GoodsCostTool.checkCostConfig(this.vo.price) == false) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "花费不足" });
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
                this.close();
                return;
            }
            this.checkNumHandler();
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: this.vo.goods.cid, num: this.vo.goods.num }, { cid: this.vo.price.cid, num: -(this.vo.price.num) }] });
            this.close();
        }
        checkNumHandler() {
            if (this.vo == ShopConfig.getCheckList(0)) {
                ShopModel.model.jinBoxNum1++;
            }
            else if (this.vo == ShopConfig.getCheckList(1)) {
                ShopModel.model.jinBoxNum2++;
            }
            else if (this.vo == ShopConfig.getCheckList(2)) {
                ShopModel.model.jinBoxNum3++;
            }
            else if (this.vo == ShopConfig.getCheckList(3)) {
                ShopModel.model.jinBoxNum4++;
            }
            else {
                ShopModel.model.saveData();
                return;
            }
        }
    }

    class ShopChestView extends ui.shop.ShopChestUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class ShopChestViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = ShopChestView;
            this.viewName = 'ShopChestView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.item0.on(Laya.Event.CLICK, this, this.shopHandler);
                this.ui.box_0.on(Laya.Event.CLICK, this, this.checkNum1Handler);
                this.ui.box_1.on(Laya.Event.CLICK, this, this.checkNum2Handler);
                this.ui.box_2.on(Laya.Event.CLICK, this, this.jinAdHandler);
                this.ui.box_3.on(Laya.Event.CLICK, this, this.jinAd2Handler);
                this.ui.box_free.on(Laya.Event.CLICK, this, this.addHandler);
                this.ui.item2.on(Laya.Event.CLICK, this, this.medalHandler);
            }
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showDataHandler);
            this.showDataHandler();
        }
        medalHandler() {
            this.dispatchEvent(ShopEvent.SHOP_MEDAL_VIEW_SHOW, { showType: ViewType.OPEN });
            this.close();
        }
        closeHandler() {
            this.close();
        }
        addHandler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
        }
        ad1Handler() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: GoodsAttrType.ATTR_TONG, num: GoodsConfig.tongGetNum }] });
            this.close();
        }
        ad2Handler() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: GoodsAttrType.ATTR_JIN, num: GoodsConfig.jinGetNum }] });
            this.close();
        }
        showDataHandler() {
            this.ui.txt_tong.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG);
            this.ui.txt_jin.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN);
            this.ui.txt_num1.text = '剩余次数' + MathUtil.int(ShopConfig.chestNum[0] - ShopModel.model.jinBoxNum1);
            this.ui.txt_num2.text = '剩余次数' + MathUtil.int(ShopConfig.chestNum[1] - ShopModel.model.jinBoxNum2);
            this.ui.txt_num3.text = '剩余次数' + MathUtil.int(ShopConfig.chestNum[2] - ShopModel.model.jinBoxNum3);
            this.ui.txt_num4.text = '剩余次数' + MathUtil.int(ShopConfig.chestNum[3] - ShopModel.model.jinBoxNum4);
        }
        shopHandler() {
            this.dispatchEvent(ShopEvent.SHOP_MALL_VIEW_SHOW, { showType: ViewType.OPEN });
            this.close();
        }
        checkNum1Handler() {
            if (ShopModel.model.jinBoxNum1 >= ShopConfig.chestNum[0]) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "次数不足" });
                return;
            }
            this.dispatchEvent(ShopEvent.SHOP_BUY_VIEW_SHOW, { vo: ShopConfig.getCheckList(0) });
        }
        checkNum2Handler() {
            if (ShopModel.model.jinBoxNum2 >= ShopConfig.chestNum[1]) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "次数不足" });
                return;
            }
            this.dispatchEvent(ShopEvent.SHOP_BUY_VIEW_SHOW, { vo: ShopConfig.getCheckList(1) });
        }
        jinAdHandler() {
            if (ShopModel.model.jinBoxNum3 >= ShopConfig.chestNum[2]) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "次数不足" });
                return;
            }
            AdTool.videoAdShow(this, this.checkNum3Handler);
        }
        jinAd2Handler() {
            if (ShopModel.model.jinBoxNum4 >= ShopConfig.chestNum[3]) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "次数不足" });
                return;
            }
            AdTool.videoAdShow(this, this.checkNum4Handler);
        }
        checkNum3Handler() {
            var vo = ShopConfig.getCheckList(2);
            ShopModel.model.jinBoxNum3++;
            ShopModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: vo.goods.cid, num: vo.goods.num }] });
        }
        checkNum4Handler() {
            var vo = ShopConfig.getCheckList(3);
            ShopModel.model.jinBoxNum4++;
            ShopModel.model.saveData();
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: [{ cid: vo.goods.cid, num: vo.goods.num }] });
        }
    }

    class ListView extends Laya.EventDispatcher {
        constructor(box) {
            super();
            this.itemRenderList = {};
            this.renderList = [];
            this.batchNum = 0;
            this._selectIndex = -1;
            this.selectBoxName = 'selectBox';
            this.box = box;
            for (var index = 0; index < box.numChildren; index++) {
                var item = box.getChildAt(index);
                this.itemRenderList[index] = item.constructor;
                this.itemRenderList[item.name] = item.constructor;
            }
            this.box.removeChildren();
            this.layouts = new FlowLayout(box);
            this.layouts.isUpdateHeight = false;
            this.id = IdUtil.getId();
            this.box.on(ViewEvent.VIEW_LAYOUT, this, this.layoutHandler);
            this.box.on(Laya.Event.CLICK, this, this.clickHandler);
        }
        layoutHandler() {
            this.layout();
        }
        showList() {
            this.renderList = [];
            this.recoverChildren();
            var list = this.data;
            for (var key in list) {
                if (list.hasOwnProperty(key)) {
                    this.renderList.push(list[key]);
                }
            }
            this.showListHandler();
        }
        showListHandler() {
            var list = this.renderList;
            if (list.length > 0) {
                if (this.batchNum) {
                    var l = Math.min(this.batchNum, list.length);
                }
                else {
                    var l = list.length;
                }
                for (var index = 0; index < l; index++) {
                    this.showItem(list.shift());
                }
            }
            if (this.layouts) {
                this.layouts.layout();
            }
            if (this.batchNum && list.length > 0) {
                Laya.timer.once(15, this, this.showListHandler);
            }
            if (list.length == 0) {
                this.layouts.updataHeight();
                this.setSelectIndex(this._selectIndex);
                DisplayUtil.refreshPanel(this.box);
            }
        }
        showItem(element) {
            if (element) {
                var i = element.itemRenderName;
                if (!i) {
                    i = 0;
                }
                var clas = this.getItemRender(i);
                if (clas) {
                    var itemName = 'ListItem_' + this.id + "_" + element.itemRenderName;
                    var item = PoolUtil.getObject(itemName, clas);
                    item.mouseEnabled = true;
                    item.dataSource = element;
                    this.box.addChild(item);
                }
            }
        }
        getItemRender(name) {
            return this.itemRenderList[name];
        }
        setItemRender(name, clas) {
            this.itemRenderList[name] = clas;
        }
        setItemRenderList(list) {
            this.itemRenderList = list;
        }
        clear() {
            this.data = null;
            this.recoverChildren();
        }
        recoverChildren() {
            var l = this.box.numChildren;
            if (l > 0) {
                for (var i = 0; i < l; i++) {
                    var item = this.box.getChildAt(i);
                    if (item) {
                        PoolUtil.recover(item);
                    }
                }
                this.box.removeChildren();
            }
        }
        addChild(item) {
            this.box.addChild(item);
        }
        getChildAt(i) {
            return this.box.getChildAt(i);
        }
        get numChildren() {
            return this.box.numChildren;
        }
        setItemList(list) {
            this.clear();
            for (var item of list) {
                this.box.addChild(item);
            }
            this.layouts.layout();
        }
        layout() {
            this.layouts.layout();
        }
        clickHandler(e) {
            var vo = this.getDataValue(e.target);
            if (vo) {
                var i = this.box.getChildIndex(e.target);
                if (i >= 0) {
                    this.setSelectIndex(i);
                }
            }
        }
        setSelectIndex(v) {
            var item = this.box.getChildAt(v);
            if (item) {
                this.clearSelectBox();
                var selectBox = item.getChildByName(this.selectBoxName);
                if (selectBox instanceof Laya.Clip) {
                    selectBox.index = 1;
                }
                else if (selectBox instanceof Laya.Button) {
                    selectBox.selected = true;
                }
                else if (this.selectBox) {
                    selectBox.visible = true;
                }
                this.selectBox = selectBox;
                this._selectIndex = v;
                this.event(Laya.Event.CHANGE);
            }
            else {
                this.clearSelectBox();
                this._selectIndex = -1;
                this.event(Laya.Event.CHANGE);
            }
        }
        clearSelectBox() {
            if (this.selectBox instanceof Laya.Clip) {
                this.selectBox.index = 0;
            }
            else if (this.selectBox instanceof Laya.Button) {
                this.selectBox.selected = false;
            }
            else if (this.selectBox) {
                this.selectBox.visible = false;
            }
        }
        set maxWidth(v) {
            this.layouts.maxWidth = v;
        }
        set dataSource(data) {
            this.data = data;
            this.showList();
        }
        get dataSource() {
            return this.data;
        }
        set selectIndex(v) {
            this.setSelectIndex(v);
        }
        get selectIndex() {
            return this._selectIndex;
        }
        get selectItem() {
            if (this._selectIndex >= 0) {
                var box = this.box.getChildAt(this._selectIndex);
                if (box) {
                    return box;
                }
            }
            return null;
        }
        get selectData() {
            if (this._selectIndex >= 0) {
                var box = this.box.getChildAt(this._selectIndex);
                if (box) {
                    return box.dataSource;
                }
            }
            return null;
        }
        getDataValue(view, key = 'vo') {
            if (!view) {
                return null;
            }
            if ('dataSource' in view) {
            }
            else {
                return null;
            }
            var data = view.dataSource;
            if (!data) {
                return null;
            }
            return data[key];
        }
    }

    class ShopRollConfig {
        static getRollData(index) {
            return this.rollConsList[index];
        }
    }
    ShopRollConfig.rollConsList = {
        0: { cid: 20010003, num: 1000, outNum: 1 },
        1: { cid: 20010001, num: 300, outNum: 2 },
        2: { cid: 20010001, num: 600, outNum: 3 },
        3: { cid: 20010001, num: 600, outNum: 4 }
    };
    ShopRollConfig.rollConsNum = [3, 2, 1];
    ShopRollConfig.rollBoxSrc = ['ui/img_uk_icon_box3.png', 'ui/img_uk_icon_box2.png', 'ui/img_uk_icon_box1.png'];
    ShopRollConfig.rollBoxTwoSrc = ['ui/img_uk_icon_boxopen3.png', 'ui/img_uk_icon_boxopen2.png', 'ui/img_uk_icon_boxopen1.png'];
    ShopRollConfig.rollList = [
        { cid: 30042002, num: 1, weight: 1 },
        { cid: 30042003, num: 1, weight: 1 },
        { cid: 30042004, num: 1, weight: 1 },
        { cid: 30042102, num: 1, weight: 1 },
        { cid: 30042103, num: 1, weight: 1 },
        { cid: 30042104, num: 1, weight: 1 },
        { cid: 30042105, num: 1, weight: 1 },
        { cid: 30042106, num: 1, weight: 1 },
        { cid: 30042107, num: 1, weight: 1 },
        { cid: 30042108, num: 1, weight: 1 },
        { cid: 30042109, num: 1, weight: 1 },
        { cid: 30042202, num: 1, weight: 1 },
        { cid: 30042203, num: 1, weight: 1 },
        { cid: 30042204, num: 1, weight: 1 },
        { cid: 30042205, num: 1, weight: 1 },
        { cid: 30042206, num: 1, weight: 1 },
        { cid: 30042207, num: 1, weight: 1 },
        { cid: 30042208, num: 1, weight: 1 },
        { cid: 30042209, num: 1, weight: 1 },
        { cid: 30042210, num: 1, weight: 1 },
        { cid: 30042211, num: 1, weight: 1 },
        { cid: 30042212, num: 1, weight: 1 },
        { cid: 30042301, num: 1, weight: 1 },
        { cid: 30042302, num: 1, weight: 1 },
        { cid: 30042303, num: 1, weight: 1 },
        { cid: 30042304, num: 1, weight: 1 },
        { cid: 30042305, num: 1, weight: 1 },
        { cid: 30042401, num: 1, weight: 1 },
        { cid: 30042402, num: 1, weight: 1 },
        { cid: 30042403, num: 1, weight: 1 },
        { cid: 30041102, num: 1, weight: 1 },
        { cid: 30041103, num: 1, weight: 1 },
        { cid: 30041104, num: 1, weight: 1 },
        { cid: 30041105, num: 1, weight: 1 },
        { cid: 30041106, num: 1, weight: 1 },
        { cid: 30041107, num: 1, weight: 1 },
        { cid: 30041108, num: 1, weight: 1 },
        { cid: 30041109, num: 1, weight: 1 },
        { cid: 30041110, num: 1, weight: 1 },
        { cid: 30041111, num: 1, weight: 1 },
        { cid: 30041202, num: 1, weight: 1 },
        { cid: 30041203, num: 1, weight: 1 },
        { cid: 30041204, num: 1, weight: 1 },
        { cid: 30041205, num: 1, weight: 1 },
        { cid: 30041206, num: 1, weight: 1 },
        { cid: 30041207, num: 1, weight: 1 },
        { cid: 30041208, num: 1, weight: 1 },
        { cid: 30041209, num: 1, weight: 1 },
        { cid: 30041210, num: 1, weight: 1 },
        { cid: 30041211, num: 1, weight: 1 },
    ];

    class ShopRollTool {
        static rollGoods(num) {
            var list = this.getRoleList();
            var list = RandomUtil.randomWeight(list, num);
            return list;
        }
        static getRoleList() {
            var list = ShopRollConfig.rollList;
            var nlist = [];
            var lv = GoodsModel.model.getGoodsLv(GoodsAttrType.ATTR_EXP);
            for (var k in list) {
                var co = list[k];
                var clv = GoodsVoBuilder.getGoodsLvn(co.cid);
                if (clv >= lv && clv <= lv + 5) {
                    var vo = GoodsModel.model.getGoodsByCid(co.cid);
                    if (!vo) {
                        nlist.push(co);
                    }
                    else if (vo.count > 0) {
                        nlist.push(co);
                    }
                }
            }
            return nlist;
        }
        static getRandomRw() {
            var rw = [];
            for (var k in ShopConfig.rwList) {
                var reward = ShopConfig.rwList[k];
                if (reward) {
                    if (SegmentModel.model.maxTriphyNum >= GoodsListConfig.getVo(reward.cid).triphyNum) {
                        rw.push(reward);
                    }
                }
            }
            return RandomUtil.randomItem(rw);
        }
    }

    class ShopMallView extends ui.shop.ShopMallUI {
        constructor() {
            super();
            this.zOrder = 50;
        }
    }

    class ShopMallViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = ShopMallView;
            this.viewName = 'ShopMallView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.listView = new ListView(this.ui.box_list);
            }
            this.parentView.addChild(this.ui);
            this.triphyNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY);
            this.ui.box_close.on(Laya.Event.CLICK, this, this.closeHandler);
            this.ui.panel_list.on(Laya.Event.CLICK, this, this.getUpHandler);
            this.ui.img_tong.on(Laya.Event.CLICK, this, this.add2Handler);
            this.ui.img_jin.on(Laya.Event.CLICK, this, this.add3Handler);
            this.tongLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_tong);
            this.jinLabel = new BitmapLabelView("font/white.json", 0.5, this.ui.txt_jin);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showHandler);
            this.addEventListener(ShopEvent.SHOP_VIEW_REFRESH, this, this.showHandler);
            this.addEventListener(BattleEvent.BATTLE_LOAD_START, this, this.close);
            this.checkTime();
            this.showHandler();
            LogTool.log('奖杯数量:' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TRIPHY));
        }
        showHandler() {
            this.tongLabel.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG);
            this.jinLabel.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN);
            var tongList = ShopConfig.bronzeBoxList;
            var goldBoxList = ShopConfig.goldBoxList;
            var jinBoxList = ShopConfig.JinBoxList;
            var preferentialList = ShopConfig.preferentialList;
            var list = [];
            for (var k in tongList) {
                var data1 = tongList[k];
                var itemTong = {};
                itemTong.itemRenderName = 'item_tong';
                itemTong.img_buy = { vo: data1 };
                var ts = ShopModel.model.getFreeTs(tongList[k].cid);
                var zero = TimeUtil.getZeroTimestamp();
                if (!ts || ts < zero) {
                    itemTong.box_price = { visible: false };
                    itemTong.img_free = { visible: true };
                }
                else {
                    itemTong.box_price = { visible: true };
                    itemTong.img_free = { visible: false };
                }
                list.push(itemTong);
            }
            for (var k in goldBoxList) {
                var data2 = goldBoxList[k];
                var itemGold = {};
                itemGold.itemRenderName = 'item_gold';
                itemGold.img_buy2 = { vo: data2 };
                list.push(itemGold);
            }
            for (var k in jinBoxList) {
                var data3 = jinBoxList[k];
                var itemJin = {};
                itemJin.itemRenderName = 'item_jin';
                itemJin.img_buy1 = { vo: data3 };
                list.push(itemJin);
            }
            for (var k in preferentialList) {
                var data4 = preferentialList[k];
                var itemPre = {};
                itemPre.itemRenderName = 'item_preferential';
                itemPre.img_buy3 = { vo: data4 };
                var ts = ShopModel.model.getFreeTs(preferentialList[k].cid);
                var zero = TimeUtil.getZeroTimestamp();
                if (!ts || ts < zero) {
                    itemPre.box_price = { visible: false };
                    itemPre.img_free = { visible: true };
                }
                else {
                    itemPre.box_price = { visible: true };
                    itemPre.img_free = { visible: false };
                }
                var rw = ShopModel.model.boxList;
                itemPre.img_card1 = GoodsViewTool.getIcoUrl(rw[0].cid);
                itemPre.img_card2 = GoodsViewTool.getIcoUrl(rw[1].cid);
                itemPre.img_card3 = GoodsViewTool.getIcoUrl(rw[2].cid);
                itemPre.img_card4 = GoodsViewTool.getIcoUrl(rw[3].cid);
                itemPre.img_card5 = GoodsViewTool.getIcoUrl(rw[4].cid);
                itemPre.img_bg1 = this.getCardBg(rw[0].cardType);
                itemPre.img_bg2 = this.getCardBg(rw[1].cardType);
                itemPre.img_bg3 = this.getCardBg(rw[2].cardType);
                itemPre.img_bg4 = this.getCardBg(rw[3].cardType);
                itemPre.img_bg5 = this.getCardBg(rw[4].cardType);
                itemPre.box_buy4 = { vo: rw[0] };
                itemPre.box_buy5 = { vo: rw[1] };
                itemPre.box_buy6 = { vo: rw[2] };
                itemPre.box_buy7 = { vo: rw[3] };
                itemPre.box_buy8 = { vo: rw[4] };
                itemPre.img_num1 = this.getCardNum(rw[0].cardType);
                itemPre.img_num2 = this.getCardNum(rw[1].cardType);
                itemPre.img_num3 = this.getCardNum(rw[2].cardType);
                itemPre.img_num4 = this.getCardNum(rw[3].cardType);
                itemPre.img_num5 = this.getCardNum(rw[4].cardType);
                list.push(itemPre);
            }
            this.listView.dataSource = list;
        }
        getUpHandler(e) {
            if (MouseTool.checkClick(e, 'img_buy')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    var ts = ShopModel.model.getFreeTs(vo.cid);
                    var zero = TimeUtil.getZeroTimestamp();
                    var reward = GoodsBoxConfig.getBronzeBox(SegmentModel.model.maxTriphyNum);
                    reward = GoodsTool.mergeList(reward);
                    if (!ts || ts < zero) {
                        ShopModel.model.setFreeTs(vo.cid, TimeUtil.getTimestamp());
                        ShopModel.model.saveData();
                        this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: reward, rewardType: vo.cid });
                        this.dispatchEvent(ShopEvent.SHOP_GETREWARD_COMPLETE, { name: '青铜宝箱' });
                    }
                    else {
                        if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN) >= vo.price.num) {
                            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: vo.price.cid, num: vo.price.num }] });
                            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: reward, rewardType: vo.cid });
                            this.dispatchEvent(ShopEvent.SHOP_GETREWARD_COMPLETE, { name: '青铜宝箱' });
                        }
                        else {
                            this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "钻石不够哦!" });
                            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
                        }
                    }
                }
            }
            if (MouseTool.checkClick(e, 'img_buy1')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    var reward1 = GoodsBoxConfig.getMasonryBox(SegmentModel.model.maxTriphyNum);
                    reward1 = GoodsTool.mergeList(reward1);
                    if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN) >= vo.price.num) {
                        this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: vo.price.cid, num: vo.price.num }] });
                        this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: reward1, rewardType: vo.cid });
                        this.dispatchEvent(ShopEvent.SHOP_GETREWARD_COMPLETE, { name: '黄金宝箱' });
                    }
                    else {
                        this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "钻石不够哦!" });
                        this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
                    }
                }
            }
            if (MouseTool.checkClick(e, 'img_buy2')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    var reward2 = GoodsBoxConfig.getGoldBox(SegmentModel.model.maxTriphyNum);
                    reward2 = GoodsTool.mergeList(reward2);
                    if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN) >= vo.price.num) {
                        this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: vo.price.cid, num: vo.price.num }] });
                        this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: reward2, rewardType: vo.cid });
                        this.dispatchEvent(ShopEvent.SHOP_GETREWARD_COMPLETE, { name: '钻石宝箱' });
                    }
                    else {
                        this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "钻石不够哦!" });
                        this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
                    }
                }
            }
            if (MouseTool.checkClick(e, 'img_buy3')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    var ts = ShopModel.model.getFreeTs(vo.cid);
                    var zero = TimeUtil.getZeroTimestamp();
                    if (!ts || ts < zero) {
                        ShopModel.model.setFreeTs(vo.cid, TimeUtil.getTimestamp());
                        ShopModel.model.saveData();
                        this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: 20010003, num: 1000 }] });
                        this.dispatchEvent(ShopEvent.SHOP_GETREWARD_COMPLETE, { name: '特惠金币礼包' });
                    }
                    else {
                        if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN) >= vo.price.num) {
                            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: vo.price.cid, num: vo.price.num }] });
                            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: 20010003, num: 1000 }] });
                            this.dispatchEvent(ShopEvent.SHOP_GETREWARD_COMPLETE, { name: '特惠金币礼包' });
                        }
                        else {
                            this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "钻石不够哦!" });
                            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
                        }
                    }
                }
            }
            this.btnClick(e, 'box_buy4');
            this.btnClick(e, 'box_buy5');
            this.btnClick(e, 'box_buy6');
            this.btnClick(e, 'box_buy7');
            this.btnClick(e, 'box_buy8');
            if (MouseTool.checkClick()) {
                this.dispatchEvent(ShopEvent.SHOP_VIEW_REFRESH);
            }
        }
        btnClick(e, btnName) {
            if (MouseTool.checkClick(e, btnName)) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN) >= vo.price.num) {
                        this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: vo.price.cid, num: vo.price.num }] });
                        this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: vo.cid, num: vo.num }] });
                        this.dispatchEvent(ShopEvent.SHOP_GETREWARD_COMPLETE, { name: '特惠英雄礼包' });
                    }
                    else {
                        this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "钻石不够哦!" });
                        this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
                    }
                }
            }
        }
        checkTime() {
            var ts = ShopModel.model.boxRefreshTs;
            var time = ts + 60 * 60 - TimeUtil.getTimestamp();
            if (ts == 0 || time < 0) {
                time = 60 * 60;
                this.refreshBox();
                ShopModel.model.boxRefreshTs = TimeUtil.getTimestamp();
                ShopModel.model.saveData();
            }
            if (time < 5) {
                time = 5;
            }
            TimerUtil.onceTimer(time * 1000, this, this.checkTime);
        }
        refreshBox() {
            for (var k = 0; k < 5; k++) {
                var item = ShopRollTool.getRandomRw();
                ShopModel.model.boxList[k] = item;
                ShopModel.model.saveData();
            }
            this.dispatchEvent(ShopEvent.SHOP_VIEW_REFRESH);
        }
        getCardBg(cardType) {
            var data = '';
            if (cardType == 0) {
                data = 'ui/img_UM_shop_ui_bg5.png';
            }
            else if (cardType == 1) {
                data = 'ui/img_UM_shop_ui_bg7.png';
            }
            else {
                data = 'ui/img_UM_shop_ui_bg6.png';
            }
            return data;
        }
        getCardNum(cardType) {
            var data = '';
            if (cardType == 0) {
                data = 'ui/img_UM_num_40.png';
            }
            else if (cardType == 1) {
                data = 'ui/img_UM_num_10.png';
            }
            else {
                data = 'ui/img_UM_num_2.png';
            }
            return data;
        }
        add2Handler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(0)] });
        }
        add3Handler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
        }
        closeHandler() {
            this.close();
        }
    }

    class ShopRollBoxView extends ui.shop.ShopRollBoxUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class ShopRollBoxViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = ShopRollBoxView;
            this.viewName = 'ShopRollBoxView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.box_open.img_cl.skin = ShopRollConfig.rollBoxSrc[this.data.index];
                this.ui.box_open.img_op.skin = ShopRollConfig.rollBoxTwoSrc[this.data.index];
            }
            this.list = this.data.list;
            TimerUtil.onceTimer(900, this, this.close);
        }
    }

    class ShopRollView extends ui.shop.ShopRollUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class ShopRollViewController extends DialogViewController {
        constructor() {
            super();
            this.selectIndex = 0;
            this.viewClass = ShopRollView;
            this.viewName = 'ShopRollView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.goods3D = new Goods3DViewController(this.ui.box_scene);
                this.startChild(this.goods3D);
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
                this.ui.tab_1.on(Laya.Event.CLICK, this, this.showGoodsHandler1);
                this.ui.btn_roll.on(Laya.Event.CLICK, this, this.goodsShopRollchekHandler);
                this.ui.list_goods.on(Laya.Event.CLICK, this, this.listClickHandler);
                this.ui.box_free.on(Laya.Event.CLICK, this, this.addHandler);
            }
            this.addEventListener(GoodsEvent.GOODS_LOC_SET_REQUEST, this, this.getShowRole);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showGoodsHandler1);
            this.showGoodsHandler();
            this.getShowRole();
        }
        close() {
            this.goods3D.close();
            super.close();
        }
        getShowRole() {
            var head = GoodsElementTool.getHelmetLoc();
            var body = GoodsElementTool.getClothesLoc();
            var gun = GoodsElementTool.getGunLoc();
            this.goods3D.showRole(0, body, head, gun, -1, 0, 1, 0, 55);
        }
        listClickHandler(e) {
            var head = GoodsElementTool.getHelmetLoc();
            var body = GoodsElementTool.getClothesLoc();
            var gun = GoodsElementTool.getGunLoc();
            var vo = ViewDataTool.getDataValue(e.target);
            if (vo) {
                if (vo.stype == 1) {
                    this.goods3D.showRole(0, body, head, vo.cid, -1, 0, 1, 0, 55);
                }
                else if (vo.stype == 2) {
                    this.goods3D.showRole(0, body, vo.cid, gun, -1, 0, 1, 0, 55);
                }
                else if (vo.stype == 3) {
                    this.goods3D.showRole(0, vo.cid, head, gun, -1, 0, 1, 0, 55);
                }
            }
        }
        showGoodsHandler() {
            this.ui.txt_tong.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG);
            this.ui.txt_jin.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN);
            this.selectIndex = this.data.index;
            this.ui.tab_1.selectedIndex = this.selectIndex;
            this.rollData = ShopRollConfig.getRollData(this.selectIndex);
            this.selectIndex = this.ui.tab_1.selectedIndex;
            this.ui.img_ico.skin = GoodsConfig.getIconUrl(this.rollData.cid);
            this.ui.txt_price.text = '' + this.rollData.num;
            var goodsList = this.rollList = ShopRollTool.getRoleList();
            var nlist = [];
            for (var k in goodsList) {
                var co = goodsList[k];
                var goodsData = GoodsViewTool.getGoodsRewardData(co);
                nlist.push(goodsData);
            }
            this.ui.list_goods.dataSource = nlist;
            console.log(this.selectIndex);
        }
        showGoodsHandler1() {
            this.ui.txt_tong.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG);
            this.ui.txt_jin.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN);
            this.selectIndex = this.data.index;
            this.selectIndex = this.ui.tab_1.selectedIndex;
            this.rollData = ShopRollConfig.getRollData(this.selectIndex);
            this.selectIndex = this.ui.tab_1.selectedIndex;
            this.ui.img_ico.skin = GoodsConfig.getIconUrl(this.rollData.cid);
            this.ui.txt_price.text = '' + this.rollData.num;
            var goodsList = this.rollList = ShopRollTool.getRoleList();
            var nlist = [];
            for (var k in goodsList) {
                var co = goodsList[k];
                var goodsData = GoodsViewTool.getGoodsRewardData(co);
                nlist.push(goodsData);
            }
            this.ui.list_goods.dataSource = nlist;
        }
        goodsShopRollchekHandler() {
            if (this.ui.tab_1.selectedIndex == 0) {
                if (ShopModel.model.tongNum >= ShopRollConfig.rollConsNum[0]) {
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "次数不足" });
                    this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(3)] });
                    return;
                }
                this.goodsShopRollHandler();
            }
            if (this.ui.tab_1.selectedIndex == 1) {
                if (ShopModel.model.yinNum >= ShopRollConfig.rollConsNum[1]) {
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "次数不足" });
                    this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(4)] });
                    return;
                }
                this.goodsShopRollHandler();
            }
            if (this.ui.tab_1.selectedIndex == 2) {
                if (ShopModel.model.jinNum >= ShopRollConfig.rollConsNum[2]) {
                    this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { text: "次数不足" });
                    this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(5)] });
                    return;
                }
                this.goodsShopRollHandler();
            }
        }
        addHandler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
        }
        goodsShopRollHandler() {
            if (GoodsCostTool.checkCostConfig(this.rollData) == false) {
                this.dispatchEvent(CommonEvent.ALERT_VIEW_SHOW, { text: "花费不足" });
                this.adHandler();
                return;
            }
            var rlList = RandomUtil.randomWeight(this.rollList, this.rollData.outNum);
            this.list = rlList;
            for (var k in rlList) {
                var co = rlList[k];
                if (MathUtil.randomHit(0.01)) {
                    this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: co.cid, count: 0 });
                }
            }
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { list: [{ cid: this.rollData.cid, num: this.rollData.num }] });
            if (this.ui.tab_1.selectedIndex == 0) {
                ShopModel.model.tongNum++;
            }
            if (this.ui.tab_1.selectedIndex == 1) {
                ShopModel.model.yinNum++;
            }
            if (this.ui.tab_1.selectedIndex == 2) {
                ShopModel.model.jinNum++;
            }
            ShopModel.model.saveData();
            this.dispatchEvent(ShopEvent.SHOP_ROLLBOX_SUCCESS, { list: rlList, index: this.ui.tab_1.selectedIndex });
            TimerUtil.onceTimer(1000, this, this.sucessHandler);
        }
        adHandler() {
            if (this.rollData.cid == GoodsAttrType.ATTR_TONG) {
                this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(0)] });
                return;
            }
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
        }
        sucessHandler() {
            this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { list: this.list });
            for (var k in this.list) {
                var co = this.list[k];
                this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: co.cid, isNew: true });
            }
        }
    }

    class ShopQualityConfig {
    }
    ShopQualityConfig.topQualityStoreList = [
        { cid: 30042002, name: 'GLOCK', ico: '30042002', image: '30042002', price: 500 },
        { cid: 30042107, name: 'SR3-VIKHR', ico: '30042107', image: '30042107', price: 600 },
        { cid: 30042207, name: 'F2000', ico: '30042207', image: '30042207', price: 600 },
        { cid: 30042108, name: 'PPSH', ico: '30042108', image: '30042108', price: 700 },
        { cid: 30042208, name: 'AK-74', ico: '30042208', image: '30042208', price: 700 },
        { cid: 30042402, name: 'SPAS-12', ico: '30042402', image: '30042402', price: 800 },
        { cid: 30042109, name: 'CHANG FENG', ico: '30042109', image: '30042109', price: 800 },
        { cid: 30042209, name: 'SCAR-H', ico: '30042209', image: '30042209', price: 800 },
        { cid: 30042210, name: 'BMR', ico: '30042210', image: '30042210', price: 900 },
        { cid: 30042302, name: 'KILLSHOT', ico: '30042302', image: '30042302', price: 1000 },
        { cid: 30042003, name: 'REVOLVER R8', ico: '30042003', image: '30042003', price: 1000 },
        { cid: 30042211, name: 'AK-5', ico: '30042211', image: '30042211', price: 1000 },
        { cid: 30042303, name: 'SNIPER AWP', ico: '30042303', image: '30042303', price: 2000 }
    ];

    class ShopMedalView extends ui.shop.ShopMedalUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class ShopMedalViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = ShopMedalView;
            this.viewName = 'ShopMedalView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler);
                this.ui.item0.on(Laya.Event.CLICK, this, this.shopHandler);
                this.ui.item2.on(Laya.Event.CLICK, this, this.boxHandler);
                this.ui.box_free.on(Laya.Event.CLICK, this, this.addHandler);
                this.ui.list_item.on(Laya.Event.CLICK, this, this.listClickHandler);
                this.ui.img_jia.visible = false;
            }
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.showDataHandler);
            this.showDataHandler();
            this.ui.list_item.selectedIndex = 0;
        }
        showDataHandler() {
            this.ui.txt_tong.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_TONG);
            this.ui.txt_jin.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_JIN);
            this.ui.txt_modal.text = '' + GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_MEDAL);
            this.showList();
        }
        showList() {
            var nlist = [];
            var list = ShopQualityConfig.topQualityStoreList;
            for (var k in list) {
                var con = list[k];
                var data = {};
                data.txt_title = GoodsVoBuilder.getGoodsName(con.cid);
                data.img_ico = GoodsViewTool.getIcoUrl(con.cid);
                data.txt_price = '价格：' + con.price;
                data.vo = con;
                if (GoodsModel.model.getGoodsNum(con.cid) > 0) {
                    data.img_dis = ViewDataType.ON;
                    data.disabled = true;
                    LogTool.log('ShopMedalViewController.已拥有');
                }
                else {
                    LogTool.log('ShopMedalViewController.未拥有');
                    data.img_dis = ViewDataType.OFF;
                    data.disabled = false;
                }
                nlist.push(data);
            }
            this.ui.list_item.dataSource = nlist;
        }
        shopBuyHandler() {
            LogTool.log('shopBuyHandler');
        }
        boxHandler() {
            this.dispatchEvent(ShopEvent.SHOP_CHEST_VIEW_SHOW, { showType: ViewType.OPEN });
            this.close();
        }
        closeHandler() {
            this.close();
        }
        shopHandler() {
            this.dispatchEvent(ShopEvent.SHOP_MALL_VIEW_SHOW, { showType: ViewType.OPEN });
            this.close();
        }
        addHandler() {
            this.dispatchEvent(PageEvent.PAGE_REWARD_VIEW_SHOW, { list: [GoodsConfig.getGoodsAddList(1)] });
        }
        listClickHandler() {
            var item = this.ui.list_item.selectedItem;
            if (item && item.vo) {
                if (MouseTool.checkClick()) {
                    var vo = item.vo;
                    if (GoodsModel.model.getGoodsNum(vo.cid) > 0) {
                        this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "已拥有!" });
                        LogTool.log('ShopMedalViewController.已拥有');
                        return;
                    }
                    else {
                        LogTool.log('ShopMedalViewController.未拥有');
                        this.dispatchEvent(ShopEvent.SHOP_MEDALBUY_VIEW_SHOW, { cidVo: vo.cid, priceVo: vo.price });
                    }
                }
            }
        }
    }

    class ShopMedalBuyView extends ui.shop.ShopMedalBuyUI {
        constructor() {
            super();
            this.zOrder = 15;
        }
    }

    class ShopMedalBuyViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = ShopMedalBuyView;
            this.viewName = 'ShopMedalBuyView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.btn_get.on(Laya.Event.CLICK, this, this.buyGunHander);
                this.ui.btn_cancel.on(Laya.Event.CLICK, this, this.close);
            }
            this.ui.img_gun.skin = GoodsViewTool.getIcoUrl(this.data.cidVo);
        }
        buyGunHander() {
            if (GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_MEDAL) < this.data.priceVo) {
                this.dispatchEvent(CommonEvent.PROMPT_VIEW_SHOW, { type: PromptType.PROMPT_ERROR, text: "勋章不够哦!" });
            }
            else {
                this.dispatchEvent(GoodsEvent.GOODS_ADD_REQUEST, { showType: 2, list: [{ cid: this.data.cidVo, num: 1 }] });
                this.dispatchEvent(GoodsEvent.GOODS_ATTR_SET_REQUEST, { cid: this.data.cidVo, count: 0 });
                this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_MEDAL, num: this.data.priceVo }] });
                this.close();
            }
        }
    }

    class ShopController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            ShopModel.model.init();
            ViewManager.register(ShopEvent.SHOP_MALL_VIEW_SHOW, this, ShopMallViewController);
            ViewManager.register(ShopEvent.SHOP_ROLL_VIEW_SHOW, this, ShopRollViewController);
            ViewManager.register(ShopEvent.SHOP_CHEST_VIEW_SHOW, this, ShopChestViewController);
            ViewManager.register(ShopEvent.SHOP_BUY_VIEW_SHOW, this, ShopBuyViewController);
            ViewManager.register(ShopEvent.SHOP_ROLLBOX_SUCCESS, this, ShopRollBoxViewController);
            ViewManager.register(ShopEvent.SHOP_MEDAL_VIEW_SHOW, this, ShopMedalViewController);
            ViewManager.register(ShopEvent.SHOP_MEDALBUY_VIEW_SHOW, this, ShopMedalBuyViewController);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.initHandler);
            this.initHandler();
        }
        initHandler() {
            ShopModel.model.shopTipsIco = this.checkIsFree();
            ShopModel.model.saveData();
            var boxTs = ShopModel.model.boxTs;
            var resTs = ShopModel.model.resTs;
            var zero = TimeUtil.getZeroTimestamp();
            if (boxTs < zero) {
                ShopModel.model.boxNum = 0;
                ShopModel.model.boxNum1 = 0;
                ShopModel.model.saveData();
            }
            if (resTs < zero) {
                ShopModel.model.resNum = 0;
                ShopModel.model.saveData();
            }
            if (PageModel.model.startGameTs < zero) {
                ShopModel.model.tongNum = 0;
                ShopModel.model.yinNum = 0;
                ShopModel.model.jinNum = 0;
                ShopModel.model.saveData();
            }
        }
        checkIsFree() {
            var ts1 = ShopModel.model.getFreeTs(3001);
            var ts2 = ShopModel.model.getFreeTs(3004);
            var zero = TimeUtil.getZeroTimestamp();
            if ((!ts1 || ts1 < zero) || (!ts2 || ts2 < zero)) {
                return true;
            }
            else {
                return false;
            }
        }
    }

    class SignDayView extends ui.sign.SignDayUI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class SignVo {
        constructor() {
            this.cid = 0;
            this.day = 0;
            this.name = '';
            this.reward = null;
        }
    }

    class SignVoBuilder {
        static getSignVo(cid) {
            var item = SignConfig.list[cid];
            if (!item) {
                return null;
            }
            var vo = new SignVo();
            vo.cid = MathUtil.int(cid);
            ObjectUtil.copy(item, vo);
            return vo;
        }
    }

    class SignDayViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = SignDayView;
            this.viewName = 'SignDayView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneHandler);
            this.ui.btn_double.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(SignEvent.SIGN_REWARD_RESPONSE, this, this.showData);
            this.showData();
        }
        showData() {
            var rewardTs = SignModel.model.rewardTs;
            var zero = TimeUtil.getZeroTimestamp();
            var dayNum = SignModel.model.dayNum;
            var list = SignConfig.list;
            for (var k in list) {
                var vo = SignVoBuilder.getSignVo(k);
                var data = {};
                var day = vo.day;
                data.vo = vo;
                var box_get = this.ui['box_get_' + day];
                var img_available = this.ui['img_available_' + day];
                var img_state = this.ui['img_state_' + day];
                var img_bg = this.ui['img_bg_' + day];
                var img_reach = this.ui['img_reach_' + day];
                var img_mask = this.ui['img_mask_' + day];
                if (day <= dayNum) {
                    data.box_get = ViewDataType.ON;
                    data.img_available = ViewDataType.OFF;
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_reach = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png' };
                }
                else {
                    if (rewardTs > zero) {
                        data.box_get = ViewDataType.ON;
                        data.img_available = ViewDataType.OFF;
                        if (day <= dayNum) {
                            data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                            data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                            data.img_reach = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                            data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png' };
                        }
                        else {
                            data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                            data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                            data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                            data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                        }
                    }
                    else if (day == dayNum + 1) {
                        data.img_available = ViewDataType.ON;
                        data.box_get = ViewDataType.OFF;
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: false };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                        data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: false };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                    }
                    else {
                        data.img_available = ViewDataType.OFF;
                        data.box_get = ViewDataType.ON;
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                        data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                    }
                }
                img_state.skin = data.img_state.skin;
                img_state.visible = data.img_state.visible;
                img_available.visible = data.img_available.visible;
                box_get.visible = data.box_get.visible;
                img_bg.skin = data.img_bg.skin;
                img_reach.skin = data.img_reach.skin;
                img_reach.visible = data.img_reach.visible;
                img_mask.skin = data.img_mask.skin;
            }
            this.showBtnState();
        }
        showBtnState() {
            var rewardTs = SignModel.model.rewardTs;
            var zero = TimeUtil.getZeroTimestamp();
            if (rewardTs > zero) {
                this.ui.btn_get.disabled = true;
                this.ui.btn_double.disabled = true;
                SignModel.model.tipsIco = false;
            }
            else {
                this.ui.btn_get.disabled = false;
                this.ui.btn_double.disabled = false;
                SignModel.model.tipsIco = true;
            }
            SignModel.model.saveData();
            this.dispatchEvent(PageEvent.PAGE_SIGN_TIP_SHOW);
        }
        getOneHandler() {
            this.dispatchEvent(SignEvent.SIGN_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoHandler() {
            this.dispatchEvent(SignEvent.SIGN_REWARD_REQUEST, { multiple: 2 });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoHandler, 'doubleGet');
        }
    }

    class SignDay1View extends ui.sign.SignDay1UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class SignDay1ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = SignDay1View;
            this.viewName = 'SignDayView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_scale.scale(PageConfig.pageScale, PageConfig.pageScale);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneHandler);
            this.ui.btn_double.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(SignEvent.SIGN_REWARD_RESPONSE, this, this.showData);
            this.showbtn();
            this.showData();
        }
        showbtn() {
            this.ui.btn_close.visible = false;
            this.ui.btn_get.visible = false;
            if (AdTool.checkRate('yanchi', true)) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_close.visible = true;
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_close.visible = true;
                this.ui.btn_get.visible = true;
            }
        }
        showData() {
            var rewardTs = SignModel.model.rewardTs;
            var zero = TimeUtil.getZeroTimestamp();
            var dayNum = SignModel.model.dayNum;
            var list = SignConfig.list;
            for (var k in list) {
                var vo = SignVoBuilder.getSignVo(k);
                var data = {};
                var day = vo.day;
                data.vo = vo;
                var box_get = this.ui['box_get_' + day];
                var img_available = this.ui['img_available_' + day];
                var img_state = this.ui['img_state_' + day];
                var img_bg = this.ui['img_bg_' + day];
                var img_reach = this.ui['img_reach_' + day];
                var img_mask = this.ui['img_mask_' + day];
                if (day <= dayNum) {
                    data.box_get = ViewDataType.ON;
                    data.img_available = ViewDataType.OFF;
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_reach = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png' };
                }
                else {
                    if (rewardTs > zero) {
                        data.box_get = ViewDataType.ON;
                        data.img_available = ViewDataType.OFF;
                        if (day <= dayNum) {
                            data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                            data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                            data.img_reach = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                            data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png' };
                        }
                        else {
                            data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                            data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                            data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                            data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                        }
                    }
                    else if (day == dayNum + 1) {
                        data.img_available = ViewDataType.ON;
                        data.box_get = ViewDataType.OFF;
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: false };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                        data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: false };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                    }
                    else {
                        data.img_available = ViewDataType.OFF;
                        data.box_get = ViewDataType.ON;
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                        data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                    }
                }
                img_state.skin = data.img_state.skin;
                img_state.visible = data.img_state.visible;
                img_available.visible = data.img_available.visible;
                box_get.visible = data.box_get.visible;
                img_bg.skin = data.img_bg.skin;
                img_reach.skin = data.img_reach.skin;
                img_reach.visible = data.img_reach.visible;
                img_mask.skin = data.img_mask.skin;
            }
            this.showBtnState();
        }
        showBtnState() {
            var rewardTs = SignModel.model.rewardTs;
            var zero = TimeUtil.getZeroTimestamp();
            if (rewardTs > zero) {
                this.ui.btn_get.disabled = true;
                this.ui.btn_double.disabled = true;
                SignModel.model.tipsIco = false;
            }
            else {
                this.ui.btn_get.disabled = false;
                this.ui.btn_double.disabled = false;
                SignModel.model.tipsIco = true;
            }
            SignModel.model.saveData();
            this.dispatchEvent(PageEvent.PAGE_SIGN_TIP_SHOW);
        }
        getOneHandler() {
            this.dispatchEvent(SignEvent.SIGN_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoHandler() {
            this.dispatchEvent(SignEvent.SIGN_REWARD_REQUEST, { multiple: 2 });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoHandler, 'doubleGet');
        }
    }

    class SignDay2View extends ui.sign.SignDay2UI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class SignDay2ViewController extends DialogViewController {
        constructor() {
            super();
            this.viewClass = SignDay2View;
            this.viewName = 'SignDayView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
            }
            this.ui.box_scale.scale(PageConfig.pageScale, PageConfig.pageScale);
            this.ui.btn_close.on(Laya.Event.CLICK, this, this.closeHandler3);
            this.ui.btn_get.on(Laya.Event.CLICK, this, this.getOneHandler);
            this.ui.btn_double.on(Laya.Event.CLICK, this, this.adHandler);
            this.addEventListener(SignEvent.SIGN_REWARD_RESPONSE, this, this.showData);
            this.showbtn();
            this.showData();
        }
        closeHandler3() {
            this.close();
            this.dispatchEvent(SignEvent.SIGN_CLOSE_CLICK);
        }
        showbtn() {
            this.ui.btn_close.visible = false;
            this.ui.btn_get.visible = false;
            if (AdModel.model.isShieldCity == false) {
                TimerUtil.onceTimer(2000, this, () => {
                    this.ui.btn_close.visible = true;
                    this.ui.btn_get.visible = true;
                });
            }
            else {
                this.ui.btn_close.visible = true;
                this.ui.btn_get.visible = true;
            }
        }
        showData() {
            var rewardTs = SignModel.model.rewardTs;
            var zero = TimeUtil.getZeroTimestamp();
            var dayNum = SignModel.model.dayNum;
            var list = SignConfig.list;
            for (var k in list) {
                var vo = SignVoBuilder.getSignVo(k);
                var data = {};
                var day = vo.day;
                data.vo = vo;
                var box_get = this.ui['box_get_' + day];
                var img_available = this.ui['img_available_' + day];
                var img_state = this.ui['img_state_' + day];
                var img_bg = this.ui['img_bg_' + day];
                var img_reach = this.ui['img_reach_' + day];
                var img_mask = this.ui['img_mask_' + day];
                if (day <= dayNum) {
                    data.box_get = ViewDataType.ON;
                    data.img_available = ViewDataType.OFF;
                    data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                    data.img_reach = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                    data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png' };
                }
                else {
                    if (rewardTs > zero) {
                        data.box_get = ViewDataType.ON;
                        data.img_available = ViewDataType.OFF;
                        if (day <= dayNum) {
                            data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                            data.img_bg = { skin: 'ui/img_UM_rank_jlbg2.png' };
                            data.img_reach = { skin: 'ui/img_UM_ui_text36.png', visible: true };
                            data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png' };
                        }
                        else {
                            data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                            data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                            data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                            data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                        }
                    }
                    else if (day == dayNum + 1) {
                        data.img_available = ViewDataType.ON;
                        data.box_get = ViewDataType.OFF;
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: false };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg1.png' };
                        data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: false };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                    }
                    else {
                        data.img_available = ViewDataType.OFF;
                        data.box_get = ViewDataType.ON;
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                        data.img_bg = { skin: 'ui/img_UM_rank_jlbg3.png' };
                        data.img_reach = { skin: 'ui/img_UM_ui_text37.png', visible: true };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png' };
                    }
                }
                img_state.skin = data.img_state.skin;
                img_state.visible = data.img_state.visible;
                img_available.visible = data.img_available.visible;
                box_get.visible = data.box_get.visible;
                img_bg.skin = data.img_bg.skin;
                img_reach.skin = data.img_reach.skin;
                img_reach.visible = data.img_reach.visible;
                img_mask.skin = data.img_mask.skin;
            }
            this.showBtnState();
        }
        showBtnState() {
            var rewardTs = SignModel.model.rewardTs;
            var zero = TimeUtil.getZeroTimestamp();
            if (rewardTs > zero) {
                this.ui.btn_get.disabled = true;
                this.ui.btn_double.disabled = true;
                SignModel.model.tipsIco = false;
            }
            else {
                this.ui.btn_get.disabled = false;
                this.ui.btn_double.disabled = false;
                SignModel.model.tipsIco = true;
            }
            SignModel.model.saveData();
            this.dispatchEvent(PageEvent.PAGE_SIGN_TIP_SHOW);
        }
        getOneHandler() {
            this.dispatchEvent(SignEvent.SIGN_REWARD_REQUEST, { multiple: 1 });
        }
        getTwoHandler() {
            this.dispatchEvent(SignEvent.SIGN_REWARD_REQUEST, { multiple: 2 });
        }
        adHandler() {
            AdTool.videoAdShow(this, this.getTwoHandler, 'doubleGet');
        }
    }

    class SignController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            SignModel.model.init();
            this.addEventListener(SignEvent.SIGN_VIEW_SHOW, this, this.signHandler);
            this.addEventListener(SignEvent.SIGN_REWARD_REQUEST, this, this.rwHadnler);
            this.initHandler();
        }
        initHandler() {
            var rewardTs = SignModel.model.rewardTs;
            var dayNum = SignModel.model.dayNum;
            var zero = TimeUtil.getZeroTimestamp();
            if (rewardTs < zero && dayNum >= 7) {
                SignModel.model.dayNum = 0;
                SignModel.model.dayType = 1;
            }
            if (rewardTs < zero) {
                SignModel.model.tipsIco = true;
            }
            else {
                SignModel.model.tipsIco = false;
            }
            SignModel.model.saveData();
        }
        rwHadnler(data) {
            var rewardTs = SignModel.model.rewardTs;
            var zero = TimeUtil.getZeroTimestamp();
            if (rewardTs > zero) {
                return;
            }
            SignModel.model.dayNum++;
            SignModel.model.rewardTs = TimeUtil.getTimestamp();
            SignModel.model.saveData();
            var co = SignConfig.getDayData(SignModel.model.dayNum, 0);
            var reward = co.reward;
            this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: [{ cid: reward.cid, num: reward.num * data.multiple }], showType: 2 });
            this.dispatchEvent(SignEvent.SIGN_REWARD_RESPONSE);
        }
        signHandler(data) {
            if (SignConfig.signType == 1) {
                ViewManager.show(this, SignDay1ViewController, data);
            }
            else if (SignConfig.signType == 2) {
                ViewManager.show(this, SignDay2ViewController, data);
            }
            else {
                ViewManager.show(this, SignDayViewController, data);
            }
        }
    }

    class TaskItemView extends ui.task.TaskItemUI {
        constructor() {
            super();
            this.txt_tongs = new BitmapLabelView("font/white.json", 0.5, this.txt_tong);
            this.txt_tongs.name = "txt_tongs";
        }
    }

    class TaskView extends ui.task.TaskUI {
        constructor() {
            super();
            this.zOrder = 45;
        }
    }

    class TaskViewController extends DialogViewController {
        constructor() {
            super();
            this.list1 = [];
            this.list2 = [];
            this.list3 = [];
            this.viewClass = TaskView;
            this.viewName = 'TaskView';
        }
        openComplete() {
            super.openComplete();
            if (!this.ui) {
                this.ui = this.view;
                this.ui.list_task.itemRender = TaskItemView;
            }
            this.addEventListener(TaskEvent.TASK_GETREWARD_RESPONSE, this, this.showList);
            this.addEventListener(TaskEvent.TASK_LIST_RESPONSE, this, this.showList);
            this.addEventListener(TaskEvent.TASK_RESET_RESPONSE, this, this.showList);
            this.addEventListener(TaskEvent.TASK_RESET_RESPONSE, this, this.timeHandler);
            this.ui.list_task.on(Laya.Event.CLICK, this, this.getRewardHandler);
            this.ui.list_box1.on(Laya.Event.CLICK, this, this.getBoxRewardHandler);
            this.ui.list_box2.on(Laya.Event.CLICK, this, this.getBoxRewardHandler2);
            this.ui.box_close.on(Laya.Event.CLICK, this, this.close);
            this.ui.list_task.scrollBar.visible = false;
            this.showList();
            TimerUtil.loopTimer(1000, this, this.timeHandler);
        }
        showList() {
            var list = TaskModel.model.list;
            var nlist = [];
            this.list1 = [];
            this.list2 = [];
            this.list3 = [];
            for (var k in list) {
                var taskVo = list[k];
                if (taskVo.name == 'threadTask') {
                    var data = {};
                    data.vo = taskVo;
                    data.txt_info = taskVo.info;
                    data.txt_num = '+' + taskVo.reward[1].num;
                    data.txt_pro = taskVo.value + '/' + taskVo.condValue;
                    data.img_bar = ProgressBarViewTool.getProgressImageDataSource(taskVo.value, taskVo.condValue);
                    data.txt_tongs = '' + taskVo.reward[0].num;
                    data.img_rw = GoodsViewTool.getIcoUrl(taskVo.reward[0].cid);
                    if (taskVo.state == 2) {
                        data.box_available = { visible: true, vo: taskVo, disabled: false };
                        data.img_available = { visible: true, vo: taskVo, skin: 'ui/img_UM_ui_text43.png' };
                        data.box_goto = { visible: false, vo: taskVo, disabled: false };
                    }
                    else if (taskVo.state == 3) {
                        data.box_available = { visible: true, vo: taskVo, disabled: true };
                        data.box_goto = { visible: false, vo: taskVo };
                        data.img_available = { visible: true, vo: taskVo, skin: 'ui/img_UM_ui_text36.png', disabled: true };
                    }
                    else {
                        data.box_available = { visible: false, vo: taskVo, disabled: false };
                        data.img_available = { visible: false, vo: taskVo, skin: 'ui/img_UM_ui_text43.png', disabled: false };
                        data.box_goto = { visible: true, vo: taskVo };
                    }
                    if (taskVo.state == 2) {
                        this.list1.push(data);
                    }
                    else if (taskVo.state == 3) {
                        this.list3.push(data);
                    }
                    else {
                        this.list2.push(data);
                    }
                }
            }
            for (var k in this.list1) {
                nlist.push(this.list1[k]);
            }
            for (var k in this.list2) {
                nlist.push(this.list2[k]);
            }
            for (var k in this.list3) {
                nlist.push(this.list3[k]);
            }
            this.ui.list_task.dataSource = nlist;
            this.boxShowList1();
            this.boxShowList2();
        }
        timeHandler() {
            var t = MathUtil.int(TaskConfig.taskTime - (TimeUtil.getTimestamp() - TaskModel.model.buildTs));
            if (t < 0) {
                t = 0;
                this.dispatchEvent(TaskEvent.TASK_RESET_REQUEST);
            }
            this.ui.txt_time.text = '剩余 ' + TimeFormatUtil.formatTime(t);
        }
        boxShowList1() {
            var list = TaskModel.model.list;
            var nlist = [];
            for (var k in list) {
                var boxTaskVo = list[k];
                if (boxTaskVo.name == 'boxTask1') {
                    var data = {};
                    data.vo = boxTaskVo;
                    var boxTaskVo = list[k];
                    data.txt_name = GoodsListConfig.getVo(boxTaskVo.reward[0].cid).name;
                    data.img_box = GoodsConfig.getSegmentIcoUrl(boxTaskVo.reward[0].cid);
                    data.txt_pro = boxTaskVo.value + '/' + boxTaskVo.condValue;
                    data.img_bar = ProgressBarViewTool.getProgressImageDataSource(boxTaskVo.value, boxTaskVo.condValue);
                    if (boxTaskVo.state == 2) {
                        data.img_available = { skin: 'ui/img_UM_ui_text41.png' };
                        data.img_bg = { skin: 'ui/img_UM_btn_OrangeButton_2.png', vo: boxTaskVo, gray: false };
                        data.img_mask = { visible: false };
                        data.img_frame = { visible: true };
                        data.img_state = { visible: false };
                    }
                    else if (boxTaskVo.state == 3) {
                        data.img_available = { skin: 'ui/img_UM_ui_text36.png' };
                        data.img_bg = { skin: 'ui/img_UM_btn_OrangeButton_2.png', gray: true };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                        data.img_frame = { visible: false };
                        data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                    }
                    else {
                        data.img_available = { skin: 'ui/img_UM_ui_text37.png' };
                        data.img_bg = { skin: 'ui/img_UM_btn_BlueButton_2.png', gray: false };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                        data.img_frame = { visible: false };
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                    }
                    nlist.push(data);
                }
            }
            this.ui.list_box1.dataSource = nlist;
        }
        boxShowList2() {
            var list = TaskModel.model.list;
            var nlist = [];
            for (var k in list) {
                var boxTaskVo = list[k];
                if (boxTaskVo.name == 'boxTask2') {
                    var data = {};
                    data.vo = boxTaskVo;
                    var boxTaskVo = list[k];
                    data.txt_name = GoodsListConfig.getVo(boxTaskVo.reward[0].cid).name;
                    data.img_box = GoodsConfig.getSegmentIcoUrl(boxTaskVo.reward[0].cid);
                    data.txt_pro = boxTaskVo.value + '/' + boxTaskVo.condValue;
                    data.img_bar = ProgressBarViewTool.getProgressImageDataSource(boxTaskVo.value, boxTaskVo.condValue);
                    if (boxTaskVo.state == 2) {
                        data.img_available = { skin: 'ui/img_UM_ui_text41.png' };
                        data.img_bg = { skin: 'ui/img_UM_shop_ui_bg9.png', vo: boxTaskVo, gray: false };
                        data.img_mask = { visible: false };
                        data.img_frame = { visible: true };
                        data.img_state = { visible: false };
                        data.img_bg2 = { skin: 'ui/img_UM_rank_obj2.png', gray: false };
                    }
                    else if (boxTaskVo.state == 3) {
                        data.img_available = { skin: 'ui/img_UM_ui_text36.png' };
                        data.img_bg = { skin: 'ui/img_UM_shop_ui_bg9.png', gray: true };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wlq.png', visible: true };
                        data.img_frame = { visible: false };
                        data.img_state = { skin: 'ui/img_UM_ui_tick.png', visible: true };
                        data.img_bg2 = { skin: 'ui/img_UM_rank_obj2.png', gray: true };
                    }
                    else {
                        data.img_available = { skin: 'ui/img_UM_ui_text37.png' };
                        data.img_bg = { skin: 'ui/img_UM_shop_ui_bg11.png', gray: false };
                        data.img_mask = { skin: 'ui/img_UM_rank_jlbg_wdb.png', visible: true };
                        data.img_frame = { visible: false };
                        data.img_state = { skin: 'ui/img_UM_ui_lock2.png', visible: true };
                        data.img_bg2 = { skin: 'ui/img_UM_ui_uibk3.png', gray: false };
                    }
                    nlist.push(data);
                }
            }
            this.ui.list_box2.dataSource = nlist;
        }
        getBoxRewardHandler(e) {
            if (MouseTool.checkClick(e, 'img_bg')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.dispatchEvent(TaskEvent.TASK_GETREWARD_REQUEST, { list: { cid: vo.cid, num: vo.num } });
                }
            }
        }
        getBoxRewardHandler2(e) {
            if (MouseTool.checkClick(e, 'img_bg')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.dispatchEvent(TaskEvent.TASK_GETREWARD_REQUEST, { list: { cid: vo.cid, num: vo.num } });
                }
            }
        }
        getRewardHandler(e) {
            if (MouseTool.checkClick(e, 'box_available')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.dispatchEvent(TaskEvent.TASK_GETREWARD_REQUEST, { list: { cid: vo.cid, num: vo.num } });
                }
            }
            if (MouseTool.checkClick(e, 'box_goto')) {
                var vo = ViewDataTool.getDataValue(e.target);
                if (vo) {
                    this.dispatchEvent(vo.goEvent, { showType: ViewType.OPEN });
                    this.close();
                }
            }
        }
        testHandler() {
            this.dispatchEvent(TaskEvent.TASK_RESET_REQUEST);
        }
    }

    class TaskController extends Controller {
        constructor() {
            super();
        }
        run() {
            super.run();
            TaskModel.model.init();
            ViewManager.register(TaskEvent.TASK_VIEW_SHOW, this, TaskViewController);
            this.addEventListener(TaskEvent.TASK_GETREWARD_REQUEST, this, this.rwdHandler);
            this.addEventListener(GoodsEvent.GOODS_LIST_RESPONSE, this, this.goodsHandler);
            this.addEventListener(TaskEvent.TASK_STATE_CHECK, this, this.checkHandler);
            this.addEventListener(MainEvent.MAIN_INIT_START, this, this.initTaskHandler);
            this.addEventListener(TaskEvent.TASK_RESET_REQUEST, this, this.resetHandler);
        }
        initTaskHandler() {
            var list = TaskModel.model.list;
            var lib = {};
            for (var k in list) {
                let vo = list[k];
                if (vo && vo.type == 'event') {
                    lib[vo.cond] = 1;
                }
            }
            for (let k in lib) {
                this.addEventListener(k, this, () => { this.checkTask('event', k, 1); });
            }
        }
        goodsHandler(data) {
            var list = data.list;
            if (list) {
                for (var k in list) {
                    var item = list[k];
                    if (item.num > 0) {
                        this.checkTask('goodsAdd', item.cid, item.num);
                    }
                    else if (item.num < 0) {
                        this.checkTask('goodsSub', item.cid, item.num);
                    }
                }
            }
        }
        checkTask(type, cond, v) {
            var list = TaskModel.model.list;
            var change = false;
            for (var k in list) {
                var vo = list[k];
                if (vo.state <= 1) {
                    if (vo.type == type && vo.cond == cond) {
                        vo.value += Math.abs(v);
                        if (vo.value >= vo.condValue) {
                            vo.value = vo.condValue;
                            vo.state = 2;
                        }
                        change = true;
                    }
                }
            }
            if (change) {
                TaskModel.model.saveData();
                this.dispatchEvent(TaskEvent.TASK_LIST_RESPONSE);
            }
        }
        rwdHandler(data) {
            var vo = TaskModel.model.getTaskVo(data.list.cid);
            var reward = [];
            if (vo.reward[0].cid == 3001) {
                reward = GoodsBoxConfig.getBronzeBox(SegmentModel.model.maxTriphyNum);
                reward = GoodsTool.mergeList(reward);
            }
            else if (vo.reward[0].cid == 3002) {
                reward = GoodsBoxConfig.getGoldBox(SegmentModel.model.maxTriphyNum);
                reward = GoodsTool.mergeList(reward);
            }
            else if (vo.reward[0].cid == 3003) {
                reward = GoodsBoxConfig.getMasonryBox(SegmentModel.model.maxTriphyNum);
                reward = GoodsTool.mergeList(reward);
            }
            else if (vo.reward[0].cid == 3004) {
                reward = GoodsBoxConfig.geLegendBox(SegmentModel.model.maxTriphyNum);
                reward = GoodsTool.mergeList(reward);
            }
            else {
                reward = GoodsBoxConfig.getRainbowBox(SegmentModel.model.maxTriphyNum);
                reward = GoodsTool.mergeList(reward);
            }
            if (vo && vo.state == 2) {
                vo.state = 3;
                if (vo.name == 'boxTask1' || vo.name == 'boxTask2') {
                    this.dispatchEvent(TaskEvent.TASK_GETREWARD_COMPLETE, { info: vo.info });
                    this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: reward, rewardType: vo.reward[0].cid });
                }
                else {
                    this.dispatchEvent(GoodsEvent.GOODS_SET_REQUEST, { list: vo.reward });
                }
                TaskModel.model.finishNum++;
                TaskModel.model.saveData();
                this.dispatchEvent(TaskEvent.TASK_GETREWARD_RESPONSE);
                this.dispatchEvent(TaskEvent.TASK_LIST_RESPONSE);
            }
        }
        checkHandler(data) {
            var vo = TaskModel.model.getTaskVo(data.cid);
            if (vo && vo.state == 3) {
                CallbackUtil.callback(data, { check: true });
            }
            else {
                CallbackUtil.callback(data, { check: false });
            }
        }
        resetHandler() {
            var currentIntegraNum = GoodsModel.model.getGoodsNum(GoodsAttrType.ATTR_INTEGRA);
            this.dispatchEvent(GoodsEvent.GOODS_SUB_REQUEST, { showType: 2, list: [{ cid: GoodsAttrType.ATTR_INTEGRA, num: currentIntegraNum }] });
            TaskModel.model.buildTasktList();
            this.dispatchEvent(TaskEvent.TASK_RESET_RESPONSE);
        }
    }

    class MainController extends Controller {
        constructor() { super(); }
        run() {
            super.run();
            MainTool.initParam();
            this.startChild(new StageMouseController());
            this.startChild(new CommonController());
            this.startChild(new LoadingController());
            this.startChild(new PlatformController());
            this.startChild(new PlayerController());
            this.startChild(new GoodsController());
            this.startChild(new SceneController());
            this.startChild(new BattleController());
            this.startChild(new PageController());
            this.startChild(new HeroController());
            this.startChild(new EpController());
            this.startChild(new GuideController());
            this.startChild(new SignController());
            this.startChild(new OnlineController());
            this.startChild(new ShopController());
            this.startChild(new HangController());
            this.startChild(new SegmentController());
            this.startChild(new TaskController());
            Laya.timer.callLater(this, this.startHandler);
        }
        startHandler() {
            this.dispatchEvent(MainEvent.MAIN_INIT_START);
        }
    }

    if (window["Laya3D"])
        Laya3D.init(GameConfig.width, GameConfig.height);
    else
        Laya.init(GameConfig.width, GameConfig.height, Laya["WebGL"]);
    Laya["Physics"] && Laya["Physics"].enable();
    Laya["DebugPanel"] && Laya["DebugPanel"].enable();
    Laya.stage.scaleMode = GameConfig.scaleMode;
    Laya.stage.screenMode = GameConfig.screenMode;
    Laya.stage.alignV = GameConfig.alignV;
    Laya.stage.alignH = GameConfig.alignH;
    Laya.URL.exportSceneToJson = GameConfig.exportSceneToJson;
    if (GameConfig.debug || Laya.Utils.getQueryString("debug") == "true")
        Laya.enableDebugPanel();
    if (GameConfig.physicsDebug && Laya["PhysicsDebugDraw"])
        Laya["PhysicsDebugDraw"].enable();
    if (GameConfig.stat)
        Laya.Stat.show();
    ControllerManager.start(new MainController());

}());
